##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM5_INT_CSR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfca00000]
lappend results [mem_read 0xfca00004]
lappend results [mem_read 0xfca00008]
lappend results [mem_read 0xfca0000c]
lappend results [mem_read 0xfca00020]
lappend results [mem_read 0xfca00028]
lappend results [mem_read 0xfca00030]
lappend results [mem_read 0xfca00040]
lappend results [mem_read 0xfca00050]
lappend results [mem_read 0xfca00058]
lappend results [mem_read 0xfca00060]
lappend results [mem_read 0xfca00068]
lappend results [mem_read 0xfca00078]
lappend results [mem_read 0xfca00080]
lappend results [mem_read 0xfca00084]
lappend results [mem_read 0xfca00088]
lappend results [mem_read 0xfca00090]
lappend results [mem_read 0xfca00094]
lappend results [mem_read 0xfca00098]
lappend results [mem_read 0xfca0009c]
lappend results [mem_read 0xfca00104]
lappend results [mem_read 0xfca00108]
lappend results [mem_read 0xfca0010c]
lappend results [mem_read 0xfca00110]
lappend results [mem_read 0xfca00118]
lappend results [mem_read 0xfca0011c]
lappend results [mem_read 0xfca00120]
lappend results [mem_read 0xfca00128]
lappend results [mem_read 0xfca0012c]
lappend results [mem_read 0xfca00130]
lappend results [mem_read 0xfca00134]
lappend results [mem_read 0xfca00138]
lappend results [mem_read 0xfca00148]
lappend results [mem_read 0xfca00200]
lappend results [mem_read 0xfca10000]
lappend results [mem_read 0xfca20000]
lappend results [mem_read 0xfca30000]
lappend results [mem_read 0xfca40000]
lappend results [mem_read 0xfca50000]
lappend results [mem_read 0xfca60000]
lappend results [mem_read 0xfca70000]
lappend results [mem_read 0xfca80000]
lappend results [mem_read 0xfcaa0000]
lappend results [mem_read 0xfcab0000]
lappend results [mem_read 0xfcac0000]
lappend results [mem_read 0xfcad0000]
lappend results [mem_read 0xfcae0000]
lappend results [mem_read 0xfcaf0000]
lappend results [mem_read 0xfcb00000]
lappend results [mem_read 0xfcb10000]
lappend results [mem_read 0xfcb20000]
lappend results [mem_read 0xfcb30000]
lappend results [mem_read 0xfcb40000]
lappend results [mem_read 0xfcb50000]
lappend results [mem_read 0xfcb60000]
lappend results [mem_read 0xfcb70000]
lappend results [mem_read 0xfcb80000]
lappend results [mem_read 0xfcb90000]
lappend results [mem_read 0xfcba0000]
lappend results [mem_read 0xfcbb0000]
lappend results [mem_read 0xfcbc0000]
lappend results [mem_read 0xfcbd0000]
lappend results [mem_read 0xfcbe0000]
lappend results [mem_read 0xfcbf0000]
