##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: LPD_IOP_SLCR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff080000]
lappend results [mem_read 0xff080004]
lappend results [mem_read 0xff080008]
lappend results [mem_read 0xff08000c]
lappend results [mem_read 0xff080010]
lappend results [mem_read 0xff080014]
lappend results [mem_read 0xff080018]
lappend results [mem_read 0xff08001c]
lappend results [mem_read 0xff080020]
lappend results [mem_read 0xff080024]
lappend results [mem_read 0xff080028]
lappend results [mem_read 0xff08002c]
lappend results [mem_read 0xff080030]
lappend results [mem_read 0xff080034]
lappend results [mem_read 0xff080038]
lappend results [mem_read 0xff08003c]
lappend results [mem_read 0xff080040]
lappend results [mem_read 0xff080044]
lappend results [mem_read 0xff080048]
lappend results [mem_read 0xff08004c]
lappend results [mem_read 0xff080050]
lappend results [mem_read 0xff080054]
lappend results [mem_read 0xff080058]
lappend results [mem_read 0xff08005c]
lappend results [mem_read 0xff080060]
lappend results [mem_read 0xff080064]
lappend results [mem_read 0xff08010c]
lappend results [mem_read 0xff080110]
lappend results [mem_read 0xff080114]
lappend results [mem_read 0xff080118]
lappend results [mem_read 0xff08011c]
lappend results [mem_read 0xff080120]
lappend results [mem_read 0xff08015c]
lappend results [mem_read 0xff080160]
lappend results [mem_read 0xff080200]
lappend results [mem_read 0xff080204]
lappend results [mem_read 0xff080300]
lappend results [mem_read 0xff080320]
lappend results [mem_read 0xff080324]
lappend results [mem_read 0xff080328]
lappend results [mem_read 0xff08032c]
lappend results [mem_read 0xff080344]
lappend results [mem_read 0xff080348]
lappend results [mem_read 0xff08034c]
lappend results [mem_read 0xff080360]
lappend results [mem_read 0xff080410]
lappend results [mem_read 0xff080428]
lappend results [mem_read 0xff08042c]
lappend results [mem_read 0xff080430]
lappend results [mem_read 0xff080600]
lappend results [mem_read 0xff080700]
lappend results [mem_read 0xff080704]
lappend results [mem_read 0xff080708]
lappend results [mem_read 0xff08070c]
lappend results [mem_read 0xff080714]
lappend results [mem_read 0xff080718]
lappend results [mem_read 0xff08071c]
lappend results [mem_read 0xff080720]
lappend results [mem_read 0xff080728]
