//! moment.js locale configuration
//! locale : Kyrgyz [ky]
//! author : Chyngyz Arystan uulu : https://github.com/chyngyz
import moment from "../moment.js";
var suffixes = {
  0: '-чү',
  1: '-чи',
  2: '-чи',
  3: '-чү',
  4: '-чү',
  5: '-чи',
  6: '-чы',
  7: '-чи',
  8: '-чи',
  9: '-чу',
  10: '-чу',
  20: '-чы',
  30: '-чу',
  40: '-чы',
  50: '-чү',
  60: '-чы',
  70: '-чи',
  80: '-чи',
  90: '-чу',
  100: '-чү'
};
export default moment.defineLocale('ky', {
  months: 'январь_февраль_март_апрель_май_июнь_июль_август_сентябрь_октябрь_ноябрь_декабрь'.split('_'),
  monthsShort: 'янв_фев_март_апр_май_июнь_июль_авг_сен_окт_ноя_дек'.split('_'),
  weekdays: 'Жекшемби_Дүйшөмбү_Шейшемби_Шаршемби_Бейшемби_Жума_Ишемби'.split('_'),
  weekdaysShort: 'Жек_Дүй_Шей_Шар_Бей_Жум_Ише'.split('_'),
  weekdaysMin: 'Жк_Дй_Шй_Шр_Бй_Жм_Иш'.split('_'),
  longDateFormat: {
    LT: 'HH:mm',
    LTS: 'HH:mm:ss',
    L: 'DD.MM.YYYY',
    LL: 'D MMMM YYYY',
    LLL: 'D MMMM YYYY HH:mm',
    LLLL: 'dddd, D MMMM YYYY HH:mm'
  },
  calendar: {
    sameDay: '[Бүгүн саат] LT',
    nextDay: '[Эртең саат] LT',
    nextWeek: 'dddd [саат] LT',
    lastDay: '[Кечээ саат] LT',
    lastWeek: '[Өткөн аптанын] dddd [күнү] [саат] LT',
    sameElse: 'L'
  },
  relativeTime: {
    future: '%s ичинде',
    past: '%s мурун',
    s: 'бирнече секунд',
    ss: '%d секунд',
    m: 'бир мүнөт',
    mm: '%d мүнөт',
    h: 'бир саат',
    hh: '%d саат',
    d: 'бир күн',
    dd: '%d күн',
    M: 'бир ай',
    MM: '%d ай',
    y: 'бир жыл',
    yy: '%d жыл'
  },
  dayOfMonthOrdinalParse: /\d{1,2}-(чи|чы|чү|чу)/,
  ordinal: function (number) {
    var a = number % 10,
        b = number >= 100 ? 100 : null;
    return number + (suffixes[number] || suffixes[a] || suffixes[b]);
  },
  week: {
    dow: 1,
    // Monday is the first day of the week.
    doy: 7 // The week that contains Jan 7th is the first week of the year.

  }
});