var restArguments = require('./restArguments.js');

var difference = require('./difference.js'); // Return a version of the array that does not contain the specified value(s).


var without = restArguments(function (array, otherArrays) {
  return difference(array, otherArrays);
});
module.exports = without;