##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: XRAM_XMPU3
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff93c000]
lappend results [mem_read 0xff93c004]
lappend results [mem_read 0xff93c008]
lappend results [mem_read 0xff93c00c]
lappend results [mem_read 0xff93c010]
lappend results [mem_read 0xff93c014]
lappend results [mem_read 0xff93c018]
lappend results [mem_read 0xff93c01c]
lappend results [mem_read 0xff93c020]
lappend results [mem_read 0xff93c100]
lappend results [mem_read 0xff93c104]
lappend results [mem_read 0xff93c108]
lappend results [mem_read 0xff93c10c]
lappend results [mem_read 0xff93c110]
lappend results [mem_read 0xff93c114]
lappend results [mem_read 0xff93c118]
lappend results [mem_read 0xff93c11c]
lappend results [mem_read 0xff93c120]
lappend results [mem_read 0xff93c124]
lappend results [mem_read 0xff93c128]
lappend results [mem_read 0xff93c12c]
lappend results [mem_read 0xff93c130]
lappend results [mem_read 0xff93c134]
lappend results [mem_read 0xff93c138]
lappend results [mem_read 0xff93c13c]
lappend results [mem_read 0xff93c140]
lappend results [mem_read 0xff93c144]
lappend results [mem_read 0xff93c148]
lappend results [mem_read 0xff93c14c]
lappend results [mem_read 0xff93c150]
lappend results [mem_read 0xff93c154]
lappend results [mem_read 0xff93c158]
lappend results [mem_read 0xff93c15c]
lappend results [mem_read 0xff93c160]
lappend results [mem_read 0xff93c164]
lappend results [mem_read 0xff93c168]
lappend results [mem_read 0xff93c16c]
lappend results [mem_read 0xff93c170]
lappend results [mem_read 0xff93c174]
lappend results [mem_read 0xff93c178]
lappend results [mem_read 0xff93c17c]
lappend results [mem_read 0xff93c180]
lappend results [mem_read 0xff93c184]
lappend results [mem_read 0xff93c188]
lappend results [mem_read 0xff93c18c]
lappend results [mem_read 0xff93c190]
lappend results [mem_read 0xff93c194]
lappend results [mem_read 0xff93c198]
lappend results [mem_read 0xff93c19c]
lappend results [mem_read 0xff93c1a0]
lappend results [mem_read 0xff93c1a4]
lappend results [mem_read 0xff93c1a8]
lappend results [mem_read 0xff93c1ac]
lappend results [mem_read 0xff93c1b0]
lappend results [mem_read 0xff93c1b4]
lappend results [mem_read 0xff93c1b8]
lappend results [mem_read 0xff93c1bc]
lappend results [mem_read 0xff93c1c0]
lappend results [mem_read 0xff93c1c4]
lappend results [mem_read 0xff93c1c8]
lappend results [mem_read 0xff93c1cc]
lappend results [mem_read 0xff93c1d0]
lappend results [mem_read 0xff93c1d4]
lappend results [mem_read 0xff93c1d8]
lappend results [mem_read 0xff93c1dc]
lappend results [mem_read 0xff93c1e0]
lappend results [mem_read 0xff93c1e4]
lappend results [mem_read 0xff93c1e8]
lappend results [mem_read 0xff93c1ec]
lappend results [mem_read 0xff93c1f0]
lappend results [mem_read 0xff93c1f4]
lappend results [mem_read 0xff93c1f8]
lappend results [mem_read 0xff93c1fc]
lappend results [mem_read 0xff93c200]
lappend results [mem_read 0xff93c204]
lappend results [mem_read 0xff93c208]
lappend results [mem_read 0xff93c20c]
lappend results [mem_read 0xff93c210]
lappend results [mem_read 0xff93c214]
lappend results [mem_read 0xff93c218]
lappend results [mem_read 0xff93c21c]
lappend results [mem_read 0xff93c220]
lappend results [mem_read 0xff93c224]
lappend results [mem_read 0xff93c228]
lappend results [mem_read 0xff93c22c]
lappend results [mem_read 0xff93c238]
lappend results [mem_read 0xff93c23c]
lappend results [mem_read 0xff93c240]
lappend results [mem_read 0xff93c244]
lappend results [mem_read 0xff93c248]
lappend results [mem_read 0xff93c24c]
lappend results [mem_read 0xff93c250]
lappend results [mem_read 0xff93c254]
lappend results [mem_read 0xff93c258]
lappend results [mem_read 0xff93c25c]
lappend results [mem_read 0xff93c260]
lappend results [mem_read 0xff93c264]
lappend results [mem_read 0xff93c268]
lappend results [mem_read 0xff93c26c]
lappend results [mem_read 0xff93c270]
lappend results [mem_read 0xff93c274]
lappend results [mem_read 0xff93c278]
lappend results [mem_read 0xff93c27c]
lappend results [mem_read 0xff93c280]
lappend results [mem_read 0xff93c284]
