##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: GEM1
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff0d0000]
lappend results [mem_read 0xff0d0004]
lappend results [mem_read 0xff0d0008]
lappend results [mem_read 0xff0d0010]
lappend results [mem_read 0xff0d0014]
lappend results [mem_read 0xff0d0018]
lappend results [mem_read 0xff0d001c]
lappend results [mem_read 0xff0d0020]
lappend results [mem_read 0xff0d0024]
lappend results [mem_read 0xff0d0028]
lappend results [mem_read 0xff0d002c]
lappend results [mem_read 0xff0d0030]
lappend results [mem_read 0xff0d0034]
lappend results [mem_read 0xff0d0038]
lappend results [mem_read 0xff0d003c]
lappend results [mem_read 0xff0d0040]
lappend results [mem_read 0xff0d0044]
lappend results [mem_read 0xff0d0048]
lappend results [mem_read 0xff0d004c]
lappend results [mem_read 0xff0d0054]
lappend results [mem_read 0xff0d0058]
lappend results [mem_read 0xff0d005c]
lappend results [mem_read 0xff0d0060]
lappend results [mem_read 0xff0d0064]
lappend results [mem_read 0xff0d0068]
lappend results [mem_read 0xff0d006c]
lappend results [mem_read 0xff0d0070]
lappend results [mem_read 0xff0d007c]
lappend results [mem_read 0xff0d0080]
lappend results [mem_read 0xff0d0084]
lappend results [mem_read 0xff0d0088]
lappend results [mem_read 0xff0d008c]
lappend results [mem_read 0xff0d0090]
lappend results [mem_read 0xff0d0094]
lappend results [mem_read 0xff0d0098]
lappend results [mem_read 0xff0d009c]
lappend results [mem_read 0xff0d00a0]
lappend results [mem_read 0xff0d00a4]
lappend results [mem_read 0xff0d00a8]
lappend results [mem_read 0xff0d00ac]
lappend results [mem_read 0xff0d00b0]
lappend results [mem_read 0xff0d00b4]
lappend results [mem_read 0xff0d00b8]
lappend results [mem_read 0xff0d00bc]
lappend results [mem_read 0xff0d00c0]
lappend results [mem_read 0xff0d00c4]
lappend results [mem_read 0xff0d00c8]
lappend results [mem_read 0xff0d00cc]
lappend results [mem_read 0xff0d00d0]
lappend results [mem_read 0xff0d00d4]
lappend results [mem_read 0xff0d00d8]
lappend results [mem_read 0xff0d00dc]
lappend results [mem_read 0xff0d00e0]
lappend results [mem_read 0xff0d00e4]
lappend results [mem_read 0xff0d00e8]
lappend results [mem_read 0xff0d00ec]
lappend results [mem_read 0xff0d00f0]
lappend results [mem_read 0xff0d00f4]
lappend results [mem_read 0xff0d00fc]
lappend results [mem_read 0xff0d0100]
lappend results [mem_read 0xff0d0104]
lappend results [mem_read 0xff0d0108]
lappend results [mem_read 0xff0d010c]
lappend results [mem_read 0xff0d0110]
lappend results [mem_read 0xff0d0114]
lappend results [mem_read 0xff0d0118]
lappend results [mem_read 0xff0d011c]
lappend results [mem_read 0xff0d0120]
lappend results [mem_read 0xff0d0124]
lappend results [mem_read 0xff0d0128]
lappend results [mem_read 0xff0d012c]
lappend results [mem_read 0xff0d0130]
lappend results [mem_read 0xff0d0134]
lappend results [mem_read 0xff0d0138]
lappend results [mem_read 0xff0d013c]
lappend results [mem_read 0xff0d0140]
lappend results [mem_read 0xff0d0144]
lappend results [mem_read 0xff0d0148]
lappend results [mem_read 0xff0d014c]
lappend results [mem_read 0xff0d0150]
lappend results [mem_read 0xff0d0154]
lappend results [mem_read 0xff0d0158]
lappend results [mem_read 0xff0d015c]
lappend results [mem_read 0xff0d0160]
lappend results [mem_read 0xff0d0164]
lappend results [mem_read 0xff0d0168]
lappend results [mem_read 0xff0d016c]
lappend results [mem_read 0xff0d0170]
lappend results [mem_read 0xff0d0174]
lappend results [mem_read 0xff0d0178]
lappend results [mem_read 0xff0d017c]
lappend results [mem_read 0xff0d0180]
lappend results [mem_read 0xff0d0184]
lappend results [mem_read 0xff0d0188]
lappend results [mem_read 0xff0d018c]
lappend results [mem_read 0xff0d0190]
lappend results [mem_read 0xff0d0194]
lappend results [mem_read 0xff0d0198]
lappend results [mem_read 0xff0d019c]
lappend results [mem_read 0xff0d01a0]
lappend results [mem_read 0xff0d01a4]
lappend results [mem_read 0xff0d01a8]
lappend results [mem_read 0xff0d01ac]
lappend results [mem_read 0xff0d01b0]
lappend results [mem_read 0xff0d01b4]
lappend results [mem_read 0xff0d01bc]
lappend results [mem_read 0xff0d01c0]
lappend results [mem_read 0xff0d01c4]
lappend results [mem_read 0xff0d01c8]
lappend results [mem_read 0xff0d01cc]
lappend results [mem_read 0xff0d01d0]
lappend results [mem_read 0xff0d01d4]
lappend results [mem_read 0xff0d01d8]
lappend results [mem_read 0xff0d01dc]
lappend results [mem_read 0xff0d01e0]
lappend results [mem_read 0xff0d01e4]
lappend results [mem_read 0xff0d01e8]
lappend results [mem_read 0xff0d01ec]
lappend results [mem_read 0xff0d01f0]
lappend results [mem_read 0xff0d01f4]
lappend results [mem_read 0xff0d01f8]
lappend results [mem_read 0xff0d01fc]
lappend results [mem_read 0xff0d0270]
lappend results [mem_read 0xff0d0274]
lappend results [mem_read 0xff0d0278]
lappend results [mem_read 0xff0d027c]
lappend results [mem_read 0xff0d0280]
lappend results [mem_read 0xff0d0284]
lappend results [mem_read 0xff0d0288]
lappend results [mem_read 0xff0d028c]
lappend results [mem_read 0xff0d0290]
lappend results [mem_read 0xff0d0294]
lappend results [mem_read 0xff0d0298]
lappend results [mem_read 0xff0d029c]
lappend results [mem_read 0xff0d02a0]
lappend results [mem_read 0xff0d02a4]
lappend results [mem_read 0xff0d02a8]
lappend results [mem_read 0xff0d02ac]
lappend results [mem_read 0xff0d0400]
lappend results [mem_read 0xff0d0440]
lappend results [mem_read 0xff0d0480]
lappend results [mem_read 0xff0d04a0]
lappend results [mem_read 0xff0d04bc]
lappend results [mem_read 0xff0d04c0]
lappend results [mem_read 0xff0d04c4]
lappend results [mem_read 0xff0d04c8]
lappend results [mem_read 0xff0d04cc]
lappend results [mem_read 0xff0d04d0]
lappend results [mem_read 0xff0d04d4]
lappend results [mem_read 0xff0d0500]
lappend results [mem_read 0xff0d0504]
lappend results [mem_read 0xff0d0508]
lappend results [mem_read 0xff0d050c]
lappend results [mem_read 0xff0d0540]
lappend results [mem_read 0xff0d0544]
lappend results [mem_read 0xff0d0548]
lappend results [mem_read 0xff0d054c]
lappend results [mem_read 0xff0d0580]
lappend results [mem_read 0xff0d0590]
lappend results [mem_read 0xff0d05a0]
lappend results [mem_read 0xff0d0600]
lappend results [mem_read 0xff0d0620]
lappend results [mem_read 0xff0d0640]
lappend results [mem_read 0xff0d06e0]
lappend results [mem_read 0xff0d06e4]
lappend results [mem_read 0xff0d06e8]
lappend results [mem_read 0xff0d06ec]
lappend results [mem_read 0xff0d0700]
lappend results [mem_read 0xff0d0704]
lappend results [mem_read 0xff0d0708]
lappend results [mem_read 0xff0d070c]
lappend results [mem_read 0xff0d0710]
lappend results [mem_read 0xff0d0714]
lappend results [mem_read 0xff0d0718]
lappend results [mem_read 0xff0d071c]
lappend results [mem_read 0xff0d0800]
lappend results [mem_read 0xff0d0804]
lappend results [mem_read 0xff0d0820]
lappend results [mem_read 0xff0d0824]
lappend results [mem_read 0xff0d0840]
lappend results [mem_read 0xff0d0844]
lappend results [mem_read 0xff0d0880]
lappend results [mem_read 0xff0d08a0]
lappend results [mem_read 0xff0d08a4]
lappend results [mem_read 0xff0d08c0]
lappend results [mem_read 0xff0d08c4]
lappend results [mem_read 0xff0d08c8]
lappend results [mem_read 0xff0d08cc]
lappend results [mem_read 0xff0d08d0]
lappend results [mem_read 0xff0d08d4]
lappend results [mem_read 0xff0d08d8]
lappend results [mem_read 0xff0d08dc]
lappend results [mem_read 0xff0d08e0]
lappend results [mem_read 0xff0d08e4]
lappend results [mem_read 0xff0d08e8]
lappend results [mem_read 0xff0d08ec]
lappend results [mem_read 0xff0d08f0]
lappend results [mem_read 0xff0d08f4]
lappend results [mem_read 0xff0d08f8]
lappend results [mem_read 0xff0d08fc]
lappend results [mem_read 0xff0d0b00]
lappend results [mem_read 0xff0d0b04]
lappend results [mem_read 0xff0d0b40]
lappend results [mem_read 0xff0d0b44]
lappend results [mem_read 0xff0d026c]
lappend results [mem_read 0xff0d0b48]
lappend results [mem_read 0xff0d0b4c]
lappend results [mem_read 0xff0d0b80]
