##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_APU_ELA
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0c60000]
lappend results [mem_read 0xf0c60004]
lappend results [mem_read 0xf0c60008]
lappend results [mem_read 0xf0c60010]
lappend results [mem_read 0xf0c60020]
lappend results [mem_read 0xf0c60024]
lappend results [mem_read 0xf0c60028]
lappend results [mem_read 0xf0c6002c]
lappend results [mem_read 0xf0c60040]
lappend results [mem_read 0xf0c60044]
lappend results [mem_read 0xf0c60048]
lappend results [mem_read 0xf0c6004c]
lappend results [mem_read 0xf0c60100]
lappend results [mem_read 0xf0c60104]
lappend results [mem_read 0xf0c60108]
lappend results [mem_read 0xf0c6010c]
lappend results [mem_read 0xf0c60110]
lappend results [mem_read 0xf0c60114]
lappend results [mem_read 0xf0c60120]
lappend results [mem_read 0xf0c60130]
lappend results [mem_read 0xf0c60134]
lappend results [mem_read 0xf0c60140]
lappend results [mem_read 0xf0c60144]
lappend results [mem_read 0xf0c60148]
lappend results [mem_read 0xf0c6014c]
lappend results [mem_read 0xf0c60180]
lappend results [mem_read 0xf0c60184]
lappend results [mem_read 0xf0c60188]
lappend results [mem_read 0xf0c6018c]
lappend results [mem_read 0xf0c60200]
lappend results [mem_read 0xf0c60204]
lappend results [mem_read 0xf0c60208]
lappend results [mem_read 0xf0c6020c]
lappend results [mem_read 0xf0c60210]
lappend results [mem_read 0xf0c60214]
lappend results [mem_read 0xf0c60220]
lappend results [mem_read 0xf0c60230]
lappend results [mem_read 0xf0c60234]
lappend results [mem_read 0xf0c60240]
lappend results [mem_read 0xf0c60244]
lappend results [mem_read 0xf0c60248]
lappend results [mem_read 0xf0c6024c]
lappend results [mem_read 0xf0c60280]
lappend results [mem_read 0xf0c60284]
lappend results [mem_read 0xf0c60288]
lappend results [mem_read 0xf0c6028c]
lappend results [mem_read 0xf0c60300]
lappend results [mem_read 0xf0c60304]
lappend results [mem_read 0xf0c60308]
lappend results [mem_read 0xf0c6030c]
lappend results [mem_read 0xf0c60310]
lappend results [mem_read 0xf0c60314]
lappend results [mem_read 0xf0c60320]
lappend results [mem_read 0xf0c60330]
lappend results [mem_read 0xf0c60334]
lappend results [mem_read 0xf0c60340]
lappend results [mem_read 0xf0c60344]
lappend results [mem_read 0xf0c60348]
lappend results [mem_read 0xf0c6034c]
lappend results [mem_read 0xf0c60380]
lappend results [mem_read 0xf0c60384]
lappend results [mem_read 0xf0c60388]
lappend results [mem_read 0xf0c6038c]
lappend results [mem_read 0xf0c60400]
lappend results [mem_read 0xf0c60404]
lappend results [mem_read 0xf0c60408]
lappend results [mem_read 0xf0c6040c]
lappend results [mem_read 0xf0c60410]
lappend results [mem_read 0xf0c60414]
lappend results [mem_read 0xf0c60420]
lappend results [mem_read 0xf0c60430]
lappend results [mem_read 0xf0c60434]
lappend results [mem_read 0xf0c60440]
lappend results [mem_read 0xf0c60444]
lappend results [mem_read 0xf0c60448]
lappend results [mem_read 0xf0c6044c]
lappend results [mem_read 0xf0c60480]
lappend results [mem_read 0xf0c60484]
lappend results [mem_read 0xf0c60488]
lappend results [mem_read 0xf0c6048c]
lappend results [mem_read 0xf0c60500]
lappend results [mem_read 0xf0c60504]
lappend results [mem_read 0xf0c60508]
lappend results [mem_read 0xf0c6050c]
lappend results [mem_read 0xf0c60510]
lappend results [mem_read 0xf0c60514]
lappend results [mem_read 0xf0c60520]
lappend results [mem_read 0xf0c60530]
lappend results [mem_read 0xf0c60534]
lappend results [mem_read 0xf0c60540]
lappend results [mem_read 0xf0c60544]
lappend results [mem_read 0xf0c60548]
lappend results [mem_read 0xf0c6054c]
lappend results [mem_read 0xf0c60580]
lappend results [mem_read 0xf0c60584]
lappend results [mem_read 0xf0c60588]
lappend results [mem_read 0xf0c6058c]
lappend results [mem_read 0xf0c60ee8]
lappend results [mem_read 0xf0c60ef8]
lappend results [mem_read 0xf0c60f00]
lappend results [mem_read 0xf0c60fb0]
lappend results [mem_read 0xf0c60fb4]
lappend results [mem_read 0xf0c60fb8]
lappend results [mem_read 0xf0c60fbc]
lappend results [mem_read 0xf0c60fc0]
lappend results [mem_read 0xf0c60fc4]
lappend results [mem_read 0xf0c60fc8]
lappend results [mem_read 0xf0c60fcc]
