##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: IPI
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff300000]
lappend results [mem_read 0xff300010]
lappend results [mem_read 0xff300014]
lappend results [mem_read 0xff300018]
lappend results [mem_read 0xff30001c]
lappend results [mem_read 0xff300028]
lappend results [mem_read 0xff300030]
lappend results [mem_read 0xff300034]
lappend results [mem_read 0xff300038]
lappend results [mem_read 0xff30003c]
lappend results [mem_read 0xff300040]
lappend results [mem_read 0xff300044]
lappend results [mem_read 0xff300048]
lappend results [mem_read 0xff30004c]
lappend results [mem_read 0xff300050]
lappend results [mem_read 0xff300054]
lappend results [mem_read 0xff300058]
lappend results [mem_read 0xff30005c]
lappend results [mem_read 0xff300060]
lappend results [mem_read 0xff300064]
lappend results [mem_read 0xff300068]
lappend results [mem_read 0xff30006c]
lappend results [mem_read 0xff300070]
lappend results [mem_read 0xff300074]
lappend results [mem_read 0xff300078]
lappend results [mem_read 0xff30007c]
lappend results [mem_read 0xff300080]
lappend results [mem_read 0xff300084]
lappend results [mem_read 0xff300088]
lappend results [mem_read 0xff30008c]
lappend results [mem_read 0xff300090]
lappend results [mem_read 0xff300094]
lappend results [mem_read 0xff300098]
lappend results [mem_read 0xff30009c]
lappend results [mem_read 0xff3000a0]
lappend results [mem_read 0xff3000a4]
lappend results [mem_read 0xff3000a8]
lappend results [mem_read 0xff3000ac]
lappend results [mem_read 0xff3000b0]
lappend results [mem_read 0xff3000b4]
lappend results [mem_read 0xff3000b8]
lappend results [mem_read 0xff3000bc]
lappend results [mem_read 0xff3000c0]
lappend results [mem_read 0xff3000c4]
lappend results [mem_read 0xff3000c8]
lappend results [mem_read 0xff3000cc]
lappend results [mem_read 0xff3000d0]
lappend results [mem_read 0xff3000d4]
lappend results [mem_read 0xff3000d8]
lappend results [mem_read 0xff3000dc]
lappend results [mem_read 0xff310000]
lappend results [mem_read 0xff310004]
lappend results [mem_read 0xff310010]
lappend results [mem_read 0xff310014]
lappend results [mem_read 0xff310018]
lappend results [mem_read 0xff31001c]
lappend results [mem_read 0xff320000]
lappend results [mem_read 0xff320004]
lappend results [mem_read 0xff320010]
lappend results [mem_read 0xff320014]
lappend results [mem_read 0xff320018]
lappend results [mem_read 0xff32001c]
lappend results [mem_read 0xff330000]
lappend results [mem_read 0xff330004]
lappend results [mem_read 0xff330010]
lappend results [mem_read 0xff330014]
lappend results [mem_read 0xff330018]
lappend results [mem_read 0xff33001c]
lappend results [mem_read 0xff340000]
lappend results [mem_read 0xff340004]
lappend results [mem_read 0xff340010]
lappend results [mem_read 0xff340014]
lappend results [mem_read 0xff340018]
lappend results [mem_read 0xff34001c]
lappend results [mem_read 0xff350000]
lappend results [mem_read 0xff350004]
lappend results [mem_read 0xff350010]
lappend results [mem_read 0xff350014]
lappend results [mem_read 0xff350018]
lappend results [mem_read 0xff35001c]
lappend results [mem_read 0xff360000]
lappend results [mem_read 0xff360004]
lappend results [mem_read 0xff360010]
lappend results [mem_read 0xff360014]
lappend results [mem_read 0xff360018]
lappend results [mem_read 0xff36001c]
lappend results [mem_read 0xff370000]
lappend results [mem_read 0xff370004]
lappend results [mem_read 0xff370010]
lappend results [mem_read 0xff370014]
lappend results [mem_read 0xff370018]
lappend results [mem_read 0xff37001c]
lappend results [mem_read 0xff380000]
lappend results [mem_read 0xff380004]
lappend results [mem_read 0xff380010]
lappend results [mem_read 0xff380014]
lappend results [mem_read 0xff380018]
lappend results [mem_read 0xff38001c]
lappend results [mem_read 0xff390000]
lappend results [mem_read 0xff390004]
lappend results [mem_read 0xff390010]
lappend results [mem_read 0xff390014]
lappend results [mem_read 0xff390018]
lappend results [mem_read 0xff39001c]
lappend results [mem_read 0xff3a0000]
lappend results [mem_read 0xff3a0004]
lappend results [mem_read 0xff3a0010]
lappend results [mem_read 0xff3a0014]
lappend results [mem_read 0xff3a0018]
lappend results [mem_read 0xff3a001c]
