##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: PMC_XPPU
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf1310000]
lappend results [mem_read 0xf1310004]
lappend results [mem_read 0xf1310008]
lappend results [mem_read 0xf131000c]
lappend results [mem_read 0xf1310010]
lappend results [mem_read 0xf1310014]
lappend results [mem_read 0xf1310018]
lappend results [mem_read 0xf131001c]
lappend results [mem_read 0xf1310020]
lappend results [mem_read 0xf131003c]
lappend results [mem_read 0xf1310044]
lappend results [mem_read 0xf1310048]
lappend results [mem_read 0xf131004c]
lappend results [mem_read 0xf1310054]
lappend results [mem_read 0xf1310058]
lappend results [mem_read 0xf131005c]
lappend results [mem_read 0xf1310100]
lappend results [mem_read 0xf1310104]
lappend results [mem_read 0xf1310108]
lappend results [mem_read 0xf131010c]
lappend results [mem_read 0xf1310110]
lappend results [mem_read 0xf1310114]
lappend results [mem_read 0xf1310118]
lappend results [mem_read 0xf131011c]
lappend results [mem_read 0xf1310120]
lappend results [mem_read 0xf1310124]
lappend results [mem_read 0xf1310128]
lappend results [mem_read 0xf131012c]
lappend results [mem_read 0xf1310130]
lappend results [mem_read 0xf1310134]
lappend results [mem_read 0xf1310138]
lappend results [mem_read 0xf131013c]
lappend results [mem_read 0xf1310140]
lappend results [mem_read 0xf1310144]
lappend results [mem_read 0xf1310148]
lappend results [mem_read 0xf131014c]
lappend results [mem_read 0xf1310150]
lappend results [mem_read 0xf1310154]
lappend results [mem_read 0xf13100fc]
lappend results [mem_read 0xf1311000]
lappend results [mem_read 0xf1311004]
lappend results [mem_read 0xf1311008]
lappend results [mem_read 0xf131100c]
lappend results [mem_read 0xf1311010]
lappend results [mem_read 0xf1311014]
lappend results [mem_read 0xf1311018]
lappend results [mem_read 0xf131101c]
lappend results [mem_read 0xf1311020]
lappend results [mem_read 0xf1311024]
lappend results [mem_read 0xf1311028]
lappend results [mem_read 0xf131102c]
lappend results [mem_read 0xf1311030]
lappend results [mem_read 0xf1311034]
lappend results [mem_read 0xf1311038]
lappend results [mem_read 0xf131103c]
lappend results [mem_read 0xf1311040]
lappend results [mem_read 0xf1311044]
lappend results [mem_read 0xf1311048]
lappend results [mem_read 0xf131104c]
lappend results [mem_read 0xf1311050]
lappend results [mem_read 0xf1311054]
lappend results [mem_read 0xf1311058]
lappend results [mem_read 0xf131105c]
lappend results [mem_read 0xf1311060]
lappend results [mem_read 0xf1311064]
lappend results [mem_read 0xf1311068]
lappend results [mem_read 0xf131106c]
lappend results [mem_read 0xf1311070]
lappend results [mem_read 0xf1311074]
lappend results [mem_read 0xf1311078]
lappend results [mem_read 0xf131107c]
lappend results [mem_read 0xf1311080]
lappend results [mem_read 0xf1311084]
lappend results [mem_read 0xf1311088]
lappend results [mem_read 0xf131108c]
lappend results [mem_read 0xf1311090]
lappend results [mem_read 0xf1311094]
lappend results [mem_read 0xf1311098]
lappend results [mem_read 0xf131109c]
lappend results [mem_read 0xf13110a0]
lappend results [mem_read 0xf13110a4]
lappend results [mem_read 0xf13110a8]
lappend results [mem_read 0xf13110ac]
lappend results [mem_read 0xf13110b0]
lappend results [mem_read 0xf13110b4]
lappend results [mem_read 0xf13110b8]
lappend results [mem_read 0xf13110bc]
lappend results [mem_read 0xf13110c0]
lappend results [mem_read 0xf13110c4]
lappend results [mem_read 0xf13110c8]
lappend results [mem_read 0xf13110cc]
lappend results [mem_read 0xf13110d0]
lappend results [mem_read 0xf13110d4]
lappend results [mem_read 0xf13110d8]
lappend results [mem_read 0xf13110dc]
lappend results [mem_read 0xf13110e0]
lappend results [mem_read 0xf13110e4]
lappend results [mem_read 0xf13110e8]
lappend results [mem_read 0xf13110ec]
lappend results [mem_read 0xf13110f0]
lappend results [mem_read 0xf13110f4]
lappend results [mem_read 0xf13110f8]
lappend results [mem_read 0xf13110fc]
lappend results [mem_read 0xf1311100]
lappend results [mem_read 0xf1311104]
lappend results [mem_read 0xf1311108]
lappend results [mem_read 0xf131110c]
lappend results [mem_read 0xf1311110]
lappend results [mem_read 0xf1311114]
lappend results [mem_read 0xf1311118]
lappend results [mem_read 0xf131111c]
lappend results [mem_read 0xf1311120]
lappend results [mem_read 0xf1311124]
lappend results [mem_read 0xf1311128]
lappend results [mem_read 0xf131112c]
lappend results [mem_read 0xf1311130]
lappend results [mem_read 0xf1311134]
lappend results [mem_read 0xf1311138]
lappend results [mem_read 0xf131113c]
lappend results [mem_read 0xf1311140]
lappend results [mem_read 0xf1311144]
lappend results [mem_read 0xf1311148]
lappend results [mem_read 0xf131114c]
lappend results [mem_read 0xf1311150]
lappend results [mem_read 0xf1311154]
lappend results [mem_read 0xf1311158]
lappend results [mem_read 0xf131115c]
lappend results [mem_read 0xf1311160]
lappend results [mem_read 0xf1311164]
lappend results [mem_read 0xf1311168]
lappend results [mem_read 0xf131116c]
lappend results [mem_read 0xf1311170]
lappend results [mem_read 0xf1311174]
lappend results [mem_read 0xf1311178]
lappend results [mem_read 0xf131117c]
lappend results [mem_read 0xf1311180]
lappend results [mem_read 0xf1311184]
lappend results [mem_read 0xf1311188]
lappend results [mem_read 0xf131118c]
lappend results [mem_read 0xf1311190]
lappend results [mem_read 0xf1311194]
lappend results [mem_read 0xf1311198]
lappend results [mem_read 0xf131119c]
lappend results [mem_read 0xf13111a0]
lappend results [mem_read 0xf13111a4]
lappend results [mem_read 0xf13111a8]
lappend results [mem_read 0xf13111ac]
lappend results [mem_read 0xf13111b0]
lappend results [mem_read 0xf13111b4]
lappend results [mem_read 0xf13111b8]
lappend results [mem_read 0xf13111bc]
lappend results [mem_read 0xf13111c0]
lappend results [mem_read 0xf13111c4]
lappend results [mem_read 0xf13111c8]
lappend results [mem_read 0xf13111cc]
lappend results [mem_read 0xf13111d0]
lappend results [mem_read 0xf13111d4]
lappend results [mem_read 0xf13111d8]
lappend results [mem_read 0xf13111dc]
lappend results [mem_read 0xf13111e0]
lappend results [mem_read 0xf13111e4]
lappend results [mem_read 0xf13111e8]
lappend results [mem_read 0xf13111ec]
lappend results [mem_read 0xf13111f0]
lappend results [mem_read 0xf13111f4]
lappend results [mem_read 0xf13111f8]
lappend results [mem_read 0xf13111fc]
lappend results [mem_read 0xf1311200]
lappend results [mem_read 0xf1311204]
lappend results [mem_read 0xf1311208]
lappend results [mem_read 0xf131120c]
lappend results [mem_read 0xf1311210]
lappend results [mem_read 0xf1311214]
lappend results [mem_read 0xf1311218]
lappend results [mem_read 0xf131121c]
lappend results [mem_read 0xf1311220]
lappend results [mem_read 0xf1311224]
lappend results [mem_read 0xf1311228]
lappend results [mem_read 0xf131122c]
lappend results [mem_read 0xf1311230]
lappend results [mem_read 0xf1311234]
lappend results [mem_read 0xf1311238]
lappend results [mem_read 0xf131123c]
lappend results [mem_read 0xf1311240]
lappend results [mem_read 0xf1311244]
lappend results [mem_read 0xf1311248]
lappend results [mem_read 0xf131124c]
lappend results [mem_read 0xf1311250]
lappend results [mem_read 0xf1311254]
lappend results [mem_read 0xf1311258]
lappend results [mem_read 0xf131125c]
lappend results [mem_read 0xf1311260]
lappend results [mem_read 0xf1311264]
lappend results [mem_read 0xf1311268]
lappend results [mem_read 0xf131126c]
lappend results [mem_read 0xf1311270]
lappend results [mem_read 0xf1311274]
lappend results [mem_read 0xf1311278]
lappend results [mem_read 0xf131127c]
lappend results [mem_read 0xf1311280]
lappend results [mem_read 0xf1311284]
lappend results [mem_read 0xf1311288]
lappend results [mem_read 0xf131128c]
lappend results [mem_read 0xf1311290]
lappend results [mem_read 0xf1311294]
lappend results [mem_read 0xf1311298]
lappend results [mem_read 0xf131129c]
lappend results [mem_read 0xf13112a0]
lappend results [mem_read 0xf13112a4]
lappend results [mem_read 0xf13112a8]
lappend results [mem_read 0xf13112ac]
lappend results [mem_read 0xf13112b0]
lappend results [mem_read 0xf13112b4]
lappend results [mem_read 0xf13112b8]
lappend results [mem_read 0xf13112bc]
lappend results [mem_read 0xf13112c0]
lappend results [mem_read 0xf13112c4]
lappend results [mem_read 0xf13112c8]
lappend results [mem_read 0xf13112cc]
lappend results [mem_read 0xf13112d0]
lappend results [mem_read 0xf13112d4]
lappend results [mem_read 0xf13112d8]
lappend results [mem_read 0xf13112dc]
lappend results [mem_read 0xf13112e0]
lappend results [mem_read 0xf13112e4]
lappend results [mem_read 0xf13112e8]
lappend results [mem_read 0xf13112ec]
lappend results [mem_read 0xf13112f0]
lappend results [mem_read 0xf13112f4]
lappend results [mem_read 0xf13112f8]
lappend results [mem_read 0xf13112fc]
lappend results [mem_read 0xf1311300]
lappend results [mem_read 0xf1311304]
lappend results [mem_read 0xf1311308]
lappend results [mem_read 0xf131130c]
lappend results [mem_read 0xf1311310]
lappend results [mem_read 0xf1311314]
lappend results [mem_read 0xf1311318]
lappend results [mem_read 0xf131131c]
lappend results [mem_read 0xf1311320]
lappend results [mem_read 0xf1311324]
lappend results [mem_read 0xf1311328]
lappend results [mem_read 0xf131132c]
lappend results [mem_read 0xf1311330]
lappend results [mem_read 0xf1311334]
lappend results [mem_read 0xf1311338]
lappend results [mem_read 0xf131133c]
lappend results [mem_read 0xf1311340]
lappend results [mem_read 0xf1311344]
lappend results [mem_read 0xf1311348]
lappend results [mem_read 0xf131134c]
lappend results [mem_read 0xf1311350]
lappend results [mem_read 0xf1311354]
lappend results [mem_read 0xf1311358]
lappend results [mem_read 0xf131135c]
lappend results [mem_read 0xf1311360]
lappend results [mem_read 0xf1311364]
lappend results [mem_read 0xf1311368]
lappend results [mem_read 0xf131136c]
lappend results [mem_read 0xf1311370]
lappend results [mem_read 0xf1311374]
lappend results [mem_read 0xf1311378]
lappend results [mem_read 0xf131137c]
lappend results [mem_read 0xf1311380]
lappend results [mem_read 0xf1311384]
lappend results [mem_read 0xf1311388]
lappend results [mem_read 0xf131138c]
lappend results [mem_read 0xf1311390]
lappend results [mem_read 0xf1311394]
lappend results [mem_read 0xf1311398]
lappend results [mem_read 0xf131139c]
lappend results [mem_read 0xf13113a0]
lappend results [mem_read 0xf13113a4]
lappend results [mem_read 0xf13113a8]
lappend results [mem_read 0xf13113ac]
lappend results [mem_read 0xf13113b0]
lappend results [mem_read 0xf13113b4]
lappend results [mem_read 0xf13113b8]
lappend results [mem_read 0xf13113bc]
lappend results [mem_read 0xf13113c0]
lappend results [mem_read 0xf13113c4]
lappend results [mem_read 0xf13113c8]
lappend results [mem_read 0xf13113cc]
lappend results [mem_read 0xf13113d0]
lappend results [mem_read 0xf13113d4]
lappend results [mem_read 0xf13113d8]
lappend results [mem_read 0xf13113dc]
lappend results [mem_read 0xf13113e0]
lappend results [mem_read 0xf13113e4]
lappend results [mem_read 0xf13113e8]
lappend results [mem_read 0xf13113ec]
lappend results [mem_read 0xf13113f0]
lappend results [mem_read 0xf13113f4]
lappend results [mem_read 0xf13113f8]
lappend results [mem_read 0xf13113fc]
lappend results [mem_read 0xf1311600]
lappend results [mem_read 0xf1311604]
lappend results [mem_read 0xf1311608]
lappend results [mem_read 0xf131160c]
lappend results [mem_read 0xf1311610]
lappend results [mem_read 0xf1311614]
lappend results [mem_read 0xf1311618]
lappend results [mem_read 0xf131161c]
lappend results [mem_read 0xf1311620]
lappend results [mem_read 0xf1311624]
lappend results [mem_read 0xf1311628]
lappend results [mem_read 0xf131162c]
lappend results [mem_read 0xf1311630]
lappend results [mem_read 0xf1311634]
lappend results [mem_read 0xf1311638]
lappend results [mem_read 0xf131163c]
lappend results [mem_read 0xf1311640]
