define(['./_setup', './_tagTester'], function (_setup, _tagTester) {
  // Is a given value an array?
  // Delegates to ECMA5's native `Array.isArray`.
  var isArray = _setup.nativeIsArray || _tagTester('Array');

  return isArray;
});