##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM5_L20_CSR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfcc04020]
lappend results [mem_read 0xfcc04040]
lappend results [mem_read 0xfcc04140]
lappend results [mem_read 0xfcc04148]
lappend results [mem_read 0xfcc04150]
lappend results [mem_read 0xfcc04158]
lappend results [mem_read 0xfcc04160]
lappend results [mem_read 0xfcc04168]
lappend results [mem_read 0xfcc04170]
lappend results [mem_read 0xfcc04178]
lappend results [mem_read 0xfcc04080]
lappend results [mem_read 0xfcc04028]
lappend results [mem_read 0xfcc04180]
lappend results [mem_read 0xfcc04100]
lappend results [mem_read 0xfcc04108]
lappend results [mem_read 0xfcc04030]
lappend results [mem_read 0xfcc04038]
lappend results [mem_read 0xfcc04088]
lappend results [mem_read 0xfcc04090]
lappend results [mem_read 0xfcc04098]
lappend results [mem_read 0xfcc040a0]
lappend results [mem_read 0xfcc040a8]
lappend results [mem_read 0xfcc040b0]
lappend results [mem_read 0xfcc040b8]
lappend results [mem_read 0xfcc040c0]
lappend results [mem_read 0xfcc040c8]
lappend results [mem_read 0xfcc04198]
lappend results [mem_read 0xfcc041a0]
lappend results [mem_read 0xfcc04190]
lappend results [mem_read 0xfcc04048]
lappend results [mem_read 0xfcc04050]
lappend results [mem_read 0xfcc041c0]
lappend results [mem_read 0xfcc041c8]
lappend results [mem_read 0xfcc041b8]
lappend results [mem_read 0xfcc041b0]
lappend results [mem_read 0xfcc041a8]
lappend results [mem_read 0xfcc041d0]
lappend results [mem_read 0xfcc04078]
lappend results [mem_read 0xfcc04000]
lappend results [mem_read 0xfcc04008]
lappend results [mem_read 0xfcc04010]
lappend results [mem_read 0xfcc04018]
lappend results [mem_read 0xfcc06050]
lappend results [mem_read 0xfcc06058]
lappend results [mem_read 0xfcc06048]
lappend results [mem_read 0xfcc06000]
lappend results [mem_read 0xfcc06008]
lappend results [mem_read 0xfcc06010]
lappend results [mem_read 0xfcc06018]
lappend results [mem_read 0xfcc06020]
lappend results [mem_read 0xfcc06028]
lappend results [mem_read 0xfcc06030]
lappend results [mem_read 0xfcc06038]
lappend results [mem_read 0xfcc060c8]
lappend results [mem_read 0xfcc06120]
lappend results [mem_read 0xfcc06118]
lappend results [mem_read 0xfcc06100]
lappend results [mem_read 0xfcc06110]
lappend results [mem_read 0xfcc06108]
lappend results [mem_read 0xfcc06180]
lappend results [mem_read 0xfcc06190]
lappend results [mem_read 0xfcc06188]
lappend results [mem_read 0xfcc06198]
lappend results [mem_read 0xfcc06070]
lappend results [mem_read 0xfcc06040]
lappend results [mem_read 0xfcc06140]
lappend results [mem_read 0xfcc06148]
lappend results [mem_read 0xfcc06150]
lappend results [mem_read 0xfcc06158]
lappend results [mem_read 0xfcc06160]
lappend results [mem_read 0xfcc06168]
lappend results [mem_read 0xfcc061c8]
lappend results [mem_read 0xfcc061d0]
lappend results [mem_read 0xfcc061c0]
lappend results [mem_read 0xfcc061e0]
lappend results [mem_read 0xfcc060e0]
lappend results [mem_read 0xfcc061d8]
lappend results [mem_read 0xfcc06078]
lappend results [mem_read 0xfcc060c0]
lappend results [mem_read 0xfcc060d0]
lappend results [mem_read 0xfcc060d8]
