/**
 * DO NOT EDIT
 *
 * This file was automatically generated by
 *   https://github.com/Polymer/tools/tree/master/packages/gen-typescript-declarations
 *
 * To modify these typings, edit the source file(s):
 *   vaadin-context-menu.js
 */


// tslint:disable:variable-name Describing an API that's defined elsewhere.

export * from './src/vaadin-context-menu.js';
export * from './@types/interfaces';
