define(['./underscore'], function (underscore) {
  // Start chaining a wrapped Underscore object.
  function chain(obj) {
    var instance = underscore(obj);
    instance._chain = true;
    return instance;
  }

  return chain;
});