##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: PMC_IOP_SLCR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf1060000]
lappend results [mem_read 0xf1060004]
lappend results [mem_read 0xf1060008]
lappend results [mem_read 0xf106000c]
lappend results [mem_read 0xf1060010]
lappend results [mem_read 0xf1060014]
lappend results [mem_read 0xf1060018]
lappend results [mem_read 0xf106001c]
lappend results [mem_read 0xf1060020]
lappend results [mem_read 0xf1060024]
lappend results [mem_read 0xf1060028]
lappend results [mem_read 0xf106002c]
lappend results [mem_read 0xf1060030]
lappend results [mem_read 0xf1060034]
lappend results [mem_read 0xf1060038]
lappend results [mem_read 0xf106003c]
lappend results [mem_read 0xf1060040]
lappend results [mem_read 0xf1060044]
lappend results [mem_read 0xf1060048]
lappend results [mem_read 0xf106004c]
lappend results [mem_read 0xf1060050]
lappend results [mem_read 0xf1060054]
lappend results [mem_read 0xf1060058]
lappend results [mem_read 0xf106005c]
lappend results [mem_read 0xf1060060]
lappend results [mem_read 0xf1060064]
lappend results [mem_read 0xf1060068]
lappend results [mem_read 0xf106006c]
lappend results [mem_read 0xf1060070]
lappend results [mem_read 0xf1060074]
lappend results [mem_read 0xf1060078]
lappend results [mem_read 0xf106007c]
lappend results [mem_read 0xf1060080]
lappend results [mem_read 0xf1060084]
lappend results [mem_read 0xf1060088]
lappend results [mem_read 0xf106008c]
lappend results [mem_read 0xf1060090]
lappend results [mem_read 0xf1060094]
lappend results [mem_read 0xf1060098]
lappend results [mem_read 0xf106009c]
lappend results [mem_read 0xf10600a0]
lappend results [mem_read 0xf10600a4]
lappend results [mem_read 0xf10600a8]
lappend results [mem_read 0xf10600ac]
lappend results [mem_read 0xf10600b0]
lappend results [mem_read 0xf10600b4]
lappend results [mem_read 0xf10600b8]
lappend results [mem_read 0xf10600bc]
lappend results [mem_read 0xf10600c0]
lappend results [mem_read 0xf10600c4]
lappend results [mem_read 0xf10600c8]
lappend results [mem_read 0xf10600cc]
lappend results [mem_read 0xf106010c]
lappend results [mem_read 0xf1060110]
lappend results [mem_read 0xf1060114]
lappend results [mem_read 0xf1060118]
lappend results [mem_read 0xf106011c]
lappend results [mem_read 0xf1060120]
lappend results [mem_read 0xf106015c]
lappend results [mem_read 0xf1060160]
lappend results [mem_read 0xf1060200]
lappend results [mem_read 0xf1060204]
lappend results [mem_read 0xf106030c]
lappend results [mem_read 0xf1060310]
lappend results [mem_read 0xf1060314]
lappend results [mem_read 0xf1060318]
lappend results [mem_read 0xf106031c]
lappend results [mem_read 0xf1060320]
lappend results [mem_read 0xf106035c]
lappend results [mem_read 0xf1060360]
lappend results [mem_read 0xf1060400]
lappend results [mem_read 0xf1060404]
lappend results [mem_read 0xf1060410]
lappend results [mem_read 0xf1060414]
lappend results [mem_read 0xf1060418]
lappend results [mem_read 0xf106041c]
lappend results [mem_read 0xf1060420]
lappend results [mem_read 0xf1060424]
lappend results [mem_read 0xf1060428]
lappend results [mem_read 0xf106042c]
lappend results [mem_read 0xf1060430]
lappend results [mem_read 0xf1060434]
lappend results [mem_read 0xf1060438]
lappend results [mem_read 0xf106043c]
lappend results [mem_read 0xf1060440]
lappend results [mem_read 0xf1060444]
lappend results [mem_read 0xf1060448]
lappend results [mem_read 0xf106044c]
lappend results [mem_read 0xf1060454]
lappend results [mem_read 0xf1060458]
lappend results [mem_read 0xf1060460]
lappend results [mem_read 0xf1060464]
lappend results [mem_read 0xf106046c]
lappend results [mem_read 0xf1060480]
lappend results [mem_read 0xf1060484]
lappend results [mem_read 0xf1060490]
lappend results [mem_read 0xf1060494]
lappend results [mem_read 0xf1060498]
lappend results [mem_read 0xf106049c]
lappend results [mem_read 0xf10604a0]
lappend results [mem_read 0xf10604a4]
lappend results [mem_read 0xf10604a8]
lappend results [mem_read 0xf10604ac]
lappend results [mem_read 0xf10604b0]
lappend results [mem_read 0xf10604b4]
lappend results [mem_read 0xf10604b8]
lappend results [mem_read 0xf10604bc]
lappend results [mem_read 0xf10604c0]
lappend results [mem_read 0xf10604c4]
lappend results [mem_read 0xf10604c8]
lappend results [mem_read 0xf10604cc]
lappend results [mem_read 0xf10604d4]
lappend results [mem_read 0xf10604d8]
lappend results [mem_read 0xf10604e0]
lappend results [mem_read 0xf10604e4]
lappend results [mem_read 0xf10604ec]
lappend results [mem_read 0xf1060504]
lappend results [mem_read 0xf1060508]
lappend results [mem_read 0xf106050c]
lappend results [mem_read 0xf1060514]
lappend results [mem_read 0xf1060530]
lappend results [mem_read 0xf1060534]
lappend results [mem_read 0xf106053c]
lappend results [mem_read 0xf1060600]
lappend results [mem_read 0xf1060604]
lappend results [mem_read 0xf1060700]
lappend results [mem_read 0xf1060800]
lappend results [mem_read 0xf1060804]
lappend results [mem_read 0xf1060808]
lappend results [mem_read 0xf106080c]
lappend results [mem_read 0xf1060814]
lappend results [mem_read 0xf1060818]
lappend results [mem_read 0xf106081c]
lappend results [mem_read 0xf1060820]
lappend results [mem_read 0xf1060828]
