var restArguments = require('./restArguments.js');

var unzip = require('./unzip.js'); // Zip together multiple lists into a single array -- elements that share
// an index go together.


var zip = restArguments(unzip);
module.exports = zip;