var _setup = require('./_setup.js');

var isNumber = require('./isNumber.js'); // Is the given value `NaN`?


function isNaN(obj) {
  return isNumber(obj) && _setup._isNaN(obj);
}

module.exports = isNaN;