var _createSizePropertyCheck = require('./_createSizePropertyCheck.js');

var _getByteLength = require('./_getByteLength.js'); // Internal helper to determine whether we should spend extensive checks against
// `ArrayBuffer` et al.


var isBufferLike = _createSizePropertyCheck(_getByteLength);

module.exports = isBufferLike;