##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
#
##
LOG_FILE = "log.txt"

CONF_DDR_NOC_0 = "ddr_noc_0.tcl"
CONF_DDR_NOC_1 = "ddr_noc_1.tcl"
CONF_DDR_NOC_2 = "ddr_noc_2.tcl"
CONF_DDR_NOC_3 = "ddr_noc_3.tcl"

PERF_DDR_NOC_0 = "perf_ddr_noc_0.tcl"
PERF_DDR_NOC_1 = "perf_ddr_noc_1.tcl"
PERF_DDR_NOC_2 = "perf_ddr_noc_2.tcl"
PERF_DDR_NOC_3 = "perf_ddr_noc_3.tcl"

CONF_DC_PERF = "DC_PERF_config.tcl"
PERF_DDR_DC = "readdcperfmon.tcl"

RESET_LPD_COUNTERS = "resetlpd.tcl"
PS_PMC_RPU_AXI0 = "if_ps_pmc_rpu_axi0.tcl"
INTLPD_AFIFSLPD_AXI = "if_intlpd_afifslpd_axi.tcl"
INTLPD_OCM_AXI = "if_intlpd_ocm_axi.tcl"
READ_LPD_COUNTERS = "readlpdcounters.tcl"
INTLPD_INTFPD_AXI = "if_intlpd_intfpd_axi.tcl"
XPPU = "XPPU.tcl"

RESET_FPD_COUNTERS = "resetfpd.tcl"
RESET_PMC_COUNTERS = "resetpmc.tcl"
FPD_SLAVE = "if_fpd_slave.tcl"
INTFLD_INTLPD_OCM = "if_intfld_intlpd_ocm.tcl"
INTFPD_INTLPD_LPD_SLAVE = "if_intfpd_intlpd_LPD_slave.tcl"
INTFPD_INTLPD_PCIE = "if_intfpd_intlpd_pcie.tcl"
PS_FPD_APM = "ps_fpd_apm.tcl"
PS_NOC_NCI_AXI0 = "ps_noc_nci_axi0.tcl"
PS_NOC_NCI_AXI1 = "ps_noc_nci_axi1.tcl"
READ_FPD_COUNTERS = "readfpdcounters.tcl"

CPM_AXI0 = "if_cpm_ps_axi0.tcl"
CPM_AXI1 = "if_cpm_ps_axi1.tcl"
CPM_PCIe = "ps_cpm_pcie_axi.tcl"
READ_CPM_COUNTERS = "readcpm.tcl"
READ_CPM_NSU = "cpm_nsu_read.tcl"

PMC_NOC_AXI = "ps_pmc_noc_axi.tcl"
READ_PMC_COUNTERS = "readpmc.tcl"

CONF_NOC_NMU = "NOC_NMU_config.tcl"
CONF_NOC_NPS = "NOC_NPS_config.tcl"
CONF_NOC_NSU = "NOC_NSU_config.tcl"
READ_NMU = "read_NOC_NMU.tcl"
READ_NPS = "read_NOC_NPS.tcl"
READ_NSU = "read_NOC_NSU.tcl"
READ_NPS_REG = "readnps"
READ_NSU_REG = "readnsu.tcl"
READ_NMU_REG = "readnmu.tcl"

CONF_APM = "configAPM.tcl"
READ_APM = "read_APM.tcl"

TEST_CASE_LIST = "testcaselist_"
QOS_LIST = "qos.tcl"
READ_ME = "read_me_counters.tcl"

JTAG_FREQUENCY = "150000"
SANITY_DATA = "0x11220044"

PS_PMC_RPU_AXI0_READ = "if_ps_pmc_rpu_axi0_read.tcl"
INTLPD_AFIFSLPD_AXI_READ = "if_intlpd_afifslpd_axi_read.tcl"
INTLPD_OCM_AXI_READ = "if_intlpd_ocm_axi_read.tcl"
INTLPD_INTFPD_AXI_READ = "if_intlpd_intfpd_axi_read.tcl"
XPPU_READ = "XPPU.tcl"
FPD_SLAVE_READ = "if_fpd_slave_read.tcl"
INTFLD_INTLPD_OCM_READ = "if_intfld_intlpd_ocm_read.tcl"
INTFPD_INTLPD_LPD_SLAVE_READ = "if_intfpd_intlpd_LPD_slave_read.tcl"
INTFPD_INTLPD_PCIE_READ = "if_intfpd_intlpd_pcie_read.tcl"
PS_FPD_APM_READ = "ps_fpd_apm_read.tcl"
PS_NOC_NCI_AXI0_READ = "ps_noc_nci_axi0_read.tcl"
PS_NOC_NCI_AXI1_READ = "ps_noc_nci_axi1_read.tcl"
CPM_AXI0_READ = "if_cpm_ps_axi0_read.tcl"
CPM_AXI1_READ = "if_cpm_ps_axi1_read.tcl"
CPM_PCIe_READ = "ps_cpm_pcie_axi_read.tcl"
PMC_NOC_AXI_READ = "ps_pmc_noc_axi_read.tcl"
CONF_DDR_NOC_0_READ = "ddr_noc_0.tcl"
CONF_DDR_NOC_1_READ = "ddr_noc_1.tcl"
CONF_DDR_NOC_2_READ = "ddr_noc_2.tcl"
CONF_DDR_NOC_3_READ = "ddr_noc_3.tcl"
CONF_DC_PERF_READ = "DC_PERF_config.tcl"
CONF_APM_READ = "configAPM.tcl"
AMS_READ = "readams.tcl"

READ_DEVICE_DNA = "readdevicedna.tcl"
fabid_lut = "NTPT"
fab_lot_lut = "0123456789ABCDEFGHKMNPQRSTUVWXYZ"
SysAIWirelessIO = "log_plnx.txt"

ConfigAWS = "configaws.tcl"
ReadAWS = "readaws.tcl"

AWS_lookup = {"0xF1271040":"VCCAUX","0xF1271044":"VCCAUX_PMC","0xF1271048":"VCCAUX_SYSMON","0xF127104C":"VCCINT","0xF1271050":"VCC_BATT","0xF1271054":"VCC_PMC","0xF1271058":"VCC_PSFP","0xF127105C":"VCC_PSLP","0xF1271060":"VCC_RAM","0xF1271064":"VCC_SOC",
"0xF1271340":"VCCAUX","0xF1271344":"VCCAUX_PMC","0xF1271348":"VCCAUX_SYSMON","0xF127134C":"VCCINT","0xF1271350":"VCC_BATT","0xF1271354":"VCC_PMC","0xF1271358":"VCC_PSFP","0xF127135C":"VCC_PSLP","0xF1271360":"VCC_RAM","0xF1271364":"VCC_SOC",
"0xF1271640":"VCCAUX","0xF1271644":"VCCAUX_PMC","0xF1271648":"VCCAUX_SYSMON","0xF127164C":"VCCINT","0xF1271650":"VCC_BATT","0xF1271654":"VCC_PMC","0xF1271658":"VCC_PSFP","0xF127165C":"VCC_PSLP","0xF1271660":"VCC_RAM","0xF1271664":"VCC_SOC"}
