/**
@license @nocompile
Copyright (c) 2018 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
(function(){/*

Copyright (c) 2016 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
'use strict';var n;function aa(a){var b=0;return function(){return b<a.length?{done:!1,value:a[b++]}:{done:!0}}}function p(a){var b="undefined"!=typeof Symbol&&Symbol.iterator&&a[Symbol.iterator];return b?b.call(a):{next:aa(a)}}function q(a){if(!(a instanceof Array)){a=p(a);for(var b,c=[];!(b=a.next()).done;)c.push(b.value);a=c}return a}
function ba(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var b=0;b<a.length;++b){var c=a[b];if(c&&c.Math==Math)return c}throw Error("Cannot find global object");}var ca=ba(this);function da(){}da.prototype.toJSON=function(){return{}};function t(a){a.__shady||(a.__shady=new da);return a.__shady}function v(a){return a&&a.__shady};var w=window.ShadyDOM||{};w.xa=!(!Element.prototype.attachShadow||!Node.prototype.getRootNode);var ea=Object.getOwnPropertyDescriptor(Node.prototype,"firstChild");w.j=!!(ea&&ea.configurable&&ea.get);w.Z=w.force||!w.xa;w.s=w.noPatch||!1;w.L=w.preferPerformance;w.ba="on-demand"===w.s;var fa;var ha=w.querySelectorImplementation;fa=-1<["native","selectorEngine"].indexOf(ha)?ha:void 0;w.Ka=fa;w.la=navigator.userAgent.match("Trident");
function ia(){return Document.prototype.msElementsFromPoint?"msElementsFromPoint":"elementsFromPoint"}function x(a){return(a=v(a))&&void 0!==a.firstChild}function y(a){return a instanceof ShadowRoot}function ja(a){return(a=(a=v(a))&&a.root)&&ka(a)}var z=Element.prototype,la=z.matches||z.matchesSelector||z.mozMatchesSelector||z.msMatchesSelector||z.oMatchesSelector||z.webkitMatchesSelector,ma=document.createTextNode(""),na=0,oa=[];
(new MutationObserver(function(){for(;oa.length;)try{oa.shift()()}catch(a){throw ma.textContent=na++,a;}})).observe(ma,{characterData:!0});function pa(a){oa.push(a);ma.textContent=na++}var qa=document.contains?function(a,b){return a.__shady_native_contains(b)}:function(a,b){return a===b||a.documentElement&&a.documentElement.__shady_native_contains(b)};function ra(a,b){for(;b;){if(b==a)return!0;b=b.__shady_parentNode}return!1}
function sa(a){for(var b=a.length-1;0<=b;b--){var c=a[b],d=c.getAttribute("id")||c.getAttribute("name");d&&"length"!==d&&isNaN(d)&&(a[d]=c)}a.item=function(e){return a[e]};a.namedItem=function(e){if("length"!==e&&isNaN(e)&&a[e])return a[e];for(var f=p(a),g=f.next();!g.done;g=f.next())if(g=g.value,(g.getAttribute("id")||g.getAttribute("name"))==e)return g;return null};return a}function ta(a){var b=[];for(a=a.__shady_native_firstChild;a;a=a.__shady_native_nextSibling)b.push(a);return b}
function ua(a){var b=[];for(a=a.__shady_firstChild;a;a=a.__shady_nextSibling)b.push(a);return b}function va(a,b,c){c.configurable=!0;if(c.value)a[b]=c.value;else try{Object.defineProperty(a,b,c)}catch(d){}}function A(a,b,c,d){c=void 0===c?"":c;for(var e in b)d&&0<=d.indexOf(e)||va(a,c+e,b[e])}function wa(a,b){for(var c in b)c in a&&va(a,c,b[c])}function B(a){var b={};Object.getOwnPropertyNames(a).forEach(function(c){b[c]=Object.getOwnPropertyDescriptor(a,c)});return b}
function xa(a,b){for(var c=Object.getOwnPropertyNames(b),d=0,e;d<c.length;d++)e=c[d],a[e]=b[e]}function ya(a){return a instanceof Node?a:document.createTextNode(""+a)}function C(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];if(1===b.length)return ya(b[0]);c=document.createDocumentFragment();b=p(b);for(var d=b.next();!d.done;d=b.next())c.appendChild(ya(d.value));return c}
function za(a){var b;for(b=void 0===b?1:b;0<b;b--)a=a.reduce(function(c,d){Array.isArray(d)?c.push.apply(c,q(d)):c.push(d);return c},[]);return a}function Aa(a){var b=[],c=new Set;a=p(a);for(var d=a.next();!d.done;d=a.next())d=d.value,c.has(d)||(b.push(d),c.add(d));return b};var Ba=[],Ca;function Da(a){Ca||(Ca=!0,pa(Ea));Ba.push(a)}function Ea(){Ca=!1;for(var a=!!Ba.length;Ba.length;)Ba.shift()();return a}Ea.list=Ba;function Fa(){this.g=!1;this.addedNodes=[];this.removedNodes=[];this.R=new Set}function Ga(a){a.g||(a.g=!0,pa(function(){a.flush()}))}Fa.prototype.flush=function(){if(this.g){this.g=!1;var a=this.takeRecords();a.length&&this.R.forEach(function(b){b(a)})}};Fa.prototype.takeRecords=function(){if(this.addedNodes.length||this.removedNodes.length){var a=[{addedNodes:this.addedNodes,removedNodes:this.removedNodes}];this.addedNodes=[];this.removedNodes=[];return a}return[]};
function Ha(a,b){var c=t(a);c.K||(c.K=new Fa);c.K.R.add(b);var d=c.K;return{pa:b,ra:d,qa:a,takeRecords:function(){return d.takeRecords()}}}function Ia(a){var b=a&&a.ra;b&&(b.R.delete(a.pa),b.R.size||(t(a.qa).K=null))}
function Ja(a,b){var c=b.getRootNode();return a.map(function(d){var e=c===d.target.getRootNode();if(e&&d.addedNodes){if(e=[].slice.call(d.addedNodes).filter(function(f){return c===f.getRootNode()}),e.length)return d=Object.create(d),Object.defineProperty(d,"addedNodes",{value:e,configurable:!0}),d}else if(e)return d}).filter(function(d){return d})};var Ka=/[&\u00A0"]/g,La=/[&\u00A0<>]/g;function Ma(a){switch(a){case "&":return"&amp;";case "<":return"&lt;";case ">":return"&gt;";case '"':return"&quot;";case "\u00a0":return"&nbsp;"}}function Na(a){for(var b={},c=0;c<a.length;c++)b[a[c]]=!0;return b}var Oa=Na("area base br col command embed hr img input keygen link meta param source track wbr".split(" ")),Qa=Na("style script xmp iframe noembed noframes plaintext noscript".split(" "));
function Ra(a,b){"template"===a.localName&&(a=a.content);for(var c="",d=b?b(a):a.childNodes,e=0,f=d.length,g=void 0;e<f&&(g=d[e]);e++){a:{var h=g;var l=a,k=b;switch(h.nodeType){case Node.ELEMENT_NODE:l=h.localName;for(var m="<"+l,r=h.attributes,u=0,N;N=r[u];u++)m+=" "+N.name+'="'+N.value.replace(Ka,Ma)+'"';m+=">";h=Oa[l]?m:m+Ra(h,k)+"</"+l+">";break a;case Node.TEXT_NODE:h=h.data;h=l&&Qa[l.localName]?h:h.replace(La,Ma);break a;case Node.COMMENT_NODE:h="\x3c!--"+h.data+"--\x3e";break a;default:throw window.console.error(h),
Error("not implemented");}}c+=h}return c};var Sa=w.j,Ta={querySelector:function(a){return this.__shady_native_querySelector(a)},querySelectorAll:function(a){return this.__shady_native_querySelectorAll(a)}},Ua={};function Va(a){Ua[a]=function(b){return b["__shady_native_"+a]}}function Wa(a,b){A(a,b,"__shady_native_");for(var c in b)Va(c)}function D(a,b){b=void 0===b?[]:b;for(var c=0;c<b.length;c++){var d=b[c],e=Object.getOwnPropertyDescriptor(a,d);e&&(Object.defineProperty(a,"__shady_native_"+d,e),e.value?Ta[d]||(Ta[d]=e.value):Va(d))}}
var E=document.createTreeWalker(document,NodeFilter.SHOW_ALL,null,!1),F=document.createTreeWalker(document,NodeFilter.SHOW_ELEMENT,null,!1),Xa=document.implementation.createHTMLDocument("inert");function Ya(a){for(var b;b=a.__shady_native_firstChild;)a.__shady_native_removeChild(b)}var Za=["firstElementChild","lastElementChild","children","childElementCount"],$a=["querySelector","querySelectorAll","append","prepend","replaceChildren"];
function ab(){var a=["dispatchEvent","addEventListener","removeEventListener"];window.EventTarget?(D(window.EventTarget.prototype,a),void 0===window.__shady_native_addEventListener&&D(Window.prototype,a)):(D(Node.prototype,a),D(Window.prototype,a),D(XMLHttpRequest.prototype,a));Sa?D(Node.prototype,"parentNode firstChild lastChild previousSibling nextSibling childNodes parentElement textContent".split(" ")):Wa(Node.prototype,{parentNode:{get:function(){E.currentNode=this;return E.parentNode()}},firstChild:{get:function(){E.currentNode=
this;return E.firstChild()}},lastChild:{get:function(){E.currentNode=this;return E.lastChild()}},previousSibling:{get:function(){E.currentNode=this;return E.previousSibling()}},nextSibling:{get:function(){E.currentNode=this;return E.nextSibling()}},childNodes:{get:function(){var b=[];E.currentNode=this;for(var c=E.firstChild();c;)b.push(c),c=E.nextSibling();return b}},parentElement:{get:function(){F.currentNode=this;return F.parentNode()}},textContent:{get:function(){switch(this.nodeType){case Node.ELEMENT_NODE:case Node.DOCUMENT_FRAGMENT_NODE:for(var b=
document.createTreeWalker(this,NodeFilter.SHOW_TEXT,null,!1),c="",d;d=b.nextNode();)c+=d.nodeValue;return c;default:return this.nodeValue}},set:function(b){if("undefined"===typeof b||null===b)b="";switch(this.nodeType){case Node.ELEMENT_NODE:case Node.DOCUMENT_FRAGMENT_NODE:Ya(this);(0<b.length||this.nodeType===Node.ELEMENT_NODE)&&this.__shady_native_insertBefore(document.createTextNode(b),void 0);break;default:this.nodeValue=b}}}});D(Node.prototype,"appendChild insertBefore removeChild replaceChild cloneNode contains".split(" "));
D(HTMLElement.prototype,["parentElement","contains"]);a={firstElementChild:{get:function(){F.currentNode=this;return F.firstChild()}},lastElementChild:{get:function(){F.currentNode=this;return F.lastChild()}},children:{get:function(){var b=[];F.currentNode=this;for(var c=F.firstChild();c;)b.push(c),c=F.nextSibling();return sa(b)}},childElementCount:{get:function(){return this.children?this.children.length:0}}};Sa?(D(Element.prototype,Za),D(Element.prototype,["previousElementSibling","nextElementSibling",
"innerHTML","className"]),D(HTMLElement.prototype,["children","innerHTML","className"])):(Wa(Element.prototype,a),Wa(Element.prototype,{previousElementSibling:{get:function(){F.currentNode=this;return F.previousSibling()}},nextElementSibling:{get:function(){F.currentNode=this;return F.nextSibling()}},innerHTML:{get:function(){return Ra(this,ta)},set:function(b){var c="template"===this.localName?this.content:this;Ya(c);var d=this.localName||"div";d=this.namespaceURI&&this.namespaceURI!==Xa.namespaceURI?
Xa.createElementNS(this.namespaceURI,d):Xa.createElement(d);d.innerHTML=b;for(b="template"===this.localName?d.content:d;d=b.__shady_native_firstChild;)c.__shady_native_insertBefore(d,void 0)}},className:{get:function(){return this.getAttribute("class")||""},set:function(b){this.setAttribute("class",b)}}}));D(Element.prototype,"setAttribute getAttribute hasAttribute removeAttribute toggleAttribute focus blur".split(" "));D(Element.prototype,$a);D(HTMLElement.prototype,["focus","blur"]);window.HTMLTemplateElement&&
D(window.HTMLTemplateElement.prototype,["innerHTML"]);Sa?D(DocumentFragment.prototype,Za):Wa(DocumentFragment.prototype,a);D(DocumentFragment.prototype,$a);Sa?(D(Document.prototype,Za),D(Document.prototype,["activeElement"])):Wa(Document.prototype,a);D(Document.prototype,["importNode","getElementById","elementFromPoint",ia()]);D(Document.prototype,$a)};var bb=B({get childNodes(){return this.__shady_childNodes},get firstChild(){return this.__shady_firstChild},get lastChild(){return this.__shady_lastChild},get childElementCount(){return this.__shady_childElementCount},get children(){return this.__shady_children},get firstElementChild(){return this.__shady_firstElementChild},get lastElementChild(){return this.__shady_lastElementChild},get shadowRoot(){return this.__shady_shadowRoot}}),cb=B({get textContent(){return this.__shady_textContent},set textContent(a){this.__shady_textContent=
a},get innerHTML(){return this.__shady_innerHTML},set innerHTML(a){this.__shady_innerHTML=a}}),db=B({get parentElement(){return this.__shady_parentElement},get parentNode(){return this.__shady_parentNode},get nextSibling(){return this.__shady_nextSibling},get previousSibling(){return this.__shady_previousSibling},get nextElementSibling(){return this.__shady_nextElementSibling},get previousElementSibling(){return this.__shady_previousElementSibling},get className(){return this.__shady_className},set className(a){this.__shady_className=
a}});function eb(a){for(var b in a){var c=a[b];c&&(c.enumerable=!1)}}eb(bb);eb(cb);eb(db);var fb=w.j||!0===w.s,gb=fb?function(){}:function(a){var b=t(a);b.na||(b.na=!0,wa(a,db))},hb=fb?function(){}:function(a){var b=t(a);b.ma||(b.ma=!0,wa(a,bb),window.customElements&&window.customElements.polyfillWrapFlushCallback&&!w.s||wa(a,cb))};var ib="__eventWrappers"+Date.now(),jb=function(){var a=Object.getOwnPropertyDescriptor(Event.prototype,"composed");return a?function(b){return a.get.call(b)}:null}(),kb=function(){function a(){}var b=!1,c={get capture(){b=!0;return!1}};window.addEventListener("test",a,c);window.removeEventListener("test",a,c);return b}();function lb(a){if(null===a||"object"!==typeof a&&"function"!==typeof a){var b=!!a;var c=!1}else{b=!!a.capture;c=!!a.once;var d=a.F}return{ja:d,capture:b,once:c,ia:kb?a:b}}
var mb={blur:!0,focus:!0,focusin:!0,focusout:!0,click:!0,dblclick:!0,mousedown:!0,mouseenter:!0,mouseleave:!0,mousemove:!0,mouseout:!0,mouseover:!0,mouseup:!0,wheel:!0,beforeinput:!0,input:!0,keydown:!0,keyup:!0,compositionstart:!0,compositionupdate:!0,compositionend:!0,touchstart:!0,touchend:!0,touchmove:!0,touchcancel:!0,pointerover:!0,pointerenter:!0,pointerdown:!0,pointermove:!0,pointerup:!0,pointercancel:!0,pointerout:!0,pointerleave:!0,gotpointercapture:!0,lostpointercapture:!0,dragstart:!0,
drag:!0,dragenter:!0,dragleave:!0,dragover:!0,drop:!0,dragend:!0,DOMActivate:!0,DOMFocusIn:!0,DOMFocusOut:!0,keypress:!0},nb={DOMAttrModified:!0,DOMAttributeNameChanged:!0,DOMCharacterDataModified:!0,DOMElementNameChanged:!0,DOMNodeInserted:!0,DOMNodeInsertedIntoDocument:!0,DOMNodeRemoved:!0,DOMNodeRemovedFromDocument:!0,DOMSubtreeModified:!0};function ob(a){return a instanceof Node?a.__shady_getRootNode():a}
function pb(a,b){var c=[],d=a;for(a=ob(a);d;)c.push(d),d=d.__shady_assignedSlot?d.__shady_assignedSlot:d.nodeType===Node.DOCUMENT_FRAGMENT_NODE&&d.host&&(b||d!==a)?d.host:d.__shady_parentNode;c[c.length-1]===document&&c.push(window);return c}function qb(a){a.__composedPath||(a.__composedPath=pb(a.target,!0));return a.__composedPath}function rb(a,b){if(!y)return a;a=pb(a,!0);for(var c=0,d,e=void 0,f,g=void 0;c<b.length;c++)if(d=b[c],f=ob(d),f!==e&&(g=a.indexOf(f),e=f),!y(f)||-1<g)return d}
var sb={get composed(){void 0===this.__composed&&(jb?this.__composed="focusin"===this.type||"focusout"===this.type||jb(this):!1!==this.isTrusted&&(this.__composed=mb[this.type]));return this.__composed||!1},composedPath:function(){this.__composedPath||(this.__composedPath=pb(this.__target,this.composed));return this.__composedPath},get target(){return rb(this.currentTarget||this.__previousCurrentTarget,this.composedPath())},get relatedTarget(){if(!this.__relatedTarget)return null;this.__relatedTargetComposedPath||
(this.__relatedTargetComposedPath=pb(this.__relatedTarget,!0));return rb(this.currentTarget||this.__previousCurrentTarget,this.__relatedTargetComposedPath)},stopPropagation:function(){Event.prototype.stopPropagation.call(this);this.W=!0},stopImmediatePropagation:function(){Event.prototype.stopImmediatePropagation.call(this);this.W=this.__immediatePropagationStopped=!0}},tb=w.j&&Object.getOwnPropertyDescriptor(Event.prototype,"eventPhase");
tb&&(Object.defineProperty(sb,"eventPhase",{get:function(){return this.currentTarget===this.target?Event.AT_TARGET:this.__shady_native_eventPhase},enumerable:!0,configurable:!0}),Object.defineProperty(sb,"__shady_native_eventPhase",tb));function ub(a){function b(c,d){c=new a(c,d);c.__composed=d&&!!d.composed;return c}b.__proto__=a;b.prototype=a.prototype;return b}var vb={focus:!0,blur:!0};function wb(a){return a.__target!==a.target||a.__relatedTarget!==a.relatedTarget}
function xb(a,b,c){if(c=b.__handlers&&b.__handlers[a.type]&&b.__handlers[a.type][c])for(var d=0,e;(e=c[d])&&(!wb(a)||a.target!==a.relatedTarget)&&(e.call(b,a),!a.__immediatePropagationStopped);d++);}var yb=(new Event("e")).hasOwnProperty("currentTarget");
function zb(a){a=yb?Object.create(a):a;var b=a.composedPath(),c=b.map(function(m){return rb(m,b)}),d=a.bubbles,e=Object.getOwnPropertyDescriptor(a,"currentTarget");Object.defineProperty(a,"currentTarget",{configurable:!0,enumerable:!0,get:function(){return l}});var f=Event.CAPTURING_PHASE,g=Object.getOwnPropertyDescriptor(a,"eventPhase");Object.defineProperty(a,"eventPhase",{configurable:!0,enumerable:!0,get:function(){return f}});try{for(var h=b.length-1;0<=h;h--){var l=b[h];f=l===c[h]?Event.AT_TARGET:
Event.CAPTURING_PHASE;xb(a,l,"capture");if(a.W)return}for(h=0;h<b.length;h++){l=b[h];var k=l===c[h];if(k||d)if(f=k?Event.AT_TARGET:Event.BUBBLING_PHASE,xb(a,l,"bubble"),a.W)break}}finally{yb||(e?Object.defineProperty(a,"currentTarget",e):delete a.currentTarget,g?Object.defineProperty(a,"eventPhase",g):delete a.eventPhase)}}function Ab(a,b,c,d){for(var e=0;e<a.length;e++){var f=a[e],g=f.type,h=f.capture;if(b===f.node&&c===g&&d===h)return e}return-1}
function Bb(a){Ea();return!w.L&&this instanceof Node&&!qa(document,this)?(a.__target||Cb(a,this),zb(a)):this.__shady_native_dispatchEvent(a)}
function Db(a,b,c){var d=this,e=lb(c),f=e.capture,g=e.once,h=e.ja;e=e.ia;if(b){var l=typeof b;if("function"===l||"object"===l)if("object"!==l||b.handleEvent&&"function"===typeof b.handleEvent){if(nb[a])return this.__shady_native_addEventListener(a,b,e);var k=h||this;if(h=b[ib]){if(-1<Ab(h,k,a,f))return}else b[ib]=[];h=function(m){g&&d.__shady_removeEventListener(a,b,c);m.__target||Cb(m);if(k!==d){var r=Object.getOwnPropertyDescriptor(m,"currentTarget");Object.defineProperty(m,"currentTarget",{get:function(){return k},
configurable:!0});var u=Object.getOwnPropertyDescriptor(m,"eventPhase");Object.defineProperty(m,"eventPhase",{configurable:!0,enumerable:!0,get:function(){return f?Event.CAPTURING_PHASE:Event.BUBBLING_PHASE}})}m.__previousCurrentTarget=m.currentTarget;if(!y(k)&&"slot"!==k.localName||-1!=m.composedPath().indexOf(k))if(m.composed||-1<m.composedPath().indexOf(k))if(wb(m)&&m.target===m.relatedTarget)m.eventPhase===Event.BUBBLING_PHASE&&m.stopImmediatePropagation();else if(m.eventPhase===Event.CAPTURING_PHASE||
m.bubbles||m.target===k||k instanceof Window){var N="function"===l?b.call(k,m):b.handleEvent&&b.handleEvent(m);k!==d&&(r?(Object.defineProperty(m,"currentTarget",r),r=null):delete m.currentTarget,u?(Object.defineProperty(m,"eventPhase",u),u=null):delete m.eventPhase);return N}};b[ib].push({node:k,type:a,capture:f,Ia:h});this.__handlers=this.__handlers||{};this.__handlers[a]=this.__handlers[a]||{capture:[],bubble:[]};this.__handlers[a][f?"capture":"bubble"].push(h);vb[a]||this.__shady_native_addEventListener(a,
h,e)}}}function Eb(a,b,c){if(b){var d=lb(c);c=d.capture;var e=d.ja;d=d.ia;if(nb[a])return this.__shady_native_removeEventListener(a,b,d);var f=e||this;e=void 0;var g=null;try{g=b[ib]}catch(h){}g&&(f=Ab(g,f,a,c),-1<f&&(e=g.splice(f,1)[0].Ia,g.length||(b[ib]=void 0)));this.__shady_native_removeEventListener(a,e||b,d);e&&this.__handlers&&this.__handlers[a]&&(a=this.__handlers[a][c?"capture":"bubble"],b=a.indexOf(e),-1<b&&a.splice(b,1))}}
function Fb(){for(var a in vb)window.__shady_native_addEventListener(a,function(b){b.__target||(Cb(b),zb(b))},!0)}var Gb=B(sb);function Cb(a,b){b=void 0===b?a.target:b;a.__target=b;a.__relatedTarget=a.relatedTarget;if(w.j){b=Object.getPrototypeOf(a);if(!b.hasOwnProperty("__shady_patchedProto")){var c=Object.create(b);c.__shady_sourceProto=b;A(c,Gb);b.__shady_patchedProto=c}a.__proto__=b.__shady_patchedProto}else A(a,Gb)}var Hb=ub(Event),Ib=ub(CustomEvent),Jb=ub(MouseEvent);
function Kb(){if(!jb&&Object.getOwnPropertyDescriptor(Event.prototype,"isTrusted")){var a=function(){var b=new MouseEvent("click",{bubbles:!0,cancelable:!0,composed:!0});this.__shady_dispatchEvent(b)};Element.prototype.click?Element.prototype.click=a:HTMLElement.prototype.click&&(HTMLElement.prototype.click=a)}}
var Lb=Object.getOwnPropertyNames(Element.prototype).filter(function(a){return"on"===a.substring(0,2)}),Mb=Object.getOwnPropertyNames(HTMLElement.prototype).filter(function(a){return"on"===a.substring(0,2)});function Nb(a){return{set:function(b){var c=t(this),d=a.substring(2);c.D||(c.D={});c.D[a]&&this.removeEventListener(d,c.D[a]);this.__shady_addEventListener(d,b);c.D[a]=b},get:function(){var b=v(this);return b&&b.D&&b.D[a]},configurable:!0}};function Ob(a,b){return{index:a,M:[],P:b}}
function Pb(a,b,c,d){var e=0,f=0,g=0,h=0,l=Math.min(b-e,d-f);if(0==e&&0==f)a:{for(g=0;g<l;g++)if(a[g]!==c[g])break a;g=l}if(b==a.length&&d==c.length){h=a.length;for(var k=c.length,m=0;m<l-g&&Qb(a[--h],c[--k]);)m++;h=m}e+=g;f+=g;b-=h;d-=h;if(0==b-e&&0==d-f)return[];if(e==b){for(b=Ob(e,0);f<d;)b.M.push(c[f++]);return[b]}if(f==d)return[Ob(e,b-e)];l=e;g=f;d=d-g+1;h=b-l+1;b=Array(d);for(k=0;k<d;k++)b[k]=Array(h),b[k][0]=k;for(k=0;k<h;k++)b[0][k]=k;for(k=1;k<d;k++)for(m=1;m<h;m++)if(a[l+m-1]===c[g+k-1])b[k][m]=
b[k-1][m-1];else{var r=b[k-1][m]+1,u=b[k][m-1]+1;b[k][m]=r<u?r:u}l=b.length-1;g=b[0].length-1;d=b[l][g];for(a=[];0<l||0<g;)0==l?(a.push(2),g--):0==g?(a.push(3),l--):(h=b[l-1][g-1],k=b[l-1][g],m=b[l][g-1],r=k<m?k<h?k:h:m<h?m:h,r==h?(h==d?a.push(0):(a.push(1),d=h),l--,g--):r==k?(a.push(3),l--,d=k):(a.push(2),g--,d=m));a.reverse();b=void 0;l=[];for(g=0;g<a.length;g++)switch(a[g]){case 0:b&&(l.push(b),b=void 0);e++;f++;break;case 1:b||(b=Ob(e,0));b.P++;e++;b.M.push(c[f]);f++;break;case 2:b||(b=Ob(e,0));
b.P++;e++;break;case 3:b||(b=Ob(e,0)),b.M.push(c[f]),f++}b&&l.push(b);return l}function Qb(a,b){return a===b};var Rb=B({dispatchEvent:Bb,addEventListener:Db,removeEventListener:Eb});var Sb=null;function G(){Sb||(Sb=window.ShadyCSS&&window.ShadyCSS.ScopingShim);return Sb||null}function Tb(a,b,c){var d=G();return d&&"class"===b?(d.setElementClass(a,c),!0):!1}function Ub(a,b){var c=G();c&&c.unscopeNode(a,b)}function Vb(a,b){var c=G();if(!c)return!0;if(a.nodeType===Node.DOCUMENT_FRAGMENT_NODE){c=!0;for(a=a.__shady_firstChild;a;a=a.__shady_nextSibling)c=c&&Vb(a,b);return c}return a.nodeType!==Node.ELEMENT_NODE?!0:c.currentScopeForNode(a)===b}
function Wb(a){if(a.nodeType!==Node.ELEMENT_NODE)return"";var b=G();return b?b.currentScopeForNode(a):""}function Xb(a,b){if(a)for(a.nodeType===Node.ELEMENT_NODE&&b(a),a=a.__shady_firstChild;a;a=a.__shady_nextSibling)a.nodeType===Node.ELEMENT_NODE&&Xb(a,b)};var Yb=window.document,Zb=w.L,$b=Object.getOwnPropertyDescriptor(Node.prototype,"isConnected"),ac=$b&&$b.get;function bc(a){for(var b;b=a.__shady_firstChild;)a.__shady_removeChild(b)}function cc(a){var b=v(a);if(b&&void 0!==b.V)for(b=a.__shady_firstChild;b;b=b.__shady_nextSibling)cc(b);if(a=v(a))a.V=void 0}function dc(a){var b=a;if(a&&"slot"===a.localName){var c=v(a);(c=c&&c.H)&&(b=c.length?c[0]:dc(a.__shady_nextSibling))}return b}
function ec(a,b,c){if(a=(a=v(a))&&a.K){if(b)if(b.nodeType===Node.DOCUMENT_FRAGMENT_NODE)for(var d=0,e=b.childNodes.length;d<e;d++)a.addedNodes.push(b.childNodes[d]);else a.addedNodes.push(b);c&&a.removedNodes.push(c);Ga(a)}}
var jc=B({get parentNode(){var a=v(this);a=a&&a.parentNode;return void 0!==a?a:this.__shady_native_parentNode},get firstChild(){var a=v(this);a=a&&a.firstChild;return void 0!==a?a:this.__shady_native_firstChild},get lastChild(){var a=v(this);a=a&&a.lastChild;return void 0!==a?a:this.__shady_native_lastChild},get nextSibling(){var a=v(this);a=a&&a.nextSibling;return void 0!==a?a:this.__shady_native_nextSibling},get previousSibling(){var a=v(this);a=a&&a.previousSibling;return void 0!==a?a:this.__shady_native_previousSibling},
get childNodes(){if(x(this)){var a=v(this);if(!a.childNodes){a.childNodes=[];for(var b=this.__shady_firstChild;b;b=b.__shady_nextSibling)a.childNodes.push(b)}var c=a.childNodes}else c=this.__shady_native_childNodes;c.item=function(d){return c[d]};return c},get parentElement(){var a=v(this);(a=a&&a.parentNode)&&a.nodeType!==Node.ELEMENT_NODE&&(a=null);return void 0!==a?a:this.__shady_native_parentElement},get isConnected(){if(ac&&ac.call(this))return!0;if(this.nodeType==Node.DOCUMENT_FRAGMENT_NODE)return!1;
var a=this.ownerDocument;if(null===a||qa(a,this))return!0;for(a=this;a&&!(a instanceof Document);)a=a.__shady_parentNode||(y(a)?a.host:void 0);return!!(a&&a instanceof Document)},get textContent(){if(x(this)){for(var a=[],b=this.__shady_firstChild;b;b=b.__shady_nextSibling)b.nodeType!==Node.COMMENT_NODE&&a.push(b.__shady_textContent);return a.join("")}return this.__shady_native_textContent},set textContent(a){if("undefined"===typeof a||null===a)a="";switch(this.nodeType){case Node.ELEMENT_NODE:case Node.DOCUMENT_FRAGMENT_NODE:if(!x(this)&&
w.j){var b=this.__shady_firstChild;(b!=this.__shady_lastChild||b&&b.nodeType!=Node.TEXT_NODE)&&bc(this);this.__shady_native_textContent=a}else bc(this),(0<a.length||this.nodeType===Node.ELEMENT_NODE)&&this.__shady_insertBefore(document.createTextNode(a));break;default:this.nodeValue=a}},insertBefore:function(a,b){if(this.ownerDocument!==Yb&&a.ownerDocument!==Yb)return this.__shady_native_insertBefore(a,b),a;if(a===this)throw Error("Failed to execute 'appendChild' on 'Node': The new child element contains the parent.");
if(b){var c=v(b);c=c&&c.parentNode;if(void 0!==c&&c!==this||void 0===c&&b.__shady_native_parentNode!==this)throw Error("Failed to execute 'insertBefore' on 'Node': The node before which the new node is to be inserted is not a child of this node.");}if(b===a)return a;ec(this,a);var d=[],e=(c=H(this))?c.host.localName:Wb(this),f=a.__shady_parentNode;if(f){var g=Wb(a);var h=!!c||!H(a)||Zb&&void 0!==this.__noInsertionPoint;f.__shady_removeChild(a,h)}f=!0;var l=(!Zb||void 0===a.__noInsertionPoint&&void 0===
this.__noInsertionPoint)&&!Vb(a,e),k=c&&!a.__noInsertionPoint&&(!Zb||a.nodeType===Node.DOCUMENT_FRAGMENT_NODE);if(k||l)l&&(g=g||Wb(a)),Xb(a,function(m){k&&"slot"===m.localName&&d.push(m);if(l){var r=g;G()&&(r&&Ub(m,r),(r=G())&&r.scopeNode(m,e))}});d.length&&(fc(c),c.i.push.apply(c.i,q(d)),I(c));x(this)&&(gc(a,this,b),h=v(this),h.root?(f=!1,ja(this)&&I(h.root)):c&&"slot"===this.localName&&(f=!1,I(c)));f?(c=y(this)?this.host:this,b?(b=dc(b),c.__shady_native_insertBefore(a,b)):c.__shady_native_appendChild(a)):
a.ownerDocument!==this.ownerDocument&&this.ownerDocument.adoptNode(a);return a},appendChild:function(a){if(this!=a||!y(a))return this.__shady_insertBefore(a)},removeChild:function(a,b){b=void 0===b?!1:b;if(this.ownerDocument!==Yb)return this.__shady_native_removeChild(a);if(a.__shady_parentNode!==this)throw Error("The node to be removed is not a child of this node: "+a);ec(this,null,a);var c=H(a),d=c&&hc(c,a),e=v(this);if(x(this)&&(ic(a,this),ja(this))){I(e.root);var f=!0}if(G()&&!b&&c&&a.nodeType!==
Node.TEXT_NODE){var g=Wb(a);Xb(a,function(h){Ub(h,g)})}cc(a);c&&((b="slot"===this.localName)&&(f=!0),(d||b)&&I(c));f||(f=y(this)?this.host:this,(!e.root&&"slot"!==a.localName||f===a.__shady_native_parentNode)&&f.__shady_native_removeChild(a));return a},replaceChild:function(a,b){this.__shady_insertBefore(a,b);this.__shady_removeChild(b);return a},cloneNode:function(a){if("template"==this.localName)return this.__shady_native_cloneNode(a);var b=this.__shady_native_cloneNode(!1);if(a&&b.nodeType!==Node.ATTRIBUTE_NODE){a=
this.__shady_firstChild;for(var c;a;a=a.__shady_nextSibling)c=a.__shady_cloneNode(!0),b.__shady_appendChild(c)}return b},getRootNode:function(a){if(this&&this.nodeType){var b=t(this),c=b.V;void 0===c&&(y(this)?(c=this,b.V=c):(c=(c=this.__shady_parentNode)?c.__shady_getRootNode(a):this,document.documentElement.__shady_native_contains(this)&&(b.V=c)));return c}},contains:function(a){return ra(this,a)}});var lc=B({get assignedSlot(){var a=this.__shady_parentNode;(a=a&&a.__shady_shadowRoot)&&kc(a);return(a=v(this))&&a.assignedSlot||null}});/*

 Copyright (c) 2022 The Polymer Project Authors
 SPDX-License-Identifier: BSD-3-Clause
*/
var mc=new Map;[["(",{end:")",U:!0}],["[",{end:"]",U:!0}],['"',{end:'"',U:!1}],["'",{end:"'",U:!1}]].forEach(function(a){var b=p(a);a=b.next().value;b=b.next().value;mc.set(a,b)});function nc(a,b,c,d){for(d=void 0===d?!0:d;b<a.length;b++)if("\\"===a[b]&&b<a.length-1&&"\n"!==a[b+1])b++;else{if(-1!==c.indexOf(a[b]))return b;if(d&&mc.has(a[b])){var e=mc.get(a[b]);b=nc(a,b+1,[e.end],e.U)}}return a.length}
function oc(a){function b(){if(0<d.length){for(;" "===d[d.length-1];)d.pop();c.push({fa:d.filter(function(l,k){return 0===k%2}),ua:d.filter(function(l,k){return 1===k%2})});d.length=0}}for(var c=[],d=[],e=0;e<a.length;){var f=d[d.length-1],g=nc(a,e,[","," ",">","+","~"]),h=g===e?a[e]:a.substring(e,g);if(","===h)b();else if(-1===[void 0," ",">","+","~"].indexOf(f)||" "!==h)" "===f&&-1!==[">","+","~"].indexOf(h)?d[d.length-1]=h:d.push(h);e=g+(g===e?1:0)}b();return c};function pc(a,b,c){var d=[];qc(a,b,c,d);return d}function qc(a,b,c,d){for(a=a.__shady_firstChild;a;a=a.__shady_nextSibling){var e;if(e=a.nodeType===Node.ELEMENT_NODE){e=a;var f=b,g=c,h=d,l=f(e);l&&h.push(e);g&&g(l)?e=l:(qc(e,f,g,h),e=void 0)}if(e)break}}
var rc={get firstElementChild(){var a=v(this);if(a&&void 0!==a.firstChild){for(a=this.__shady_firstChild;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.__shady_nextSibling;return a}return this.__shady_native_firstElementChild},get lastElementChild(){var a=v(this);if(a&&void 0!==a.lastChild){for(a=this.__shady_lastChild;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.__shady_previousSibling;return a}return this.__shady_native_lastElementChild},get children(){return x(this)?sa(Array.prototype.filter.call(ua(this),function(a){return a.nodeType===
Node.ELEMENT_NODE})):this.__shady_native_children},get childElementCount(){var a=this.__shady_children;return a?a.length:0}},J=B((rc.append=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];this.__shady_insertBefore(C.apply(null,q(b)),null)},rc.prepend=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];this.__shady_insertBefore(C.apply(null,q(b)),this.__shady_firstChild)},rc.replaceChildren=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];
for(;null!==(c=this.__shady_firstChild);)this.__shady_removeChild(c);this.__shady_insertBefore(C.apply(null,q(b)),null)},rc));
function sc(a,b){function c(e,f){return(e===a||-1===f.indexOf(":scope"))&&la.call(e,f)}var d=oc(b);if(1>d.length)return[];for(b=za(pc(a,function(){return!0}).map(function(e){return za(d.map(function(f){var g=f.fa,h=g.length-1;return c(e,g[h])?{target:e,I:f,J:e,index:h}:[]}))}));b.some(function(e){return 0<e.index});)b=za(b.map(function(e){if(0>=e.index)return e;var f=e.target,g=e.J,h=e.I;e=e.index-1;var l=h.ua[e],k=h.fa[e];if(" "===l){l=[];for(g=g.__shady_parentElement;g;g=g.__shady_parentElement)c(g,
k)&&l.push({target:f,I:h,J:g,index:e});return l}if(">"===l)return g=g.__shady_parentElement,c(g,k)?{target:f,I:h,J:g,index:e}:[];if("+"===l)return(g=g.__shady_previousElementSibling)&&c(g,k)?{target:f,I:h,J:g,index:e}:[];if("~"===l){l=[];for(g=g.__shady_previousElementSibling;g;g=g.__shady_previousElementSibling)c(g,k)&&l.push({target:f,I:h,J:g,index:e});return l}throw Error("Unrecognized combinator: '"+l+"'.");}));return Aa(b.map(function(e){return e.target}))}
var K=w.querySelectorImplementation,tc=B({querySelector:function(a){if("native"===K){var b=Array.prototype.slice.call((this instanceof ShadowRoot?this.host:this).__shady_native_querySelectorAll(a)),c=this.__shady_getRootNode();b=p(b);for(var d=b.next();!d.done;d=b.next())if(d=d.value,d.__shady_getRootNode()==c)return d;return null}if("selectorEngine"===K)return sc(this,a)[0]||null;if(void 0===K)return pc(this,function(e){return la.call(e,a)},function(e){return!!e})[0]||null;throw Error("Unrecognized value of ShadyDOM.querySelectorImplementation: '"+
(K+"'"));},querySelectorAll:function(a,b){if(b||"native"===K){b=Array.prototype.slice.call((this instanceof ShadowRoot?this.host:this).__shady_native_querySelectorAll(a));var c=this.__shady_getRootNode();return sa(b.filter(function(d){return d.__shady_getRootNode()==c}))}if("selectorEngine"===K)return sa(sc(this,a));if(void 0===K)return sa(pc(this,function(d){return la.call(d,a)}));throw Error("Unrecognized value of ShadyDOM.querySelectorImplementation: '"+(K+"'"));}}),uc=w.L&&!w.s?xa({},J):J;
xa(J,tc);/*

Copyright (c) 2020 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
var vc=B({after:function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];c=this.__shady_parentNode;if(null!==c){var d=this.__shady_nextSibling;c.__shady_insertBefore(C.apply(null,q(b)),d)}},before:function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];c=this.__shady_parentNode;null!==c&&c.__shady_insertBefore(C.apply(null,q(b)),this)},remove:function(){var a=this.__shady_parentNode;null!==a&&a.__shady_removeChild(this)},replaceWith:function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=
arguments[c];c=this.__shady_parentNode;if(null!==c){var d=this.__shady_nextSibling;c.__shady_removeChild(this);c.__shady_insertBefore(C.apply(null,q(b)),d)}}});var wc=window.document;function xc(a,b){if("slot"===b)a=a.__shady_parentNode,ja(a)&&I(v(a).root);else if("slot"===a.localName&&"name"===b&&(b=H(a))){if(b.g){yc(b);var c=a.oa,d=zc(a);if(d!==c){c=b.h[c];var e=c.indexOf(a);0<=e&&c.splice(e,1);c=b.h[d]||(b.h[d]=[]);c.push(a);1<c.length&&(b.h[d]=Ac(c))}}I(b)}}
var Bc=B({get previousElementSibling(){var a=v(this);if(a&&void 0!==a.previousSibling){for(a=this.__shady_previousSibling;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.__shady_previousSibling;return a}return this.__shady_native_previousElementSibling},get nextElementSibling(){var a=v(this);if(a&&void 0!==a.nextSibling){for(a=this.__shady_nextSibling;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.__shady_nextSibling;return a}return this.__shady_native_nextElementSibling},get slot(){return this.getAttribute("slot")},
set slot(a){this.__shady_setAttribute("slot",a)},get className(){return this.getAttribute("class")||""},set className(a){this.__shady_setAttribute("class",a)},setAttribute:function(a,b){this.ownerDocument!==wc?this.__shady_native_setAttribute(a,b):Tb(this,a,b)||(this.__shady_native_setAttribute(a,b),xc(this,a))},removeAttribute:function(a){this.ownerDocument!==wc?this.__shady_native_removeAttribute(a):Tb(this,a,"")?""===this.getAttribute(a)&&this.__shady_native_removeAttribute(a):(this.__shady_native_removeAttribute(a),
xc(this,a))},toggleAttribute:function(a,b){if(this.ownerDocument!==wc)return this.__shady_native_toggleAttribute(a,b);if(!Tb(this,a,""))return b=this.__shady_native_toggleAttribute(a,b),xc(this,a),b;if(""===this.getAttribute(a)&&!b)return this.__shady_native_toggleAttribute(a,b)}});w.L||Lb.forEach(function(a){Bc[a]=Nb(a)});
var Gc=B({attachShadow:function(a){if(!this)throw Error("Must provide a host.");if(!a)throw Error("Not enough arguments.");if(a.shadyUpgradeFragment&&!w.la){var b=a.shadyUpgradeFragment;b.__proto__=ShadowRoot.prototype;Cc(b,this,a);Dc(b,b);a=b.__noInsertionPoint?null:b.querySelectorAll("slot");b.__noInsertionPoint=void 0;if(a&&a.length){var c=b;fc(c);c.i.push.apply(c.i,q(a));I(b)}b.host.__shady_native_appendChild(b)}else b=new Ec(Fc,this,a);return this.__CE_shadowRoot=b},get shadowRoot(){var a=v(this);
return a&&a.Ba||null}});xa(Bc,Gc);var Hc=document.implementation.createHTMLDocument("inert"),Ic=B({get innerHTML(){return x(this)?Ra("template"===this.localName?this.content:this,ua):this.__shady_native_innerHTML},set innerHTML(a){if("template"===this.localName)this.__shady_native_innerHTML=a;else{bc(this);var b=this.localName||"div";b=this.namespaceURI&&this.namespaceURI!==Hc.namespaceURI?Hc.createElementNS(this.namespaceURI,b):Hc.createElement(b);for(w.j?b.__shady_native_innerHTML=a:b.innerHTML=a;a=b.__shady_firstChild;)this.__shady_insertBefore(a)}}});var Jc=B({blur:function(){var a=v(this);(a=(a=a&&a.root)&&a.activeElement)?a.__shady_blur():this.__shady_native_blur()}});w.L||Mb.forEach(function(a){Jc[a]=Nb(a)});var Kc=B({assignedNodes:function(a){if("slot"===this.localName){var b=this.__shady_getRootNode();b&&y(b)&&kc(b);return(b=v(this))?(a&&a.flatten?b.H:b.assignedNodes)||[]:[]}},addEventListener:function(a,b,c){if("slot"!==this.localName||"slotchange"===a)Db.call(this,a,b,c);else{"object"!==typeof c&&(c={capture:!!c});var d=this.__shady_parentNode;if(!d)throw Error("ShadyDOM cannot attach event to slot unless it has a `parentNode`");c.F=this;d.__shady_addEventListener(a,b,c)}},removeEventListener:function(a,
b,c){if("slot"!==this.localName||"slotchange"===a)Eb.call(this,a,b,c);else{"object"!==typeof c&&(c={capture:!!c});var d=this.__shady_parentNode;if(!d)throw Error("ShadyDOM cannot attach event to slot unless it has a `parentNode`");c.F=this;d.__shady_removeEventListener(a,b,c)}}});var Lc=B({getElementById:function(a){return""===a?null:pc(this,function(b){return b.id==a},function(b){return!!b})[0]||null}});function Mc(a,b){for(var c;b&&!a.has(c=b.__shady_getRootNode());)b=c.host;return b}function Nc(a){var b=new Set;for(b.add(a);y(a)&&a.host;)a=a.host.__shady_getRootNode(),b.add(a);return b}
var Oc="__shady_native_"+ia(),Pc=B({get activeElement(){var a=w.j?document.__shady_native_activeElement:document.activeElement;if(!a||!a.nodeType)return null;var b=!!y(this);if(!(this===document||b&&this.host!==a&&this.host.__shady_native_contains(a)))return null;for(b=H(a);b&&b!==this;)a=b.host,b=H(a);return this===document?b?null:a:b===this?a:null},elementsFromPoint:function(a,b){a=document[Oc](a,b);if(this===document&&w.useNativeDocumentEFP)return a;a=[].slice.call(a);b=Nc(this);for(var c=new Set,
d=0;d<a.length;d++)c.add(Mc(b,a[d]));var e=[];c.forEach(function(f){return e.push(f)});return e},elementFromPoint:function(a,b){return this===document&&w.useNativeDocumentEFP?this.__shady_native_elementFromPoint(a,b):this.__shady_elementsFromPoint(a,b)[0]||null}});var Qc=window.document,Rc=B({importNode:function(a,b){if(a.ownerDocument!==Qc||"template"===a.localName)return this.__shady_native_importNode(a,b);var c=this.__shady_native_importNode(a,!1);if(b)for(a=a.__shady_firstChild;a;a=a.__shady_nextSibling)b=this.__shady_importNode(a,!0),c.__shady_appendChild(b);return c}});var Sc=B({dispatchEvent:Bb,addEventListener:Db.bind(window),removeEventListener:Eb.bind(window)});var L={};Object.getOwnPropertyDescriptor(HTMLElement.prototype,"parentElement")&&(L.parentElement=jc.parentElement);Object.getOwnPropertyDescriptor(HTMLElement.prototype,"contains")&&(L.contains=jc.contains);Object.getOwnPropertyDescriptor(HTMLElement.prototype,"children")&&(L.children=J.children);Object.getOwnPropertyDescriptor(HTMLElement.prototype,"innerHTML")&&(L.innerHTML=Ic.innerHTML);Object.getOwnPropertyDescriptor(HTMLElement.prototype,"className")&&(L.className=Bc.className);
var M={EventTarget:[Rb],Node:[jc,window.EventTarget?null:Rb],Text:[lc],Comment:[lc],CDATASection:[lc],ProcessingInstruction:[lc],Element:[Bc,J,vc,lc,!w.j||"innerHTML"in Element.prototype?Ic:null,window.HTMLSlotElement?null:Kc],HTMLElement:[Jc,L],HTMLSlotElement:[Kc],DocumentFragment:[uc,Lc],Document:[Rc,uc,Lc,Pc],Window:[Sc],CharacterData:[vc],XMLHttpRequest:[window.EventTarget?null:Rb]},Tc=w.j?null:["innerHTML","textContent"];function O(a,b,c,d){b.forEach(function(e){return a&&e&&A(a,e,c,d)})}
function Uc(a){var b=a?null:Tc,c;for(c in M)O(window[c]&&window[c].prototype,M[c],a,b)}["Text","Comment","CDATASection","ProcessingInstruction"].forEach(function(a){var b=window[a],c=Object.create(b.prototype);c.__shady_protoIsPatched=!0;O(c,M.EventTarget);O(c,M.Node);M[a]&&O(c,M[a]);b.prototype.__shady_patchedProto=c});function Vc(a){a.__shady_protoIsPatched=!0;O(a,M.EventTarget);O(a,M.Node);O(a,M.Element);O(a,M.HTMLElement);O(a,M.HTMLSlotElement);return a};var Wc=w.ba,Xc=w.j;function Yc(a,b){if(Wc&&!a.__shady_protoIsPatched&&!y(a)){var c=Object.getPrototypeOf(a),d=c.hasOwnProperty("__shady_patchedProto")&&c.__shady_patchedProto;d||(d=Object.create(c),Vc(d),c.__shady_patchedProto=d);Object.setPrototypeOf(a,d)}Xc||(1===b?gb(a):2===b&&hb(a))}
function Zc(a,b,c,d){Yc(a,1);d=d||null;var e=t(a),f=d?t(d):null;e.previousSibling=d?f.previousSibling:b.__shady_lastChild;if(f=v(e.previousSibling))f.nextSibling=a;if(f=v(e.nextSibling=d))f.previousSibling=a;e.parentNode=b;d?d===c.firstChild&&(c.firstChild=a):(c.lastChild=a,c.firstChild||(c.firstChild=a));c.childNodes=null}
function gc(a,b,c){Yc(b,2);var d=t(b);void 0!==d.firstChild&&(d.childNodes=null);if(a.nodeType===Node.DOCUMENT_FRAGMENT_NODE)for(a=a.__shady_native_firstChild;a;a=a.__shady_native_nextSibling)Zc(a,b,d,c);else Zc(a,b,d,c)}
function ic(a,b){var c=t(a);b=t(b);a===b.firstChild&&(b.firstChild=c.nextSibling);a===b.lastChild&&(b.lastChild=c.previousSibling);a=c.previousSibling;var d=c.nextSibling;a&&(t(a).nextSibling=d);d&&(t(d).previousSibling=a);c.parentNode=c.previousSibling=c.nextSibling=void 0;void 0!==b.childNodes&&(b.childNodes=null)}
function Dc(a,b){var c=t(a);if(b||void 0===c.firstChild){c.childNodes=null;var d=c.firstChild=a.__shady_native_firstChild;c.lastChild=a.__shady_native_lastChild;Yc(a,2);c=d;for(d=void 0;c;c=c.__shady_native_nextSibling){var e=t(c);e.parentNode=b||a;e.nextSibling=c.__shady_native_nextSibling;e.previousSibling=d||null;d=c;Yc(c,1)}}};var $c=B({addEventListener:function(a,b,c){"object"!==typeof c&&(c={capture:!!c});c.F=c.F||this;this.host.__shady_addEventListener(a,b,c)},removeEventListener:function(a,b,c){"object"!==typeof c&&(c={capture:!!c});c.F=c.F||this;this.host.__shady_removeEventListener(a,b,c)}});function ad(a,b){A(a,$c,b);A(a,Pc,b);A(a,Ic,b);A(a,J,b);w.s&&!b?(A(a,jc,b),A(a,Lc,b)):w.j||(A(a,db),A(a,bb),A(a,cb))};var Fc={},P=w.deferConnectionCallbacks&&"loading"===document.readyState,bd;function cd(a){var b=[];do b.unshift(a);while(a=a.__shady_parentNode);return b}function Ec(a,b,c){if(a!==Fc)throw new TypeError("Illegal constructor");this.g=null;Cc(this,b,c)}
function Cc(a,b,c){a.host=b;a.mode=c&&c.mode;Dc(a.host);b=t(a.host);b.root=a;b.Ba="closed"!==a.mode?a:null;b=t(a);b.firstChild=b.lastChild=b.parentNode=b.nextSibling=b.previousSibling=null;if(w.preferPerformance)for(;b=a.host.__shady_native_firstChild;)a.host.__shady_native_removeChild(b);else I(a)}function I(a){a.G||(a.G=!0,Da(function(){return kc(a)}))}
function kc(a){var b;if(b=a.G){for(var c;a;)a:{a.G&&(c=a),b=a;a=b.host.__shady_getRootNode();if(y(a)&&(b=v(b.host))&&0<b.O)break a;a=void 0}b=c}(c=b)&&c._renderSelf()}
Ec.prototype._renderSelf=function(){var a=P;P=!0;this.G=!1;if(this.g){yc(this);for(var b=0,c;b<this.g.length;b++){c=this.g[b];var d=v(c),e=d.assignedNodes;d.assignedNodes=[];d.H=[];if(d.ea=e)for(d=0;d<e.length;d++){var f=v(e[d]);f.X=f.assignedSlot;f.assignedSlot===c&&(f.assignedSlot=null)}}for(b=this.host.__shady_firstChild;b;b=b.__shady_nextSibling)dd(this,b);for(b=0;b<this.g.length;b++){c=this.g[b];e=v(c);if(!e.assignedNodes.length)for(d=c.__shady_firstChild;d;d=d.__shady_nextSibling)dd(this,d,
c);(d=(d=v(c.__shady_parentNode))&&d.root)&&(ka(d)||d.G)&&d._renderSelf();ed(this,e.H,e.assignedNodes);if(d=e.ea){for(f=0;f<d.length;f++)v(d[f]).X=null;e.ea=null;d.length>e.assignedNodes.length&&(e.Y=!0)}e.Y&&(e.Y=!1,fd(this,c))}c=this.g;b=[];for(e=0;e<c.length;e++)d=c[e].__shady_parentNode,(f=v(d))&&f.root||!(0>b.indexOf(d))||b.push(d);for(c=0;c<b.length;c++){f=b[c];e=f===this?this.host:f;d=[];for(f=f.__shady_firstChild;f;f=f.__shady_nextSibling)if("slot"==f.localName)for(var g=v(f).H,h=0;h<g.length;h++)d.push(g[h]);
else d.push(f);f=ta(e);g=Pb(d,d.length,f,f.length);for(var l=h=0,k=void 0;h<g.length&&(k=g[h]);h++){for(var m=0,r=void 0;m<k.M.length&&(r=k.M[m]);m++)r.__shady_native_parentNode===e&&e.__shady_native_removeChild(r),f.splice(k.index+l,1);l-=k.P}l=0;for(k=void 0;l<g.length&&(k=g[l]);l++)for(h=f[k.index],m=k.index;m<k.index+k.P;m++)r=d[m],e.__shady_native_insertBefore(r,h),f.splice(m,0,r)}}if(!w.preferPerformance&&!this.da)for(b=this.host.__shady_firstChild;b;b=b.__shady_nextSibling)c=v(b),b.__shady_native_parentNode!==
this.host||"slot"!==b.localName&&c.assignedSlot||this.host.__shady_native_removeChild(b);this.da=!0;P=a;bd&&bd()};function dd(a,b,c){var d=t(b),e=d.X;d.X=null;c||(c=(a=a.h[b.__shady_slot||"__catchall"])&&a[0]);c?(t(c).assignedNodes.push(b),d.assignedSlot=c):d.assignedSlot=void 0;e!==d.assignedSlot&&d.assignedSlot&&(t(d.assignedSlot).Y=!0)}function ed(a,b,c){for(var d=0,e=void 0;d<c.length&&(e=c[d]);d++)if("slot"==e.localName){var f=v(e).assignedNodes;f&&f.length&&ed(a,b,f)}else b.push(c[d])}
function fd(a,b){b.__shady_native_dispatchEvent(new Event("slotchange"));b=v(b);b.assignedSlot&&fd(a,b.assignedSlot)}function fc(a){a.i=a.i||[];a.g=a.g||[];a.h=a.h||{}}function yc(a){if(a.i&&a.i.length){for(var b=a.i,c,d=0;d<b.length;d++){var e=b[d];Dc(e);var f=e.__shady_parentNode;Dc(f);f=v(f);f.O=(f.O||0)+1;f=zc(e);a.h[f]?(c=c||{},c[f]=!0,a.h[f].push(e)):a.h[f]=[e];a.g.push(e)}if(c)for(var g in c)a.h[g]=Ac(a.h[g]);a.i=[]}}
function zc(a){var b=a.name||a.getAttribute("name")||"__catchall";return a.oa=b}function Ac(a){return a.sort(function(b,c){b=cd(b);for(var d=cd(c),e=0;e<b.length;e++){c=b[e];var f=d[e];if(c!==f)return b=ua(c.__shady_parentNode),b.indexOf(c)-b.indexOf(f)}})}
function hc(a,b){if(a.g){yc(a);var c=a.h,d;for(d in c)for(var e=c[d],f=0;f<e.length;f++){var g=e[f];if(ra(b,g)){e.splice(f,1);var h=a.g.indexOf(g);0<=h&&(a.g.splice(h,1),(h=v(g.__shady_parentNode))&&h.O&&h.O--);f--;g=v(g);if(h=g.H)for(var l=0;l<h.length;l++){var k=h[l],m=k.__shady_native_parentNode;m&&m.__shady_native_removeChild(k)}g.H=[];g.assignedNodes=[];h=!0}}return h}}function ka(a){yc(a);return!(!a.g||!a.g.length)}
(function(a){a.__proto__=DocumentFragment.prototype;ad(a,"__shady_");ad(a);Object.defineProperties(a,{nodeType:{value:Node.DOCUMENT_FRAGMENT_NODE,configurable:!0},nodeName:{value:"#document-fragment",configurable:!0},nodeValue:{value:null,configurable:!0}});["localName","namespaceURI","prefix"].forEach(function(b){Object.defineProperty(a,b,{value:void 0,configurable:!0})});["ownerDocument","baseURI","isConnected"].forEach(function(b){Object.defineProperty(a,b,{get:function(){return this.host[b]},
configurable:!0})})})(Ec.prototype);
if(window.customElements&&window.customElements.define&&w.Z&&!w.preferPerformance){var gd=new Map;bd=function(){var a=[];gd.forEach(function(d,e){a.push([e,d])});gd.clear();for(var b=0;b<a.length;b++){var c=a[b][0];a[b][1]?c.__shadydom_connectedCallback():c.__shadydom_disconnectedCallback()}};P&&document.addEventListener("readystatechange",function(){P=!1;bd()},{once:!0});var hd=function(a,b,c){var d=0,e="__isConnected"+d++;if(b||c)a.prototype.connectedCallback=a.prototype.__shadydom_connectedCallback=
function(){P?gd.set(this,!0):this[e]||(this[e]=!0,b&&b.call(this))},a.prototype.disconnectedCallback=a.prototype.__shadydom_disconnectedCallback=function(){P?this.isConnected||gd.set(this,!1):this[e]&&(this[e]=!1,c&&c.call(this))};return a},id=window.customElements.define,jd=function(a,b){var c=b.prototype.connectedCallback,d=b.prototype.disconnectedCallback;id.call(window.customElements,a,hd(b,c,d));b.prototype.connectedCallback=c;b.prototype.disconnectedCallback=d};window.customElements.define=
jd;Object.defineProperty(window.CustomElementRegistry.prototype,"define",{value:jd,configurable:!0})}function H(a){a=a.__shady_getRootNode();if(y(a))return a};function Q(a){this.node=a}n=Q.prototype;n.addEventListener=function(a,b,c){return this.node.__shady_addEventListener(a,b,c)};n.removeEventListener=function(a,b,c){return this.node.__shady_removeEventListener(a,b,c)};n.appendChild=function(a){return this.node.__shady_appendChild(a)};n.insertBefore=function(a,b){return this.node.__shady_insertBefore(a,b)};n.removeChild=function(a){return this.node.__shady_removeChild(a)};n.replaceChild=function(a,b){return this.node.__shady_replaceChild(a,b)};
n.cloneNode=function(a){return this.node.__shady_cloneNode(a)};n.getRootNode=function(a){return this.node.__shady_getRootNode(a)};n.contains=function(a){return this.node.__shady_contains(a)};n.dispatchEvent=function(a){return this.node.__shady_dispatchEvent(a)};n.setAttribute=function(a,b){this.node.__shady_setAttribute(a,b)};n.getAttribute=function(a){return this.node.__shady_native_getAttribute(a)};n.removeAttribute=function(a){this.node.__shady_removeAttribute(a)};
n.toggleAttribute=function(a,b){return this.node.__shady_toggleAttribute(a,b)};n.attachShadow=function(a){return this.node.__shady_attachShadow(a)};n.focus=function(){this.node.__shady_native_focus()};n.blur=function(){this.node.__shady_blur()};n.importNode=function(a,b){if(this.node.nodeType===Node.DOCUMENT_NODE)return this.node.__shady_importNode(a,b)};n.getElementById=function(a){if(this.node.nodeType===Node.DOCUMENT_NODE)return this.node.__shady_getElementById(a)};
n.elementsFromPoint=function(a,b){return this.node.__shady_elementsFromPoint(a,b)};n.elementFromPoint=function(a,b){return this.node.__shady_elementFromPoint(a,b)};n.querySelector=function(a){return this.node.__shady_querySelector(a)};n.querySelectorAll=function(a,b){return this.node.__shady_querySelectorAll(a,b)};n.assignedNodes=function(a){if("slot"===this.node.localName)return this.node.__shady_assignedNodes(a)};
n.append=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];return this.node.__shady_append.apply(this.node,q(b))};n.prepend=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];return this.node.__shady_prepend.apply(this.node,q(b))};n.after=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];return this.node.__shady_after.apply(this.node,q(b))};
n.before=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];return this.node.__shady_before.apply(this.node,q(b))};n.remove=function(){return this.node.__shady_remove()};n.replaceWith=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];return this.node.__shady_replaceWith.apply(this.node,q(b))};
ca.Object.defineProperties(Q.prototype,{activeElement:{configurable:!0,enumerable:!0,get:function(){if(y(this.node)||this.node.nodeType===Node.DOCUMENT_NODE)return this.node.__shady_activeElement}},_activeElement:{configurable:!0,enumerable:!0,get:function(){return this.activeElement}},host:{configurable:!0,enumerable:!0,get:function(){if(y(this.node))return this.node.host}},parentNode:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_parentNode}},firstChild:{configurable:!0,
enumerable:!0,get:function(){return this.node.__shady_firstChild}},lastChild:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_lastChild}},nextSibling:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_nextSibling}},previousSibling:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_previousSibling}},childNodes:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_childNodes}},parentElement:{configurable:!0,enumerable:!0,
get:function(){return this.node.__shady_parentElement}},firstElementChild:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_firstElementChild}},lastElementChild:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_lastElementChild}},nextElementSibling:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_nextElementSibling}},previousElementSibling:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_previousElementSibling}},
children:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_children}},childElementCount:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_childElementCount}},shadowRoot:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_shadowRoot}},assignedSlot:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_assignedSlot}},isConnected:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_isConnected}},innerHTML:{configurable:!0,
enumerable:!0,get:function(){return this.node.__shady_innerHTML},set:function(a){this.node.__shady_innerHTML=a}},textContent:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_textContent},set:function(a){this.node.__shady_textContent=a}},slot:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_slot},set:function(a){this.node.__shady_slot=a}},className:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_className},set:function(a){this.node.__shady_className=
a}}});function kd(a){Object.defineProperty(Q.prototype,a,{get:function(){return this.node["__shady_"+a]},set:function(b){this.node["__shady_"+a]=b},configurable:!0})}Lb.forEach(function(a){return kd(a)});Mb.forEach(function(a){return kd(a)});var ld=new WeakMap;function md(a){if(y(a)||a instanceof Q)return a;var b=ld.get(a);b||(b=new Q(a),ld.set(a,b));return b};if(w.Z){var nd=w.j?function(a){return a}:function(a){hb(a);gb(a);return a},ShadyDOM={inUse:w.Z,patch:nd,isShadyRoot:y,enqueue:Da,flush:Ea,flushInitial:function(a){!a.da&&a.G&&kc(a)},settings:w,filterMutations:Ja,observeChildren:Ha,unobserveChildren:Ia,deferConnectionCallbacks:w.deferConnectionCallbacks,preferPerformance:w.preferPerformance,handlesDynamicScoping:!0,wrap:w.s?md:nd,wrapIfNeeded:!0===w.s?md:function(a){return a},Wrapper:Q,composedPath:qb,noPatch:w.s,patchOnDemand:w.ba,nativeMethods:Ta,
nativeTree:Ua,patchElementProto:Vc,querySelectorImplementation:w.querySelectorImplementation};window.ShadyDOM=ShadyDOM;ab();Uc("__shady_");Object.defineProperty(document,"_activeElement",Pc.activeElement);A(Window.prototype,Sc,"__shady_");w.s?w.ba&&A(Element.prototype,Gc):(Uc(),Kb());Fb();window.Event=Hb;window.CustomEvent=Ib;window.MouseEvent=Jb;window.ShadowRoot=Ec};/*

Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
function od(){this.end=this.start=0;this.rules=this.parent=this.previous=null;this.cssText=this.parsedCssText="";this.atRule=!1;this.type=0;this.parsedSelector=this.selector=this.keyframesName=""}
function pd(a){var b=a=a.replace(qd,"").replace(rd,""),c=new od;c.start=0;c.end=b.length;for(var d=c,e=0,f=b.length;e<f;e++)if("{"===b[e]){d.rules||(d.rules=[]);var g=d,h=g.rules[g.rules.length-1]||null;d=new od;d.start=e+1;d.parent=g;d.previous=h;g.rules.push(d)}else"}"===b[e]&&(d.end=e+1,d=d.parent||c);return sd(c,a)}
function sd(a,b){var c=b.substring(a.start,a.end-1);a.parsedCssText=a.cssText=c.trim();a.parent&&(c=b.substring(a.previous?a.previous.end:a.parent.start,a.start-1),c=td(c),c=c.replace(ud," "),c=c.substring(c.lastIndexOf(";")+1),c=a.parsedSelector=a.selector=c.trim(),a.atRule=0===c.indexOf("@"),a.atRule?0===c.indexOf("@media")?a.type=vd:c.match(wd)&&(a.type=xd,a.keyframesName=a.selector.split(ud).pop()):a.type=0===c.indexOf("--")?yd:zd);if(c=a.rules)for(var d=0,e=c.length,f=void 0;d<e&&(f=c[d]);d++)sd(f,
b);return a}function td(a){return a.replace(/\\([0-9a-f]{1,6})\s/gi,function(b,c){b=c;for(c=6-b.length;c--;)b="0"+b;return"\\"+b})}
function Ad(a,b,c){c=void 0===c?"":c;var d="";if(a.cssText||a.rules){var e=a.rules,f;if(f=e)f=e[0],f=!(f&&f.selector&&0===f.selector.indexOf("--"));if(f){f=0;for(var g=e.length,h=void 0;f<g&&(h=e[f]);f++)d=Ad(h,b,d)}else b?b=a.cssText:(b=a.cssText,b=b.replace(Bd,"").replace(Cd,""),b=b.replace(Dd,"").replace(Ed,"")),(d=b.trim())&&(d="  "+d+"\n")}d&&(a.selector&&(c+=a.selector+" {\n"),c+=d,a.selector&&(c+="}\n\n"));return c}
var zd=1,xd=7,vd=4,yd=1E3,qd=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//gim,rd=/@import[^;]*;/gim,Bd=/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?(?:[;\n]|$)/gim,Cd=/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?{[^}]*?}(?:[;\n]|$)?/gim,Dd=/@apply\s*\(?[^);]*\)?\s*(?:[;\n]|$)?/gim,Ed=/[^;:]*?:[^;]*?var\([^;]*\)(?:[;\n]|$)?/gim,wd=/^@[^\s]*keyframes/,ud=/\s+/g;var R=!(window.ShadyDOM&&window.ShadyDOM.inUse),Fd;function Gd(a){Fd=a&&a.shimcssproperties?!1:R||!(navigator.userAgent.match(/AppleWebKit\/601|Edge\/15/)||!window.CSS||!CSS.supports||!CSS.supports("box-shadow","0 0 0 var(--foo)"))}var Hd;window.ShadyCSS&&void 0!==window.ShadyCSS.cssBuild&&(Hd=window.ShadyCSS.cssBuild);var Id=!(!window.ShadyCSS||!window.ShadyCSS.disableRuntime);
window.ShadyCSS&&void 0!==window.ShadyCSS.nativeCss?Fd=window.ShadyCSS.nativeCss:window.ShadyCSS?(Gd(window.ShadyCSS),window.ShadyCSS=void 0):Gd(window.WebComponents&&window.WebComponents.flags);var S=Fd;var Jd=/(?:^|[;\s{]\s*)(--[\w-]*?)\s*:\s*(?:((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};{])+)|\{([^}]*)\}(?:(?=[;\s}])|$))/gi,Kd=/(?:^|\W+)@apply\s*\(?([^);\n]*)\)?/gi,Ld=/(--[\w-]+)\s*([:,;)]|$)/gi,Md=/(animation\s*:)|(animation-name\s*:)/,Nd=/@media\s(.*)/,Od=/\{[^}]*\}/g;var Pd=new Set;function Qd(a,b){if(!a)return"";"string"===typeof a&&(a=pd(a));b&&Rd(a,b);return Ad(a,S)}function Sd(a){!a.__cssRules&&a.textContent&&(a.__cssRules=pd(a.textContent));return a.__cssRules||null}function Td(a){return!!a.parent&&a.parent.type===xd}function Rd(a,b,c,d){if(a){var e=!1,f=a.type;if(d&&f===vd){var g=a.selector.match(Nd);g&&(window.matchMedia(g[1]).matches||(e=!0))}f===zd?b(a):c&&f===xd?c(a):f===yd&&(e=!0);if((a=a.rules)&&!e)for(e=0,f=a.length,g=void 0;e<f&&(g=a[e]);e++)Rd(g,b,c,d)}}
function Ud(a,b,c,d){var e=document.createElement("style");b&&e.setAttribute("scope",b);e.textContent=a;Vd(e,c,d);return e}var T=null;function Wd(a){a=document.createComment(" Shady DOM styles for "+a+" ");var b=document.head;b.insertBefore(a,(T?T.nextSibling:null)||b.firstChild);return T=a}function Vd(a,b,c){b=b||document.head;b.insertBefore(a,c&&c.nextSibling||b.firstChild);T?a.compareDocumentPosition(T)===Node.DOCUMENT_POSITION_PRECEDING&&(T=a):T=a}
function Xd(a,b){for(var c=0,d=a.length;b<d;b++)if("("===a[b])c++;else if(")"===a[b]&&0===--c)return b;return-1}function Yd(a,b){var c=a.indexOf("var(");if(-1===c)return b(a,"","","");var d=Xd(a,c+3),e=a.substring(c+4,d);c=a.substring(0,c);a=Yd(a.substring(d+1),b);d=e.indexOf(",");return-1===d?b(c,e.trim(),"",a):b(c,e.substring(0,d).trim(),e.substring(d+1).trim(),a)}function Zd(a,b){R?a.setAttribute("class",b):window.ShadyDOM.nativeMethods.setAttribute.call(a,"class",b)}
var $d=window.ShadyDOM&&window.ShadyDOM.wrap||function(a){return a};function U(a){var b=a.localName,c="";b?-1<b.indexOf("-")||(c=b,b=a.getAttribute&&a.getAttribute("is")||""):(b=a.is,c=a.extends);return{is:b,N:c}}function ae(a){for(var b=[],c="",d=0;0<=d&&d<a.length;d++)if("("===a[d]){var e=Xd(a,d);c+=a.slice(d,e+1);d=e}else","===a[d]?(b.push(c),c=""):c+=a[d];c&&b.push(c);return b}
function be(a){if(void 0!==Hd)return Hd;if(void 0===a.__cssBuild){var b=a.getAttribute("css-build");if(b)a.__cssBuild=b;else{a:{b="template"===a.localName?a.content.firstChild:a.firstChild;if(b instanceof Comment&&(b=b.textContent.trim().split(":"),"css-build"===b[0])){b=b[1];break a}b=""}if(""!==b){var c="template"===a.localName?a.content.firstChild:a.firstChild;c.parentNode.removeChild(c)}a.__cssBuild=b}}return a.__cssBuild||""}
function ce(a){a=void 0===a?"":a;return""!==a&&S?R?"shadow"===a:"shady"===a:!1};function de(){}function ee(a,b){fe(V,a,function(c){W(c,b||"")})}function fe(a,b,c){b.nodeType===Node.ELEMENT_NODE&&c(b);var d;"template"===b.localName?d=(b.content||b._content||b).childNodes:d=b.children||b.childNodes;if(d)for(b=0;b<d.length;b++)fe(a,d[b],c)}
function W(a,b,c){if(b)if(a.classList)c?(a.classList.remove("style-scope"),a.classList.remove(b)):(a.classList.add("style-scope"),a.classList.add(b));else if(a.getAttribute){var d=a.getAttribute("class");c?d&&(b=d.replace("style-scope","").replace(b,""),Zd(a,b)):Zd(a,(d?d+" ":"")+"style-scope "+b)}}function ge(a,b,c){fe(V,a,function(d){W(d,b,!0);W(d,c)})}function he(a,b){fe(V,a,function(c){W(c,b||"",!0)})}
function ie(a,b,c,d,e){var f=V;e=void 0===e?"":e;""===e&&(R||"shady"===(void 0===d?"":d)?e=Qd(b,c):(a=U(a),e=je(f,b,a.is,a.N,c)+"\n\n"));return e.trim()}function je(a,b,c,d,e){var f=ke(c,d);c=c?"."+c:"";return Qd(b,function(g){g.i||(g.selector=g.m=le(a,g,a.h,c,f),g.i=!0);e&&e(g,c,f)})}function ke(a,b){return b?"[is="+a+"]":a}
function le(a,b,c,d,e){var f=ae(b.selector);if(!Td(b)){b=0;for(var g=f.length,h=void 0;b<g&&(h=f[b]);b++)f[b]=c.call(a,h,d,e)}return f.filter(function(l){return!!l}).join(",")}function me(a){return a.replace(ne,function(b,c,d){-1<d.indexOf("+")?d=d.replace(/\+/g,"___"):-1<d.indexOf("___")&&(d=d.replace(/___/g,"+"));return":"+c+"("+d+")"})}
function oe(a){for(var b=[],c;c=a.match(pe);){var d=c.index,e=Xd(a,d);if(-1===e)throw Error(c.input+" selector missing ')'");c=a.slice(d,e+1);a=a.replace(c,"\ue000");b.push(c)}return{ca:a,matches:b}}function qe(a,b){var c=a.split("\ue000");return b.reduce(function(d,e,f){return d+e+c[f+1]},c[0])}
de.prototype.h=function(a,b,c){var d=!1;a=a.trim();var e=ne.test(a);e&&(a=a.replace(ne,function(h,l,k){return":"+l+"("+k.replace(/\s/g,"")+")"}),a=me(a));var f=pe.test(a);if(f){var g=oe(a);a=g.ca;g=g.matches}a=a.replace(re,":host $1");a=a.replace(se,function(h,l,k){d||(h=te(k,l,b,c),d=d||h.stop,l=h.ta,k=h.value);return l+k});f&&(a=qe(a,g));e&&(a=me(a));return a=a.replace(ue,function(h,l,k,m){return'[dir="'+k+'"] '+l+m+", "+l+'[dir="'+k+'"]'+m})};
function te(a,b,c,d){var e=a.indexOf("::slotted");0<=a.indexOf(":host")?a=ve(a,d):0!==e&&(a=c?we(a,c):a);c=!1;0<=e&&(b="",c=!0);if(c){var f=!0;c&&(a=a.replace(xe,function(g,h){return" > "+h}))}return{value:a,ta:b,stop:f}}function we(a,b){a=a.split(/(\[.+?\])/);for(var c=[],d=0;d<a.length;d++)if(1===d%2)c.push(a[d]);else{var e=a[d];if(""!==e||d!==a.length-1)e=e.split(":"),e[0]+=b,c.push(e.join(":"))}return c.join("")}
function ve(a,b){var c=a.match(ye);return(c=c&&c[2].trim()||"")?c[0].match(ze)?a.replace(ye,function(d,e,f){return b+f}):c.split(ze)[0]===b?c:"should_not_match":a.replace(":host",b)}function Ae(a){":root"===a.selector&&(a.selector="html")}de.prototype.i=function(a){return a.match(":host")?"":a.match("::slotted")?this.h(a,":not(.style-scope)"):we(a.trim(),":not(.style-scope)")};ca.Object.defineProperties(de.prototype,{g:{configurable:!0,enumerable:!0,get:function(){return"style-scope"}}});
var ne=/:(nth[-\w]+)\(([^)]+)\)/,se=/(^|[\s>+~]+)((?:\[.+?\]|[^\s>+~=[])+)/g,ze=/[[.:#*]/,re=/^(::slotted)/,ye=/(:host)(?:\(((?:\([^)(]*\)|[^)(]*)+?)\))/,xe=/(?:::slotted)(?:\(((?:\([^)(]*\)|[^)(]*)+?)\))/,ue=/(.*):dir\((?:(ltr|rtl))\)(.*)/,pe=/:(?:matches|any|-(?:webkit|moz)-any)/,V=new de;function Be(a,b,c,d,e){this.A=a||null;this.h=b||null;this.aa=c||[];this.u=null;this.cssBuild=e||"";this.N=d||"";this.g=this.v=this.C=null}function X(a){return a?a.__styleInfo:null}function Ce(a,b){return a.__styleInfo=b}Be.prototype.i=function(){return this.A};Be.prototype._getStyleRules=Be.prototype.i;function De(a){var b=this.matches||this.matchesSelector||this.mozMatchesSelector||this.msMatchesSelector||this.oMatchesSelector||this.webkitMatchesSelector;return b&&b.call(this,a)}var Ee=/:host\s*>\s*/,Fe=navigator.userAgent.match("Trident");function Ge(){}function He(a){var b={},c=[],d=0;Rd(a,function(f){Ie(f);f.index=d++;f=f.l.cssText;for(var g;g=Ld.exec(f);){var h=g[1];":"!==g[2]&&(b[h]=!0)}},function(f){c.push(f)});a.h=c;a=[];for(var e in b)a.push(e);return a}
function Ie(a){if(!a.l){var b={},c={};Je(a,c)&&(b.B=c,a.rules=null);b.cssText=a.parsedCssText.replace(Od,"").replace(Jd,"");a.l=b}}function Je(a,b){var c=a.l;if(c){if(c.B)return Object.assign(b,c.B),!0}else{c=a.parsedCssText;for(var d;a=Jd.exec(c);){d=(a[2]||a[3]).trim();if("inherit"!==d||"unset"!==d)b[a[1].trim()]=d;d=!0}return d}}
function Ke(a,b,c){b&&(b=0<=b.indexOf(";")?Le(a,b,c):Yd(b,function(d,e,f,g){if(!e)return d+g;(e=Ke(a,c[e],c))&&"initial"!==e?"apply-shim-inherit"===e&&(e="inherit"):e=Ke(a,c[f]||f,c)||f;return d+(e||"")+g}));return b&&b.trim()||""}
function Le(a,b,c){b=b.split(";");for(var d=0,e,f;d<b.length;d++)if(e=b[d]){Kd.lastIndex=0;if(f=Kd.exec(e))e=Ke(a,c[f[1]],c);else if(f=e.indexOf(":"),-1!==f){var g=e.substring(f);g=g.trim();g=Ke(a,g,c)||g;e=e.substring(0,f)+g}b[d]=e&&e.lastIndexOf(";")===e.length-1?e.slice(0,-1):e||""}return b.join(";")}
function Me(a,b){var c={},d=[];Rd(a,function(e){e.l||Ie(e);var f=e.m||e.parsedSelector;b&&e.l.B&&f&&De.call(b,f)&&(Je(e,c),e=e.index,f=parseInt(e/32,10),d[f]=(d[f]||0)|1<<e%32)},null,!0);return{B:c,key:d}}
function Ne(a,b,c,d){b.l||Ie(b);if(b.l.B){var e=U(a);a=e.is;e=e.N;e=a?ke(a,e):"html";var f=b.parsedSelector;var g=!!f.match(Ee)||"html"===e&&-1<f.indexOf("html");var h=0===f.indexOf(":host")&&!g;"shady"===c&&(g=f===e+" > *."+e||-1!==f.indexOf("html"),h=!g&&0===f.indexOf(e));if(g||h)c=e,h&&(b.m||(b.m=le(V,b,V.h,a?"."+a:"",e)),c=b.m||e),g&&"html"===e&&(c=b.m||b.T),d({ca:c,za:h,Ja:g})}}
function Oe(a,b,c){var d={},e={};Rd(b,function(f){Ne(a,f,c,function(g){De.call(a._element||a,g.ca)&&(g.za?Je(f,d):Je(f,e))})},null,!0);return{Ca:e,ya:d}}
function Pe(a,b,c,d){var e=U(b),f=ke(e.is,e.N),g=new RegExp("(?:^|[^.#[:])"+(b.extends?"\\"+f.slice(0,-1)+"\\]":f)+"($|[.:[\\s>+~])"),h=X(b);e=h.A;h=h.cssBuild;var l=Qe(e,d);return ie(b,e,function(k){var m="";k.l||Ie(k);k.l.cssText&&(m=Le(a,k.l.cssText,c));k.cssText=m;if(!R&&!Td(k)&&k.cssText){var r=m=k.cssText;null==k.ga&&(k.ga=Md.test(m));if(k.ga)if(null==k.S){k.S=[];for(var u in l)r=l[u],r=r(m),m!==r&&(m=r,k.S.push(u))}else{for(u=0;u<k.S.length;++u)r=l[k.S[u]],m=r(m);r=m}k.cssText=r;k.m=k.m||k.selector;
m="."+d;u=ae(k.m);r=0;for(var N=u.length,Pa=void 0;r<N&&(Pa=u[r]);r++)u[r]=Pa.match(g)?Pa.replace(f,m):m+" "+Pa;k.selector=u.join(",")}},h)}function Qe(a,b){a=a.h;var c={};if(!R&&a)for(var d=0,e=a[d];d<a.length;e=a[++d]){var f=e,g=b;f.o=new RegExp("\\b"+f.keyframesName+"(?!\\B|-)","g");f.g=f.keyframesName+"-"+g;f.m=f.m||f.selector;f.selector=f.m.replace(f.keyframesName,f.g);c[e.keyframesName]=Re(e)}return c}function Re(a){return function(b){return b.replace(a.o,a.g)}}
function Se(a,b){var c=Te,d=Sd(a);a.textContent=Qd(d,function(e){var f=e.cssText=e.parsedCssText;e.l&&e.l.cssText&&(f=f.replace(Bd,"").replace(Cd,""),e.cssText=Le(c,f,b))})}ca.Object.defineProperties(Ge.prototype,{g:{configurable:!0,enumerable:!0,get:function(){return"x-scope"}}});var Te=new Ge;var Ue={},Ve=window.customElements;if(Ve&&!R&&!Id){var We=Ve.define;Ve.define=function(a,b,c){Ue[a]||(Ue[a]=Wd(a));We.call(Ve,a,b,c)}};function Xe(){this.cache={}}Xe.prototype.store=function(a,b,c,d){var e=this.cache[a]||[];e.push({B:b,styleElement:c,v:d});100<e.length&&e.shift();this.cache[a]=e};function Ye(){}var Ze=new RegExp(V.g+"\\s*([^\\s]*)");function $e(a){return(a=(a.classList&&a.classList.value?a.classList.value:a.getAttribute("class")||"").match(Ze))?a[1]:""}function af(a){var b=$d(a).getRootNode();return b===a||b===a.ownerDocument?"":(a=b.host)?U(a).is:""}
function bf(a){for(var b=0;b<a.length;b++){var c=a[b];if(c.target!==document.documentElement&&c.target!==document.head)for(var d=0;d<c.addedNodes.length;d++){var e=c.addedNodes[d];if(e.nodeType===Node.ELEMENT_NODE){var f=e.getRootNode(),g=$e(e);if(g&&f===e.ownerDocument&&("style"!==e.localName&&"template"!==e.localName||""===be(e)))he(e,g);else if(f instanceof ShadowRoot)for(f=af(e),f!==g&&ge(e,g,f),e=window.ShadyDOM.nativeMethods.querySelectorAll.call(e,":not(."+V.g+")"),g=0;g<e.length;g++){f=e[g];
var h=af(f);h&&W(f,h)}}}}}
if(!(R||window.ShadyDOM&&window.ShadyDOM.handlesDynamicScoping)){var cf=new MutationObserver(bf),df=function(a){cf.observe(a,{childList:!0,subtree:!0})};if(window.customElements&&!window.customElements.polyfillWrapFlushCallback)df(document);else{var ef=function(){df(document.body)};window.HTMLImports?window.HTMLImports.whenReady(ef):requestAnimationFrame(function(){if("loading"===document.readyState){var a=function(){ef();document.removeEventListener("readystatechange",a)};document.addEventListener("readystatechange",
a)}else ef()})}Ye=function(){bf(cf.takeRecords())}};var ff={};var gf=Promise.resolve();function hf(a){if(a=ff[a])a._applyShimCurrentVersion=a._applyShimCurrentVersion||0,a._applyShimValidatingVersion=a._applyShimValidatingVersion||0,a._applyShimNextVersion=(a._applyShimNextVersion||0)+1}function jf(a){return a._applyShimCurrentVersion===a._applyShimNextVersion}function kf(a){a._applyShimValidatingVersion=a._applyShimNextVersion;a._validating||(a._validating=!0,gf.then(function(){a._applyShimCurrentVersion=a._applyShimNextVersion;a._validating=!1}))};var lf={},mf=new Xe;function Y(){this.ha={};this.i=document.documentElement;var a=new od;a.rules=[];this.o=Ce(this.i,new Be(a));this.T=!1;this.g=this.h=null}n=Y.prototype;n.flush=function(){Ye()};n.wa=function(a){return Sd(a)};n.Ga=function(a){return Qd(a)};n.prepareTemplate=function(a,b,c){this.prepareTemplateDom(a,b);this.prepareTemplateStyles(a,b,c)};
n.prepareTemplateStyles=function(a,b,c){if(!a._prepared&&!Id){R||Ue[b]||(Ue[b]=Wd(b));a._prepared=!0;a.name=b;a.extends=c;ff[b]=a;var d=be(a),e=ce(d);c={is:b,extends:c};for(var f=[],g=a.content.querySelectorAll("style"),h=0;h<g.length;h++){var l=g[h];if(l.hasAttribute("shady-unscoped")){if(!R){var k=l.textContent;if(!Pd.has(k)){Pd.add(k);var m=document.createElement("style");m.setAttribute("shady-unscoped","");m.textContent=k;document.head.appendChild(m)}l.parentNode.removeChild(l)}}else f.push(l.textContent),
l.parentNode.removeChild(l)}f=f.join("").trim()+(lf[b]||"");nf(this);if(!e){if(g=!d)g=Kd.test(f)||Jd.test(f),Kd.lastIndex=0,Jd.lastIndex=0;h=pd(f);g&&S&&this.h&&this.h.transformRules(h,b);a._styleAst=h}g=[];S||(g=He(a._styleAst));if(!g.length||S)h=R?a.content:null,b=Ue[b]||null,d=ie(c,a._styleAst,null,d,e?f:""),d=d.length?Ud(d,c.is,h,b):null,a._style=d;a.g=g}};n.Aa=function(a,b){lf[b]=a.join(" ")};
n.prepareTemplateDom=function(a,b){if(!Id){var c=be(a);R||"shady"===c||a._domPrepared||(a._domPrepared=!0,ee(a.content,b))}};function of(a){var b=U(a),c=b.is;b=b.N;var d=Ue[c]||null,e=ff[c];if(e){c=e._styleAst;var f=e.g;e=be(e);b=new Be(c,d,f,b,e);Ce(a,b);return b}}
function pf(a){!a.g&&window.ShadyCSS&&window.ShadyCSS.CustomStyleInterface&&(a.g=window.ShadyCSS.CustomStyleInterface,a.g.transformCallback=function(b){a.ka(b)},a.g.validateCallback=function(){requestAnimationFrame(function(){(a.g.enqueued||a.T)&&a.flushCustomStyles()})})}function nf(a){if(!a.h&&window.ShadyCSS&&window.ShadyCSS.ApplyShim){a.h=window.ShadyCSS.ApplyShim;a.h.invalidCallback=hf;var b=!0}else b=!1;pf(a);return b}
n.flushCustomStyles=function(){if(!Id){var a=nf(this);if(this.g){var b=this.g.processStyles();if((a||this.g.enqueued)&&!ce(this.o.cssBuild)){if(S){if(!this.o.cssBuild)for(a=0;a<b.length;a++){var c=this.g.getStyleForCustomStyle(b[a]);if(c&&S&&this.h){var d=Sd(c);nf(this);this.h.transformRules(d);c.textContent=Qd(d)}}}else{qf(this,b);rf(this,this.i,this.o);for(a=0;a<b.length;a++)(c=this.g.getStyleForCustomStyle(b[a]))&&Se(c,this.o.C);this.T&&this.styleDocument()}this.g.enqueued=!1}}}};
function qf(a,b){b=b.map(function(c){return a.g.getStyleForCustomStyle(c)}).filter(function(c){return!!c});b.sort(function(c,d){c=d.compareDocumentPosition(c);return c&Node.DOCUMENT_POSITION_FOLLOWING?1:c&Node.DOCUMENT_POSITION_PRECEDING?-1:0});a.o.A.rules=b.map(function(c){return Sd(c)})}
n.styleElement=function(a,b){if(Id){if(b){X(a)||Ce(a,new Be(null));var c=X(a);c.u=c.u||{};Object.assign(c.u,b);sf(this,a,c)}}else if(c=X(a)||of(a))if(a!==this.i&&(this.T=!0),b&&(c.u=c.u||{},Object.assign(c.u,b)),S)sf(this,a,c);else if(this.flush(),rf(this,a,c),c.aa&&c.aa.length){b=U(a).is;var d;a:{if(d=mf.cache[b])for(var e=d.length-1;0<=e;e--){var f=d[e];b:{var g=c.aa;for(var h=0;h<g.length;h++){var l=g[h];if(f.B[l]!==c.C[l]){g=!1;break b}}g=!0}if(g){d=f;break a}}d=void 0}g=d?d.styleElement:null;
e=c.v;(f=d&&d.v)||(f=this.ha[b]=(this.ha[b]||0)+1,f=b+"-"+f);c.v=f;f=c.v;h=Te;h=g?g.textContent||"":Pe(h,a,c.C,f);l=X(a);var k=l.g;k&&!R&&k!==g&&(k._useCount--,0>=k._useCount&&k.parentNode&&k.parentNode.removeChild(k));R?l.g?(l.g.textContent=h,g=l.g):h&&(g=Ud(h,f,a.shadowRoot,l.h)):g?g.parentNode||(Fe&&-1<h.indexOf("@media")&&(g.textContent=h),Vd(g,null,l.h)):h&&(g=Ud(h,f,null,l.h));g&&(g._useCount=g._useCount||0,l.g!=g&&g._useCount++,l.g=g);f=g;R||(g=c.v,l=h=a.getAttribute("class")||"",e&&(l=h.replace(new RegExp("\\s*x-scope\\s*"+
e+"\\s*","g")," ")),l+=(l?" ":"")+"x-scope "+g,h!==l&&Zd(a,l));d||mf.store(b,c.C,f,c.v)}};
function sf(a,b,c){var d=U(b).is;if(c.u){var e=c.u,f;for(f in e)null===f?b.style.removeProperty(f):b.style.setProperty(f,e[f])}e=ff[d];if(!(!e&&b!==a.i||e&&""!==be(e))&&e&&e._style&&!jf(e)){if(jf(e)||e._applyShimValidatingVersion!==e._applyShimNextVersion)nf(a),a.h&&a.h.transformRules(e._styleAst,d),e._style.textContent=ie(b,c.A),kf(e);R&&(a=b.shadowRoot)&&(a=a.querySelector("style"))&&(a.textContent=ie(b,c.A));c.A=e._styleAst}}
function tf(a,b){return(b=$d(b).getRootNode().host)?X(b)||of(b)?b:tf(a,b):a.i}function rf(a,b,c){var d=tf(a,b),e=X(d),f=e.C;d===a.i||f||(rf(a,d,e),f=e.C);a=Object.create(f||null);d=Oe(b,c.A,c.cssBuild);b=Me(e.A,b).B;Object.assign(a,d.ya,b,d.Ca);b=c.u;for(var g in b)if((e=b[g])||0===e)a[g]=e;g=Te;b=Object.getOwnPropertyNames(a);for(e=0;e<b.length;e++)d=b[e],a[d]=Ke(g,a[d],a);c.C=a}n.styleDocument=function(a){this.styleSubtree(this.i,a)};
n.styleSubtree=function(a,b){var c=$d(a),d=c.shadowRoot,e=a===this.i;(d||e)&&this.styleElement(a,b);if(a=e?c:d)for(a=Array.from(a.querySelectorAll("*")).filter(function(f){return $d(f).shadowRoot}),b=0;b<a.length;b++)this.styleSubtree(a[b])};
n.ka=function(a){var b=this,c=be(a);c!==this.o.cssBuild&&(this.o.cssBuild=c);if(!ce(c)){var d=Sd(a);Rd(d,function(e){if(R)Ae(e);else{var f=V;e.selector=e.parsedSelector;Ae(e);e.selector=e.m=le(f,e,f.i,void 0,void 0)}S&&""===c&&(nf(b),b.h&&b.h.transformRule(e))});S?a.textContent=Qd(d):this.o.A.rules.push(d)}};n.getComputedStyleValue=function(a,b){var c;S||(c=(X(a)||X(tf(this,a))).C[b]);return(c=c||window.getComputedStyle(a).getPropertyValue(b))?c.trim():""};
n.Fa=function(a,b){var c=$d(a).getRootNode();b=b?("string"===typeof b?b:String(b)).split(/\s/):[];c=c.host&&c.host.localName;if(!c){var d=a.getAttribute("class");if(d){d=d.split(/\s/);for(var e=0;e<d.length;e++)if(d[e]===V.g){c=d[e+1];break}}}c&&b.push(V.g,c);S||(c=X(a))&&c.v&&b.push(Te.g,c.v);Zd(a,b.join(" "))};n.sa=function(a){return X(a)};n.Ea=function(a,b){W(a,b)};n.Ha=function(a,b){W(a,b,!0)};n.Da=function(a){return af(a)};n.va=function(a){return $e(a)};Y.prototype.flush=Y.prototype.flush;
Y.prototype.prepareTemplate=Y.prototype.prepareTemplate;Y.prototype.styleElement=Y.prototype.styleElement;Y.prototype.styleDocument=Y.prototype.styleDocument;Y.prototype.styleSubtree=Y.prototype.styleSubtree;Y.prototype.getComputedStyleValue=Y.prototype.getComputedStyleValue;Y.prototype.setElementClass=Y.prototype.Fa;Y.prototype._styleInfoForNode=Y.prototype.sa;Y.prototype.transformCustomStyleForDocument=Y.prototype.ka;Y.prototype.getStyleAst=Y.prototype.wa;Y.prototype.styleAstToString=Y.prototype.Ga;
Y.prototype.flushCustomStyles=Y.prototype.flushCustomStyles;Y.prototype.scopeNode=Y.prototype.Ea;Y.prototype.unscopeNode=Y.prototype.Ha;Y.prototype.scopeForNode=Y.prototype.Da;Y.prototype.currentScopeForNode=Y.prototype.va;Y.prototype.prepareAdoptedCssText=Y.prototype.Aa;Object.defineProperties(Y.prototype,{nativeShadow:{get:function(){return R}},nativeCss:{get:function(){return S}}});var Z=new Y,uf,vf;window.ShadyCSS&&(uf=window.ShadyCSS.ApplyShim,vf=window.ShadyCSS.CustomStyleInterface);
window.ShadyCSS={ScopingShim:Z,prepareTemplate:function(a,b,c){Z.flushCustomStyles();Z.prepareTemplate(a,b,c)},prepareTemplateDom:function(a,b){Z.prepareTemplateDom(a,b)},prepareTemplateStyles:function(a,b,c){Z.flushCustomStyles();Z.prepareTemplateStyles(a,b,c)},styleSubtree:function(a,b){Z.flushCustomStyles();Z.styleSubtree(a,b)},styleElement:function(a){Z.flushCustomStyles();Z.styleElement(a)},styleDocument:function(a){Z.flushCustomStyles();Z.styleDocument(a)},flushCustomStyles:function(){Z.flushCustomStyles()},
getComputedStyleValue:function(a,b){return Z.getComputedStyleValue(a,b)},nativeCss:S,nativeShadow:R,cssBuild:Hd,disableRuntime:Id};uf&&(window.ShadyCSS.ApplyShim=uf);vf&&(window.ShadyCSS.CustomStyleInterface=vf);}).call(this);

//# sourceMappingURL=webcomponents-sd.js.map
