var _setup = require('./_setup.js');

var _tagTester = require('./_tagTester.js'); // Is a given value an array?
// Delegates to ECMA5's native `Array.isArray`.


var isArray = _setup.nativeIsArray || _tagTester('Array');

module.exports = isArray;