##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
#
##
queues = [
    {
        "name":"lpd",
        "config":{
            "method":"getlpdcounters",
            "dbname":"lpdcounters",
            "tabname":"lpd",
            "logfile":"LPD_PERF",
            "configuration":"configurelpdCounters",
            "file_name":"READ_LPD_COUNTERS"
        }
    },
    {
        "name": "fpd",
        "config": {
            "method": "getfpdcounters",
            "dbname": "fpdcounters",
            "tabname":"fpd",
            "logfile":"FPD_PERF",
            "configuration":"configurefpdCounters",
            "file_name": "READ_FPD_COUNTERS"
        }
    },
    {
        "name":"cpm",
        "config":{
            "method":"getcpmcounters",
            "dbname":"cpmcounters",
            "tabname":"cpm",
            "logfile":"CPM_AXI_PERF",
            "configuration":"configurecpmcounters",
            "file_name": "READ_CPM_COUNTERS"
        }
    },
    {
        "name":"cpm_nsu",
        "config":{
            "method":"getcpmnsu",
            "dbname":"cpmcounters",
            "tabname":"cpm_nsu",
            "logfile":"CPM_NSU_PERF",
            # "configuration":"configurecpmcounters",
            "file_name": "READ_CPM_COUNTERS"
        }
    },
    {
        "name":"pmc",
        "config":{
            "method":"getpmccounters",
            "dbname":"pmccounters",
            "tabname":"pmc",
            "logfile":"PMC_PERF",
            "configuration":"configurepmccounters",
            "file_name": "READ_PMC_COUNTERS"
        }
    },
    {
        "name":"mrd_noc_0",
        "config":{
            "method":"getperf",
            "file_name":"perf_ddr_noc_0",
            "instances":[0],
            "subname":".tcl",
            "dbname":"perfmon_1",
            "tabname":"mrd_noc_0",
            "logfile":"DDR_NOC_0_PERF",
            "configuration":"configuremonitors0"
        }
    },
    {
        "name":"dc",
        "config":{
            "method":"getdcperformance",
            "dbname":"dcperf",
            "tabname":"dc",
            "logfile":"DC_PERF",
            "configuration":"configuredcmonitors",
            "file_name": "PERF_DDR_DC"
        }
    },
    {
        "name":"mrd_noc_1",
        "config":{
            "method":"getperf",
            "file_name":"perf_ddr_noc_1",
            "instances":[1],
            "subname":".tcl",
            "dbname":"perfmon_1",
            "tabname":"mrd_noc_1",
            "logfile":"DDR_NOC_1_PERF",
            "configuration":"configuremonitors1"
        }
    },
    {
        "name":"mrd_noc_2",
        "config":{
            "method":"getperf",
            "file_name":"perf_ddr_noc_2",
            "instances":[2],
            "subname":".tcl",
            "dbname":"perfmon_1",
            "tabname":"mrd_noc_2",
            "logfile":"DDR_NOC_2_PERF",
            "configuration":"configuremonitors2"
        }
    },
    {
        "name":"mrd_noc_3",
        "config":{
            "method":"getperf",
            "file_name":"perf_ddr_noc_3",
            "instances":[3],
            "subname":".tcl",
            "dbname":"perfmon_1",
            "tabname":"mrd_noc_3",
            "logfile":"DDR_NOC_3_PERF",
            "configuration":"configuremonitors3"
        }
    },
    {
        "name":"noc",
        "config":{
            "method":"getnocperformance",
            "dbname":"nocperf",
            "tabname":"noc",
            "logfile":"NOC_PERF",
            "file_name": ["READ_NMU_REG","READ_NSU_REG","READ_NPS_REG"]
        }
    },
    {
        "name": "pl",
        "config": {
            "method": "getapmperformance",
            "dbname": "apmcounters",
            "tabname":"pl",
            "logfile":"APM_PERF",
            "configuration":"configureapmmonitors",
            "file_name": "READ_APM"
        }
    },
    {
        "name": "aiengine",
        "config": {
            "method": "getmeperf",
            "dbname": "mecounters",
            "tabname":"aiengine",
            "logfile":"ME_PERF",
            "file_name": "READ_ME"
        }
    },
    {
        "name": "plot",
        "config": {
            "method": "",
            "dbname": "overlaydb",
            "tabname": "plot",
            "logfile": "plot"
        }
    },
    {
            "name": "ams",
            "config": {
                "method": "",
                "dbname": "amsdb",
                "tabname": "ams",
                "logfile": "ams"
            }
        },
    {
            "name": "overlay",
            "config": {
                "method": "",
                "dbname": "overlaydb",
                "tabname": "overlay",
                "logfile": "overlay"
            }
        },
    {
            "name": "ddr_efficiency",
            "config": {
                "method": "",
                "dbname": "ddr_efficiency",
                "tabname": "ddr_efficiency",
                "logfile": "ddr_efficiency"
            }
        },
    {
        "name":"mrd_noc_0_efficiency",
        "config":{
            "method":"",
            "file_name":"perf_ddr_noc_0",
            "instances":[0],
            "subname":".tcl",
            "dbname":"ddr_efficiency",
            "tabname":"ddrmc0_efficiency",
            "logfile":"DDR_NOC_0_EFFICIENCY"
        }
    },
    {
        "name":"mrd_noc_1_efficiency",
        "config":{
            "method":"",
            "file_name":"perf_ddr_noc_1",
            "instances":[1],
            "subname":".tcl",
            "dbname":"ddr_efficiency",
            "tabname":"ddrmc1_efficiency",
            "logfile":"DDR_NOC_1_PERF_EFFICIENCY"
        }
    },
    {
        "name":"mrd_noc_2_efficiency",
        "config":{
            "method":"",
            "file_name":"perf_ddr_noc_2",
            "instances":[2],
            "subname":".tcl",
            "dbname":"ddr_efficiency",
            "tabname":"ddrmc2_efficiency",
            "logfile":"DDR_NOC_2_PERF_EFFICIENCY"
        }
    },
    {
        "name":"mrd_noc_3_efficiency",
        "config":{
            "method":"",
            "file_name":"perf_ddr_noc_3",
            "instances":[3],
            "subname":".tcl",
            "dbname":"ddr_efficiency",
            "tabname":"ddrmc3_efficiency",
            "logfile":"DDR_NOC_3_PERF_EFFICIENCY"
        }
    },
]