##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_CPM_ELA2C
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0f60000]
lappend results [mem_read 0xf0f60004]
lappend results [mem_read 0xf0f60008]
lappend results [mem_read 0xf0f60010]
lappend results [mem_read 0xf0f60020]
lappend results [mem_read 0xf0f60024]
lappend results [mem_read 0xf0f60028]
lappend results [mem_read 0xf0f6002c]
lappend results [mem_read 0xf0f60040]
lappend results [mem_read 0xf0f60044]
lappend results [mem_read 0xf0f60048]
lappend results [mem_read 0xf0f6004c]
lappend results [mem_read 0xf0f60100]
lappend results [mem_read 0xf0f60104]
lappend results [mem_read 0xf0f60108]
lappend results [mem_read 0xf0f6010c]
lappend results [mem_read 0xf0f60110]
lappend results [mem_read 0xf0f60114]
lappend results [mem_read 0xf0f60120]
lappend results [mem_read 0xf0f60130]
lappend results [mem_read 0xf0f60134]
lappend results [mem_read 0xf0f60140]
lappend results [mem_read 0xf0f60144]
lappend results [mem_read 0xf0f60148]
lappend results [mem_read 0xf0f6014c]
lappend results [mem_read 0xf0f60180]
lappend results [mem_read 0xf0f60184]
lappend results [mem_read 0xf0f60188]
lappend results [mem_read 0xf0f6018c]
lappend results [mem_read 0xf0f60200]
lappend results [mem_read 0xf0f60204]
lappend results [mem_read 0xf0f60208]
lappend results [mem_read 0xf0f6020c]
lappend results [mem_read 0xf0f60210]
lappend results [mem_read 0xf0f60214]
lappend results [mem_read 0xf0f60220]
lappend results [mem_read 0xf0f60230]
lappend results [mem_read 0xf0f60234]
lappend results [mem_read 0xf0f60240]
lappend results [mem_read 0xf0f60244]
lappend results [mem_read 0xf0f60248]
lappend results [mem_read 0xf0f6024c]
lappend results [mem_read 0xf0f60280]
lappend results [mem_read 0xf0f60284]
lappend results [mem_read 0xf0f60288]
lappend results [mem_read 0xf0f6028c]
lappend results [mem_read 0xf0f60300]
lappend results [mem_read 0xf0f60304]
lappend results [mem_read 0xf0f60308]
lappend results [mem_read 0xf0f6030c]
lappend results [mem_read 0xf0f60310]
lappend results [mem_read 0xf0f60314]
lappend results [mem_read 0xf0f60320]
lappend results [mem_read 0xf0f60330]
lappend results [mem_read 0xf0f60334]
lappend results [mem_read 0xf0f60340]
lappend results [mem_read 0xf0f60344]
lappend results [mem_read 0xf0f60348]
lappend results [mem_read 0xf0f6034c]
lappend results [mem_read 0xf0f60380]
lappend results [mem_read 0xf0f60384]
lappend results [mem_read 0xf0f60388]
lappend results [mem_read 0xf0f6038c]
lappend results [mem_read 0xf0f60400]
lappend results [mem_read 0xf0f60404]
lappend results [mem_read 0xf0f60408]
lappend results [mem_read 0xf0f6040c]
lappend results [mem_read 0xf0f60410]
lappend results [mem_read 0xf0f60414]
lappend results [mem_read 0xf0f60420]
lappend results [mem_read 0xf0f60430]
lappend results [mem_read 0xf0f60434]
lappend results [mem_read 0xf0f60440]
lappend results [mem_read 0xf0f60444]
lappend results [mem_read 0xf0f60448]
lappend results [mem_read 0xf0f6044c]
lappend results [mem_read 0xf0f60480]
lappend results [mem_read 0xf0f60484]
lappend results [mem_read 0xf0f60488]
lappend results [mem_read 0xf0f6048c]
lappend results [mem_read 0xf0f60500]
lappend results [mem_read 0xf0f60504]
lappend results [mem_read 0xf0f60508]
lappend results [mem_read 0xf0f6050c]
lappend results [mem_read 0xf0f60510]
lappend results [mem_read 0xf0f60514]
lappend results [mem_read 0xf0f60520]
lappend results [mem_read 0xf0f60530]
lappend results [mem_read 0xf0f60534]
lappend results [mem_read 0xf0f60540]
lappend results [mem_read 0xf0f60544]
lappend results [mem_read 0xf0f60548]
lappend results [mem_read 0xf0f6054c]
lappend results [mem_read 0xf0f60580]
lappend results [mem_read 0xf0f60584]
lappend results [mem_read 0xf0f60588]
lappend results [mem_read 0xf0f6058c]
lappend results [mem_read 0xf0f60ee8]
lappend results [mem_read 0xf0f60ef8]
lappend results [mem_read 0xf0f60f00]
lappend results [mem_read 0xf0f60fb0]
lappend results [mem_read 0xf0f60fb4]
lappend results [mem_read 0xf0f60fb8]
lappend results [mem_read 0xf0f60fbc]
lappend results [mem_read 0xf0f60fc0]
lappend results [mem_read 0xf0f60fc4]
lappend results [mem_read 0xf0f60fc8]
lappend results [mem_read 0xf0f60fcc]
