define(function () {
  // Predicate-generating function. Often useful outside of Underscore.
  function constant(value) {
    return function () {
      return value;
    };
  }

  return constant;
});