define(['./_createEscaper', './_escapeMap'], function (_createEscaper, _escapeMap) {
  // Function for escaping strings to HTML interpolation.
  var _escape = _createEscaper(_escapeMap);

  return _escape;
});