##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_CPM_CTI2A
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0fa0000]
lappend results [mem_read 0xf0fa0010]
lappend results [mem_read 0xf0fa0014]
lappend results [mem_read 0xf0fa0018]
lappend results [mem_read 0xf0fa001c]
lappend results [mem_read 0xf0fa0020]
lappend results [mem_read 0xf0fa0024]
lappend results [mem_read 0xf0fa0028]
lappend results [mem_read 0xf0fa002c]
lappend results [mem_read 0xf0fa0030]
lappend results [mem_read 0xf0fa0034]
lappend results [mem_read 0xf0fa0038]
lappend results [mem_read 0xf0fa003c]
lappend results [mem_read 0xf0fa00a0]
lappend results [mem_read 0xf0fa00a4]
lappend results [mem_read 0xf0fa00a8]
lappend results [mem_read 0xf0fa00ac]
lappend results [mem_read 0xf0fa00b0]
lappend results [mem_read 0xf0fa00b4]
lappend results [mem_read 0xf0fa00b8]
lappend results [mem_read 0xf0fa00bc]
lappend results [mem_read 0xf0fa0130]
lappend results [mem_read 0xf0fa0134]
lappend results [mem_read 0xf0fa0138]
lappend results [mem_read 0xf0fa013c]
lappend results [mem_read 0xf0fa0140]
lappend results [mem_read 0xf0fa0144]
lappend results [mem_read 0xf0fa0edc]
lappend results [mem_read 0xf0fa0ee0]
lappend results [mem_read 0xf0fa0ee4]
lappend results [mem_read 0xf0fa0ee8]
lappend results [mem_read 0xf0fa0eec]
lappend results [mem_read 0xf0fa0ef0]
lappend results [mem_read 0xf0fa0ef4]
lappend results [mem_read 0xf0fa0ef8]
lappend results [mem_read 0xf0fa0f00]
lappend results [mem_read 0xf0fa0fa0]
lappend results [mem_read 0xf0fa0fa4]
lappend results [mem_read 0xf0fa0fb0]
lappend results [mem_read 0xf0fa0fb4]
lappend results [mem_read 0xf0fa0fb8]
