// Side effect imports
import "./prototype.js";
import { createDuration } from "./create.js";
import { isDuration } from "./constructor.js";
import { getSetRelativeTimeRounding, getSetRelativeTimeThreshold } from "./humanize.js";
export { createDuration, isDuration, getSetRelativeTimeRounding, getSetRelativeTimeThreshold };