##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM5_L21_CSR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfcc84020]
lappend results [mem_read 0xfcc84040]
lappend results [mem_read 0xfcc84140]
lappend results [mem_read 0xfcc84148]
lappend results [mem_read 0xfcc84150]
lappend results [mem_read 0xfcc84158]
lappend results [mem_read 0xfcc84160]
lappend results [mem_read 0xfcc84168]
lappend results [mem_read 0xfcc84170]
lappend results [mem_read 0xfcc84178]
lappend results [mem_read 0xfcc84080]
lappend results [mem_read 0xfcc84028]
lappend results [mem_read 0xfcc84180]
lappend results [mem_read 0xfcc84100]
lappend results [mem_read 0xfcc84108]
lappend results [mem_read 0xfcc84030]
lappend results [mem_read 0xfcc84038]
lappend results [mem_read 0xfcc84088]
lappend results [mem_read 0xfcc84090]
lappend results [mem_read 0xfcc84098]
lappend results [mem_read 0xfcc840a0]
lappend results [mem_read 0xfcc840a8]
lappend results [mem_read 0xfcc840b0]
lappend results [mem_read 0xfcc840b8]
lappend results [mem_read 0xfcc840c0]
lappend results [mem_read 0xfcc840c8]
lappend results [mem_read 0xfcc84198]
lappend results [mem_read 0xfcc841a0]
lappend results [mem_read 0xfcc84190]
lappend results [mem_read 0xfcc84048]
lappend results [mem_read 0xfcc84050]
lappend results [mem_read 0xfcc841c0]
lappend results [mem_read 0xfcc841c8]
lappend results [mem_read 0xfcc841b8]
lappend results [mem_read 0xfcc841b0]
lappend results [mem_read 0xfcc841a8]
lappend results [mem_read 0xfcc841d0]
lappend results [mem_read 0xfcc84078]
lappend results [mem_read 0xfcc84000]
lappend results [mem_read 0xfcc84008]
lappend results [mem_read 0xfcc84010]
lappend results [mem_read 0xfcc84018]
lappend results [mem_read 0xfcc86050]
lappend results [mem_read 0xfcc86058]
lappend results [mem_read 0xfcc86048]
lappend results [mem_read 0xfcc86000]
lappend results [mem_read 0xfcc86008]
lappend results [mem_read 0xfcc86010]
lappend results [mem_read 0xfcc86018]
lappend results [mem_read 0xfcc86020]
lappend results [mem_read 0xfcc86028]
lappend results [mem_read 0xfcc86030]
lappend results [mem_read 0xfcc86038]
lappend results [mem_read 0xfcc860c8]
lappend results [mem_read 0xfcc86120]
lappend results [mem_read 0xfcc86118]
lappend results [mem_read 0xfcc86100]
lappend results [mem_read 0xfcc86110]
lappend results [mem_read 0xfcc86108]
lappend results [mem_read 0xfcc86180]
lappend results [mem_read 0xfcc86190]
lappend results [mem_read 0xfcc86188]
lappend results [mem_read 0xfcc86198]
lappend results [mem_read 0xfcc86070]
lappend results [mem_read 0xfcc86040]
lappend results [mem_read 0xfcc86140]
lappend results [mem_read 0xfcc86148]
lappend results [mem_read 0xfcc86150]
lappend results [mem_read 0xfcc86158]
lappend results [mem_read 0xfcc86160]
lappend results [mem_read 0xfcc86168]
lappend results [mem_read 0xfcc861c8]
lappend results [mem_read 0xfcc861d0]
lappend results [mem_read 0xfcc861c0]
lappend results [mem_read 0xfcc861e0]
lappend results [mem_read 0xfcc860e0]
lappend results [mem_read 0xfcc861d8]
lappend results [mem_read 0xfcc86078]
lappend results [mem_read 0xfcc860c0]
lappend results [mem_read 0xfcc860d0]
lappend results [mem_read 0xfcc860d8]
