define(['./_createReduce'], function (_createReduce) {
  // **Reduce** builds up a single result from a list of values, aka `inject`,
  // or `foldl`.
  var reduce = _createReduce(1);

  return reduce;
});