##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_RPU0_ETM
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0a30000]
lappend results [mem_read 0xf0a30004]
lappend results [mem_read 0xf0a30008]
lappend results [mem_read 0xf0a30010]
lappend results [mem_read 0xf0a30014]
lappend results [mem_read 0xf0a30018]
lappend results [mem_read 0xf0a3001c]
lappend results [mem_read 0xf0a30020]
lappend results [mem_read 0xf0a30024]
lappend results [mem_read 0xf0a3002c]
lappend results [mem_read 0xf0a30030]
lappend results [mem_read 0xf0a30034]
lappend results [mem_read 0xf0a3003c]
lappend results [mem_read 0xf0a30040]
lappend results [mem_read 0xf0a30044]
lappend results [mem_read 0xf0a30048]
lappend results [mem_read 0xf0a3004c]
lappend results [mem_read 0xf0a30050]
lappend results [mem_read 0xf0a30054]
lappend results [mem_read 0xf0a30058]
lappend results [mem_read 0xf0a3005c]
lappend results [mem_read 0xf0a30080]
lappend results [mem_read 0xf0a30084]
lappend results [mem_read 0xf0a30088]
lappend results [mem_read 0xf0a3008c]
lappend results [mem_read 0xf0a30090]
lappend results [mem_read 0xf0a30094]
lappend results [mem_read 0xf0a30098]
lappend results [mem_read 0xf0a3009c]
lappend results [mem_read 0xf0a300c0]
lappend results [mem_read 0xf0a300c8]
lappend results [mem_read 0xf0a30100]
lappend results [mem_read 0xf0a30108]
lappend results [mem_read 0xf0a30140]
lappend results [mem_read 0xf0a30144]
lappend results [mem_read 0xf0a30150]
lappend results [mem_read 0xf0a30154]
lappend results [mem_read 0xf0a30160]
lappend results [mem_read 0xf0a30164]
lappend results [mem_read 0xf0a30170]
lappend results [mem_read 0xf0a30174]
lappend results [mem_read 0xf0a30180]
lappend results [mem_read 0xf0a30184]
lappend results [mem_read 0xf0a30188]
lappend results [mem_read 0xf0a3018c]
lappend results [mem_read 0xf0a30190]
lappend results [mem_read 0xf0a30194]
lappend results [mem_read 0xf0a3019c]
lappend results [mem_read 0xf0a301a0]
lappend results [mem_read 0xf0a301a4]
lappend results [mem_read 0xf0a301b0]
lappend results [mem_read 0xf0a301bc]
lappend results [mem_read 0xf0a301e0]
lappend results [mem_read 0xf0a301e4]
lappend results [mem_read 0xf0a301e8]
lappend results [mem_read 0xf0a301ec]
lappend results [mem_read 0xf0a30200]
lappend results [mem_read 0xf0a30314]
lappend results [mem_read 0xf0a30ed8]
lappend results [mem_read 0xf0a30edc]
lappend results [mem_read 0xf0a30ee0]
lappend results [mem_read 0xf0a30ee4]
lappend results [mem_read 0xf0a30ee8]
lappend results [mem_read 0xf0a30eec]
lappend results [mem_read 0xf0a30ef0]
lappend results [mem_read 0xf0a30ef4]
lappend results [mem_read 0xf0a30ef8]
lappend results [mem_read 0xf0a30f00]
lappend results [mem_read 0xf0a30fa0]
lappend results [mem_read 0xf0a30fa4]
lappend results [mem_read 0xf0a30fb0]
lappend results [mem_read 0xf0a30fb4]
lappend results [mem_read 0xf0a30fb8]
lappend results [mem_read 0xf0a30fc8]
lappend results [mem_read 0xf0a30fcc]
