##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_APU0_DBG
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0d00020]
lappend results [mem_read 0xf0d00024]
lappend results [mem_read 0xf0d00030]
lappend results [mem_read 0xf0d00034]
lappend results [mem_read 0xf0d00080]
lappend results [mem_read 0xf0d00084]
lappend results [mem_read 0xf0d00088]
lappend results [mem_read 0xf0d0008c]
lappend results [mem_read 0xf0d00090]
lappend results [mem_read 0xf0d00094]
lappend results [mem_read 0xf0d00098]
lappend results [mem_read 0xf0d000a0]
lappend results [mem_read 0xf0d000a4]
lappend results [mem_read 0xf0d000a8]
lappend results [mem_read 0xf0d000ac]
lappend results [mem_read 0xf0d00300]
lappend results [mem_read 0xf0d00310]
lappend results [mem_read 0xf0d00314]
lappend results [mem_read 0xf0d00400]
lappend results [mem_read 0xf0d00404]
lappend results [mem_read 0xf0d00408]
lappend results [mem_read 0xf0d00410]
lappend results [mem_read 0xf0d00414]
lappend results [mem_read 0xf0d00418]
lappend results [mem_read 0xf0d00420]
lappend results [mem_read 0xf0d00424]
lappend results [mem_read 0xf0d00428]
lappend results [mem_read 0xf0d00430]
lappend results [mem_read 0xf0d00434]
lappend results [mem_read 0xf0d00438]
lappend results [mem_read 0xf0d00440]
lappend results [mem_read 0xf0d00444]
lappend results [mem_read 0xf0d00448]
lappend results [mem_read 0xf0d00450]
lappend results [mem_read 0xf0d00454]
lappend results [mem_read 0xf0d00458]
lappend results [mem_read 0xf0d00800]
lappend results [mem_read 0xf0d00804]
lappend results [mem_read 0xf0d00808]
lappend results [mem_read 0xf0d00810]
lappend results [mem_read 0xf0d00814]
lappend results [mem_read 0xf0d00818]
lappend results [mem_read 0xf0d00820]
lappend results [mem_read 0xf0d00824]
lappend results [mem_read 0xf0d00828]
lappend results [mem_read 0xf0d00830]
lappend results [mem_read 0xf0d00834]
lappend results [mem_read 0xf0d00838]
lappend results [mem_read 0xf0d00d00]
lappend results [mem_read 0xf0d00d20]
lappend results [mem_read 0xf0d00d24]
lappend results [mem_read 0xf0d00d28]
lappend results [mem_read 0xf0d00d2c]
lappend results [mem_read 0xf0d00d30]
lappend results [mem_read 0xf0d00d34]
lappend results [mem_read 0xf0d00d38]
lappend results [mem_read 0xf0d00d3c]
lappend results [mem_read 0xf0d00ef8]
lappend results [mem_read 0xf0d00efc]
lappend results [mem_read 0xf0d00f00]
lappend results [mem_read 0xf0d00fa0]
lappend results [mem_read 0xf0d00fa4]
lappend results [mem_read 0xf0d00fa8]
lappend results [mem_read 0xf0d00fac]
lappend results [mem_read 0xf0d00fb0]
lappend results [mem_read 0xf0d00fb4]
lappend results [mem_read 0xf0d00fb8]
lappend results [mem_read 0xf0d00fbc]
lappend results [mem_read 0xf0d00fc0]
lappend results [mem_read 0xf0d00fc4]
lappend results [mem_read 0xf0d00fc8]
lappend results [mem_read 0xf0d00fcc]
