##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_STM
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0b70c04]
lappend results [mem_read 0xf0b70c08]
lappend results [mem_read 0xf0b70c0c]
lappend results [mem_read 0xf0b70c10]
lappend results [mem_read 0xf0b70cfc]
lappend results [mem_read 0xf0b70d00]
lappend results [mem_read 0xf0b70d20]
lappend results [mem_read 0xf0b70d60]
lappend results [mem_read 0xf0b70d64]
lappend results [mem_read 0xf0b70d68]
lappend results [mem_read 0xf0b70df4]
lappend results [mem_read 0xf0b70df8]
lappend results [mem_read 0xf0b70dfc]
lappend results [mem_read 0xf0b70e00]
lappend results [mem_read 0xf0b70e20]
lappend results [mem_read 0xf0b70e60]
lappend results [mem_read 0xf0b70e64]
lappend results [mem_read 0xf0b70e68]
lappend results [mem_read 0xf0b70e6c]
lappend results [mem_read 0xf0b70e70]
lappend results [mem_read 0xf0b70e80]
lappend results [mem_read 0xf0b70e84]
lappend results [mem_read 0xf0b70e8c]
lappend results [mem_read 0xf0b70e90]
lappend results [mem_read 0xf0b70e94]
lappend results [mem_read 0xf0b70ea0]
lappend results [mem_read 0xf0b70ea4]
lappend results [mem_read 0xf0b70ea8]
lappend results [mem_read 0xf0b70ee8]
lappend results [mem_read 0xf0b70eec]
lappend results [mem_read 0xf0b70ef0]
lappend results [mem_read 0xf0b70ef4]
lappend results [mem_read 0xf0b70ef8]
lappend results [mem_read 0xf0b70f00]
lappend results [mem_read 0xf0b70fa0]
lappend results [mem_read 0xf0b70fa4]
lappend results [mem_read 0xf0b70fb0]
lappend results [mem_read 0xf0b70fb4]
lappend results [mem_read 0xf0b70fb8]
lappend results [mem_read 0xf0b70fbc]
lappend results [mem_read 0xf0b70fc8]
lappend results [mem_read 0xf0b70fcc]
lappend results [mem_read 0xf0b70fe0]
lappend results [mem_read 0xf0b70fe4]
lappend results [mem_read 0xf0b70fe8]
lappend results [mem_read 0xf0b70fec]
lappend results [mem_read 0xf0b70fd0]
lappend results [mem_read 0xf0b70fd4]
lappend results [mem_read 0xf0b70fd8]
lappend results [mem_read 0xf0b70fdc]
lappend results [mem_read 0xf0b70ff0]
lappend results [mem_read 0xf0b70ff4]
lappend results [mem_read 0xf0b70ff8]
lappend results [mem_read 0xf0b70ffc]
