##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_RPU0_DBG
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0a00000]
lappend results [mem_read 0xf0a00018]
lappend results [mem_read 0xf0a0001c]
lappend results [mem_read 0xf0a00028]
lappend results [mem_read 0xf0a00080]
lappend results [mem_read 0xf0a00084]
lappend results [mem_read 0xf0a00088]
lappend results [mem_read 0xf0a0008c]
lappend results [mem_read 0xf0a00090]
lappend results [mem_read 0xf0a00100]
lappend results [mem_read 0xf0a00104]
lappend results [mem_read 0xf0a00108]
lappend results [mem_read 0xf0a0010c]
lappend results [mem_read 0xf0a00110]
lappend results [mem_read 0xf0a00114]
lappend results [mem_read 0xf0a00118]
lappend results [mem_read 0xf0a0011c]
lappend results [mem_read 0xf0a00140]
lappend results [mem_read 0xf0a00144]
lappend results [mem_read 0xf0a00148]
lappend results [mem_read 0xf0a0014c]
lappend results [mem_read 0xf0a00150]
lappend results [mem_read 0xf0a00154]
lappend results [mem_read 0xf0a00158]
lappend results [mem_read 0xf0a0015c]
lappend results [mem_read 0xf0a00180]
lappend results [mem_read 0xf0a00184]
lappend results [mem_read 0xf0a00188]
lappend results [mem_read 0xf0a0018c]
lappend results [mem_read 0xf0a00190]
lappend results [mem_read 0xf0a00194]
lappend results [mem_read 0xf0a00198]
lappend results [mem_read 0xf0a0019c]
lappend results [mem_read 0xf0a001c0]
lappend results [mem_read 0xf0a001c4]
lappend results [mem_read 0xf0a001c8]
lappend results [mem_read 0xf0a001cc]
lappend results [mem_read 0xf0a001d0]
lappend results [mem_read 0xf0a001d4]
lappend results [mem_read 0xf0a001d8]
lappend results [mem_read 0xf0a001dc]
lappend results [mem_read 0xf0a00304]
lappend results [mem_read 0xf0a00310]
lappend results [mem_read 0xf0a00314]
lappend results [mem_read 0xf0a00d00]
lappend results [mem_read 0xf0a00d04]
lappend results [mem_read 0xf0a00d08]
lappend results [mem_read 0xf0a00d10]
lappend results [mem_read 0xf0a00d14]
lappend results [mem_read 0xf0a00d20]
lappend results [mem_read 0xf0a00d24]
lappend results [mem_read 0xf0a00d28]
lappend results [mem_read 0xf0a00d2c]
lappend results [mem_read 0xf0a00d30]
lappend results [mem_read 0xf0a00d34]
lappend results [mem_read 0xf0a00d38]
lappend results [mem_read 0xf0a00d3c]
lappend results [mem_read 0xf0a00d40]
lappend results [mem_read 0xf0a00d44]
lappend results [mem_read 0xf0a00d48]
lappend results [mem_read 0xf0a00d4c]
lappend results [mem_read 0xf0a00d50]
lappend results [mem_read 0xf0a00d54]
lappend results [mem_read 0xf0a00ed8]
lappend results [mem_read 0xf0a00ef8]
lappend results [mem_read 0xf0a00efc]
lappend results [mem_read 0xf0a00f00]
lappend results [mem_read 0xf0a00fa0]
lappend results [mem_read 0xf0a00fa4]
lappend results [mem_read 0xf0a00fb0]
lappend results [mem_read 0xf0a00fb4]
lappend results [mem_read 0xf0a00fb8]
lappend results [mem_read 0xf0a00fc8]
lappend results [mem_read 0xf0a00fcc]
