##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: PSM_GLOBAL
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xffc90000]
lappend results [mem_read 0xffc90008]
lappend results [mem_read 0xffc90010]
lappend results [mem_read 0xffc90014]
lappend results [mem_read 0xffc90018]
lappend results [mem_read 0xffc9001c]
lappend results [mem_read 0xffc90020]
lappend results [mem_read 0xffc90024]
lappend results [mem_read 0xffc90030]
lappend results [mem_read 0xffc90034]
lappend results [mem_read 0xffc90038]
lappend results [mem_read 0xffc9003c]
lappend results [mem_read 0xffc90040]
lappend results [mem_read 0xffc90044]
lappend results [mem_read 0xffc90048]
lappend results [mem_read 0xffc9004c]
lappend results [mem_read 0xffc90050]
lappend results [mem_read 0xffc90054]
lappend results [mem_read 0xffc90058]
lappend results [mem_read 0xffc9005c]
lappend results [mem_read 0xffc90060]
lappend results [mem_read 0xffc90064]
lappend results [mem_read 0xffc90068]
lappend results [mem_read 0xffc9006c]
lappend results [mem_read 0xffc90100]
lappend results [mem_read 0xffc90104]
lappend results [mem_read 0xffc90110]
lappend results [mem_read 0xffc90114]
lappend results [mem_read 0xffc90118]
lappend results [mem_read 0xffc9011c]
lappend results [mem_read 0xffc90120]
lappend results [mem_read 0xffc90210]
lappend results [mem_read 0xffc90214]
lappend results [mem_read 0xffc90218]
lappend results [mem_read 0xffc9021c]
lappend results [mem_read 0xffc90220]
lappend results [mem_read 0xffc90310]
lappend results [mem_read 0xffc90314]
lappend results [mem_read 0xffc90318]
lappend results [mem_read 0xffc9031c]
lappend results [mem_read 0xffc90320]
lappend results [mem_read 0xffc90410]
lappend results [mem_read 0xffc90414]
lappend results [mem_read 0xffc90418]
lappend results [mem_read 0xffc9041c]
lappend results [mem_read 0xffc90420]
lappend results [mem_read 0xffc90700]
lappend results [mem_read 0xffc90704]
lappend results [mem_read 0xffc90708]
lappend results [mem_read 0xffc9070c]
lappend results [mem_read 0xffc90710]
lappend results [mem_read 0xffc90714]
lappend results [mem_read 0xffc90718]
lappend results [mem_read 0xffc9071c]
lappend results [mem_read 0xffc90720]
lappend results [mem_read 0xffc90724]
lappend results [mem_read 0xffc90808]
lappend results [mem_read 0xffc90a00]
lappend results [mem_read 0xffc91000]
lappend results [mem_read 0xffc91004]
lappend results [mem_read 0xffc91010]
lappend results [mem_read 0xffc91014]
lappend results [mem_read 0xffc91020]
lappend results [mem_read 0xffc91024]
lappend results [mem_read 0xffc91028]
lappend results [mem_read 0xffc91030]
lappend results [mem_read 0xffc91034]
lappend results [mem_read 0xffc91038]
lappend results [mem_read 0xffc91040]
lappend results [mem_read 0xffc91044]
lappend results [mem_read 0xffc91048]
lappend results [mem_read 0xffc91050]
lappend results [mem_read 0xffc91054]
lappend results [mem_read 0xffc91058]
lappend results [mem_read 0xffc91060]
lappend results [mem_read 0xffc91064]
lappend results [mem_read 0xffc91068]
lappend results [mem_read 0xffc91070]
lappend results [mem_read 0xffc91074]
lappend results [mem_read 0xffc91078]
lappend results [mem_read 0xffc92000]
lappend results [mem_read 0xffc92004]
lappend results [mem_read 0xffc92008]
lappend results [mem_read 0xffc9200c]
lappend results [mem_read 0xffc92014]
lappend results [mem_read 0xffc92018]
lappend results [mem_read 0xffc9201c]
lappend results [mem_read 0xffc92020]
lappend results [mem_read 0xffc92028]
lappend results [mem_read 0xffc9202c]
lappend results [mem_read 0xffc92030]
lappend results [mem_read 0xffc92034]
lappend results [mem_read 0xffc9203c]
lappend results [mem_read 0xffc92040]
lappend results [mem_read 0xffc92044]
lappend results [mem_read 0xffc92048]
lappend results [mem_read 0xffc92050]
lappend results [mem_read 0xffc92054]
lappend results [mem_read 0xffc92058]
lappend results [mem_read 0xffc9205c]
lappend results [mem_read 0xffc920a0]
lappend results [mem_read 0xffc920a4]
lappend results [mem_read 0xffc920a8]
lappend results [mem_read 0xffc920ac]
