var _createPredicateIndexFinder = require('./_createPredicateIndexFinder.js'); // Returns the first index on an array-like that passes a truth test.


var findIndex = _createPredicateIndexFinder(1);

module.exports = findIndex;