##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: XRAM_XMPU1
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff934000]
lappend results [mem_read 0xff934004]
lappend results [mem_read 0xff934008]
lappend results [mem_read 0xff93400c]
lappend results [mem_read 0xff934010]
lappend results [mem_read 0xff934014]
lappend results [mem_read 0xff934018]
lappend results [mem_read 0xff93401c]
lappend results [mem_read 0xff934020]
lappend results [mem_read 0xff934100]
lappend results [mem_read 0xff934104]
lappend results [mem_read 0xff934108]
lappend results [mem_read 0xff93410c]
lappend results [mem_read 0xff934110]
lappend results [mem_read 0xff934114]
lappend results [mem_read 0xff934118]
lappend results [mem_read 0xff93411c]
lappend results [mem_read 0xff934120]
lappend results [mem_read 0xff934124]
lappend results [mem_read 0xff934128]
lappend results [mem_read 0xff93412c]
lappend results [mem_read 0xff934130]
lappend results [mem_read 0xff934134]
lappend results [mem_read 0xff934138]
lappend results [mem_read 0xff93413c]
lappend results [mem_read 0xff934140]
lappend results [mem_read 0xff934144]
lappend results [mem_read 0xff934148]
lappend results [mem_read 0xff93414c]
lappend results [mem_read 0xff934150]
lappend results [mem_read 0xff934154]
lappend results [mem_read 0xff934158]
lappend results [mem_read 0xff93415c]
lappend results [mem_read 0xff934160]
lappend results [mem_read 0xff934164]
lappend results [mem_read 0xff934168]
lappend results [mem_read 0xff93416c]
lappend results [mem_read 0xff934170]
lappend results [mem_read 0xff934174]
lappend results [mem_read 0xff934178]
lappend results [mem_read 0xff93417c]
lappend results [mem_read 0xff934180]
lappend results [mem_read 0xff934184]
lappend results [mem_read 0xff934188]
lappend results [mem_read 0xff93418c]
lappend results [mem_read 0xff934190]
lappend results [mem_read 0xff934194]
lappend results [mem_read 0xff934198]
lappend results [mem_read 0xff93419c]
lappend results [mem_read 0xff9341a0]
lappend results [mem_read 0xff9341a4]
lappend results [mem_read 0xff9341a8]
lappend results [mem_read 0xff9341ac]
lappend results [mem_read 0xff9341b0]
lappend results [mem_read 0xff9341b4]
lappend results [mem_read 0xff9341b8]
lappend results [mem_read 0xff9341bc]
lappend results [mem_read 0xff9341c0]
lappend results [mem_read 0xff9341c4]
lappend results [mem_read 0xff9341c8]
lappend results [mem_read 0xff9341cc]
lappend results [mem_read 0xff9341d0]
lappend results [mem_read 0xff9341d4]
lappend results [mem_read 0xff9341d8]
lappend results [mem_read 0xff9341dc]
lappend results [mem_read 0xff9341e0]
lappend results [mem_read 0xff9341e4]
lappend results [mem_read 0xff9341e8]
lappend results [mem_read 0xff9341ec]
lappend results [mem_read 0xff9341f0]
lappend results [mem_read 0xff9341f4]
lappend results [mem_read 0xff9341f8]
lappend results [mem_read 0xff9341fc]
lappend results [mem_read 0xff934200]
lappend results [mem_read 0xff934204]
lappend results [mem_read 0xff934208]
lappend results [mem_read 0xff93420c]
lappend results [mem_read 0xff934210]
lappend results [mem_read 0xff934214]
lappend results [mem_read 0xff934218]
lappend results [mem_read 0xff93421c]
lappend results [mem_read 0xff934220]
lappend results [mem_read 0xff934224]
lappend results [mem_read 0xff934228]
lappend results [mem_read 0xff93422c]
lappend results [mem_read 0xff934238]
lappend results [mem_read 0xff93423c]
lappend results [mem_read 0xff934240]
lappend results [mem_read 0xff934244]
lappend results [mem_read 0xff934248]
lappend results [mem_read 0xff93424c]
lappend results [mem_read 0xff934250]
lappend results [mem_read 0xff934254]
lappend results [mem_read 0xff934258]
lappend results [mem_read 0xff93425c]
lappend results [mem_read 0xff934260]
lappend results [mem_read 0xff934264]
lappend results [mem_read 0xff934268]
lappend results [mem_read 0xff93426c]
lappend results [mem_read 0xff934270]
lappend results [mem_read 0xff934274]
lappend results [mem_read 0xff934278]
lappend results [mem_read 0xff93427c]
lappend results [mem_read 0xff934280]
lappend results [mem_read 0xff934284]
