define(['./underscore', './toPath'], function (underscore, toPath$1) {
  // Internal wrapper for `_.toPath` to enable minification.
  // Similar to `cb` for `_.iteratee`.
  function toPath(path) {
    return underscore.toPath(path);
  }

  return toPath;
});