##
# Copyright (c) 2021 Xilinx, Inc.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
# associated documentation files (the "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial
# portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

#
#
#
##
0xF62C0804 0x00000000 reg_ref_0
0xF62C0228 0x05100080 reg_ref_1
0xF62C022C 0x00009002 reg_ref_3
0xF62C080C 0x00020000 reg_com_1
0xF62C0810 0x00020000 reg_com_2
0xF62C0234 0x00200918 reg_mrs_0
0xF62C0240 0xFF401550 reg_scrub0
0xF62C0258 0x00401210 reg_config0
0xF62C025C 0x00000011 reg_pinout
0xF62C0824 0x00000006 reg_config1
0xF62C0828 0x00000641 reg_config2
0xF62C0220 0x062B604C reg_retry_0
0xF6210044 0x30C30C30 reg_adec4
0xF6210048 0x15513491 reg_adec5
0xF621004C 0x1A6585D6 reg_adec6
0xF6210050 0x1F79D71B reg_adec7
0xF6210054 0x03C30C20 reg_adec8
0xF6210058 0x0C2CA144 reg_adec9
0xF621005C 0x0840F38D reg_adec10
0xF6210060 0x00C07189 reg_adec11
0xF62C082C 0x00000000 cal_mode
0xF62C08B0 0x0000007F seq_cmd_default
0xF62C0964 0x00000000 t_txbit
0xF62C0960 0x000000A5 default_pattern
0xF62C0944 0x00000414 xpi_oe_all_nib
0xF62C0948 0x00000414 xpi_wrdata_all_nib
0xF62C0830 0x00000016 phy_rden0
0xF62C0834 0x00000016 phy_rden1
0xF62C0838 0x00000016 phy_rden2
0xF62C083C 0x00000016 phy_rden3
0xF62C0840 0x00000016 phy_rden4
0xF62C0844 0x00000016 phy_rden5
0xF62C0848 0x00000016 phy_rden6
0xF62C084C 0x00000016 phy_rden7
0xF62C0850 0x00000016 phy_rden8
0xF62C0854 0x00000016 phy_rden9
0xF62C0858 0x00000016 phy_rden10
0xF62C085C 0x00000016 phy_rden11
0xF62C0860 0x00000016 phy_rden12
0xF62C0864 0x00000016 phy_rden13
0xF62C0868 0x00000016 phy_rden14
0xF62C086C 0x00000016 phy_rden15
0xF62C0870 0x00000016 phy_rden16
0xF62C0874 0x00000016 phy_rden17
0xF62C0878 0x00000016 phy_rden18
0xF62C087C 0x00000016 phy_rden19
0xF62C0880 0x00000016 phy_rden20
0xF62C0884 0x00000016 phy_rden21
0xF62C0888 0x00000016 phy_rden22
0xF62C088C 0x00000016 phy_rden23
0xF62C0890 0x00000016 phy_rden24
0xF62C0894 0x00000016 phy_rden25
0xF62C0898 0x00000016 phy_rden26
0xF62C089C 0x0000000F fifo_rden
0xF62C0958 0x00000001 xpi_write_dm_dbi
0xF62C095C 0x00000000 xpi_read_dbi
0xF62C094C 0x00000101 xpi_oe
0xF62C08C4 0x00000070 seq_cmd_por
0xF62C0224 0x0B068140 reg_retry_1
