var underscore = require('./underscore.js');

require('./toPath.js'); // Internal wrapper for `_.toPath` to enable minification.
// Similar to `cb` for `_.iteratee`.


function toPath(path) {
  return underscore.toPath(path);
}

module.exports = toPath;