##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM5_DPLL0_ATTR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfce30000]
lappend results [mem_read 0xfce30004]
lappend results [mem_read 0xfce30008]
lappend results [mem_read 0xfce3000c]
lappend results [mem_read 0xfce30010]
lappend results [mem_read 0xfce30014]
lappend results [mem_read 0xfce30018]
lappend results [mem_read 0xfce3001c]
lappend results [mem_read 0xfce30020]
lappend results [mem_read 0xfce30024]
lappend results [mem_read 0xfce30030]
lappend results [mem_read 0xfce30034]
lappend results [mem_read 0xfce30038]
lappend results [mem_read 0xfce3003c]
lappend results [mem_read 0xfce30040]
lappend results [mem_read 0xfce30044]
lappend results [mem_read 0xfce30048]
lappend results [mem_read 0xfce3004c]
lappend results [mem_read 0xfce30050]
lappend results [mem_read 0xfce30054]
lappend results [mem_read 0xfce30058]
lappend results [mem_read 0xfce3005c]
lappend results [mem_read 0xfce30060]
lappend results [mem_read 0xfce30064]
lappend results [mem_read 0xfce30068]
lappend results [mem_read 0xfce3006c]
lappend results [mem_read 0xfce30070]
lappend results [mem_read 0xfce30074]
lappend results [mem_read 0xfce30078]
lappend results [mem_read 0xfce3007c]
lappend results [mem_read 0xfce30080]
lappend results [mem_read 0xfce30084]
lappend results [mem_read 0xfce30088]
lappend results [mem_read 0xfce3008c]
lappend results [mem_read 0xfce30090]
lappend results [mem_read 0xfce30094]
lappend results [mem_read 0xfce30098]
lappend results [mem_read 0xfce3009c]
lappend results [mem_read 0xfce300a0]
lappend results [mem_read 0xfce300a4]
lappend results [mem_read 0xfce300a8]
lappend results [mem_read 0xfce300ac]
lappend results [mem_read 0xfce300b0]
lappend results [mem_read 0xfce300b4]
lappend results [mem_read 0xfce300b8]
