##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: RPU_GIC_PL390
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf9001000]
lappend results [mem_read 0xf9001004]
lappend results [mem_read 0xf9001008]
lappend results [mem_read 0xf900100c]
lappend results [mem_read 0xf9001010]
lappend results [mem_read 0xf9001014]
lappend results [mem_read 0xf9001018]
lappend results [mem_read 0xf900101c]
lappend results [mem_read 0xf9001050]
lappend results [mem_read 0xf9001054]
lappend results [mem_read 0xf90010fc]
lappend results [mem_read 0xf9001fd0]
lappend results [mem_read 0xf9001fd4]
lappend results [mem_read 0xf9001fd8]
lappend results [mem_read 0xf9001fdc]
lappend results [mem_read 0xf9001fe0]
lappend results [mem_read 0xf9001fe4]
lappend results [mem_read 0xf9001fe8]
lappend results [mem_read 0xf9001fec]
lappend results [mem_read 0xf9001fc0]
lappend results [mem_read 0xf9000000]
lappend results [mem_read 0xf9000004]
lappend results [mem_read 0xf9000008]
lappend results [mem_read 0xf9000080]
lappend results [mem_read 0xf9000084]
lappend results [mem_read 0xf9000088]
lappend results [mem_read 0xf900008c]
lappend results [mem_read 0xf9000090]
lappend results [mem_read 0xf9000094]
lappend results [mem_read 0xf9000104]
lappend results [mem_read 0xf9000108]
lappend results [mem_read 0xf900010c]
lappend results [mem_read 0xf9000110]
lappend results [mem_read 0xf9000114]
lappend results [mem_read 0xf9000184]
lappend results [mem_read 0xf9000188]
lappend results [mem_read 0xf900018c]
lappend results [mem_read 0xf9000190]
lappend results [mem_read 0xf9000194]
lappend results [mem_read 0xf9000204]
lappend results [mem_read 0xf9000208]
lappend results [mem_read 0xf900020c]
lappend results [mem_read 0xf9000210]
lappend results [mem_read 0xf9000214]
lappend results [mem_read 0xf9000280]
lappend results [mem_read 0xf9000284]
lappend results [mem_read 0xf9000288]
lappend results [mem_read 0xf900028c]
lappend results [mem_read 0xf9000290]
lappend results [mem_read 0xf9000294]
lappend results [mem_read 0xf9000300]
lappend results [mem_read 0xf9000304]
lappend results [mem_read 0xf9000308]
lappend results [mem_read 0xf900030c]
lappend results [mem_read 0xf9000310]
lappend results [mem_read 0xf9000314]
lappend results [mem_read 0xf9000400]
lappend results [mem_read16 0xf9000401]
lappend results [mem_read16 0xf9000402]
lappend results [mem_read16 0xf9000403]
lappend results [mem_read 0xf9000404]
lappend results [mem_read16 0xf9000405]
lappend results [mem_read16 0xf9000406]
lappend results [mem_read16 0xf9000407]
lappend results [mem_read 0xf9000408]
lappend results [mem_read16 0xf9000409]
lappend results [mem_read16 0xf900040a]
lappend results [mem_read16 0xf900040b]
lappend results [mem_read 0xf900040c]
lappend results [mem_read16 0xf900040d]
lappend results [mem_read16 0xf900040e]
lappend results [mem_read16 0xf900040f]
lappend results [mem_read 0xf9000420]
lappend results [mem_read16 0xf9000421]
lappend results [mem_read16 0xf9000422]
lappend results [mem_read16 0xf9000423]
lappend results [mem_read 0xf9000424]
lappend results [mem_read16 0xf9000425]
lappend results [mem_read16 0xf9000426]
lappend results [mem_read16 0xf9000427]
lappend results [mem_read 0xf9000428]
lappend results [mem_read16 0xf9000429]
lappend results [mem_read16 0xf900042a]
lappend results [mem_read16 0xf900042b]
lappend results [mem_read 0xf900042c]
lappend results [mem_read16 0xf900042d]
lappend results [mem_read16 0xf900042e]
lappend results [mem_read16 0xf900042f]
lappend results [mem_read 0xf9000430]
lappend results [mem_read16 0xf9000431]
lappend results [mem_read16 0xf9000432]
lappend results [mem_read16 0xf9000433]
lappend results [mem_read 0xf9000434]
lappend results [mem_read16 0xf9000435]
lappend results [mem_read16 0xf9000436]
lappend results [mem_read16 0xf9000437]
lappend results [mem_read 0xf9000438]
lappend results [mem_read16 0xf9000439]
lappend results [mem_read16 0xf900043a]
lappend results [mem_read16 0xf900043b]
lappend results [mem_read 0xf900043c]
lappend results [mem_read16 0xf900043d]
lappend results [mem_read16 0xf900043e]
lappend results [mem_read16 0xf900043f]
lappend results [mem_read 0xf9000440]
lappend results [mem_read16 0xf9000441]
lappend results [mem_read16 0xf9000442]
lappend results [mem_read16 0xf9000443]
lappend results [mem_read 0xf9000444]
lappend results [mem_read16 0xf9000445]
lappend results [mem_read16 0xf9000446]
lappend results [mem_read16 0xf9000447]
lappend results [mem_read 0xf9000448]
lappend results [mem_read16 0xf9000449]
lappend results [mem_read16 0xf900044a]
lappend results [mem_read16 0xf900044b]
lappend results [mem_read 0xf900044c]
lappend results [mem_read16 0xf900044d]
lappend results [mem_read16 0xf900044e]
lappend results [mem_read16 0xf900044f]
lappend results [mem_read 0xf9000450]
lappend results [mem_read16 0xf9000451]
lappend results [mem_read16 0xf9000452]
lappend results [mem_read16 0xf9000453]
lappend results [mem_read 0xf9000454]
lappend results [mem_read16 0xf9000455]
lappend results [mem_read16 0xf9000456]
lappend results [mem_read16 0xf9000457]
lappend results [mem_read 0xf9000458]
lappend results [mem_read16 0xf9000459]
lappend results [mem_read16 0xf900045a]
lappend results [mem_read16 0xf900045b]
lappend results [mem_read 0xf900045c]
lappend results [mem_read16 0xf900045d]
lappend results [mem_read16 0xf900045e]
lappend results [mem_read16 0xf900045f]
lappend results [mem_read 0xf9000460]
lappend results [mem_read16 0xf9000461]
lappend results [mem_read16 0xf9000462]
lappend results [mem_read16 0xf9000463]
lappend results [mem_read 0xf9000464]
lappend results [mem_read16 0xf9000465]
lappend results [mem_read16 0xf9000466]
lappend results [mem_read16 0xf9000467]
lappend results [mem_read 0xf9000468]
lappend results [mem_read16 0xf9000469]
lappend results [mem_read16 0xf900046a]
lappend results [mem_read16 0xf900046b]
lappend results [mem_read 0xf900046c]
lappend results [mem_read16 0xf900046d]
lappend results [mem_read16 0xf900046e]
lappend results [mem_read16 0xf900046f]
lappend results [mem_read 0xf9000470]
lappend results [mem_read16 0xf9000471]
lappend results [mem_read16 0xf9000472]
lappend results [mem_read16 0xf9000473]
lappend results [mem_read 0xf9000474]
lappend results [mem_read16 0xf9000475]
lappend results [mem_read16 0xf9000476]
lappend results [mem_read16 0xf9000477]
lappend results [mem_read 0xf9000478]
lappend results [mem_read16 0xf9000479]
lappend results [mem_read16 0xf900047a]
lappend results [mem_read16 0xf900047b]
lappend results [mem_read 0xf900047c]
lappend results [mem_read16 0xf900047d]
lappend results [mem_read16 0xf900047e]
lappend results [mem_read16 0xf900047f]
lappend results [mem_read 0xf9000480]
lappend results [mem_read16 0xf9000481]
lappend results [mem_read16 0xf9000482]
lappend results [mem_read16 0xf9000483]
lappend results [mem_read 0xf9000484]
lappend results [mem_read16 0xf9000485]
lappend results [mem_read16 0xf9000486]
lappend results [mem_read16 0xf9000487]
lappend results [mem_read 0xf9000488]
lappend results [mem_read16 0xf9000489]
lappend results [mem_read16 0xf900048a]
lappend results [mem_read16 0xf900048b]
lappend results [mem_read 0xf900048c]
lappend results [mem_read16 0xf900048d]
lappend results [mem_read16 0xf900048e]
lappend results [mem_read16 0xf900048f]
lappend results [mem_read 0xf9000490]
lappend results [mem_read16 0xf9000491]
lappend results [mem_read16 0xf9000492]
lappend results [mem_read16 0xf9000493]
lappend results [mem_read 0xf9000494]
lappend results [mem_read16 0xf9000495]
lappend results [mem_read16 0xf9000496]
lappend results [mem_read16 0xf9000497]
lappend results [mem_read 0xf9000498]
lappend results [mem_read16 0xf9000499]
lappend results [mem_read16 0xf900049a]
lappend results [mem_read16 0xf900049b]
lappend results [mem_read 0xf900049c]
lappend results [mem_read16 0xf900049d]
lappend results [mem_read16 0xf900049e]
lappend results [mem_read16 0xf900049f]
lappend results [mem_read 0xf90004a0]
lappend results [mem_read16 0xf90004a1]
lappend results [mem_read16 0xf90004a2]
lappend results [mem_read16 0xf90004a3]
lappend results [mem_read 0xf90004a4]
lappend results [mem_read16 0xf90004a5]
lappend results [mem_read16 0xf90004a6]
lappend results [mem_read16 0xf90004a7]
lappend results [mem_read 0xf90004a8]
lappend results [mem_read16 0xf90004a9]
lappend results [mem_read16 0xf90004aa]
lappend results [mem_read16 0xf90004ab]
lappend results [mem_read 0xf90004ac]
lappend results [mem_read16 0xf90004ad]
lappend results [mem_read16 0xf90004ae]
lappend results [mem_read16 0xf90004af]
lappend results [mem_read 0xf90004b0]
lappend results [mem_read16 0xf90004b1]
lappend results [mem_read16 0xf90004b2]
lappend results [mem_read16 0xf90004b3]
lappend results [mem_read 0xf90004b4]
lappend results [mem_read16 0xf90004b5]
lappend results [mem_read16 0xf90004b6]
lappend results [mem_read16 0xf90004b7]
lappend results [mem_read 0xf90004b8]
lappend results [mem_read16 0xf90004b9]
lappend results [mem_read16 0xf90004ba]
lappend results [mem_read16 0xf90004bb]
lappend results [mem_read 0xf90004bc]
lappend results [mem_read16 0xf90004bd]
lappend results [mem_read16 0xf90004be]
lappend results [mem_read16 0xf90004bf]
lappend results [mem_read 0xf9000820]
lappend results [mem_read16 0xf9000821]
lappend results [mem_read16 0xf9000822]
lappend results [mem_read16 0xf9000823]
lappend results [mem_read 0xf9000824]
lappend results [mem_read16 0xf9000825]
lappend results [mem_read16 0xf9000826]
lappend results [mem_read16 0xf9000827]
lappend results [mem_read 0xf9000828]
lappend results [mem_read16 0xf9000829]
lappend results [mem_read16 0xf900082a]
lappend results [mem_read16 0xf900082b]
lappend results [mem_read 0xf900082c]
lappend results [mem_read16 0xf900082d]
lappend results [mem_read16 0xf900082e]
lappend results [mem_read16 0xf900082f]
lappend results [mem_read 0xf9000830]
lappend results [mem_read16 0xf9000831]
lappend results [mem_read16 0xf9000832]
lappend results [mem_read16 0xf9000833]
lappend results [mem_read 0xf9000834]
lappend results [mem_read16 0xf9000835]
lappend results [mem_read16 0xf9000836]
lappend results [mem_read16 0xf9000837]
lappend results [mem_read 0xf9000838]
lappend results [mem_read16 0xf9000839]
lappend results [mem_read16 0xf900083a]
lappend results [mem_read16 0xf900083b]
lappend results [mem_read 0xf900083c]
lappend results [mem_read16 0xf900083d]
lappend results [mem_read16 0xf900083e]
lappend results [mem_read16 0xf900083f]
lappend results [mem_read 0xf9000840]
lappend results [mem_read16 0xf9000841]
lappend results [mem_read16 0xf9000842]
lappend results [mem_read16 0xf9000843]
lappend results [mem_read 0xf9000844]
lappend results [mem_read16 0xf9000845]
lappend results [mem_read16 0xf9000846]
lappend results [mem_read16 0xf9000847]
lappend results [mem_read 0xf9000848]
lappend results [mem_read16 0xf9000849]
lappend results [mem_read16 0xf900084a]
lappend results [mem_read16 0xf900084b]
lappend results [mem_read 0xf900084c]
lappend results [mem_read16 0xf900084d]
lappend results [mem_read16 0xf900084e]
lappend results [mem_read16 0xf900084f]
lappend results [mem_read 0xf9000850]
lappend results [mem_read16 0xf9000851]
lappend results [mem_read16 0xf9000852]
lappend results [mem_read16 0xf9000853]
lappend results [mem_read 0xf9000854]
lappend results [mem_read16 0xf9000855]
lappend results [mem_read16 0xf9000856]
lappend results [mem_read16 0xf9000857]
lappend results [mem_read 0xf9000858]
lappend results [mem_read16 0xf9000859]
lappend results [mem_read16 0xf900085a]
lappend results [mem_read16 0xf900085b]
lappend results [mem_read 0xf900085c]
lappend results [mem_read16 0xf900085d]
lappend results [mem_read16 0xf900085e]
lappend results [mem_read16 0xf900085f]
lappend results [mem_read 0xf9000860]
lappend results [mem_read16 0xf9000861]
lappend results [mem_read16 0xf9000862]
lappend results [mem_read16 0xf9000863]
lappend results [mem_read 0xf9000864]
lappend results [mem_read16 0xf9000865]
lappend results [mem_read16 0xf9000866]
lappend results [mem_read16 0xf9000867]
lappend results [mem_read 0xf9000868]
lappend results [mem_read16 0xf9000869]
lappend results [mem_read16 0xf900086a]
lappend results [mem_read16 0xf900086b]
lappend results [mem_read 0xf900086c]
lappend results [mem_read16 0xf900086d]
lappend results [mem_read16 0xf900086e]
lappend results [mem_read16 0xf900086f]
lappend results [mem_read 0xf9000870]
lappend results [mem_read16 0xf9000871]
lappend results [mem_read16 0xf9000872]
lappend results [mem_read16 0xf9000873]
lappend results [mem_read 0xf9000874]
lappend results [mem_read16 0xf9000875]
lappend results [mem_read16 0xf9000876]
lappend results [mem_read16 0xf9000877]
lappend results [mem_read 0xf9000878]
lappend results [mem_read16 0xf9000879]
lappend results [mem_read16 0xf900087a]
lappend results [mem_read16 0xf900087b]
lappend results [mem_read 0xf900087c]
lappend results [mem_read16 0xf900087d]
lappend results [mem_read16 0xf900087e]
lappend results [mem_read16 0xf900087f]
lappend results [mem_read 0xf9000880]
lappend results [mem_read16 0xf9000881]
lappend results [mem_read16 0xf9000882]
lappend results [mem_read16 0xf9000883]
lappend results [mem_read 0xf9000884]
lappend results [mem_read16 0xf9000885]
lappend results [mem_read16 0xf9000886]
lappend results [mem_read16 0xf9000887]
lappend results [mem_read 0xf9000888]
lappend results [mem_read16 0xf9000889]
lappend results [mem_read16 0xf900088a]
lappend results [mem_read16 0xf900088b]
lappend results [mem_read 0xf900088c]
lappend results [mem_read16 0xf900088d]
lappend results [mem_read16 0xf900088e]
lappend results [mem_read16 0xf900088f]
lappend results [mem_read 0xf9000890]
lappend results [mem_read16 0xf9000891]
lappend results [mem_read16 0xf9000892]
lappend results [mem_read16 0xf9000893]
lappend results [mem_read 0xf9000894]
lappend results [mem_read16 0xf9000895]
lappend results [mem_read16 0xf9000896]
lappend results [mem_read16 0xf9000897]
lappend results [mem_read 0xf9000898]
lappend results [mem_read16 0xf9000899]
lappend results [mem_read16 0xf900089a]
lappend results [mem_read16 0xf900089b]
lappend results [mem_read 0xf900089c]
lappend results [mem_read16 0xf900089d]
lappend results [mem_read16 0xf900089e]
lappend results [mem_read16 0xf900089f]
lappend results [mem_read 0xf90008a0]
lappend results [mem_read16 0xf90008a1]
lappend results [mem_read16 0xf90008a2]
lappend results [mem_read16 0xf90008a3]
lappend results [mem_read 0xf90008a4]
lappend results [mem_read16 0xf90008a5]
lappend results [mem_read16 0xf90008a6]
lappend results [mem_read16 0xf90008a7]
lappend results [mem_read 0xf90008a8]
lappend results [mem_read16 0xf90008a9]
lappend results [mem_read16 0xf90008aa]
lappend results [mem_read16 0xf90008ab]
lappend results [mem_read 0xf90008ac]
lappend results [mem_read16 0xf90008ad]
lappend results [mem_read16 0xf90008ae]
lappend results [mem_read16 0xf90008af]
lappend results [mem_read 0xf90008b0]
lappend results [mem_read16 0xf90008b1]
lappend results [mem_read16 0xf90008b2]
lappend results [mem_read16 0xf90008b3]
lappend results [mem_read 0xf90008b4]
lappend results [mem_read16 0xf90008b5]
lappend results [mem_read16 0xf90008b6]
lappend results [mem_read16 0xf90008b7]
lappend results [mem_read 0xf90008b8]
lappend results [mem_read16 0xf90008b9]
lappend results [mem_read16 0xf90008ba]
lappend results [mem_read16 0xf90008bb]
lappend results [mem_read 0xf90008bc]
lappend results [mem_read16 0xf90008bd]
lappend results [mem_read16 0xf90008be]
lappend results [mem_read16 0xf90008bf]
lappend results [mem_read 0xf9000c08]
lappend results [mem_read 0xf9000c0c]
lappend results [mem_read 0xf9000c10]
lappend results [mem_read 0xf9000c14]
lappend results [mem_read 0xf9000c18]
lappend results [mem_read 0xf9000d04]
lappend results [mem_read 0xf9000dd4]
lappend results [mem_read 0xf9000de0]
lappend results [mem_read 0xf9000de4]
lappend results [mem_read 0xf9000f00]
