##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: PMC_GPIO
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf1020000]
lappend results [mem_read 0xf1020004]
lappend results [mem_read 0xf1020008]
lappend results [mem_read 0xf102000c]
lappend results [mem_read 0xf1020018]
lappend results [mem_read 0xf102001c]
lappend results [mem_read 0xf1020020]
lappend results [mem_read 0xf1020024]
lappend results [mem_read 0xf1020040]
lappend results [mem_read 0xf1020044]
lappend results [mem_read 0xf102004c]
lappend results [mem_read 0xf1020050]
lappend results [mem_read 0xf1020060]
lappend results [mem_read 0xf1020064]
lappend results [mem_read 0xf102006c]
lappend results [mem_read 0xf1020070]
lappend results [mem_read 0xf1020204]
lappend results [mem_read 0xf1020208]
lappend results [mem_read 0xf102020c]
lappend results [mem_read 0xf1020210]
lappend results [mem_read 0xf1020214]
lappend results [mem_read 0xf1020218]
lappend results [mem_read 0xf102021c]
lappend results [mem_read 0xf1020220]
lappend results [mem_read 0xf1020224]
lappend results [mem_read 0xf1020244]
lappend results [mem_read 0xf1020248]
lappend results [mem_read 0xf102024c]
lappend results [mem_read 0xf1020250]
lappend results [mem_read 0xf1020254]
lappend results [mem_read 0xf1020258]
lappend results [mem_read 0xf102025c]
lappend results [mem_read 0xf1020260]
lappend results [mem_read 0xf1020264]
lappend results [mem_read 0xf10202c4]
lappend results [mem_read 0xf10202c8]
lappend results [mem_read 0xf10202cc]
lappend results [mem_read 0xf10202d0]
lappend results [mem_read 0xf10202d4]
lappend results [mem_read 0xf10202d8]
lappend results [mem_read 0xf10202dc]
lappend results [mem_read 0xf10202e0]
lappend results [mem_read 0xf10202e4]
lappend results [mem_read 0xf1020304]
lappend results [mem_read 0xf1020308]
lappend results [mem_read 0xf102030c]
lappend results [mem_read 0xf1020310]
lappend results [mem_read 0xf1020314]
lappend results [mem_read 0xf1020318]
lappend results [mem_read 0xf102031c]
lappend results [mem_read 0xf1020320]
lappend results [mem_read 0xf1020324]
