##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM4_SLCR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfca10000]
lappend results [mem_read 0xfca10004]
lappend results [mem_read 0xfca10008]
lappend results [mem_read 0xfca1000c]
lappend results [mem_read 0xfca10010]
lappend results [mem_read 0xfca10020]
lappend results [mem_read 0xfca10200]
lappend results [mem_read 0xfca10204]
lappend results [mem_read 0xfca10208]
lappend results [mem_read 0xfca1020c]
lappend results [mem_read 0xfca10210]
lappend results [mem_read 0xfca10214]
lappend results [mem_read 0xfca10300]
lappend results [mem_read 0xfca10304]
lappend results [mem_read 0xfca10308]
lappend results [mem_read 0xfca1030c]
lappend results [mem_read 0xfca10320]
lappend results [mem_read 0xfca10324]
lappend results [mem_read 0xfca10328]
lappend results [mem_read 0xfca1032c]
lappend results [mem_read 0xfca10340]
lappend results [mem_read 0xfca10344]
lappend results [mem_read 0xfca10348]
lappend results [mem_read 0xfca1034c]
lappend results [mem_read 0xfca10360]
lappend results [mem_read 0xfca10364]
lappend results [mem_read 0xfca10368]
lappend results [mem_read 0xfca1036c]
lappend results [mem_read 0xfca10380]
lappend results [mem_read 0xfca10384]
lappend results [mem_read 0xfca10388]
lappend results [mem_read 0xfca1038c]
lappend results [mem_read 0xfca103a0]
lappend results [mem_read 0xfca103a4]
lappend results [mem_read 0xfca103a8]
lappend results [mem_read 0xfca103ac]
lappend results [mem_read 0xfca103bc]
lappend results [mem_read 0xfca103c0]
lappend results [mem_read 0xfca103c4]
lappend results [mem_read 0xfca103c8]
lappend results [mem_read 0xfca103cc]
lappend results [mem_read 0xfca103d0]
lappend results [mem_read 0xfca103d4]
lappend results [mem_read 0xfca103d8]
lappend results [mem_read 0xfca103dc]
lappend results [mem_read 0xfca103e0]
lappend results [mem_read 0xfca103e4]
lappend results [mem_read 0xfca103e8]
