define(['./_setup'], function (_setup) {
  // Is a given value a boolean?
  function isBoolean(obj) {
    return obj === true || obj === false || _setup.toString.call(obj) === '[object Boolean]';
  }

  return isBoolean;
});