##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CRP
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf1260000]
lappend results [mem_read 0xf1260004]
lappend results [mem_read 0xf1260008]
lappend results [mem_read 0xf126000c]
lappend results [mem_read 0xf1260010]
lappend results [mem_read 0xf126001c]
lappend results [mem_read 0xf1260040]
lappend results [mem_read 0xf1260044]
lappend results [mem_read 0xf1260050]
lappend results [mem_read 0xf1260054]
lappend results [mem_read 0xf1260060]
lappend results [mem_read 0xf1260100]
lappend results [mem_read 0xf1260104]
lappend results [mem_read 0xf1260108]
lappend results [mem_read 0xf1260114]
lappend results [mem_read 0xf1260118]
lappend results [mem_read 0xf1260120]
lappend results [mem_read 0xf1260160]
lappend results [mem_read 0xf1260124]
lappend results [mem_read 0xf1260128]
lappend results [mem_read 0xf126012c]
lappend results [mem_read 0xf1260130]
lappend results [mem_read 0xf1260134]
lappend results [mem_read 0xf1260138]
lappend results [mem_read 0xf1260140]
lappend results [mem_read 0xf1260144]
lappend results [mem_read 0xf1260148]
lappend results [mem_read 0xf126014c]
lappend results [mem_read 0xf1260150]
lappend results [mem_read 0xf1260240]
lappend results [mem_read 0xf1260244]
lappend results [mem_read 0xf1260248]
lappend results [mem_read 0xf126024c]
lappend results [mem_read 0xf1260250]
lappend results [mem_read 0xf1260260]
lappend results [mem_read 0xf1260264]
lappend results [mem_read 0xf1260268]
lappend results [mem_read 0xf126026c]
lappend results [mem_read 0xf1260270]
lappend results [mem_read 0xf1260274]
lappend results [mem_read 0xf1260278]
lappend results [mem_read 0xf126027c]
lappend results [mem_read 0xf1260280]
lappend results [mem_read 0xf1260284]
lappend results [mem_read 0xf1260288]
lappend results [mem_read 0xf126028c]
lappend results [mem_read 0xf1260290]
lappend results [mem_read 0xf1260294]
lappend results [mem_read 0xf1260298]
lappend results [mem_read 0xf126029c]
lappend results [mem_read 0xf12602a0]
lappend results [mem_read 0xf12602a4]
lappend results [mem_read 0xf12602a8]
lappend results [mem_read 0xf12602ac]
lappend results [mem_read 0xf12602b0]
lappend results [mem_read 0xf12602b4]
lappend results [mem_read 0xf12602b8]
lappend results [mem_read 0xf12602bc]
lappend results [mem_read 0xf12602c0]
lappend results [mem_read 0xf12602c4]
lappend results [mem_read 0xf12602c8]
lappend results [mem_read 0xf12602cc]
lappend results [mem_read 0xf12602d0]
lappend results [mem_read 0xf12602d4]
lappend results [mem_read 0xf12602d8]
lappend results [mem_read 0xf12602dc]
lappend results [mem_read 0xf12604fc]
lappend results [mem_read 0xf12605c0]
lappend results [mem_read 0xf12605c4]
lappend results [mem_read 0xf12605c8]
lappend results [mem_read 0xf12605cc]
lappend results [mem_read 0xf1260200]
lappend results [mem_read 0xf1260204]
lappend results [mem_read 0xf1260220]
lappend results [mem_read 0xf1260300]
lappend results [mem_read 0xf1260304]
lappend results [mem_read 0xf1260308]
lappend results [mem_read 0xf126030c]
lappend results [mem_read 0xf1260314]
lappend results [mem_read 0xf1260318]
lappend results [mem_read 0xf126031c]
lappend results [mem_read 0xf1260320]
lappend results [mem_read 0xf1260324]
lappend results [mem_read 0xf1260328]
lappend results [mem_read 0xf1260330]
lappend results [mem_read 0xf126032c]
lappend results [mem_read 0xf1260400]
lappend results [mem_read 0xf1260334]
