##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CANFD0
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff060000]
lappend results [mem_read 0xff060004]
lappend results [mem_read 0xff060008]
lappend results [mem_read 0xff06000c]
lappend results [mem_read 0xff060010]
lappend results [mem_read 0xff060014]
lappend results [mem_read 0xff060018]
lappend results [mem_read 0xff06001c]
lappend results [mem_read 0xff060020]
lappend results [mem_read 0xff060024]
lappend results [mem_read 0xff060028]
lappend results [mem_read 0xff060088]
lappend results [mem_read 0xff06008c]
lappend results [mem_read 0xff060090]
lappend results [mem_read 0xff060094]
lappend results [mem_read 0xff060098]
lappend results [mem_read 0xff06009c]
lappend results [mem_read 0xff0600a0]
lappend results [mem_read 0xff0600a4]
lappend results [mem_read 0xff0600e0]
lappend results [mem_read 0xff0600e8]
lappend results [mem_read 0xff0600ec]
lappend results [mem_read 0xff060100]
lappend results [mem_read 0xff060104]
lappend results [mem_read 0xff060108]
lappend results [mem_read 0xff06010c]
lappend results [mem_read 0xff060110]
lappend results [mem_read 0xff060114]
lappend results [mem_read 0xff060118]
lappend results [mem_read 0xff06011c]
lappend results [mem_read 0xff060120]
lappend results [mem_read 0xff060124]
lappend results [mem_read 0xff060128]
lappend results [mem_read 0xff06012c]
lappend results [mem_read 0xff060130]
lappend results [mem_read 0xff060134]
lappend results [mem_read 0xff060138]
lappend results [mem_read 0xff06013c]
lappend results [mem_read 0xff060140]
lappend results [mem_read 0xff060144]
lappend results [mem_read 0xff060a00]
lappend results [mem_read 0xff060a04]
lappend results [mem_read 0xff062000]
lappend results [mem_read 0xff062004]
lappend results [mem_read 0xff062100]
lappend results [mem_read 0xff062104]
lappend results [mem_read 0xff062108]
lappend results [mem_read 0xff06210c]
lappend results [mem_read 0xff062110]
lappend results [mem_read 0xff062114]
lappend results [mem_read 0xff062118]
lappend results [mem_read 0xff06211c]
lappend results [mem_read 0xff062120]
lappend results [mem_read 0xff062124]
lappend results [mem_read 0xff062128]
lappend results [mem_read 0xff06212c]
lappend results [mem_read 0xff062130]
lappend results [mem_read 0xff062134]
lappend results [mem_read 0xff062138]
lappend results [mem_read 0xff06213c]
lappend results [mem_read 0xff062140]
lappend results [mem_read 0xff062144]
lappend results [mem_read 0xff064100]
lappend results [mem_read 0xff064104]
lappend results [mem_read 0xff064108]
lappend results [mem_read 0xff06410c]
lappend results [mem_read 0xff064110]
lappend results [mem_read 0xff064114]
lappend results [mem_read 0xff064118]
lappend results [mem_read 0xff06411c]
lappend results [mem_read 0xff064120]
lappend results [mem_read 0xff064124]
lappend results [mem_read 0xff064128]
lappend results [mem_read 0xff06412c]
lappend results [mem_read 0xff064130]
lappend results [mem_read 0xff064134]
lappend results [mem_read 0xff064138]
lappend results [mem_read 0xff06413c]
lappend results [mem_read 0xff064140]
lappend results [mem_read 0xff064144]
