##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CRL
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff5e0000]
lappend results [mem_read 0xff5e0004]
lappend results [mem_read 0xff5e0008]
lappend results [mem_read 0xff5e000c]
lappend results [mem_read 0xff5e0010]
lappend results [mem_read 0xff5e001c]
lappend results [mem_read 0xff5e0040]
lappend results [mem_read 0xff5e0044]
lappend results [mem_read 0xff5e0050]
lappend results [mem_read 0xff5e0100]
lappend results [mem_read 0xff5e0104]
lappend results [mem_read 0xff5e0108]
lappend results [mem_read 0xff5e010c]
lappend results [mem_read 0xff5e0114]
lappend results [mem_read 0xff5e0118]
lappend results [mem_read 0xff5e011c]
lappend results [mem_read 0xff5e0120]
lappend results [mem_read 0xff5e0124]
lappend results [mem_read 0xff5e0128]
lappend results [mem_read 0xff5e012c]
lappend results [mem_read 0xff5e0130]
lappend results [mem_read 0xff5e0134]
lappend results [mem_read 0xff5e0138]
lappend results [mem_read 0xff5e013c]
lappend results [mem_read 0xff5e0140]
lappend results [mem_read 0xff5e0144]
lappend results [mem_read 0xff5e0148]
lappend results [mem_read 0xff5e014c]
lappend results [mem_read 0xff5e0150]
lappend results [mem_read 0xff5e0154]
lappend results [mem_read 0xff5e0158]
lappend results [mem_read 0xff5e015c]
lappend results [mem_read 0xff5e01a0]
lappend results [mem_read 0xff5e0300]
lappend results [mem_read 0xff5e0304]
lappend results [mem_read 0xff5e0308]
lappend results [mem_read 0xff5e030c]
lappend results [mem_read 0xff5e0314]
lappend results [mem_read 0xff5e0318]
lappend results [mem_read 0xff5e031c]
lappend results [mem_read 0xff5e0320]
lappend results [mem_read 0xff5e0324]
lappend results [mem_read 0xff5e0328]
lappend results [mem_read 0xff5e032c]
lappend results [mem_read 0xff5e0330]
lappend results [mem_read 0xff5e0334]
lappend results [mem_read 0xff5e0338]
lappend results [mem_read 0xff5e033c]
lappend results [mem_read 0xff5e0344]
lappend results [mem_read 0xff5e0348]
lappend results [mem_read 0xff5e034c]
lappend results [mem_read 0xff5e0360]
lappend results [mem_read 0xff5e0364]
lappend results [mem_read 0xff5e0350]
lappend results [mem_read 0xff5e0354]
lappend results [mem_read 0xff5e0358]
lappend results [mem_read 0xff5e0370]
