##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_CPM_ELA2D
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0f70000]
lappend results [mem_read 0xf0f70004]
lappend results [mem_read 0xf0f70008]
lappend results [mem_read 0xf0f70010]
lappend results [mem_read 0xf0f70020]
lappend results [mem_read 0xf0f70024]
lappend results [mem_read 0xf0f70028]
lappend results [mem_read 0xf0f7002c]
lappend results [mem_read 0xf0f70040]
lappend results [mem_read 0xf0f70044]
lappend results [mem_read 0xf0f70048]
lappend results [mem_read 0xf0f7004c]
lappend results [mem_read 0xf0f70100]
lappend results [mem_read 0xf0f70104]
lappend results [mem_read 0xf0f70108]
lappend results [mem_read 0xf0f7010c]
lappend results [mem_read 0xf0f70110]
lappend results [mem_read 0xf0f70114]
lappend results [mem_read 0xf0f70120]
lappend results [mem_read 0xf0f70130]
lappend results [mem_read 0xf0f70134]
lappend results [mem_read 0xf0f70140]
lappend results [mem_read 0xf0f70144]
lappend results [mem_read 0xf0f70148]
lappend results [mem_read 0xf0f7014c]
lappend results [mem_read 0xf0f70180]
lappend results [mem_read 0xf0f70184]
lappend results [mem_read 0xf0f70188]
lappend results [mem_read 0xf0f7018c]
lappend results [mem_read 0xf0f70200]
lappend results [mem_read 0xf0f70204]
lappend results [mem_read 0xf0f70208]
lappend results [mem_read 0xf0f7020c]
lappend results [mem_read 0xf0f70210]
lappend results [mem_read 0xf0f70214]
lappend results [mem_read 0xf0f70220]
lappend results [mem_read 0xf0f70230]
lappend results [mem_read 0xf0f70234]
lappend results [mem_read 0xf0f70240]
lappend results [mem_read 0xf0f70244]
lappend results [mem_read 0xf0f70248]
lappend results [mem_read 0xf0f7024c]
lappend results [mem_read 0xf0f70280]
lappend results [mem_read 0xf0f70284]
lappend results [mem_read 0xf0f70288]
lappend results [mem_read 0xf0f7028c]
lappend results [mem_read 0xf0f70300]
lappend results [mem_read 0xf0f70304]
lappend results [mem_read 0xf0f70308]
lappend results [mem_read 0xf0f7030c]
lappend results [mem_read 0xf0f70310]
lappend results [mem_read 0xf0f70314]
lappend results [mem_read 0xf0f70320]
lappend results [mem_read 0xf0f70330]
lappend results [mem_read 0xf0f70334]
lappend results [mem_read 0xf0f70340]
lappend results [mem_read 0xf0f70344]
lappend results [mem_read 0xf0f70348]
lappend results [mem_read 0xf0f7034c]
lappend results [mem_read 0xf0f70380]
lappend results [mem_read 0xf0f70384]
lappend results [mem_read 0xf0f70388]
lappend results [mem_read 0xf0f7038c]
lappend results [mem_read 0xf0f70400]
lappend results [mem_read 0xf0f70404]
lappend results [mem_read 0xf0f70408]
lappend results [mem_read 0xf0f7040c]
lappend results [mem_read 0xf0f70410]
lappend results [mem_read 0xf0f70414]
lappend results [mem_read 0xf0f70420]
lappend results [mem_read 0xf0f70430]
lappend results [mem_read 0xf0f70434]
lappend results [mem_read 0xf0f70440]
lappend results [mem_read 0xf0f70444]
lappend results [mem_read 0xf0f70448]
lappend results [mem_read 0xf0f7044c]
lappend results [mem_read 0xf0f70480]
lappend results [mem_read 0xf0f70484]
lappend results [mem_read 0xf0f70488]
lappend results [mem_read 0xf0f7048c]
lappend results [mem_read 0xf0f70500]
lappend results [mem_read 0xf0f70504]
lappend results [mem_read 0xf0f70508]
lappend results [mem_read 0xf0f7050c]
lappend results [mem_read 0xf0f70510]
lappend results [mem_read 0xf0f70514]
lappend results [mem_read 0xf0f70520]
lappend results [mem_read 0xf0f70530]
lappend results [mem_read 0xf0f70534]
lappend results [mem_read 0xf0f70540]
lappend results [mem_read 0xf0f70544]
lappend results [mem_read 0xf0f70548]
lappend results [mem_read 0xf0f7054c]
lappend results [mem_read 0xf0f70580]
lappend results [mem_read 0xf0f70584]
lappend results [mem_read 0xf0f70588]
lappend results [mem_read 0xf0f7058c]
lappend results [mem_read 0xf0f70ee8]
lappend results [mem_read 0xf0f70ef8]
lappend results [mem_read 0xf0f70f00]
lappend results [mem_read 0xf0f70fb0]
lappend results [mem_read 0xf0f70fb4]
lappend results [mem_read 0xf0f70fb8]
lappend results [mem_read 0xf0f70fbc]
lappend results [mem_read 0xf0f70fc0]
lappend results [mem_read 0xf0f70fc4]
lappend results [mem_read 0xf0f70fc8]
lappend results [mem_read 0xf0f70fcc]
