##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_APU1_ETM
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0d70004]
lappend results [mem_read 0xf0d7000c]
lappend results [mem_read 0xf0d70010]
lappend results [mem_read 0xf0d70018]
lappend results [mem_read 0xf0d70020]
lappend results [mem_read 0xf0d70024]
lappend results [mem_read 0xf0d70030]
lappend results [mem_read 0xf0d70034]
lappend results [mem_read 0xf0d70038]
lappend results [mem_read 0xf0d7003c]
lappend results [mem_read 0xf0d70040]
lappend results [mem_read 0xf0d70080]
lappend results [mem_read 0xf0d70084]
lappend results [mem_read 0xf0d70088]
lappend results [mem_read 0xf0d70100]
lappend results [mem_read 0xf0d70104]
lappend results [mem_read 0xf0d70108]
lappend results [mem_read 0xf0d70118]
lappend results [mem_read 0xf0d7011c]
lappend results [mem_read 0xf0d70120]
lappend results [mem_read 0xf0d70140]
lappend results [mem_read 0xf0d70144]
lappend results [mem_read 0xf0d70150]
lappend results [mem_read 0xf0d70154]
lappend results [mem_read 0xf0d70160]
lappend results [mem_read 0xf0d70164]
lappend results [mem_read 0xf0d70180]
lappend results [mem_read 0xf0d70184]
lappend results [mem_read 0xf0d70188]
lappend results [mem_read 0xf0d7018c]
lappend results [mem_read 0xf0d70190]
lappend results [mem_read 0xf0d70194]
lappend results [mem_read 0xf0d701c0]
lappend results [mem_read 0xf0d701e0]
lappend results [mem_read 0xf0d701e4]
lappend results [mem_read 0xf0d701e8]
lappend results [mem_read 0xf0d701ec]
lappend results [mem_read 0xf0d701f0]
lappend results [mem_read 0xf0d701f4]
lappend results [mem_read 0xf0d70208]
lappend results [mem_read 0xf0d7020c]
lappend results [mem_read 0xf0d70210]
lappend results [mem_read 0xf0d70214]
lappend results [mem_read 0xf0d70218]
lappend results [mem_read 0xf0d7021c]
lappend results [mem_read 0xf0d70220]
lappend results [mem_read 0xf0d70224]
lappend results [mem_read 0xf0d70228]
lappend results [mem_read 0xf0d7022c]
lappend results [mem_read 0xf0d70230]
lappend results [mem_read 0xf0d70234]
lappend results [mem_read 0xf0d70238]
lappend results [mem_read 0xf0d7023c]
lappend results [mem_read 0xf0d70280]
lappend results [mem_read 0xf0d702a0]
lappend results [mem_read 0xf0d70300]
lappend results [mem_read 0xf0d70304]
lappend results [mem_read 0xf0d70310]
lappend results [mem_read 0xf0d70314]
lappend results [mem_read 0xf0d70400]
lappend results [mem_read 0xf0d70404]
lappend results [mem_read 0xf0d70408]
lappend results [mem_read 0xf0d7040c]
lappend results [mem_read 0xf0d70410]
lappend results [mem_read 0xf0d70414]
lappend results [mem_read 0xf0d70418]
lappend results [mem_read 0xf0d7041c]
lappend results [mem_read 0xf0d70420]
lappend results [mem_read 0xf0d70424]
lappend results [mem_read 0xf0d70428]
lappend results [mem_read 0xf0d7042c]
lappend results [mem_read 0xf0d70430]
lappend results [mem_read 0xf0d70434]
lappend results [mem_read 0xf0d70438]
lappend results [mem_read 0xf0d7043c]
lappend results [mem_read 0xf0d70480]
lappend results [mem_read 0xf0d70488]
lappend results [mem_read 0xf0d70490]
lappend results [mem_read 0xf0d70498]
lappend results [mem_read 0xf0d704a0]
lappend results [mem_read 0xf0d704a8]
lappend results [mem_read 0xf0d704b0]
lappend results [mem_read 0xf0d704b8]
lappend results [mem_read 0xf0d70600]
lappend results [mem_read 0xf0d70640]
lappend results [mem_read 0xf0d70680]
lappend results [mem_read 0xf0d70edc]
lappend results [mem_read 0xf0d70ee0]
lappend results [mem_read 0xf0d70eec]
lappend results [mem_read 0xf0d70ef0]
lappend results [mem_read 0xf0d70ef4]
lappend results [mem_read 0xf0d70ef8]
lappend results [mem_read 0xf0d70f00]
lappend results [mem_read 0xf0d70fa0]
lappend results [mem_read 0xf0d70fa4]
lappend results [mem_read 0xf0d70fa8]
lappend results [mem_read 0xf0d70fac]
lappend results [mem_read 0xf0d70fb0]
lappend results [mem_read 0xf0d70fb4]
lappend results [mem_read 0xf0d70fb8]
lappend results [mem_read 0xf0d70fbc]
lappend results [mem_read 0xf0d70fc8]
lappend results [mem_read 0xf0d70fcc]
lappend results [mem_read 0xf0d70fd0]
