##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_APU0_ETM
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0d30004]
lappend results [mem_read 0xf0d3000c]
lappend results [mem_read 0xf0d30010]
lappend results [mem_read 0xf0d30018]
lappend results [mem_read 0xf0d30020]
lappend results [mem_read 0xf0d30024]
lappend results [mem_read 0xf0d30030]
lappend results [mem_read 0xf0d30034]
lappend results [mem_read 0xf0d30038]
lappend results [mem_read 0xf0d3003c]
lappend results [mem_read 0xf0d30040]
lappend results [mem_read 0xf0d30080]
lappend results [mem_read 0xf0d30084]
lappend results [mem_read 0xf0d30088]
lappend results [mem_read 0xf0d30100]
lappend results [mem_read 0xf0d30104]
lappend results [mem_read 0xf0d30108]
lappend results [mem_read 0xf0d30118]
lappend results [mem_read 0xf0d3011c]
lappend results [mem_read 0xf0d30120]
lappend results [mem_read 0xf0d30140]
lappend results [mem_read 0xf0d30144]
lappend results [mem_read 0xf0d30150]
lappend results [mem_read 0xf0d30154]
lappend results [mem_read 0xf0d30160]
lappend results [mem_read 0xf0d30164]
lappend results [mem_read 0xf0d30180]
lappend results [mem_read 0xf0d30184]
lappend results [mem_read 0xf0d30188]
lappend results [mem_read 0xf0d3018c]
lappend results [mem_read 0xf0d30190]
lappend results [mem_read 0xf0d30194]
lappend results [mem_read 0xf0d301c0]
lappend results [mem_read 0xf0d301e0]
lappend results [mem_read 0xf0d301e4]
lappend results [mem_read 0xf0d301e8]
lappend results [mem_read 0xf0d301ec]
lappend results [mem_read 0xf0d301f0]
lappend results [mem_read 0xf0d301f4]
lappend results [mem_read 0xf0d30208]
lappend results [mem_read 0xf0d3020c]
lappend results [mem_read 0xf0d30210]
lappend results [mem_read 0xf0d30214]
lappend results [mem_read 0xf0d30218]
lappend results [mem_read 0xf0d3021c]
lappend results [mem_read 0xf0d30220]
lappend results [mem_read 0xf0d30224]
lappend results [mem_read 0xf0d30228]
lappend results [mem_read 0xf0d3022c]
lappend results [mem_read 0xf0d30230]
lappend results [mem_read 0xf0d30234]
lappend results [mem_read 0xf0d30238]
lappend results [mem_read 0xf0d3023c]
lappend results [mem_read 0xf0d30280]
lappend results [mem_read 0xf0d302a0]
lappend results [mem_read 0xf0d30300]
lappend results [mem_read 0xf0d30304]
lappend results [mem_read 0xf0d30310]
lappend results [mem_read 0xf0d30314]
lappend results [mem_read 0xf0d30400]
lappend results [mem_read 0xf0d30404]
lappend results [mem_read 0xf0d30408]
lappend results [mem_read 0xf0d3040c]
lappend results [mem_read 0xf0d30410]
lappend results [mem_read 0xf0d30414]
lappend results [mem_read 0xf0d30418]
lappend results [mem_read 0xf0d3041c]
lappend results [mem_read 0xf0d30420]
lappend results [mem_read 0xf0d30424]
lappend results [mem_read 0xf0d30428]
lappend results [mem_read 0xf0d3042c]
lappend results [mem_read 0xf0d30430]
lappend results [mem_read 0xf0d30434]
lappend results [mem_read 0xf0d30438]
lappend results [mem_read 0xf0d3043c]
lappend results [mem_read 0xf0d30480]
lappend results [mem_read 0xf0d30488]
lappend results [mem_read 0xf0d30490]
lappend results [mem_read 0xf0d30498]
lappend results [mem_read 0xf0d304a0]
lappend results [mem_read 0xf0d304a8]
lappend results [mem_read 0xf0d304b0]
lappend results [mem_read 0xf0d304b8]
lappend results [mem_read 0xf0d30600]
lappend results [mem_read 0xf0d30640]
lappend results [mem_read 0xf0d30680]
lappend results [mem_read 0xf0d30edc]
lappend results [mem_read 0xf0d30ee0]
lappend results [mem_read 0xf0d30eec]
lappend results [mem_read 0xf0d30ef0]
lappend results [mem_read 0xf0d30ef4]
lappend results [mem_read 0xf0d30ef8]
lappend results [mem_read 0xf0d30f00]
lappend results [mem_read 0xf0d30fa0]
lappend results [mem_read 0xf0d30fa4]
lappend results [mem_read 0xf0d30fa8]
lappend results [mem_read 0xf0d30fac]
lappend results [mem_read 0xf0d30fb0]
lappend results [mem_read 0xf0d30fb4]
lappend results [mem_read 0xf0d30fb8]
lappend results [mem_read 0xf0d30fbc]
lappend results [mem_read 0xf0d30fc8]
lappend results [mem_read 0xf0d30fcc]
