/*
* Copyright (c) 2021 Xilinx, Inc.
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
* associated documentation files (the "Software"), to deal in the Software without restriction, including 
* without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
* copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
* the following conditions: 
* 
* The above copyright notice and this permission notice shall be included in all copies or substantial 
* portions of the Software. 
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
* LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
* 
*
*
*/
export const filePath = {
  "fpd_ams": "../",
  "user_dashboard": "../templates/userdashboard/",
  "user_performance": "../templates/userdashboard/userperformance/",
  "overlay_performance": "../templates/userdashboard/overlay/",
  "system_status": "../templates/systemmoniter/status/",
  "aiengine_status": "../templates/systemmoniter/status/",
  "noc_status": "../templates/systemmoniter/status/",
  "pmc_status": "../templates/systemmoniter/status/",
  "cpm_status": "../templates/systemmoniter/status/",
  "firmware_device": "../templates/systemmoniter/status/",
  "power_isolation": "../templates/systemmoniter/status/",
  "clock_ps": "../templates/systemmoniter/clocks/",
  "clock_cpm": "../templates/systemmoniter/clocks/",
  "clock_aiengine": "../templates/systemmoniter/clocks/",
  "clock_table": "../templates/systemmoniter/clocks/",
  "clockaiengine_table": "../templates/systemmoniter/clocks/",
  "tree_view": "../templates/systemmoniter/clocks/",
  "clockcpm_table": "../templates/systemmoniter/clocks/",
  "clockcpm_tree": "../templates/systemmoniter/clocks/",
  "clockaiengine_tree": "../templates/systemmoniter/clocks/",
  "apll_tree": "../templates/systemmoniter/clocks/",
  "npll_tree": "../templates/systemmoniter/clocks/",
  "ppll_tree": "../templates/systemmoniter/clocks/",
  "rpll_tree": "../templates/systemmoniter/clocks/",
  "clkcpm_tree": "../templates/systemmoniter/clocks/",
  "clockai_tree": "../templates/systemmoniter/clocks/",
  "clockcpm_diagram": "../templates/systemmoniter/clocks/",
  "ddr_config": "../templates/systemmoniter/ddr/",
  "ddr_init": "../templates/systemmoniter/ddr/",
  "tenzing_ddrmc": "../templates/systemmoniter/ddr/",
  "tenzing_phy": "../templates/systemmoniter/ddr/",
  "tenzinginit_ddrmc": "../templates/systemmoniter/ddr/",
  "config_ddrmc0": "../templates/systemmoniter/ddr/",
  "config_ddrmc1": "../templates/systemmoniter/ddr/",
  "config_ddrmc2": "../templates/systemmoniter/ddr/",
  "config_ddrmc3": "../templates/systemmoniter/ddr/",
  "configinit_ddrmc0": "../templates/systemmoniter/ddr/",
  "configinit_ddrmc1": "../templates/systemmoniter/ddr/",
  "configinit_ddrmc2": "../templates/systemmoniter/ddr/",
  "configinit_ddrmc3": "../templates/systemmoniter/ddr/",
  "efficiency_ddrmc0": "../templates/efficiency/",
  "efficiency_ddrmc1": "../templates/efficiency/",
  "efficiency_ddrmc2": "../templates/efficiency/",
  "efficiency_ddrmc3": "../templates/efficiency/",
  "efficiency-data": "../",
  "root_ams": "../templates/systemmoniter/ams/",
  "root_plot": "../templates/systemmoniter/ams/",
  "sys_mon": "../templates/systemmoniter/ams/",
  "ams_data": "../templates/systemmoniter/ams/",
  "status_tabs": "../templates/systemmoniter/status/",
  "clock_reset": "../templates/systemmoniter/clocks/",
  "sanity_tab": "../templates/sanity/",
  "reset_table": "../templates/systemmoniter/clocks/",
  "cpmreset_table": "../templates/systemmoniter/clocks/",
  "ddr_tab": "../templates/systemmoniter/ddr/",
  "traffic_data": "../templates/systemmoniter/noctraffic/",
  "qos_data": "../templates/systemmoniter/qos/",
  "sysai_wireless": "../templates/systemmoniter/aiwireless/",
  "digital_image_processing": "../templates/systemmoniter/digitalimageprocessing/",
  "pmc_data": "../templates/performance/",
  "lpd_data": "../templates/performance/",
  "fpd_data": "../templates/performance/",
  "cpm_tabs": "../templates/performance/",
  "cpm_data": "../templates/performance/",
  "cpm_nsu": "../templates/performance/",
  "ddr0_data": "../templates/performance/",
  "ddr1_data": "../templates/performance/",
  "ddrmc1_data": "../templates/performance/",
  "ddrmc2_data": "../templates/performance/",
  "ddrmc3_data": "../templates/performance/",
  "ddr2_data": "../templates/performance/",
  "ddr3_data": "../templates/performance/",
  "noc_data": "../templates/performance/",
  "aiengine_data": "../templates/performance/",
  "pl_data": "../templates/performance/",
  "nsu_data": "../templates/performance/",
  "dc_data": "../templates/performance/",
  "perf_config": "../templates/performance/",
  "command_interface": "../templates/debugger/",
  "memory_watch": "../templates/debugger/",
  "ddr_regression": "../templates/regressions/",
  "me_regression": "../templates/regressions/",
  "cpm_regression": "../templates/regressions/",
  "traffic_generator": "../templates/regressions/",
  "test_suite": "../templates/regressions/"
};