##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: PMC_XPPU_NPI
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf1300000]
lappend results [mem_read 0xf1300004]
lappend results [mem_read 0xf1300008]
lappend results [mem_read 0xf130000c]
lappend results [mem_read 0xf1300010]
lappend results [mem_read 0xf1300014]
lappend results [mem_read 0xf1300018]
lappend results [mem_read 0xf130001c]
lappend results [mem_read 0xf1300020]
lappend results [mem_read 0xf130003c]
lappend results [mem_read 0xf1300044]
lappend results [mem_read 0xf1300048]
lappend results [mem_read 0xf130004c]
lappend results [mem_read 0xf1300054]
lappend results [mem_read 0xf1300058]
lappend results [mem_read 0xf130005c]
lappend results [mem_read 0xf1300100]
lappend results [mem_read 0xf1300104]
lappend results [mem_read 0xf1300108]
lappend results [mem_read 0xf130010c]
lappend results [mem_read 0xf1300110]
lappend results [mem_read 0xf1300114]
lappend results [mem_read 0xf1300118]
lappend results [mem_read 0xf130011c]
lappend results [mem_read 0xf1300120]
lappend results [mem_read 0xf1300124]
lappend results [mem_read 0xf1300128]
lappend results [mem_read 0xf130012c]
lappend results [mem_read 0xf1300130]
lappend results [mem_read 0xf1300134]
lappend results [mem_read 0xf1300138]
lappend results [mem_read 0xf130013c]
lappend results [mem_read 0xf1300140]
lappend results [mem_read 0xf1300144]
lappend results [mem_read 0xf1300148]
lappend results [mem_read 0xf130014c]
lappend results [mem_read 0xf1300150]
lappend results [mem_read 0xf1300154]
lappend results [mem_read 0xf13000fc]
lappend results [mem_read 0xf1301000]
lappend results [mem_read 0xf1301004]
lappend results [mem_read 0xf1301008]
lappend results [mem_read 0xf130100c]
lappend results [mem_read 0xf1301010]
lappend results [mem_read 0xf1301014]
lappend results [mem_read 0xf1301018]
lappend results [mem_read 0xf130101c]
lappend results [mem_read 0xf1301020]
lappend results [mem_read 0xf1301024]
lappend results [mem_read 0xf1301028]
lappend results [mem_read 0xf130102c]
lappend results [mem_read 0xf1301030]
lappend results [mem_read 0xf1301034]
lappend results [mem_read 0xf1301038]
lappend results [mem_read 0xf130103c]
lappend results [mem_read 0xf1301040]
lappend results [mem_read 0xf1301044]
lappend results [mem_read 0xf1301048]
lappend results [mem_read 0xf130104c]
lappend results [mem_read 0xf1301050]
lappend results [mem_read 0xf1301054]
lappend results [mem_read 0xf1301058]
lappend results [mem_read 0xf130105c]
lappend results [mem_read 0xf1301060]
lappend results [mem_read 0xf1301064]
lappend results [mem_read 0xf1301068]
lappend results [mem_read 0xf130106c]
lappend results [mem_read 0xf1301070]
lappend results [mem_read 0xf1301074]
lappend results [mem_read 0xf1301078]
lappend results [mem_read 0xf130107c]
lappend results [mem_read 0xf1301080]
lappend results [mem_read 0xf1301084]
lappend results [mem_read 0xf1301088]
lappend results [mem_read 0xf130108c]
lappend results [mem_read 0xf1301090]
lappend results [mem_read 0xf1301094]
lappend results [mem_read 0xf1301098]
lappend results [mem_read 0xf130109c]
lappend results [mem_read 0xf13010a0]
lappend results [mem_read 0xf13010a4]
lappend results [mem_read 0xf13010a8]
lappend results [mem_read 0xf13010ac]
lappend results [mem_read 0xf13010b0]
lappend results [mem_read 0xf13010b4]
lappend results [mem_read 0xf13010b8]
lappend results [mem_read 0xf13010bc]
lappend results [mem_read 0xf13010c0]
lappend results [mem_read 0xf13010c4]
lappend results [mem_read 0xf13010c8]
lappend results [mem_read 0xf13010cc]
lappend results [mem_read 0xf13010d0]
lappend results [mem_read 0xf13010d4]
lappend results [mem_read 0xf13010d8]
lappend results [mem_read 0xf13010dc]
lappend results [mem_read 0xf13010e0]
lappend results [mem_read 0xf13010e4]
lappend results [mem_read 0xf13010e8]
lappend results [mem_read 0xf13010ec]
lappend results [mem_read 0xf13010f0]
lappend results [mem_read 0xf13010f4]
lappend results [mem_read 0xf13010f8]
lappend results [mem_read 0xf13010fc]
lappend results [mem_read 0xf1301100]
lappend results [mem_read 0xf1301104]
lappend results [mem_read 0xf1301108]
lappend results [mem_read 0xf130110c]
lappend results [mem_read 0xf1301110]
lappend results [mem_read 0xf1301114]
lappend results [mem_read 0xf1301118]
lappend results [mem_read 0xf130111c]
lappend results [mem_read 0xf1301120]
lappend results [mem_read 0xf1301124]
lappend results [mem_read 0xf1301128]
lappend results [mem_read 0xf130112c]
lappend results [mem_read 0xf1301130]
lappend results [mem_read 0xf1301134]
lappend results [mem_read 0xf1301138]
lappend results [mem_read 0xf130113c]
lappend results [mem_read 0xf1301140]
lappend results [mem_read 0xf1301144]
lappend results [mem_read 0xf1301148]
lappend results [mem_read 0xf130114c]
lappend results [mem_read 0xf1301150]
lappend results [mem_read 0xf1301154]
lappend results [mem_read 0xf1301158]
lappend results [mem_read 0xf130115c]
lappend results [mem_read 0xf1301160]
lappend results [mem_read 0xf1301164]
lappend results [mem_read 0xf1301168]
lappend results [mem_read 0xf130116c]
lappend results [mem_read 0xf1301170]
lappend results [mem_read 0xf1301174]
lappend results [mem_read 0xf1301178]
lappend results [mem_read 0xf130117c]
lappend results [mem_read 0xf1301180]
lappend results [mem_read 0xf1301184]
lappend results [mem_read 0xf1301188]
lappend results [mem_read 0xf130118c]
lappend results [mem_read 0xf1301190]
lappend results [mem_read 0xf1301194]
lappend results [mem_read 0xf1301198]
lappend results [mem_read 0xf130119c]
lappend results [mem_read 0xf13011a0]
lappend results [mem_read 0xf13011a4]
lappend results [mem_read 0xf13011a8]
lappend results [mem_read 0xf13011ac]
lappend results [mem_read 0xf13011b0]
lappend results [mem_read 0xf13011b4]
lappend results [mem_read 0xf13011b8]
lappend results [mem_read 0xf13011bc]
lappend results [mem_read 0xf13011c0]
lappend results [mem_read 0xf13011c4]
lappend results [mem_read 0xf13011c8]
lappend results [mem_read 0xf13011cc]
lappend results [mem_read 0xf13011d0]
lappend results [mem_read 0xf13011d4]
lappend results [mem_read 0xf13011d8]
lappend results [mem_read 0xf13011dc]
lappend results [mem_read 0xf13011e0]
lappend results [mem_read 0xf13011e4]
lappend results [mem_read 0xf13011e8]
lappend results [mem_read 0xf13011ec]
lappend results [mem_read 0xf13011f0]
lappend results [mem_read 0xf13011f4]
lappend results [mem_read 0xf13011f8]
lappend results [mem_read 0xf13011fc]
lappend results [mem_read 0xf1301200]
lappend results [mem_read 0xf1301204]
lappend results [mem_read 0xf1301208]
lappend results [mem_read 0xf130120c]
lappend results [mem_read 0xf1301210]
lappend results [mem_read 0xf1301214]
lappend results [mem_read 0xf1301218]
lappend results [mem_read 0xf130121c]
lappend results [mem_read 0xf1301220]
lappend results [mem_read 0xf1301224]
lappend results [mem_read 0xf1301228]
lappend results [mem_read 0xf130122c]
lappend results [mem_read 0xf1301230]
lappend results [mem_read 0xf1301234]
lappend results [mem_read 0xf1301238]
lappend results [mem_read 0xf130123c]
lappend results [mem_read 0xf1301240]
lappend results [mem_read 0xf1301244]
lappend results [mem_read 0xf1301248]
lappend results [mem_read 0xf130124c]
lappend results [mem_read 0xf1301250]
lappend results [mem_read 0xf1301254]
lappend results [mem_read 0xf1301258]
lappend results [mem_read 0xf130125c]
lappend results [mem_read 0xf1301260]
lappend results [mem_read 0xf1301264]
lappend results [mem_read 0xf1301268]
lappend results [mem_read 0xf130126c]
lappend results [mem_read 0xf1301270]
lappend results [mem_read 0xf1301274]
lappend results [mem_read 0xf1301278]
lappend results [mem_read 0xf130127c]
lappend results [mem_read 0xf1301280]
lappend results [mem_read 0xf1301284]
lappend results [mem_read 0xf1301288]
lappend results [mem_read 0xf130128c]
lappend results [mem_read 0xf1301290]
lappend results [mem_read 0xf1301294]
lappend results [mem_read 0xf1301298]
lappend results [mem_read 0xf130129c]
lappend results [mem_read 0xf13012a0]
lappend results [mem_read 0xf13012a4]
lappend results [mem_read 0xf13012a8]
lappend results [mem_read 0xf13012ac]
lappend results [mem_read 0xf13012b0]
lappend results [mem_read 0xf13012b4]
lappend results [mem_read 0xf13012b8]
lappend results [mem_read 0xf13012bc]
lappend results [mem_read 0xf13012c0]
lappend results [mem_read 0xf13012c4]
lappend results [mem_read 0xf13012c8]
lappend results [mem_read 0xf13012cc]
lappend results [mem_read 0xf13012d0]
lappend results [mem_read 0xf13012d4]
lappend results [mem_read 0xf13012d8]
lappend results [mem_read 0xf13012dc]
lappend results [mem_read 0xf13012e0]
lappend results [mem_read 0xf13012e4]
lappend results [mem_read 0xf13012e8]
lappend results [mem_read 0xf13012ec]
lappend results [mem_read 0xf13012f0]
lappend results [mem_read 0xf13012f4]
lappend results [mem_read 0xf13012f8]
lappend results [mem_read 0xf13012fc]
lappend results [mem_read 0xf1301300]
lappend results [mem_read 0xf1301304]
lappend results [mem_read 0xf1301308]
lappend results [mem_read 0xf130130c]
lappend results [mem_read 0xf1301310]
lappend results [mem_read 0xf1301314]
lappend results [mem_read 0xf1301318]
lappend results [mem_read 0xf130131c]
lappend results [mem_read 0xf1301320]
lappend results [mem_read 0xf1301324]
lappend results [mem_read 0xf1301328]
lappend results [mem_read 0xf130132c]
lappend results [mem_read 0xf1301330]
lappend results [mem_read 0xf1301334]
lappend results [mem_read 0xf1301338]
lappend results [mem_read 0xf130133c]
lappend results [mem_read 0xf1301340]
lappend results [mem_read 0xf1301344]
lappend results [mem_read 0xf1301348]
lappend results [mem_read 0xf130134c]
lappend results [mem_read 0xf1301350]
lappend results [mem_read 0xf1301354]
lappend results [mem_read 0xf1301358]
lappend results [mem_read 0xf130135c]
lappend results [mem_read 0xf1301360]
lappend results [mem_read 0xf1301364]
lappend results [mem_read 0xf1301368]
lappend results [mem_read 0xf130136c]
lappend results [mem_read 0xf1301370]
lappend results [mem_read 0xf1301374]
lappend results [mem_read 0xf1301378]
lappend results [mem_read 0xf130137c]
lappend results [mem_read 0xf1301380]
lappend results [mem_read 0xf1301384]
lappend results [mem_read 0xf1301388]
lappend results [mem_read 0xf130138c]
lappend results [mem_read 0xf1301390]
lappend results [mem_read 0xf1301394]
lappend results [mem_read 0xf1301398]
lappend results [mem_read 0xf130139c]
lappend results [mem_read 0xf13013a0]
lappend results [mem_read 0xf13013a4]
lappend results [mem_read 0xf13013a8]
lappend results [mem_read 0xf13013ac]
lappend results [mem_read 0xf13013b0]
lappend results [mem_read 0xf13013b4]
lappend results [mem_read 0xf13013b8]
lappend results [mem_read 0xf13013bc]
lappend results [mem_read 0xf13013c0]
lappend results [mem_read 0xf13013c4]
lappend results [mem_read 0xf13013c8]
lappend results [mem_read 0xf13013cc]
lappend results [mem_read 0xf13013d0]
lappend results [mem_read 0xf13013d4]
lappend results [mem_read 0xf13013d8]
lappend results [mem_read 0xf13013dc]
lappend results [mem_read 0xf13013e0]
lappend results [mem_read 0xf13013e4]
lappend results [mem_read 0xf13013e8]
lappend results [mem_read 0xf13013ec]
lappend results [mem_read 0xf13013f0]
lappend results [mem_read 0xf13013f4]
lappend results [mem_read 0xf13013f8]
lappend results [mem_read 0xf13013fc]
lappend results [mem_read 0xf1301600]
lappend results [mem_read 0xf1301604]
lappend results [mem_read 0xf1301608]
lappend results [mem_read 0xf130160c]
lappend results [mem_read 0xf1301610]
lappend results [mem_read 0xf1301614]
lappend results [mem_read 0xf1301618]
lappend results [mem_read 0xf130161c]
lappend results [mem_read 0xf1301620]
lappend results [mem_read 0xf1301624]
lappend results [mem_read 0xf1301628]
lappend results [mem_read 0xf130162c]
lappend results [mem_read 0xf1301630]
lappend results [mem_read 0xf1301634]
lappend results [mem_read 0xf1301638]
lappend results [mem_read 0xf130163c]
lappend results [mem_read 0xf1301640]
