/*
* Copyright (c) 2021 Xilinx, Inc.
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
* associated documentation files (the "Software"), to deal in the Software without restriction, including 
* without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
* copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
* the following conditions: 
* 
* The above copyright notice and this permission notice shall be included in all copies or substantial 
* portions of the Software. 
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
* LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
* 
*
*
*/
export let $_graphContainer = document.createElement('template');
$_graphContainer.innerHTML = `<dom-module id="shared-styles">
  <template>
    <style>
      :host {
        display: block;
      }
      .graph-body {
        width:100%;
        display:inline-block;
        margin-top: 12px;
      }
      .graph_sec {
        width:48%;
        margin:1%;
        float:left;
        display:inline-block;
        position:relative;
      }
      .bar-icon {
        position:absolute;
        right:0px;
        top:0px;
        z-index: 1;
      }
      paper-dialog {
        width:calc(100vw - 432px);
        height:calc(100vh - 220px);
        left: 300px !important;
        overflow: hidden;
        cursor: zoom-in;
      }
      .h-100 {
        height: 100%
      }
      .m-0 {
        margin: 0px;
      }
      .p-0 {
        padding: 0px;
      }
      .imageBoard {
        width: 100%;
        height: 100%;
        background-repeat: no-repeat;
        background-position: center;
        background-size: contain;
        transition: transform .5s ease-out;
      }
      .commonBtn {
        background-color: var(--paper-blue-500);
        color:white;
        height:30px;
        font-size:14px;
        margin-right: 0px;
      }
      .text-right {
        text-align: right;
      }
      a {
        text-decoration: none !important;
      }
      .resetBtn{
        font-family: 'Roboto', 'Noto', sans-serif;
        font-weight: normal;
        font-size: 14px;
        -webkit-font-smoothing: antialiased;
        height: 30px;
        background-color: var(--paper-blue-500);
        color: white;
      }
    </style>
  </template>
</dom-module>`;