##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: USB2_XHCI
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfe20c200]
lappend results [mem_read 0xfe20c280]
lappend results [mem_read 0xfe20c300]
lappend results [mem_read 0xfe20c304]
lappend results [mem_read 0xfe20c308]
lappend results [mem_read 0xfe20c30c]
lappend results [mem_read 0xfe20c310]
lappend results [mem_read 0xfe20c314]
lappend results [mem_read 0xfe20c380]
lappend results [mem_read 0xfe20c384]
lappend results [mem_read 0xfe20c388]
lappend results [mem_read 0xfe20c400]
lappend results [mem_read 0xfe20c404]
lappend results [mem_read 0xfe20c408]
lappend results [mem_read 0xfe20c40c]
lappend results [mem_read 0xfe20c410]
lappend results [mem_read 0xfe20c414]
lappend results [mem_read 0xfe20c418]
lappend results [mem_read 0xfe20c41c]
lappend results [mem_read 0xfe20c420]
lappend results [mem_read 0xfe20c424]
lappend results [mem_read 0xfe20c428]
lappend results [mem_read 0xfe20c42c]
lappend results [mem_read 0xfe20c430]
lappend results [mem_read 0xfe20c434]
lappend results [mem_read 0xfe20c438]
lappend results [mem_read 0xfe20c43c]
lappend results [mem_read 0xfe20c100]
lappend results [mem_read 0xfe20c104]
lappend results [mem_read 0xfe20c10c]
lappend results [mem_read 0xfe20c110]
lappend results [mem_read 0xfe20c118]
lappend results [mem_read 0xfe20c11c]
lappend results [mem_read 0xfe20c120]
lappend results [mem_read 0xfe20c124]
lappend results [mem_read 0xfe20c128]
lappend results [mem_read 0xfe20c12c]
lappend results [mem_read 0xfe20c130]
lappend results [mem_read 0xfe20c134]
lappend results [mem_read 0xfe20c140]
lappend results [mem_read 0xfe20c144]
lappend results [mem_read 0xfe20c148]
lappend results [mem_read 0xfe20c14c]
lappend results [mem_read 0xfe20c150]
lappend results [mem_read 0xfe20c154]
lappend results [mem_read 0xfe20c158]
lappend results [mem_read 0xfe20c15c]
lappend results [mem_read 0xfe20c160]
lappend results [mem_read 0xfe20c19c]
lappend results [mem_read 0xfe20c600]
lappend results [mem_read 0xfe20c610]
lappend results [mem_read 0xfe20c618]
lappend results [mem_read 0xfe20c61c]
lappend results [mem_read 0xfe20c624]
lappend results [mem_read 0xfe20c630]
lappend results [mem_read 0xfe20c800]
lappend results [mem_read 0xfe20c804]
lappend results [mem_read 0xfe20c808]
lappend results [mem_read 0xfe20c80c]
lappend results [mem_read 0xfe20c810]
lappend results [mem_read 0xfe20c814]
lappend results [mem_read 0xfe20c818]
lappend results [mem_read 0xfe20c81c]
lappend results [mem_read 0xfe20c820]
lappend results [mem_read 0xfe20c824]
lappend results [mem_read 0xfe20c828]
lappend results [mem_read 0xfe20c82c]
lappend results [mem_read 0xfe20c830]
lappend results [mem_read 0xfe20c834]
lappend results [mem_read 0xfe20c838]
lappend results [mem_read 0xfe20c83c]
lappend results [mem_read 0xfe20c840]
lappend results [mem_read 0xfe20c844]
lappend results [mem_read 0xfe20c848]
lappend results [mem_read 0xfe20c84c]
lappend results [mem_read 0xfe20c850]
lappend results [mem_read 0xfe20c854]
lappend results [mem_read 0xfe20c858]
lappend results [mem_read 0xfe20c85c]
lappend results [mem_read 0xfe20c860]
lappend results [mem_read 0xfe20c864]
lappend results [mem_read 0xfe20c868]
lappend results [mem_read 0xfe20c86c]
lappend results [mem_read 0xfe20c870]
lappend results [mem_read 0xfe20c874]
lappend results [mem_read 0xfe20c878]
lappend results [mem_read 0xfe20c87c]
lappend results [mem_read 0xfe20c880]
lappend results [mem_read 0xfe20c884]
lappend results [mem_read 0xfe20c888]
lappend results [mem_read 0xfe20c88c]
lappend results [mem_read 0xfe20c890]
lappend results [mem_read 0xfe20c894]
lappend results [mem_read 0xfe20c898]
lappend results [mem_read 0xfe20c89c]
lappend results [mem_read 0xfe20c8a0]
lappend results [mem_read 0xfe20c8a4]
lappend results [mem_read 0xfe20c8a8]
lappend results [mem_read 0xfe20c8ac]
lappend results [mem_read 0xfe20c8b0]
lappend results [mem_read 0xfe20c8b4]
lappend results [mem_read 0xfe20c8b8]
lappend results [mem_read 0xfe20c8bc]
lappend results [mem_read 0xfe20ca00]
lappend results [mem_read 0xfe20ca04]
lappend results [mem_read 0xfe20ca08]
lappend results [mem_read 0xfe20ca0c]
lappend results [mem_read 0xfe20c700]
lappend results [mem_read 0xfe20c704]
lappend results [mem_read 0xfe20c708]
lappend results [mem_read 0xfe20c70c]
lappend results [mem_read 0xfe20c710]
lappend results [mem_read 0xfe20c714]
lappend results [mem_read 0xfe20c720]
lappend results [mem_read 0xfe20cc00]
lappend results [mem_read 0xfe20cc04]
lappend results [mem_read 0xfe20cc08]
lappend results [mem_read 0xfe20cc0c]
lappend results [mem_read 0xfe20cc10]
lappend results [mem_read 0xfe20cc28]
lappend results [mem_read 0xfe200000]
lappend results [mem_read 0xfe200004]
lappend results [mem_read 0xfe200008]
lappend results [mem_read 0xfe20000c]
lappend results [mem_read 0xfe200010]
lappend results [mem_read 0xfe200014]
lappend results [mem_read 0xfe200018]
lappend results [mem_read 0xfe20001c]
lappend results [mem_read 0xfe200020]
lappend results [mem_read 0xfe200024]
lappend results [mem_read 0xfe200028]
lappend results [mem_read 0xfe200034]
lappend results [mem_read 0xfe200038]
lappend results [mem_read 0xfe20003c]
lappend results [mem_read 0xfe200050]
lappend results [mem_read 0xfe200054]
lappend results [mem_read 0xfe200058]
lappend results [mem_read 0xfe200420]
lappend results [mem_read 0xfe20042c]
lappend results [mem_read 0xfe200440]
lappend results [mem_read 0xfe200460]
lappend results [mem_read 0xfe200464]
lappend results [mem_read 0xfe200468]
lappend results [mem_read 0xfe200470]
lappend results [mem_read 0xfe200474]
lappend results [mem_read 0xfe200478]
lappend results [mem_read 0xfe20047c]
lappend results [mem_read 0xfe200480]
lappend results [mem_read 0xfe200484]
lappend results [mem_read 0xfe200488]
lappend results [mem_read 0xfe200490]
lappend results [mem_read 0xfe200494]
lappend results [mem_read 0xfe200498]
lappend results [mem_read 0xfe20049c]
lappend results [mem_read 0xfe2004a0]
lappend results [mem_read 0xfe2004a4]
lappend results [mem_read 0xfe2004a8]
lappend results [mem_read 0xfe2004b0]
lappend results [mem_read 0xfe2004b4]
lappend results [mem_read 0xfe2004b8]
lappend results [mem_read 0xfe2004bc]
lappend results [mem_read 0xfe2004c0]
lappend results [mem_read 0xfe2004c4]
lappend results [mem_read 0xfe2004c8]
lappend results [mem_read 0xfe2004d0]
lappend results [mem_read 0xfe2004d4]
lappend results [mem_read 0xfe2004d8]
lappend results [mem_read 0xfe2004dc]
lappend results [mem_read 0xfe2004e0]
lappend results [mem_read 0xfe2004e4]
lappend results [mem_read 0xfe2004e8]
lappend results [mem_read 0xfe2004ec]
lappend results [mem_read 0xfe2004f0]
lappend results [mem_read 0xfe2004f4]
lappend results [mem_read 0xfe2004f8]
lappend results [mem_read 0xfe2004fc]
lappend results [mem_read 0xfe200500]
lappend results [mem_read 0xfe200504]
lappend results [mem_read 0xfe200508]
lappend results [mem_read 0xfe20050c]
lappend results [mem_read 0xfe200510]
lappend results [mem_read 0xfe200514]
lappend results [mem_read 0xfe200518]
lappend results [mem_read 0xfe20051c]
lappend results [mem_read 0xfe200520]
lappend results [mem_read 0xfe200524]
lappend results [mem_read 0xfe200528]
lappend results [mem_read 0xfe20052c]
lappend results [mem_read 0xfe200530]
lappend results [mem_read 0xfe200534]
lappend results [mem_read 0xfe200538]
lappend results [mem_read 0xfe20053c]
lappend results [mem_read 0xfe200540]
lappend results [mem_read 0xfe200544]
lappend results [mem_read 0xfe200548]
lappend results [mem_read 0xfe20054c]
lappend results [mem_read 0xfe200550]
lappend results [mem_read 0xfe200554]
lappend results [mem_read 0xfe200558]
lappend results [mem_read 0xfe20055c]
lappend results [mem_read 0xfe200560]
lappend results [mem_read 0xfe200564]
lappend results [mem_read 0xfe200568]
lappend results [mem_read 0xfe20056c]
lappend results [mem_read 0xfe200570]
lappend results [mem_read 0xfe200574]
lappend results [mem_read 0xfe200578]
lappend results [mem_read 0xfe20057c]
lappend results [mem_read 0xfe200580]
lappend results [mem_read 0xfe200584]
lappend results [mem_read 0xfe200588]
lappend results [mem_read 0xfe20058c]
lappend results [mem_read 0xfe200590]
lappend results [mem_read 0xfe200594]
lappend results [mem_read 0xfe200598]
lappend results [mem_read 0xfe20059c]
lappend results [mem_read 0xfe2005a0]
lappend results [mem_read 0xfe2005a4]
lappend results [mem_read 0xfe2005a8]
lappend results [mem_read 0xfe2005ac]
lappend results [mem_read 0xfe2005b0]
lappend results [mem_read 0xfe2005b4]
lappend results [mem_read 0xfe2005b8]
lappend results [mem_read 0xfe2005bc]
lappend results [mem_read 0xfe2005c0]
lappend results [mem_read 0xfe2005c4]
lappend results [mem_read 0xfe2005c8]
lappend results [mem_read 0xfe2005cc]
lappend results [mem_read 0xfe2005d0]
lappend results [mem_read 0xfe2005d4]
lappend results [mem_read 0xfe2005d8]
lappend results [mem_read 0xfe2005dc]
lappend results [mem_read 0xfe2005e0]
lappend results [mem_read 0xfe2008e0]
lappend results [mem_read 0xfe2008e4]
lappend results [mem_read 0xfe2008f0]
lappend results [mem_read 0xfe2008f4]
lappend results [mem_read 0xfe2008f8]
lappend results [mem_read 0xfe2008fc]
