##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM4_XDMA_CSR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xe1000000]
lappend results [mem_read 0xe1000004]
lappend results [mem_read 0xe1000008]
lappend results [mem_read 0xe100000c]
lappend results [mem_read 0xe1000040]
lappend results [mem_read 0xe1000044]
lappend results [mem_read 0xe1000048]
lappend results [mem_read 0xe100004c]
lappend results [mem_read 0xe1000088]
lappend results [mem_read 0xe100008c]
lappend results [mem_read 0xe1000090]
lappend results [mem_read 0xe1000094]
lappend results [mem_read 0xe1000098]
lappend results [mem_read 0xe10000c0]
lappend results [mem_read 0xe10000c4]
lappend results [mem_read 0xe10000c8]
lappend results [mem_read 0xe10000cc]
lappend results [mem_read 0xe10000d0]
lappend results [mem_read 0xe1000100]
lappend results [mem_read 0xe1000104]
lappend results [mem_read 0xe1000108]
lappend results [mem_read 0xe100010c]
lappend results [mem_read 0xe1000140]
lappend results [mem_read 0xe1000144]
lappend results [mem_read 0xe1000148]
lappend results [mem_read 0xe100014c]
lappend results [mem_read 0xe1000188]
lappend results [mem_read 0xe100018c]
lappend results [mem_read 0xe1000190]
lappend results [mem_read 0xe1000194]
lappend results [mem_read 0xe1000198]
lappend results [mem_read 0xe10001c0]
lappend results [mem_read 0xe10001c4]
lappend results [mem_read 0xe10001c8]
lappend results [mem_read 0xe10001cc]
lappend results [mem_read 0xe10001d0]
lappend results [mem_read 0xe1000200]
lappend results [mem_read 0xe1000204]
lappend results [mem_read 0xe1000208]
lappend results [mem_read 0xe100020c]
lappend results [mem_read 0xe1000240]
lappend results [mem_read 0xe1000244]
lappend results [mem_read 0xe1000248]
lappend results [mem_read 0xe100024c]
lappend results [mem_read 0xe1000288]
lappend results [mem_read 0xe100028c]
lappend results [mem_read 0xe1000290]
lappend results [mem_read 0xe1000294]
lappend results [mem_read 0xe1000298]
lappend results [mem_read 0xe10002c0]
lappend results [mem_read 0xe10002c4]
lappend results [mem_read 0xe10002c8]
lappend results [mem_read 0xe10002cc]
lappend results [mem_read 0xe10002d0]
lappend results [mem_read 0xe1000300]
lappend results [mem_read 0xe1000304]
lappend results [mem_read 0xe1000308]
lappend results [mem_read 0xe100030c]
lappend results [mem_read 0xe1000340]
lappend results [mem_read 0xe1000344]
lappend results [mem_read 0xe1000348]
lappend results [mem_read 0xe100034c]
lappend results [mem_read 0xe1000388]
lappend results [mem_read 0xe100038c]
lappend results [mem_read 0xe1000390]
lappend results [mem_read 0xe1000394]
lappend results [mem_read 0xe1000398]
lappend results [mem_read 0xe10003c0]
lappend results [mem_read 0xe10003c4]
lappend results [mem_read 0xe10003c8]
lappend results [mem_read 0xe10003cc]
lappend results [mem_read 0xe10003d0]
lappend results [mem_read 0xe1001000]
lappend results [mem_read 0xe1001004]
lappend results [mem_read 0xe1001008]
lappend results [mem_read 0xe100100c]
lappend results [mem_read 0xe1001040]
lappend results [mem_read 0xe1001044]
lappend results [mem_read 0xe1001048]
lappend results [mem_read 0xe100104c]
lappend results [mem_read 0xe1001088]
lappend results [mem_read 0xe100108c]
lappend results [mem_read 0xe1001090]
lappend results [mem_read 0xe1001094]
lappend results [mem_read 0xe1001098]
lappend results [mem_read 0xe10010c0]
lappend results [mem_read 0xe10010c4]
lappend results [mem_read 0xe10010c8]
lappend results [mem_read 0xe10010cc]
lappend results [mem_read 0xe10010d0]
lappend results [mem_read 0xe1001100]
lappend results [mem_read 0xe1001104]
lappend results [mem_read 0xe1001108]
lappend results [mem_read 0xe100110c]
lappend results [mem_read 0xe1001140]
lappend results [mem_read 0xe1001144]
lappend results [mem_read 0xe1001148]
lappend results [mem_read 0xe100114c]
lappend results [mem_read 0xe1001188]
lappend results [mem_read 0xe100118c]
lappend results [mem_read 0xe1001190]
lappend results [mem_read 0xe1001194]
lappend results [mem_read 0xe1001198]
lappend results [mem_read 0xe10011c0]
lappend results [mem_read 0xe10011c4]
lappend results [mem_read 0xe10011c8]
lappend results [mem_read 0xe10011cc]
lappend results [mem_read 0xe10011d0]
lappend results [mem_read 0xe1001200]
lappend results [mem_read 0xe1001204]
lappend results [mem_read 0xe1001208]
lappend results [mem_read 0xe100120c]
lappend results [mem_read 0xe1001240]
lappend results [mem_read 0xe1001244]
lappend results [mem_read 0xe1001248]
lappend results [mem_read 0xe100124c]
lappend results [mem_read 0xe1001288]
lappend results [mem_read 0xe100128c]
lappend results [mem_read 0xe1001290]
lappend results [mem_read 0xe1001294]
lappend results [mem_read 0xe1001298]
lappend results [mem_read 0xe10012c0]
lappend results [mem_read 0xe10012c4]
lappend results [mem_read 0xe10012c8]
lappend results [mem_read 0xe10012cc]
lappend results [mem_read 0xe10012d0]
lappend results [mem_read 0xe1001300]
lappend results [mem_read 0xe1001304]
lappend results [mem_read 0xe1001308]
lappend results [mem_read 0xe100130c]
lappend results [mem_read 0xe1001340]
lappend results [mem_read 0xe1001344]
lappend results [mem_read 0xe1001348]
lappend results [mem_read 0xe100134c]
lappend results [mem_read 0xe1001388]
lappend results [mem_read 0xe100138c]
lappend results [mem_read 0xe1001390]
lappend results [mem_read 0xe1001394]
lappend results [mem_read 0xe1001398]
lappend results [mem_read 0xe10013c0]
lappend results [mem_read 0xe10013c4]
lappend results [mem_read 0xe10013c8]
lappend results [mem_read 0xe10013cc]
lappend results [mem_read 0xe10013d0]
lappend results [mem_read 0xe1002000]
lappend results [mem_read 0xe1002004]
lappend results [mem_read 0xe1002008]
lappend results [mem_read 0xe100200c]
lappend results [mem_read 0xe1002010]
lappend results [mem_read 0xe1002014]
lappend results [mem_read 0xe1002018]
lappend results [mem_read 0xe1002040]
lappend results [mem_read 0xe1002044]
lappend results [mem_read 0xe1002048]
lappend results [mem_read 0xe100204c]
lappend results [mem_read 0xe1002080]
lappend results [mem_read 0xe1002084]
lappend results [mem_read 0xe1002088]
lappend results [mem_read 0xe100208c]
lappend results [mem_read 0xe10020a0]
lappend results [mem_read 0xe10020a4]
lappend results [mem_read 0xe1003000]
lappend results [mem_read 0xe1003004]
lappend results [mem_read 0xe1003008]
lappend results [mem_read 0xe100300c]
lappend results [mem_read 0xe1003010]
lappend results [mem_read 0xe1003014]
lappend results [mem_read 0xe1003018]
lappend results [mem_read 0xe100301c]
lappend results [mem_read 0xe1003040]
lappend results [mem_read 0xe1003044]
lappend results [mem_read 0xe100304c]
lappend results [mem_read 0xe1003060]
lappend results [mem_read 0xe1004000]
lappend results [mem_read 0xe1004080]
lappend results [mem_read 0xe1004084]
lappend results [mem_read 0xe1004088]
lappend results [mem_read 0xe100408c]
lappend results [mem_read 0xe1004100]
lappend results [mem_read 0xe1004180]
lappend results [mem_read 0xe1004184]
lappend results [mem_read 0xe1004188]
lappend results [mem_read 0xe100418c]
lappend results [mem_read 0xe1004200]
lappend results [mem_read 0xe1004280]
lappend results [mem_read 0xe1004284]
lappend results [mem_read 0xe1004288]
lappend results [mem_read 0xe100428c]
lappend results [mem_read 0xe1004300]
lappend results [mem_read 0xe1004380]
lappend results [mem_read 0xe1004384]
lappend results [mem_read 0xe1004388]
lappend results [mem_read 0xe100438c]
lappend results [mem_read 0xe1005000]
lappend results [mem_read 0xe1005080]
lappend results [mem_read 0xe1005084]
lappend results [mem_read 0xe1005088]
lappend results [mem_read 0xe100508c]
lappend results [mem_read 0xe1005100]
lappend results [mem_read 0xe1005180]
lappend results [mem_read 0xe1005184]
lappend results [mem_read 0xe1005188]
lappend results [mem_read 0xe100518c]
lappend results [mem_read 0xe1005200]
lappend results [mem_read 0xe1005280]
lappend results [mem_read 0xe1005284]
lappend results [mem_read 0xe1005288]
lappend results [mem_read 0xe100528c]
lappend results [mem_read 0xe1005300]
lappend results [mem_read 0xe1005380]
lappend results [mem_read 0xe1005384]
lappend results [mem_read 0xe1005388]
lappend results [mem_read 0xe100538c]
lappend results [mem_read 0xe1006000]
lappend results [mem_read 0xe1006010]
lappend results [mem_read 0xe1006014]
lappend results [mem_read 0xe1006018]
lappend results [mem_read 0xe1006020]
lappend results [mem_read 0xe1006024]
lappend results [mem_read 0xe1006028]
lappend results [mem_read 0xe1000e00]
lappend results [mem_read 0xe1000e04]
lappend results [mem_read 0xe1000e08]
lappend results [mem_read 0xe1000e0c]
lappend results [mem_read 0xe1000e10]
lappend results [mem_read 0xe1000e14]
lappend results [mem_read 0xe1000e18]
lappend results [mem_read 0xe1000e1c]
lappend results [mem_read 0xe1000e20]
lappend results [mem_read 0xe1000e24]
lappend results [mem_read 0xe1000e28]
lappend results [mem_read 0xe1000e2c]
lappend results [mem_read 0xe1000e30]
lappend results [mem_read 0xe1000e34]
lappend results [mem_read 0xe1000e38]
lappend results [mem_read 0xe1000e3c]
lappend results [mem_read 0xe1000e40]
lappend results [mem_read 0xe1000e44]
lappend results [mem_read 0xe1000e48]
lappend results [mem_read 0xe1000e4c]
lappend results [mem_read 0xe1000e50]
lappend results [mem_read 0xe1000e54]
lappend results [mem_read 0xe1000e58]
lappend results [mem_read 0xe1000e5c]
lappend results [mem_read 0xe1000e60]
lappend results [mem_read 0xe1000e64]
lappend results [mem_read 0xe1000e68]
lappend results [mem_read 0xe1000e6c]
lappend results [mem_read 0xe1000e70]
lappend results [mem_read 0xe1000e74]
lappend results [mem_read 0xe1000e78]
lappend results [mem_read 0xe1000e7c]
lappend results [mem_read 0xe1000ed8]
lappend results [mem_read 0xe1000edc]
lappend results [mem_read 0xe1000ee0]
lappend results [mem_read 0xe1000ee4]
lappend results [mem_read 0xe1000ee8]
lappend results [mem_read 0xe1000eec]
lappend results [mem_read 0xe1000ef0]
lappend results [mem_read 0xe1000ef4]
lappend results [mem_read 0xe1000ef8]
lappend results [mem_read 0xe1000efc]
lappend results [mem_read 0xe1000f00]
lappend results [mem_read 0xe1000f04]
lappend results [mem_read 0xe1000f08]
lappend results [mem_read 0xe1000f0c]
