var findLastIndex = require('./findLastIndex.js');

var _createIndexFinder = require('./_createIndexFinder.js'); // Return the position of the last occurrence of an item in an array,
// or -1 if the item is not included in the array.


var lastIndexOf = _createIndexFinder(-1, findLastIndex);

module.exports = lastIndexOf;