##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_CPM_ELA2B
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0f50000]
lappend results [mem_read 0xf0f50004]
lappend results [mem_read 0xf0f50008]
lappend results [mem_read 0xf0f50010]
lappend results [mem_read 0xf0f50020]
lappend results [mem_read 0xf0f50024]
lappend results [mem_read 0xf0f50028]
lappend results [mem_read 0xf0f5002c]
lappend results [mem_read 0xf0f50040]
lappend results [mem_read 0xf0f50044]
lappend results [mem_read 0xf0f50048]
lappend results [mem_read 0xf0f5004c]
lappend results [mem_read 0xf0f50100]
lappend results [mem_read 0xf0f50104]
lappend results [mem_read 0xf0f50108]
lappend results [mem_read 0xf0f5010c]
lappend results [mem_read 0xf0f50110]
lappend results [mem_read 0xf0f50114]
lappend results [mem_read 0xf0f50120]
lappend results [mem_read 0xf0f50130]
lappend results [mem_read 0xf0f50134]
lappend results [mem_read 0xf0f50140]
lappend results [mem_read 0xf0f50144]
lappend results [mem_read 0xf0f50148]
lappend results [mem_read 0xf0f5014c]
lappend results [mem_read 0xf0f50180]
lappend results [mem_read 0xf0f50184]
lappend results [mem_read 0xf0f50188]
lappend results [mem_read 0xf0f5018c]
lappend results [mem_read 0xf0f50200]
lappend results [mem_read 0xf0f50204]
lappend results [mem_read 0xf0f50208]
lappend results [mem_read 0xf0f5020c]
lappend results [mem_read 0xf0f50210]
lappend results [mem_read 0xf0f50214]
lappend results [mem_read 0xf0f50220]
lappend results [mem_read 0xf0f50230]
lappend results [mem_read 0xf0f50234]
lappend results [mem_read 0xf0f50240]
lappend results [mem_read 0xf0f50244]
lappend results [mem_read 0xf0f50248]
lappend results [mem_read 0xf0f5024c]
lappend results [mem_read 0xf0f50280]
lappend results [mem_read 0xf0f50284]
lappend results [mem_read 0xf0f50288]
lappend results [mem_read 0xf0f5028c]
lappend results [mem_read 0xf0f50300]
lappend results [mem_read 0xf0f50304]
lappend results [mem_read 0xf0f50308]
lappend results [mem_read 0xf0f5030c]
lappend results [mem_read 0xf0f50310]
lappend results [mem_read 0xf0f50314]
lappend results [mem_read 0xf0f50320]
lappend results [mem_read 0xf0f50330]
lappend results [mem_read 0xf0f50334]
lappend results [mem_read 0xf0f50340]
lappend results [mem_read 0xf0f50344]
lappend results [mem_read 0xf0f50348]
lappend results [mem_read 0xf0f5034c]
lappend results [mem_read 0xf0f50380]
lappend results [mem_read 0xf0f50384]
lappend results [mem_read 0xf0f50388]
lappend results [mem_read 0xf0f5038c]
lappend results [mem_read 0xf0f50400]
lappend results [mem_read 0xf0f50404]
lappend results [mem_read 0xf0f50408]
lappend results [mem_read 0xf0f5040c]
lappend results [mem_read 0xf0f50410]
lappend results [mem_read 0xf0f50414]
lappend results [mem_read 0xf0f50420]
lappend results [mem_read 0xf0f50430]
lappend results [mem_read 0xf0f50434]
lappend results [mem_read 0xf0f50440]
lappend results [mem_read 0xf0f50444]
lappend results [mem_read 0xf0f50448]
lappend results [mem_read 0xf0f5044c]
lappend results [mem_read 0xf0f50480]
lappend results [mem_read 0xf0f50484]
lappend results [mem_read 0xf0f50488]
lappend results [mem_read 0xf0f5048c]
lappend results [mem_read 0xf0f50500]
lappend results [mem_read 0xf0f50504]
lappend results [mem_read 0xf0f50508]
lappend results [mem_read 0xf0f5050c]
lappend results [mem_read 0xf0f50510]
lappend results [mem_read 0xf0f50514]
lappend results [mem_read 0xf0f50520]
lappend results [mem_read 0xf0f50530]
lappend results [mem_read 0xf0f50534]
lappend results [mem_read 0xf0f50540]
lappend results [mem_read 0xf0f50544]
lappend results [mem_read 0xf0f50548]
lappend results [mem_read 0xf0f5054c]
lappend results [mem_read 0xf0f50580]
lappend results [mem_read 0xf0f50584]
lappend results [mem_read 0xf0f50588]
lappend results [mem_read 0xf0f5058c]
lappend results [mem_read 0xf0f50ee8]
lappend results [mem_read 0xf0f50ef8]
lappend results [mem_read 0xf0f50f00]
lappend results [mem_read 0xf0f50fb0]
lappend results [mem_read 0xf0f50fb4]
lappend results [mem_read 0xf0f50fb8]
lappend results [mem_read 0xf0f50fbc]
lappend results [mem_read 0xf0f50fc0]
lappend results [mem_read 0xf0f50fc4]
lappend results [mem_read 0xf0f50fc8]
lappend results [mem_read 0xf0f50fcc]
