##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM5_SLCR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfcdd0000]
lappend results [mem_read 0xfcdd0004]
lappend results [mem_read 0xfcdd0008]
lappend results [mem_read 0xfcdd000c]
lappend results [mem_read 0xfcdd0010]
lappend results [mem_read 0xfcdd0014]
lappend results [mem_read 0xfcdd0018]
lappend results [mem_read 0xfcdd0020]
lappend results [mem_read 0xfcdd008c]
lappend results [mem_read 0xfcdd0120]
lappend results [mem_read 0xfcdd0124]
lappend results [mem_read 0xfcdd0128]
lappend results [mem_read 0xfcdd012c]
lappend results [mem_read 0xfcdd0130]
lappend results [mem_read 0xfcdd0134]
lappend results [mem_read 0xfcdd0138]
lappend results [mem_read 0xfcdd013c]
lappend results [mem_read 0xfcdd0140]
lappend results [mem_read 0xfcdd0200]
lappend results [mem_read 0xfcdd0204]
lappend results [mem_read 0xfcdd0208]
lappend results [mem_read 0xfcdd020c]
lappend results [mem_read 0xfcdd0210]
lappend results [mem_read 0xfcdd0218]
lappend results [mem_read 0xfcdd021c]
lappend results [mem_read 0xfcdd0220]
lappend results [mem_read 0xfcdd0224]
lappend results [mem_read 0xfcdd022c]
lappend results [mem_read 0xfcdd0230]
lappend results [mem_read 0xfcdd0234]
lappend results [mem_read 0xfcdd0238]
lappend results [mem_read 0xfcdd023c]
lappend results [mem_read 0xfcdd0240]
lappend results [mem_read 0xfcdd0244]
lappend results [mem_read 0xfcdd0248]
lappend results [mem_read 0xfcdd024c]
lappend results [mem_read 0xfcdd0254]
lappend results [mem_read 0xfcdd0258]
lappend results [mem_read 0xfcdd025c]
lappend results [mem_read 0xfcdd0260]
lappend results [mem_read 0xfcdd0264]
lappend results [mem_read 0xfcdd026c]
lappend results [mem_read 0xfcdd0270]
lappend results [mem_read 0xfcdd0274]
lappend results [mem_read 0xfcdd029c]
lappend results [mem_read 0xfcdd02a0]
lappend results [mem_read 0xfcdd02a4]
lappend results [mem_read 0xfcdd02a8]
lappend results [mem_read 0xfcdd02ac]
lappend results [mem_read 0xfcdd02b4]
lappend results [mem_read 0xfcdd02b8]
lappend results [mem_read 0xfcdd02bc]
lappend results [mem_read 0xfcdd02c0]
lappend results [mem_read 0xfcdd02c8]
lappend results [mem_read 0xfcdd02cc]
lappend results [mem_read 0xfcdd0300]
lappend results [mem_read 0xfcdd0304]
lappend results [mem_read 0xfcdd0308]
lappend results [mem_read 0xfcdd030c]
lappend results [mem_read 0xfcdd0320]
lappend results [mem_read 0xfcdd0324]
lappend results [mem_read 0xfcdd0328]
lappend results [mem_read 0xfcdd032c]
lappend results [mem_read 0xfcdd0340]
lappend results [mem_read 0xfcdd0344]
lappend results [mem_read 0xfcdd0348]
lappend results [mem_read 0xfcdd034c]
lappend results [mem_read 0xfcdd0360]
lappend results [mem_read 0xfcdd0364]
lappend results [mem_read 0xfcdd0368]
lappend results [mem_read 0xfcdd036c]
lappend results [mem_read 0xfcdd0380]
lappend results [mem_read 0xfcdd0384]
lappend results [mem_read 0xfcdd0388]
lappend results [mem_read 0xfcdd038c]
lappend results [mem_read 0xfcdd03a0]
lappend results [mem_read 0xfcdd03a4]
lappend results [mem_read 0xfcdd03a8]
lappend results [mem_read 0xfcdd03ac]
lappend results [mem_read 0xfcdd0408]
lappend results [mem_read 0xfcdd040c]
lappend results [mem_read 0xfcdd0420]
lappend results [mem_read 0xfcdd0424]
lappend results [mem_read 0xfcdd0428]
lappend results [mem_read 0xfcdd042c]
lappend results [mem_read 0xfcdd0430]
lappend results [mem_read 0xfcdd0434]
lappend results [mem_read 0xfcdd0438]
lappend results [mem_read 0xfcdd043c]
lappend results [mem_read 0xfcdd0440]
lappend results [mem_read 0xfcdd0444]
lappend results [mem_read 0xfcdd0448]
lappend results [mem_read 0xfcdd044c]
lappend results [mem_read 0xfcdd0490]
lappend results [mem_read 0xfcdd0494]
lappend results [mem_read 0xfcdd04b0]
lappend results [mem_read 0xfcdd04b4]
lappend results [mem_read 0xfcdd04b8]
lappend results [mem_read 0xfcdd04bc]
lappend results [mem_read 0xfcdd04c4]
lappend results [mem_read 0xfcdd04c8]
lappend results [mem_read 0xfcdd04cc]
lappend results [mem_read 0xfcdd04d0]
lappend results [mem_read 0xfcdd04d8]
lappend results [mem_read 0xfcdd04dc]
lappend results [mem_read 0xfcdd04e0]
lappend results [mem_read 0xfcdd04e4]
lappend results [mem_read 0xfcdd04ec]
lappend results [mem_read 0xfcdd04f0]
lappend results [mem_read 0xfcdd04f4]
lappend results [mem_read 0xfcdd04f8]
lappend results [mem_read 0xfcdd0610]
