define(['./_createAssigner', './keys'], function (_createAssigner, keys) {
  // Assigns a given object with all the own properties in the passed-in
  // object(s).
  // (https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object/assign)
  var extendOwn = _createAssigner(keys);

  return extendOwn;
});