##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: XRAM_SLCR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff950000]
lappend results [mem_read 0xff950004]
lappend results [mem_read 0xff950008]
lappend results [mem_read 0xff95000c]
lappend results [mem_read 0xff951000]
lappend results [mem_read 0xff951004]
lappend results [mem_read 0xff951010]
lappend results [mem_read 0xff951100]
lappend results [mem_read 0xff951104]
lappend results [mem_read 0xff951108]
lappend results [mem_read 0xff951110]
lappend results [mem_read 0xff951114]
lappend results [mem_read 0xff951118]
lappend results [mem_read 0xff951120]
lappend results [mem_read 0xff951124]
lappend results [mem_read 0xff951128]
lappend results [mem_read 0xff951130]
lappend results [mem_read 0xff951134]
lappend results [mem_read 0xff951138]
lappend results [mem_read 0xff951800]
lappend results [mem_read 0xff951804]
lappend results [mem_read 0xff951900]
lappend results [mem_read 0xff951904]
lappend results [mem_read 0xff951a00]
lappend results [mem_read 0xff951a04]
lappend results [mem_read 0xff951b00]
lappend results [mem_read 0xff951b04]
lappend results [mem_read 0xff952000]
lappend results [mem_read 0xff9520fc]
lappend results [mem_read 0xff952100]
lappend results [mem_read 0xff952104]
lappend results [mem_read 0xff952108]
lappend results [mem_read 0xff955000]
lappend results [mem_read 0xff955100]
lappend results [mem_read 0xff955104]
lappend results [mem_read 0xff955110]
lappend results [mem_read 0xff955114]
lappend results [mem_read 0xff955120]
lappend results [mem_read 0xff955124]
lappend results [mem_read 0xff955180]
lappend results [mem_read 0xff955184]
lappend results [mem_read 0xff955200]
lappend results [mem_read 0xff955204]
lappend results [mem_read 0xff955280]
lappend results [mem_read 0xff955284]
lappend results [mem_read 0xff955300]
lappend results [mem_read 0xff955304]
lappend results [mem_read 0xff955310]
lappend results [mem_read 0xff955314]
lappend results [mem_read 0xff955320]
lappend results [mem_read 0xff955324]
lappend results [mem_read 0xff955330]
lappend results [mem_read 0xff955334]
lappend results [mem_read 0xff955380]
lappend results [mem_read 0xff955384]
lappend results [mem_read 0xff955390]
lappend results [mem_read 0xff955394]
lappend results [mem_read 0xff9553a0]
lappend results [mem_read 0xff9553a4]
lappend results [mem_read 0xff9553b0]
lappend results [mem_read 0xff9553b4]
lappend results [mem_read 0xff955400]
lappend results [mem_read 0xff955404]
lappend results [mem_read 0xff959000]
lappend results [mem_read 0xff959004]
lappend results [mem_read 0xff959010]
lappend results [mem_read 0xff959014]
lappend results [mem_read 0xff959020]
lappend results [mem_read 0xff959024]
lappend results [mem_read 0xff95a000]
lappend results [mem_read 0xff95a004]
lappend results [mem_read 0xff95a008]
lappend results [mem_read 0xff95a00c]
lappend results [mem_read 0xff95a010]
lappend results [mem_read 0xff95a014]
lappend results [mem_read 0xff95a018]
lappend results [mem_read 0xff95a01c]
lappend results [mem_read 0xff95a020]
lappend results [mem_read 0xff95a024]
lappend results [mem_read 0xff95a028]
lappend results [mem_read 0xff95a02c]
lappend results [mem_read 0xff95a030]
lappend results [mem_read 0xff95a034]
lappend results [mem_read 0xff95a038]
lappend results [mem_read 0xff95a03c]
lappend results [mem_read 0xff95a060]
lappend results [mem_read 0xff95a064]
lappend results [mem_read 0xff95a068]
lappend results [mem_read 0xff95a06c]
lappend results [mem_read 0xff95a070]
lappend results [mem_read 0xff95a080]
lappend results [mem_read 0xff95a084]
lappend results [mem_read 0xff95a088]
lappend results [mem_read 0xff95a08c]
lappend results [mem_read 0xff95a090]
lappend results [mem_read 0xff95a094]
lappend results [mem_read 0xff95a098]
lappend results [mem_read 0xff95a09c]
lappend results [mem_read 0xff95a0a0]
lappend results [mem_read 0xff95a0a4]
lappend results [mem_read 0xff95a0a8]
lappend results [mem_read 0xff95a0ac]
lappend results [mem_read 0xff95a0b0]
lappend results [mem_read 0xff95a0b4]
lappend results [mem_read 0xff95a0b8]
lappend results [mem_read 0xff95a0bc]
lappend results [mem_read 0xff95a0c0]
lappend results [mem_read 0xff95a0c4]
lappend results [mem_read 0xff95a0c8]
lappend results [mem_read 0xff95a0cc]
lappend results [mem_read 0xff95a0d0]
lappend results [mem_read 0xff95a0d4]
lappend results [mem_read 0xff95a0d8]
lappend results [mem_read 0xff95a0dc]
lappend results [mem_read 0xff95a0e0]
lappend results [mem_read 0xff95a0e4]
lappend results [mem_read 0xff95a0e8]
lappend results [mem_read 0xff95a0ec]
lappend results [mem_read 0xff95a0f0]
lappend results [mem_read 0xff95a0f4]
lappend results [mem_read 0xff95a0f8]
lappend results [mem_read 0xff95a0fc]
lappend results [mem_read 0xff95a100]
lappend results [mem_read 0xff95a104]
lappend results [mem_read 0xff95a160]
lappend results [mem_read 0xff95a164]
lappend results [mem_read 0xff95a168]
lappend results [mem_read 0xff95a16c]
lappend results [mem_read 0xff95a170]
lappend results [mem_read 0xff95a174]
lappend results [mem_read 0xff95a178]
lappend results [mem_read 0xff95a17c]
lappend results [mem_read 0xff95a180]
lappend results [mem_read 0xff95a188]
lappend results [mem_read 0xff95a18c]
lappend results [mem_read 0xff95a190]
lappend results [mem_read 0xff95a194]
lappend results [mem_read 0xff95a198]
lappend results [mem_read 0xff95a19c]
lappend results [mem_read 0xff95a1a0]
lappend results [mem_read 0xff95a1a4]
lappend results [mem_read 0xff95a1a8]
lappend results [mem_read 0xff95a1ac]
lappend results [mem_read 0xff95a1b0]
lappend results [mem_read 0xff95a1b4]
lappend results [mem_read 0xff95a1b8]
lappend results [mem_read 0xff95a1bc]
lappend results [mem_read 0xff95a1e0]
lappend results [mem_read 0xff95a1e4]
lappend results [mem_read 0xff95a1e8]
lappend results [mem_read 0xff95a1ec]
lappend results [mem_read 0xff95a1f0]
lappend results [mem_read 0xff95a1f4]
lappend results [mem_read 0xff95a1f8]
lappend results [mem_read 0xff95a1fc]
