/**
 * @license
 * Copyright (c) 2014 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt The complete set of authors may be found
 * at http://polymer.github.io/AUTHORS.txt The complete set of contributors may
 * be found at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by
 * Google as part of the polymer project is also subject to an additional IP
 * rights grant found at http://polymer.github.io/PATENTS.txt
 */
// It's desireable to provide a default stylesheet
// that's convenient for styling unresolved elements, but
// it's cumbersome to have to include this manually in every page.
// It would make sense to put inside some HTMLImport but
// the HTMLImports polyfill does not allow loading of stylesheets
// that block rendering. Therefore this injection is tolerated here.
//
// NOTE: position: relative fixes IE's failure to inherit opacity
// when a child is not statically positioned.
const style = document.createElement('style');
style.textContent =
    '' +
        'body {' +
        'transition: opacity ease-in 0.2s;' +
        ' } \n' +
        'body[unresolved] {' +
        'opacity: 0; display: block; overflow: hidden; position: relative;' +
        ' } \n';
const head = document.querySelector('head');
head.insertBefore(style, head.firstChild);
export {};
//# sourceMappingURL=unresolved.js.map