##
# Copyright (c) 2021, Xilinx Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# MONGO_URI = "mongodb://vncmgr:vncw0rld19@xsj-pvdbvnc02:27060,xsj-pvdbvnc03:27060,xsj-pvdbvnc04:27060/xregv?authSource=admin&readPreference=secondaryPreferred"
MONGO_URI = "mongodb://localhost:27017/xregv"
SECRET_KEY = 'the quick brown fox jumps over the lazy dog'
CORS_HEADERS = 'Content-Type'
ENVIRONMENT = 'production'

URI = 'ldap://ldap.xilinx.com:389'
LDAP_DOMAIN = 'xilinx.com'
LDAP_SEARCH_BASE = 'OU=people,DC=xilinx,DC=com'

# DB_Lookup = {"S80_ES1_VnC":{"PS":"xregv_ps_S80_ES1_VnC","PMC":"xregv_ps_S80_ES1_VnC","CPM":"xregv_ps_S80_ES1_VnC","NPI":"xregv_npi_S80_ES1_VnC","PL":"xregvpl_S80_ES1_VnC","AI_ENGINE":"xregvme_S80_ES1_VnC","DDR":"xregv_npi_S80_ES1_VnC"},
# "S80_ES1_VCK190":{"PS":"xregv_ps_S80_ES1_VCK180","PMC":"xregv_ps_S80_ES1_VCK180","CPM":"xregv_ps_S80_ES1_VCK180","NPI":"xregv_npi_S80_ES1_VCK180","PL":"xregvpl_S80_ES1_VnC","AI_ENGINE":"xregvme_S80_ES1_VnC","DDR":"xregv_npi_S80_ES1_VCK180"},
# "S80_ES2_VnC":{"PS":"xregv_ps_S80_ES2_VnC","PMC":"xregv_ps_S80_ES2_VnC","CPM":"xregv_ps_S80_ES2_VnC","NPI":"xregv_npi_S80_ES1_VnC","PL":"xregvpl_S80_ES1_VnC","AI_ENGINE":"xregvme_S80_ES1_VnC","DDR":"xregv_npi_S80_ES1_VnC"}}

DB_Lookup = {"S80_ES1_VCK190":{"PS":"xregv_ps_S80_ES1_VCK180","AM012":"xregv_ps_S80_ES1_VCK180","PMC":"xregv_ps_S80_ES1_VCK180","CPM":"xregv_ps_S80_ES1_VCK180","NPI":"xregv_npi_S80_ES1_VCK180","PL":"xregvpl_S80_ES1_VnC","AI_ENGINE":"xregvme_S80_ES1_VnC","DDR":"xregv_npi_S80_ES1_VCK180"}}
