##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_APU_CTI
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0ca0000]
lappend results [mem_read 0xf0ca0010]
lappend results [mem_read 0xf0ca0014]
lappend results [mem_read 0xf0ca0018]
lappend results [mem_read 0xf0ca001c]
lappend results [mem_read 0xf0ca0020]
lappend results [mem_read 0xf0ca0024]
lappend results [mem_read 0xf0ca0028]
lappend results [mem_read 0xf0ca002c]
lappend results [mem_read 0xf0ca0030]
lappend results [mem_read 0xf0ca0034]
lappend results [mem_read 0xf0ca0038]
lappend results [mem_read 0xf0ca003c]
lappend results [mem_read 0xf0ca00a0]
lappend results [mem_read 0xf0ca00a4]
lappend results [mem_read 0xf0ca00a8]
lappend results [mem_read 0xf0ca00ac]
lappend results [mem_read 0xf0ca00b0]
lappend results [mem_read 0xf0ca00b4]
lappend results [mem_read 0xf0ca00b8]
lappend results [mem_read 0xf0ca00bc]
lappend results [mem_read 0xf0ca0130]
lappend results [mem_read 0xf0ca0134]
lappend results [mem_read 0xf0ca0138]
lappend results [mem_read 0xf0ca013c]
lappend results [mem_read 0xf0ca0140]
lappend results [mem_read 0xf0ca0144]
lappend results [mem_read 0xf0ca0edc]
lappend results [mem_read 0xf0ca0ee0]
lappend results [mem_read 0xf0ca0ee4]
lappend results [mem_read 0xf0ca0ee8]
lappend results [mem_read 0xf0ca0eec]
lappend results [mem_read 0xf0ca0ef0]
lappend results [mem_read 0xf0ca0ef4]
lappend results [mem_read 0xf0ca0ef8]
lappend results [mem_read 0xf0ca0f00]
lappend results [mem_read 0xf0ca0fa0]
lappend results [mem_read 0xf0ca0fa4]
lappend results [mem_read 0xf0ca0fb0]
lappend results [mem_read 0xf0ca0fb4]
lappend results [mem_read 0xf0ca0fb8]
