##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM5_DMA1_ATTR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfce90030]
lappend results [mem_read 0xfce90034]
lappend results [mem_read 0xfce90038]
lappend results [mem_read 0xfce9003c]
lappend results [mem_read 0xfce90040]
lappend results [mem_read 0xfce90044]
lappend results [mem_read 0xfce90048]
lappend results [mem_read 0xfce9004c]
lappend results [mem_read 0xfce90050]
lappend results [mem_read 0xfce90054]
lappend results [mem_read 0xfce90058]
lappend results [mem_read 0xfce9005c]
lappend results [mem_read 0xfce90060]
lappend results [mem_read 0xfce90064]
lappend results [mem_read 0xfce90068]
lappend results [mem_read 0xfce9006c]
lappend results [mem_read 0xfce90070]
lappend results [mem_read 0xfce90074]
lappend results [mem_read 0xfce90078]
lappend results [mem_read 0xfce9007c]
lappend results [mem_read 0xfce90080]
lappend results [mem_read 0xfce90084]
lappend results [mem_read 0xfce900c4]
lappend results [mem_read 0xfce900c8]
lappend results [mem_read 0xfce900cc]
lappend results [mem_read 0xfce900d0]
lappend results [mem_read 0xfce900d4]
lappend results [mem_read 0xfce900d8]
lappend results [mem_read 0xfce900dc]
lappend results [mem_read 0xfce900e0]
lappend results [mem_read 0xfce900e4]
lappend results [mem_read 0xfce900e8]
lappend results [mem_read 0xfce900ec]
lappend results [mem_read 0xfce900f0]
lappend results [mem_read 0xfce900f4]
lappend results [mem_read 0xfce900f8]
lappend results [mem_read 0xfce900fc]
lappend results [mem_read 0xfce90100]
lappend results [mem_read 0xfce90104]
lappend results [mem_read 0xfce90108]
lappend results [mem_read 0xfce9010c]
lappend results [mem_read 0xfce90110]
lappend results [mem_read 0xfce90114]
lappend results [mem_read 0xfce90118]
lappend results [mem_read 0xfce9011c]
lappend results [mem_read 0xfce90120]
lappend results [mem_read 0xfce90124]
lappend results [mem_read 0xfce90128]
lappend results [mem_read 0xfce9012c]
lappend results [mem_read 0xfce90130]
lappend results [mem_read 0xfce90134]
lappend results [mem_read 0xfce90138]
lappend results [mem_read 0xfce9013c]
lappend results [mem_read 0xfce90140]
lappend results [mem_read 0xfce90144]
lappend results [mem_read 0xfce90148]
lappend results [mem_read 0xfce9014c]
lappend results [mem_read 0xfce90150]
lappend results [mem_read 0xfce90154]
lappend results [mem_read 0xfce90158]
lappend results [mem_read 0xfce9015c]
lappend results [mem_read 0xfce90160]
lappend results [mem_read 0xfce90164]
lappend results [mem_read 0xfce9016c]
lappend results [mem_read 0xfce90170]
lappend results [mem_read 0xfce90174]
lappend results [mem_read 0xfce90178]
lappend results [mem_read 0xfce9017c]
lappend results [mem_read 0xfce90180]
lappend results [mem_read 0xfce90184]
lappend results [mem_read 0xfce90188]
lappend results [mem_read 0xfce9018c]
lappend results [mem_read 0xfce90190]
lappend results [mem_read 0xfce90194]
lappend results [mem_read 0xfce90198]
lappend results [mem_read 0xfce9019c]
lappend results [mem_read 0xfce901a0]
lappend results [mem_read 0xfce901a4]
lappend results [mem_read 0xfce901a8]
lappend results [mem_read 0xfce901ac]
lappend results [mem_read 0xfce901b0]
lappend results [mem_read 0xfce901b4]
lappend results [mem_read 0xfce901b8]
lappend results [mem_read 0xfce901bc]
lappend results [mem_read 0xfce901c0]
lappend results [mem_read 0xfce901c4]
lappend results [mem_read 0xfce901c8]
lappend results [mem_read 0xfce901cc]
lappend results [mem_read 0xfce901d0]
lappend results [mem_read 0xfce901d4]
lappend results [mem_read 0xfce901d8]
lappend results [mem_read 0xfce901dc]
lappend results [mem_read 0xfce901e0]
lappend results [mem_read 0xfce901e4]
lappend results [mem_read 0xfce901e8]
lappend results [mem_read 0xfce901ec]
lappend results [mem_read 0xfce901f0]
lappend results [mem_read 0xfce901f4]
lappend results [mem_read 0xfce901f8]
lappend results [mem_read 0xfce901fc]
lappend results [mem_read 0xfce90200]
lappend results [mem_read 0xfce90204]
lappend results [mem_read 0xfce90208]
lappend results [mem_read 0xfce9020c]
lappend results [mem_read 0xfce90210]
lappend results [mem_read 0xfce90214]
lappend results [mem_read 0xfce90218]
lappend results [mem_read 0xfce9021c]
lappend results [mem_read 0xfce90220]
lappend results [mem_read 0xfce90224]
lappend results [mem_read 0xfce90228]
lappend results [mem_read 0xfce9022c]
lappend results [mem_read 0xfce90230]
lappend results [mem_read 0xfce90234]
lappend results [mem_read 0xfce90238]
lappend results [mem_read 0xfce9023c]
lappend results [mem_read 0xfce90240]
lappend results [mem_read 0xfce90244]
lappend results [mem_read 0xfce90248]
lappend results [mem_read 0xfce9024c]
lappend results [mem_read 0xfce90250]
lappend results [mem_read 0xfce90254]
lappend results [mem_read 0xfce90258]
lappend results [mem_read 0xfce9025c]
lappend results [mem_read 0xfce90260]
lappend results [mem_read 0xfce90264]
lappend results [mem_read 0xfce90268]
lappend results [mem_read 0xfce9026c]
lappend results [mem_read 0xfce90270]
lappend results [mem_read 0xfce90274]
lappend results [mem_read 0xfce90278]
lappend results [mem_read 0xfce9027c]
lappend results [mem_read 0xfce90280]
lappend results [mem_read 0xfce90284]
lappend results [mem_read 0xfce90288]
lappend results [mem_read 0xfce9028c]
lappend results [mem_read 0xfce90290]
lappend results [mem_read 0xfce90294]
lappend results [mem_read 0xfce90298]
lappend results [mem_read 0xfce9029c]
lappend results [mem_read 0xfce902a0]
lappend results [mem_read 0xfce902a4]
lappend results [mem_read 0xfce902a8]
lappend results [mem_read 0xfce902ac]
lappend results [mem_read 0xfce902b0]
lappend results [mem_read 0xfce902b4]
lappend results [mem_read 0xfce902b8]
lappend results [mem_read 0xfce902bc]
lappend results [mem_read 0xfce902c0]
lappend results [mem_read 0xfce902c4]
lappend results [mem_read 0xfce902c8]
lappend results [mem_read 0xfce902cc]
lappend results [mem_read 0xfce902d0]
lappend results [mem_read 0xfce902d4]
lappend results [mem_read 0xfce902d8]
lappend results [mem_read 0xfce902dc]
lappend results [mem_read 0xfce902e0]
lappend results [mem_read 0xfce902e4]
lappend results [mem_read 0xfce902e8]
lappend results [mem_read 0xfce902ec]
lappend results [mem_read 0xfce902f0]
lappend results [mem_read 0xfce902f4]
lappend results [mem_read 0xfce902f8]
lappend results [mem_read 0xfce902fc]
lappend results [mem_read 0xfce90300]
lappend results [mem_read 0xfce90304]
lappend results [mem_read 0xfce90308]
lappend results [mem_read 0xfce9030c]
lappend results [mem_read 0xfce90310]
lappend results [mem_read 0xfce90314]
lappend results [mem_read 0xfce90318]
lappend results [mem_read 0xfce9031c]
lappend results [mem_read 0xfce90320]
lappend results [mem_read 0xfce90324]
lappend results [mem_read 0xfce90328]
lappend results [mem_read 0xfce9032c]
lappend results [mem_read 0xfce90330]
lappend results [mem_read 0xfce90334]
lappend results [mem_read 0xfce90338]
lappend results [mem_read 0xfce9033c]
lappend results [mem_read 0xfce90340]
lappend results [mem_read 0xfce90344]
lappend results [mem_read 0xfce90348]
lappend results [mem_read 0xfce9034c]
lappend results [mem_read 0xfce90350]
lappend results [mem_read 0xfce90354]
lappend results [mem_read 0xfce90358]
lappend results [mem_read 0xfce9035c]
lappend results [mem_read 0xfce90360]
lappend results [mem_read 0xfce90364]
lappend results [mem_read 0xfce90368]
lappend results [mem_read 0xfce9036c]
lappend results [mem_read 0xfce90370]
lappend results [mem_read 0xfce90374]
lappend results [mem_read 0xfce90378]
lappend results [mem_read 0xfce9037c]
lappend results [mem_read 0xfce90380]
lappend results [mem_read 0xfce90384]
lappend results [mem_read 0xfce90388]
lappend results [mem_read 0xfce9038c]
lappend results [mem_read 0xfce90390]
lappend results [mem_read 0xfce90394]
lappend results [mem_read 0xfce90398]
lappend results [mem_read 0xfce9039c]
lappend results [mem_read 0xfce903a0]
lappend results [mem_read 0xfce903a4]
lappend results [mem_read 0xfce903a8]
lappend results [mem_read 0xfce903ac]
lappend results [mem_read 0xfce903b0]
lappend results [mem_read 0xfce903b4]
lappend results [mem_read 0xfce903b8]
lappend results [mem_read 0xfce903bc]
lappend results [mem_read 0xfce903c0]
lappend results [mem_read 0xfce903c4]
lappend results [mem_read 0xfce903c8]
lappend results [mem_read 0xfce903cc]
lappend results [mem_read 0xfce903d0]
lappend results [mem_read 0xfce903d4]
lappend results [mem_read 0xfce903d8]
lappend results [mem_read 0xfce903dc]
lappend results [mem_read 0xfce903e0]
lappend results [mem_read 0xfce903e4]
lappend results [mem_read 0xfce903e8]
lappend results [mem_read 0xfce903ec]
lappend results [mem_read 0xfce903f0]
lappend results [mem_read 0xfce903f4]
lappend results [mem_read 0xfce903f8]
lappend results [mem_read 0xfce903fc]
lappend results [mem_read 0xfce90400]
lappend results [mem_read 0xfce90404]
lappend results [mem_read 0xfce90408]
lappend results [mem_read 0xfce9040c]
lappend results [mem_read 0xfce90410]
lappend results [mem_read 0xfce90414]
lappend results [mem_read 0xfce90418]
lappend results [mem_read 0xfce9041c]
lappend results [mem_read 0xfce90420]
lappend results [mem_read 0xfce90424]
lappend results [mem_read 0xfce90428]
lappend results [mem_read 0xfce9042c]
lappend results [mem_read 0xfce90430]
lappend results [mem_read 0xfce90434]
lappend results [mem_read 0xfce90438]
lappend results [mem_read 0xfce9043c]
lappend results [mem_read 0xfce90440]
lappend results [mem_read 0xfce90444]
lappend results [mem_read 0xfce90448]
lappend results [mem_read 0xfce9044c]
lappend results [mem_read 0xfce90450]
lappend results [mem_read 0xfce90454]
lappend results [mem_read 0xfce90458]
lappend results [mem_read 0xfce9045c]
lappend results [mem_read 0xfce90460]
lappend results [mem_read 0xfce90464]
lappend results [mem_read 0xfce90468]
lappend results [mem_read 0xfce9046c]
lappend results [mem_read 0xfce90470]
lappend results [mem_read 0xfce90474]
lappend results [mem_read 0xfce90478]
lappend results [mem_read 0xfce9047c]
lappend results [mem_read 0xfce90480]
lappend results [mem_read 0xfce90484]
lappend results [mem_read 0xfce90488]
lappend results [mem_read 0xfce9048c]
lappend results [mem_read 0xfce90490]
lappend results [mem_read 0xfce90494]
lappend results [mem_read 0xfce90498]
lappend results [mem_read 0xfce9049c]
lappend results [mem_read 0xfce904a0]
lappend results [mem_read 0xfce904a4]
lappend results [mem_read 0xfce904a8]
lappend results [mem_read 0xfce904ac]
lappend results [mem_read 0xfce904b0]
lappend results [mem_read 0xfce904b4]
lappend results [mem_read 0xfce904b8]
lappend results [mem_read 0xfce904bc]
lappend results [mem_read 0xfce904c0]
lappend results [mem_read 0xfce904c4]
lappend results [mem_read 0xfce904c8]
lappend results [mem_read 0xfce904cc]
lappend results [mem_read 0xfce904d0]
lappend results [mem_read 0xfce904d4]
lappend results [mem_read 0xfce904d8]
lappend results [mem_read 0xfce904dc]
lappend results [mem_read 0xfce904e0]
lappend results [mem_read 0xfce904e4]
lappend results [mem_read 0xfce904e8]
lappend results [mem_read 0xfce904ec]
lappend results [mem_read 0xfce904f0]
lappend results [mem_read 0xfce904f4]
lappend results [mem_read 0xfce904f8]
lappend results [mem_read 0xfce904fc]
lappend results [mem_read 0xfce90500]
lappend results [mem_read 0xfce90504]
lappend results [mem_read 0xfce90508]
lappend results [mem_read 0xfce9050c]
lappend results [mem_read 0xfce90510]
lappend results [mem_read 0xfce90514]
lappend results [mem_read 0xfce90518]
lappend results [mem_read 0xfce9051c]
lappend results [mem_read 0xfce90520]
lappend results [mem_read 0xfce90524]
lappend results [mem_read 0xfce90528]
lappend results [mem_read 0xfce9052c]
lappend results [mem_read 0xfce90530]
lappend results [mem_read 0xfce90534]
lappend results [mem_read 0xfce90538]
lappend results [mem_read 0xfce9053c]
lappend results [mem_read 0xfce90540]
lappend results [mem_read 0xfce90544]
lappend results [mem_read 0xfce90548]
lappend results [mem_read 0xfce9054c]
lappend results [mem_read 0xfce90550]
lappend results [mem_read 0xfce90554]
lappend results [mem_read 0xfce90558]
lappend results [mem_read 0xfce9055c]
lappend results [mem_read 0xfce90560]
lappend results [mem_read 0xfce90564]
lappend results [mem_read 0xfce90568]
lappend results [mem_read 0xfce9056c]
lappend results [mem_read 0xfce90570]
lappend results [mem_read 0xfce90574]
lappend results [mem_read 0xfce90578]
lappend results [mem_read 0xfce9057c]
lappend results [mem_read 0xfce90580]
lappend results [mem_read 0xfce90584]
lappend results [mem_read 0xfce90588]
lappend results [mem_read 0xfce9058c]
lappend results [mem_read 0xfce90590]
lappend results [mem_read 0xfce90594]
lappend results [mem_read 0xfce90598]
lappend results [mem_read 0xfce9059c]
lappend results [mem_read 0xfce905a0]
lappend results [mem_read 0xfce905a4]
lappend results [mem_read 0xfce905a8]
lappend results [mem_read 0xfce905ac]
lappend results [mem_read 0xfce905b0]
lappend results [mem_read 0xfce905b4]
lappend results [mem_read 0xfce905b8]
lappend results [mem_read 0xfce905bc]
lappend results [mem_read 0xfce905c0]
lappend results [mem_read 0xfce905c4]
lappend results [mem_read 0xfce905c8]
lappend results [mem_read 0xfce905cc]
lappend results [mem_read 0xfce905d0]
lappend results [mem_read 0xfce905d4]
lappend results [mem_read 0xfce905d8]
lappend results [mem_read 0xfce905dc]
lappend results [mem_read 0xfce905e0]
lappend results [mem_read 0xfce905e4]
lappend results [mem_read 0xfce905e8]
lappend results [mem_read 0xfce905ec]
lappend results [mem_read 0xfce905f0]
lappend results [mem_read 0xfce905f4]
lappend results [mem_read 0xfce905f8]
lappend results [mem_read 0xfce905fc]
lappend results [mem_read 0xfce90600]
lappend results [mem_read 0xfce90604]
lappend results [mem_read 0xfce90608]
lappend results [mem_read 0xfce9060c]
lappend results [mem_read 0xfce90610]
lappend results [mem_read 0xfce90614]
lappend results [mem_read 0xfce90618]
lappend results [mem_read 0xfce9061c]
lappend results [mem_read 0xfce90620]
lappend results [mem_read 0xfce90624]
lappend results [mem_read 0xfce90628]
lappend results [mem_read 0xfce9062c]
lappend results [mem_read 0xfce90630]
lappend results [mem_read 0xfce90634]
lappend results [mem_read 0xfce90638]
lappend results [mem_read 0xfce9063c]
lappend results [mem_read 0xfce90640]
lappend results [mem_read 0xfce90644]
lappend results [mem_read 0xfce90648]
lappend results [mem_read 0xfce9064c]
lappend results [mem_read 0xfce90650]
lappend results [mem_read 0xfce90654]
lappend results [mem_read 0xfce90658]
lappend results [mem_read 0xfce9065c]
lappend results [mem_read 0xfce90660]
lappend results [mem_read 0xfce90664]
lappend results [mem_read 0xfce90668]
lappend results [mem_read 0xfce9066c]
lappend results [mem_read 0xfce90670]
lappend results [mem_read 0xfce90674]
lappend results [mem_read 0xfce90678]
lappend results [mem_read 0xfce9067c]
lappend results [mem_read 0xfce90680]
lappend results [mem_read 0xfce90684]
lappend results [mem_read 0xfce90688]
lappend results [mem_read 0xfce9068c]
lappend results [mem_read 0xfce90690]
lappend results [mem_read 0xfce90694]
lappend results [mem_read 0xfce90698]
lappend results [mem_read 0xfce9069c]
lappend results [mem_read 0xfce906a0]
lappend results [mem_read 0xfce906a4]
lappend results [mem_read 0xfce906a8]
lappend results [mem_read 0xfce906ac]
lappend results [mem_read 0xfce906b0]
lappend results [mem_read 0xfce906b4]
lappend results [mem_read 0xfce906b8]
lappend results [mem_read 0xfce906bc]
lappend results [mem_read 0xfce906c0]
lappend results [mem_read 0xfce906c4]
lappend results [mem_read 0xfce906c8]
lappend results [mem_read 0xfce906cc]
lappend results [mem_read 0xfce906d0]
lappend results [mem_read 0xfce906d4]
lappend results [mem_read 0xfce906d8]
lappend results [mem_read 0xfce906dc]
lappend results [mem_read 0xfce906e0]
lappend results [mem_read 0xfce906e4]
lappend results [mem_read 0xfce906e8]
lappend results [mem_read 0xfce906ec]
lappend results [mem_read 0xfce906f0]
lappend results [mem_read 0xfce906f4]
lappend results [mem_read 0xfce906f8]
lappend results [mem_read 0xfce906fc]
lappend results [mem_read 0xfce90700]
lappend results [mem_read 0xfce90704]
lappend results [mem_read 0xfce90708]
lappend results [mem_read 0xfce9070c]
lappend results [mem_read 0xfce90710]
lappend results [mem_read 0xfce90714]
lappend results [mem_read 0xfce90718]
lappend results [mem_read 0xfce9071c]
lappend results [mem_read 0xfce90720]
lappend results [mem_read 0xfce90724]
lappend results [mem_read 0xfce90728]
lappend results [mem_read 0xfce9072c]
lappend results [mem_read 0xfce90730]
lappend results [mem_read 0xfce90734]
lappend results [mem_read 0xfce90738]
lappend results [mem_read 0xfce9073c]
lappend results [mem_read 0xfce90740]
lappend results [mem_read 0xfce90744]
lappend results [mem_read 0xfce90748]
lappend results [mem_read 0xfce9074c]
lappend results [mem_read 0xfce90750]
lappend results [mem_read 0xfce90754]
lappend results [mem_read 0xfce90758]
lappend results [mem_read 0xfce9075c]
lappend results [mem_read 0xfce90760]
lappend results [mem_read 0xfce90764]
lappend results [mem_read 0xfce90768]
lappend results [mem_read 0xfce9076c]
lappend results [mem_read 0xfce90770]
lappend results [mem_read 0xfce90774]
lappend results [mem_read 0xfce90778]
lappend results [mem_read 0xfce9077c]
