var _createReduce = require('./_createReduce.js'); // **Reduce** builds up a single result from a list of values, aka `inject`,
// or `foldl`.


var reduce = _createReduce(1);

module.exports = reduce;