define(['./_setup'], function (_setup) {
  // Internal function to check whether `key` is an own property name of `obj`.
  function has(obj, key) {
    return obj != null && _setup.hasOwnProperty.call(obj, key);
  }

  return has;
});