var _createEscaper = require('./_createEscaper.js');

var _escapeMap = require('./_escapeMap.js'); // Function for escaping strings to HTML interpolation.


var _escape = _createEscaper(_escapeMap);

module.exports = _escape;