##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_RPU1_DBG
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0a40000]
lappend results [mem_read 0xf0a40018]
lappend results [mem_read 0xf0a4001c]
lappend results [mem_read 0xf0a40028]
lappend results [mem_read 0xf0a40080]
lappend results [mem_read 0xf0a40084]
lappend results [mem_read 0xf0a40088]
lappend results [mem_read 0xf0a4008c]
lappend results [mem_read 0xf0a40090]
lappend results [mem_read 0xf0a40100]
lappend results [mem_read 0xf0a40104]
lappend results [mem_read 0xf0a40108]
lappend results [mem_read 0xf0a4010c]
lappend results [mem_read 0xf0a40110]
lappend results [mem_read 0xf0a40114]
lappend results [mem_read 0xf0a40118]
lappend results [mem_read 0xf0a4011c]
lappend results [mem_read 0xf0a40140]
lappend results [mem_read 0xf0a40144]
lappend results [mem_read 0xf0a40148]
lappend results [mem_read 0xf0a4014c]
lappend results [mem_read 0xf0a40150]
lappend results [mem_read 0xf0a40154]
lappend results [mem_read 0xf0a40158]
lappend results [mem_read 0xf0a4015c]
lappend results [mem_read 0xf0a40180]
lappend results [mem_read 0xf0a40184]
lappend results [mem_read 0xf0a40188]
lappend results [mem_read 0xf0a4018c]
lappend results [mem_read 0xf0a40190]
lappend results [mem_read 0xf0a40194]
lappend results [mem_read 0xf0a40198]
lappend results [mem_read 0xf0a4019c]
lappend results [mem_read 0xf0a401c0]
lappend results [mem_read 0xf0a401c4]
lappend results [mem_read 0xf0a401c8]
lappend results [mem_read 0xf0a401cc]
lappend results [mem_read 0xf0a401d0]
lappend results [mem_read 0xf0a401d4]
lappend results [mem_read 0xf0a401d8]
lappend results [mem_read 0xf0a401dc]
lappend results [mem_read 0xf0a40304]
lappend results [mem_read 0xf0a40310]
lappend results [mem_read 0xf0a40314]
lappend results [mem_read 0xf0a40d00]
lappend results [mem_read 0xf0a40d04]
lappend results [mem_read 0xf0a40d08]
lappend results [mem_read 0xf0a40d10]
lappend results [mem_read 0xf0a40d14]
lappend results [mem_read 0xf0a40d20]
lappend results [mem_read 0xf0a40d24]
lappend results [mem_read 0xf0a40d28]
lappend results [mem_read 0xf0a40d2c]
lappend results [mem_read 0xf0a40d30]
lappend results [mem_read 0xf0a40d34]
lappend results [mem_read 0xf0a40d38]
lappend results [mem_read 0xf0a40d3c]
lappend results [mem_read 0xf0a40d40]
lappend results [mem_read 0xf0a40d44]
lappend results [mem_read 0xf0a40d48]
lappend results [mem_read 0xf0a40d4c]
lappend results [mem_read 0xf0a40d50]
lappend results [mem_read 0xf0a40d54]
lappend results [mem_read 0xf0a40ed8]
lappend results [mem_read 0xf0a40ef8]
lappend results [mem_read 0xf0a40efc]
lappend results [mem_read 0xf0a40f00]
lappend results [mem_read 0xf0a40fa0]
lappend results [mem_read 0xf0a40fa4]
lappend results [mem_read 0xf0a40fb0]
lappend results [mem_read 0xf0a40fb4]
lappend results [mem_read 0xf0a40fb8]
lappend results [mem_read 0xf0a40fc8]
lappend results [mem_read 0xf0a40fcc]
