##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_APU1_DBG
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0d40020]
lappend results [mem_read 0xf0d40024]
lappend results [mem_read 0xf0d40030]
lappend results [mem_read 0xf0d40034]
lappend results [mem_read 0xf0d40080]
lappend results [mem_read 0xf0d40084]
lappend results [mem_read 0xf0d40088]
lappend results [mem_read 0xf0d4008c]
lappend results [mem_read 0xf0d40090]
lappend results [mem_read 0xf0d40094]
lappend results [mem_read 0xf0d40098]
lappend results [mem_read 0xf0d400a0]
lappend results [mem_read 0xf0d400a4]
lappend results [mem_read 0xf0d400a8]
lappend results [mem_read 0xf0d400ac]
lappend results [mem_read 0xf0d40300]
lappend results [mem_read 0xf0d40310]
lappend results [mem_read 0xf0d40314]
lappend results [mem_read 0xf0d40400]
lappend results [mem_read 0xf0d40404]
lappend results [mem_read 0xf0d40408]
lappend results [mem_read 0xf0d40410]
lappend results [mem_read 0xf0d40414]
lappend results [mem_read 0xf0d40418]
lappend results [mem_read 0xf0d40420]
lappend results [mem_read 0xf0d40424]
lappend results [mem_read 0xf0d40428]
lappend results [mem_read 0xf0d40430]
lappend results [mem_read 0xf0d40434]
lappend results [mem_read 0xf0d40438]
lappend results [mem_read 0xf0d40440]
lappend results [mem_read 0xf0d40444]
lappend results [mem_read 0xf0d40448]
lappend results [mem_read 0xf0d40450]
lappend results [mem_read 0xf0d40454]
lappend results [mem_read 0xf0d40458]
lappend results [mem_read 0xf0d40800]
lappend results [mem_read 0xf0d40804]
lappend results [mem_read 0xf0d40808]
lappend results [mem_read 0xf0d40810]
lappend results [mem_read 0xf0d40814]
lappend results [mem_read 0xf0d40818]
lappend results [mem_read 0xf0d40820]
lappend results [mem_read 0xf0d40824]
lappend results [mem_read 0xf0d40828]
lappend results [mem_read 0xf0d40830]
lappend results [mem_read 0xf0d40834]
lappend results [mem_read 0xf0d40838]
lappend results [mem_read 0xf0d40d00]
lappend results [mem_read 0xf0d40d20]
lappend results [mem_read 0xf0d40d24]
lappend results [mem_read 0xf0d40d28]
lappend results [mem_read 0xf0d40d2c]
lappend results [mem_read 0xf0d40d30]
lappend results [mem_read 0xf0d40d34]
lappend results [mem_read 0xf0d40d38]
lappend results [mem_read 0xf0d40d3c]
lappend results [mem_read 0xf0d40ef8]
lappend results [mem_read 0xf0d40efc]
lappend results [mem_read 0xf0d40f00]
lappend results [mem_read 0xf0d40fa0]
lappend results [mem_read 0xf0d40fa4]
lappend results [mem_read 0xf0d40fa8]
lappend results [mem_read 0xf0d40fac]
lappend results [mem_read 0xf0d40fb0]
lappend results [mem_read 0xf0d40fb4]
lappend results [mem_read 0xf0d40fb8]
lappend results [mem_read 0xf0d40fbc]
lappend results [mem_read 0xf0d40fc0]
lappend results [mem_read 0xf0d40fc4]
lappend results [mem_read 0xf0d40fc8]
lappend results [mem_read 0xf0d40fcc]
