##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM4_ADDRREMAP
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfcf30000]
lappend results [mem_read 0xfcf30004]
lappend results [mem_read 0xfcf30008]
lappend results [mem_read 0xfcf3000c]
lappend results [mem_read 0xfcf30020]
lappend results [mem_read 0xfcf30024]
lappend results [mem_read 0xfcf30028]
lappend results [mem_read 0xfcf3002c]
lappend results [mem_read 0xfcf30030]
lappend results [mem_read 0xfcf30034]
lappend results [mem_read 0xfcf30038]
lappend results [mem_read 0xfcf3003c]
lappend results [mem_read 0xfcf30040]
lappend results [mem_read 0xfcf30044]
lappend results [mem_read 0xfcf30048]
lappend results [mem_read 0xfcf3004c]
lappend results [mem_read 0xfcf30050]
lappend results [mem_read 0xfcf30054]
lappend results [mem_read 0xfcf30058]
lappend results [mem_read 0xfcf3005c]
lappend results [mem_read 0xfcf30060]
lappend results [mem_read 0xfcf30064]
lappend results [mem_read 0xfcf30068]
lappend results [mem_read 0xfcf3006c]
lappend results [mem_read 0xfcf30070]
lappend results [mem_read 0xfcf30074]
lappend results [mem_read 0xfcf30078]
lappend results [mem_read 0xfcf3007c]
lappend results [mem_read 0xfcf30080]
lappend results [mem_read 0xfcf30084]
lappend results [mem_read 0xfcf30088]
lappend results [mem_read 0xfcf3008c]
lappend results [mem_read 0xfcf30090]
lappend results [mem_read 0xfcf30094]
lappend results [mem_read 0xfcf30098]
lappend results [mem_read 0xfcf3009c]
lappend results [mem_read 0xfcf300a0]
lappend results [mem_read 0xfcf300a4]
lappend results [mem_read 0xfcf300a8]
lappend results [mem_read 0xfcf300ac]
lappend results [mem_read 0xfcf300b0]
lappend results [mem_read 0xfcf300b4]
lappend results [mem_read 0xfcf300b8]
lappend results [mem_read 0xfcf300bc]
lappend results [mem_read 0xfcf300c0]
lappend results [mem_read 0xfcf300c4]
lappend results [mem_read 0xfcf300c8]
lappend results [mem_read 0xfcf300cc]
lappend results [mem_read 0xfcf300d0]
lappend results [mem_read 0xfcf300d4]
lappend results [mem_read 0xfcf300d8]
lappend results [mem_read 0xfcf300dc]
lappend results [mem_read 0xfcf300e0]
lappend results [mem_read 0xfcf300e4]
