##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: GEM0
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff0c0000]
lappend results [mem_read 0xff0c0004]
lappend results [mem_read 0xff0c0008]
lappend results [mem_read 0xff0c0010]
lappend results [mem_read 0xff0c0014]
lappend results [mem_read 0xff0c0018]
lappend results [mem_read 0xff0c001c]
lappend results [mem_read 0xff0c0020]
lappend results [mem_read 0xff0c0024]
lappend results [mem_read 0xff0c0028]
lappend results [mem_read 0xff0c002c]
lappend results [mem_read 0xff0c0030]
lappend results [mem_read 0xff0c0034]
lappend results [mem_read 0xff0c0038]
lappend results [mem_read 0xff0c003c]
lappend results [mem_read 0xff0c0040]
lappend results [mem_read 0xff0c0044]
lappend results [mem_read 0xff0c0048]
lappend results [mem_read 0xff0c004c]
lappend results [mem_read 0xff0c0054]
lappend results [mem_read 0xff0c0058]
lappend results [mem_read 0xff0c005c]
lappend results [mem_read 0xff0c0060]
lappend results [mem_read 0xff0c0064]
lappend results [mem_read 0xff0c0068]
lappend results [mem_read 0xff0c006c]
lappend results [mem_read 0xff0c0070]
lappend results [mem_read 0xff0c007c]
lappend results [mem_read 0xff0c0080]
lappend results [mem_read 0xff0c0084]
lappend results [mem_read 0xff0c0088]
lappend results [mem_read 0xff0c008c]
lappend results [mem_read 0xff0c0090]
lappend results [mem_read 0xff0c0094]
lappend results [mem_read 0xff0c0098]
lappend results [mem_read 0xff0c009c]
lappend results [mem_read 0xff0c00a0]
lappend results [mem_read 0xff0c00a4]
lappend results [mem_read 0xff0c00a8]
lappend results [mem_read 0xff0c00ac]
lappend results [mem_read 0xff0c00b0]
lappend results [mem_read 0xff0c00b4]
lappend results [mem_read 0xff0c00b8]
lappend results [mem_read 0xff0c00bc]
lappend results [mem_read 0xff0c00c0]
lappend results [mem_read 0xff0c00c4]
lappend results [mem_read 0xff0c00c8]
lappend results [mem_read 0xff0c00cc]
lappend results [mem_read 0xff0c00d0]
lappend results [mem_read 0xff0c00d4]
lappend results [mem_read 0xff0c00d8]
lappend results [mem_read 0xff0c00dc]
lappend results [mem_read 0xff0c00e0]
lappend results [mem_read 0xff0c00e4]
lappend results [mem_read 0xff0c00e8]
lappend results [mem_read 0xff0c00ec]
lappend results [mem_read 0xff0c00f0]
lappend results [mem_read 0xff0c00f4]
lappend results [mem_read 0xff0c00fc]
lappend results [mem_read 0xff0c0100]
lappend results [mem_read 0xff0c0104]
lappend results [mem_read 0xff0c0108]
lappend results [mem_read 0xff0c010c]
lappend results [mem_read 0xff0c0110]
lappend results [mem_read 0xff0c0114]
lappend results [mem_read 0xff0c0118]
lappend results [mem_read 0xff0c011c]
lappend results [mem_read 0xff0c0120]
lappend results [mem_read 0xff0c0124]
lappend results [mem_read 0xff0c0128]
lappend results [mem_read 0xff0c012c]
lappend results [mem_read 0xff0c0130]
lappend results [mem_read 0xff0c0134]
lappend results [mem_read 0xff0c0138]
lappend results [mem_read 0xff0c013c]
lappend results [mem_read 0xff0c0140]
lappend results [mem_read 0xff0c0144]
lappend results [mem_read 0xff0c0148]
lappend results [mem_read 0xff0c014c]
lappend results [mem_read 0xff0c0150]
lappend results [mem_read 0xff0c0154]
lappend results [mem_read 0xff0c0158]
lappend results [mem_read 0xff0c015c]
lappend results [mem_read 0xff0c0160]
lappend results [mem_read 0xff0c0164]
lappend results [mem_read 0xff0c0168]
lappend results [mem_read 0xff0c016c]
lappend results [mem_read 0xff0c0170]
lappend results [mem_read 0xff0c0174]
lappend results [mem_read 0xff0c0178]
lappend results [mem_read 0xff0c017c]
lappend results [mem_read 0xff0c0180]
lappend results [mem_read 0xff0c0184]
lappend results [mem_read 0xff0c0188]
lappend results [mem_read 0xff0c018c]
lappend results [mem_read 0xff0c0190]
lappend results [mem_read 0xff0c0194]
lappend results [mem_read 0xff0c0198]
lappend results [mem_read 0xff0c019c]
lappend results [mem_read 0xff0c01a0]
lappend results [mem_read 0xff0c01a4]
lappend results [mem_read 0xff0c01a8]
lappend results [mem_read 0xff0c01ac]
lappend results [mem_read 0xff0c01b0]
lappend results [mem_read 0xff0c01b4]
lappend results [mem_read 0xff0c01bc]
lappend results [mem_read 0xff0c01c0]
lappend results [mem_read 0xff0c01c4]
lappend results [mem_read 0xff0c01c8]
lappend results [mem_read 0xff0c01cc]
lappend results [mem_read 0xff0c01d0]
lappend results [mem_read 0xff0c01d4]
lappend results [mem_read 0xff0c01d8]
lappend results [mem_read 0xff0c01dc]
lappend results [mem_read 0xff0c01e0]
lappend results [mem_read 0xff0c01e4]
lappend results [mem_read 0xff0c01e8]
lappend results [mem_read 0xff0c01ec]
lappend results [mem_read 0xff0c01f0]
lappend results [mem_read 0xff0c01f4]
lappend results [mem_read 0xff0c01f8]
lappend results [mem_read 0xff0c01fc]
lappend results [mem_read 0xff0c0270]
lappend results [mem_read 0xff0c0274]
lappend results [mem_read 0xff0c0278]
lappend results [mem_read 0xff0c027c]
lappend results [mem_read 0xff0c0280]
lappend results [mem_read 0xff0c0284]
lappend results [mem_read 0xff0c0288]
lappend results [mem_read 0xff0c028c]
lappend results [mem_read 0xff0c0290]
lappend results [mem_read 0xff0c0294]
lappend results [mem_read 0xff0c0298]
lappend results [mem_read 0xff0c029c]
lappend results [mem_read 0xff0c02a0]
lappend results [mem_read 0xff0c02a4]
lappend results [mem_read 0xff0c02a8]
lappend results [mem_read 0xff0c02ac]
lappend results [mem_read 0xff0c0400]
lappend results [mem_read 0xff0c0440]
lappend results [mem_read 0xff0c0480]
lappend results [mem_read 0xff0c04a0]
lappend results [mem_read 0xff0c04bc]
lappend results [mem_read 0xff0c04c0]
lappend results [mem_read 0xff0c04c4]
lappend results [mem_read 0xff0c04c8]
lappend results [mem_read 0xff0c04cc]
lappend results [mem_read 0xff0c04d0]
lappend results [mem_read 0xff0c04d4]
lappend results [mem_read 0xff0c0500]
lappend results [mem_read 0xff0c0504]
lappend results [mem_read 0xff0c0508]
lappend results [mem_read 0xff0c050c]
lappend results [mem_read 0xff0c0540]
lappend results [mem_read 0xff0c0544]
lappend results [mem_read 0xff0c0548]
lappend results [mem_read 0xff0c054c]
lappend results [mem_read 0xff0c0580]
lappend results [mem_read 0xff0c0590]
lappend results [mem_read 0xff0c05a0]
lappend results [mem_read 0xff0c0600]
lappend results [mem_read 0xff0c0620]
lappend results [mem_read 0xff0c0640]
lappend results [mem_read 0xff0c06e0]
lappend results [mem_read 0xff0c06e4]
lappend results [mem_read 0xff0c06e8]
lappend results [mem_read 0xff0c06ec]
lappend results [mem_read 0xff0c0700]
lappend results [mem_read 0xff0c0704]
lappend results [mem_read 0xff0c0708]
lappend results [mem_read 0xff0c070c]
lappend results [mem_read 0xff0c0710]
lappend results [mem_read 0xff0c0714]
lappend results [mem_read 0xff0c0718]
lappend results [mem_read 0xff0c071c]
lappend results [mem_read 0xff0c0800]
lappend results [mem_read 0xff0c0804]
lappend results [mem_read 0xff0c0820]
lappend results [mem_read 0xff0c0824]
lappend results [mem_read 0xff0c0840]
lappend results [mem_read 0xff0c0844]
lappend results [mem_read 0xff0c0880]
lappend results [mem_read 0xff0c08a0]
lappend results [mem_read 0xff0c08a4]
lappend results [mem_read 0xff0c08c0]
lappend results [mem_read 0xff0c08c4]
lappend results [mem_read 0xff0c08c8]
lappend results [mem_read 0xff0c08cc]
lappend results [mem_read 0xff0c08d0]
lappend results [mem_read 0xff0c08d4]
lappend results [mem_read 0xff0c08d8]
lappend results [mem_read 0xff0c08dc]
lappend results [mem_read 0xff0c08e0]
lappend results [mem_read 0xff0c08e4]
lappend results [mem_read 0xff0c08e8]
lappend results [mem_read 0xff0c08ec]
lappend results [mem_read 0xff0c08f0]
lappend results [mem_read 0xff0c08f4]
lappend results [mem_read 0xff0c08f8]
lappend results [mem_read 0xff0c08fc]
lappend results [mem_read 0xff0c0b00]
lappend results [mem_read 0xff0c0b04]
lappend results [mem_read 0xff0c0b40]
lappend results [mem_read 0xff0c0b44]
lappend results [mem_read 0xff0c026c]
lappend results [mem_read 0xff0c0b48]
lappend results [mem_read 0xff0c0b4c]
lappend results [mem_read 0xff0c0b80]
