##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: FPD_XMPU
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfd390000]
lappend results [mem_read 0xfd390004]
lappend results [mem_read 0xfd390008]
lappend results [mem_read 0xfd39000c]
lappend results [mem_read 0xfd390010]
lappend results [mem_read 0xfd390014]
lappend results [mem_read 0xfd390018]
lappend results [mem_read 0xfd39001c]
lappend results [mem_read 0xfd390020]
lappend results [mem_read 0xfd390100]
lappend results [mem_read 0xfd390104]
lappend results [mem_read 0xfd390108]
lappend results [mem_read 0xfd39010c]
lappend results [mem_read 0xfd390110]
lappend results [mem_read 0xfd390114]
lappend results [mem_read 0xfd390118]
lappend results [mem_read 0xfd39011c]
lappend results [mem_read 0xfd390120]
lappend results [mem_read 0xfd390124]
lappend results [mem_read 0xfd390128]
lappend results [mem_read 0xfd39012c]
lappend results [mem_read 0xfd390130]
lappend results [mem_read 0xfd390134]
lappend results [mem_read 0xfd390138]
lappend results [mem_read 0xfd39013c]
lappend results [mem_read 0xfd390140]
lappend results [mem_read 0xfd390144]
lappend results [mem_read 0xfd390148]
lappend results [mem_read 0xfd39014c]
lappend results [mem_read 0xfd390150]
lappend results [mem_read 0xfd390154]
lappend results [mem_read 0xfd390158]
lappend results [mem_read 0xfd39015c]
lappend results [mem_read 0xfd390160]
lappend results [mem_read 0xfd390164]
lappend results [mem_read 0xfd390168]
lappend results [mem_read 0xfd39016c]
lappend results [mem_read 0xfd390170]
lappend results [mem_read 0xfd390174]
lappend results [mem_read 0xfd390178]
lappend results [mem_read 0xfd39017c]
lappend results [mem_read 0xfd390180]
lappend results [mem_read 0xfd390184]
lappend results [mem_read 0xfd390188]
lappend results [mem_read 0xfd39018c]
lappend results [mem_read 0xfd390190]
lappend results [mem_read 0xfd390194]
lappend results [mem_read 0xfd390198]
lappend results [mem_read 0xfd39019c]
lappend results [mem_read 0xfd3901a0]
lappend results [mem_read 0xfd3901a4]
lappend results [mem_read 0xfd3901a8]
lappend results [mem_read 0xfd3901ac]
lappend results [mem_read 0xfd3901b0]
lappend results [mem_read 0xfd3901b4]
lappend results [mem_read 0xfd3901b8]
lappend results [mem_read 0xfd3901bc]
lappend results [mem_read 0xfd3901c0]
lappend results [mem_read 0xfd3901c4]
lappend results [mem_read 0xfd3901c8]
lappend results [mem_read 0xfd3901cc]
lappend results [mem_read 0xfd3901d0]
lappend results [mem_read 0xfd3901d4]
lappend results [mem_read 0xfd3901d8]
lappend results [mem_read 0xfd3901dc]
lappend results [mem_read 0xfd3901e0]
lappend results [mem_read 0xfd3901e4]
lappend results [mem_read 0xfd3901e8]
lappend results [mem_read 0xfd3901ec]
lappend results [mem_read 0xfd3901f0]
lappend results [mem_read 0xfd3901f4]
lappend results [mem_read 0xfd3901f8]
lappend results [mem_read 0xfd3901fc]
lappend results [mem_read 0xfd390200]
lappend results [mem_read 0xfd390204]
lappend results [mem_read 0xfd390208]
lappend results [mem_read 0xfd39020c]
lappend results [mem_read 0xfd390210]
lappend results [mem_read 0xfd390214]
lappend results [mem_read 0xfd390218]
lappend results [mem_read 0xfd39021c]
lappend results [mem_read 0xfd390220]
lappend results [mem_read 0xfd390224]
lappend results [mem_read 0xfd390228]
lappend results [mem_read 0xfd39022c]
lappend results [mem_read 0xfd390238]
lappend results [mem_read 0xfd39023c]
lappend results [mem_read 0xfd390240]
lappend results [mem_read 0xfd390244]
lappend results [mem_read 0xfd390248]
lappend results [mem_read 0xfd39024c]
lappend results [mem_read 0xfd390250]
lappend results [mem_read 0xfd390254]
lappend results [mem_read 0xfd390258]
lappend results [mem_read 0xfd39025c]
lappend results [mem_read 0xfd390260]
lappend results [mem_read 0xfd390264]
lappend results [mem_read 0xfd390268]
lappend results [mem_read 0xfd39026c]
lappend results [mem_read 0xfd390270]
lappend results [mem_read 0xfd390274]
lappend results [mem_read 0xfd390278]
lappend results [mem_read 0xfd39027c]
lappend results [mem_read 0xfd390280]
lappend results [mem_read 0xfd390284]
