##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: LPD_IOP_INT_GPV
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfe000000]
lappend results [mem_read 0xfe000004]
lappend results [mem_read 0xfe000008]
lappend results [mem_read 0xfe00000c]
lappend results [mem_read 0xfe000010]
lappend results [mem_read 0xfe000014]
lappend results [mem_read 0xfe000018]
lappend results [mem_read 0xfe00001c]
lappend results [mem_read 0xfe000020]
lappend results [mem_read 0xfe000024]
lappend results [mem_read 0xfe000028]
lappend results [mem_read 0xfe00002c]
lappend results [mem_read 0xfe000030]
lappend results [mem_read 0xfe000034]
lappend results [mem_read 0xfe000038]
lappend results [mem_read 0xfe00003c]
lappend results [mem_read 0xfe000040]
lappend results [mem_read 0xfe000044]
lappend results [mem_read 0xfe000048]
lappend results [mem_read 0xfe00004c]
lappend results [mem_read 0xfe000050]
lappend results [mem_read 0xfe000054]
lappend results [mem_read 0xfe000058]
lappend results [mem_read 0xfe00005c]
lappend results [mem_read 0xfe000060]
lappend results [mem_read 0xfe000064]
lappend results [mem_read 0xfe000068]
lappend results [mem_read 0xfe00006c]
lappend results [mem_read 0xfe000070]
lappend results [mem_read 0xfe000074]
lappend results [mem_read 0xfe000078]
lappend results [mem_read 0xfe00007c]
lappend results [mem_read 0xfe000080]
lappend results [mem_read 0xfe000084]
lappend results [mem_read 0xfe000088]
lappend results [mem_read 0xfe00008c]
lappend results [mem_read 0xfe000090]
lappend results [mem_read 0xfe000094]
lappend results [mem_read 0xfe000098]
lappend results [mem_read 0xfe00009c]
lappend results [mem_read 0xfe0000a0]
lappend results [mem_read 0xfe0000a4]
lappend results [mem_read 0xfe0000a8]
lappend results [mem_read 0xfe0000ac]
lappend results [mem_read 0xfe0000b0]
lappend results [mem_read 0xfe0000b4]
lappend results [mem_read 0xfe0000b8]
lappend results [mem_read 0xfe0000bc]
lappend results [mem_read 0xfe0000c0]
lappend results [mem_read 0xfe0000c4]
lappend results [mem_read 0xfe0000c8]
lappend results [mem_read 0xfe0000cc]
lappend results [mem_read 0xfe0000d0]
lappend results [mem_read 0xfe0000d4]
lappend results [mem_read 0xfe0000d8]
lappend results [mem_read 0xfe0000dc]
lappend results [mem_read 0xfe0000e0]
lappend results [mem_read 0xfe0000e4]
lappend results [mem_read 0xfe0000e8]
lappend results [mem_read 0xfe0000ec]
lappend results [mem_read 0xfe0000f0]
lappend results [mem_read 0xfe0000f4]
lappend results [mem_read 0xfe0000f8]
lappend results [mem_read 0xfe0000fc]
lappend results [mem_read 0xfe000100]
lappend results [mem_read 0xfe000104]
lappend results [mem_read 0xfe000108]
lappend results [mem_read 0xfe00010c]
lappend results [mem_read 0xfe000110]
lappend results [mem_read 0xfe000114]
lappend results [mem_read 0xfe000118]
lappend results [mem_read 0xfe00011c]
lappend results [mem_read 0xfe000120]
lappend results [mem_read 0xfe000124]
lappend results [mem_read 0xfe000128]
lappend results [mem_read 0xfe00012c]
lappend results [mem_read 0xfe000130]
lappend results [mem_read 0xfe000134]
lappend results [mem_read 0xfe000138]
lappend results [mem_read 0xfe00013c]
lappend results [mem_read 0xfe000140]
lappend results [mem_read 0xfe000144]
lappend results [mem_read 0xfe000148]
lappend results [mem_read 0xfe00014c]
lappend results [mem_read 0xfe000150]
lappend results [mem_read 0xfe000154]
lappend results [mem_read 0xfe000158]
lappend results [mem_read 0xfe00015c]
lappend results [mem_read 0xfe000160]
lappend results [mem_read 0xfe000164]
lappend results [mem_read 0xfe000168]
lappend results [mem_read 0xfe00016c]
lappend results [mem_read 0xfe000170]
lappend results [mem_read 0xfe000174]
lappend results [mem_read 0xfe000178]
lappend results [mem_read 0xfe00017c]
