define(['./restArguments', './_flatten', './bind'], function (restArguments, _flatten, bind) {
  // Bind a number of an object's methods to that object. Remaining arguments
  // are the method names to be bound. Useful for ensuring that all callbacks
  // defined on an object belong to it.
  var bindAll = restArguments(function (obj, keys) {
    keys = _flatten(keys, false, false);
    var index = keys.length;
    if (index < 1) throw new Error('bindAll must be passed function names');

    while (index--) {
      var key = keys[index];
      obj[key] = bind(obj[key], obj);
    }

    return obj;
  });
  return bindAll;
});