##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: XRAM_XMPU2
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff938000]
lappend results [mem_read 0xff938004]
lappend results [mem_read 0xff938008]
lappend results [mem_read 0xff93800c]
lappend results [mem_read 0xff938010]
lappend results [mem_read 0xff938014]
lappend results [mem_read 0xff938018]
lappend results [mem_read 0xff93801c]
lappend results [mem_read 0xff938020]
lappend results [mem_read 0xff938100]
lappend results [mem_read 0xff938104]
lappend results [mem_read 0xff938108]
lappend results [mem_read 0xff93810c]
lappend results [mem_read 0xff938110]
lappend results [mem_read 0xff938114]
lappend results [mem_read 0xff938118]
lappend results [mem_read 0xff93811c]
lappend results [mem_read 0xff938120]
lappend results [mem_read 0xff938124]
lappend results [mem_read 0xff938128]
lappend results [mem_read 0xff93812c]
lappend results [mem_read 0xff938130]
lappend results [mem_read 0xff938134]
lappend results [mem_read 0xff938138]
lappend results [mem_read 0xff93813c]
lappend results [mem_read 0xff938140]
lappend results [mem_read 0xff938144]
lappend results [mem_read 0xff938148]
lappend results [mem_read 0xff93814c]
lappend results [mem_read 0xff938150]
lappend results [mem_read 0xff938154]
lappend results [mem_read 0xff938158]
lappend results [mem_read 0xff93815c]
lappend results [mem_read 0xff938160]
lappend results [mem_read 0xff938164]
lappend results [mem_read 0xff938168]
lappend results [mem_read 0xff93816c]
lappend results [mem_read 0xff938170]
lappend results [mem_read 0xff938174]
lappend results [mem_read 0xff938178]
lappend results [mem_read 0xff93817c]
lappend results [mem_read 0xff938180]
lappend results [mem_read 0xff938184]
lappend results [mem_read 0xff938188]
lappend results [mem_read 0xff93818c]
lappend results [mem_read 0xff938190]
lappend results [mem_read 0xff938194]
lappend results [mem_read 0xff938198]
lappend results [mem_read 0xff93819c]
lappend results [mem_read 0xff9381a0]
lappend results [mem_read 0xff9381a4]
lappend results [mem_read 0xff9381a8]
lappend results [mem_read 0xff9381ac]
lappend results [mem_read 0xff9381b0]
lappend results [mem_read 0xff9381b4]
lappend results [mem_read 0xff9381b8]
lappend results [mem_read 0xff9381bc]
lappend results [mem_read 0xff9381c0]
lappend results [mem_read 0xff9381c4]
lappend results [mem_read 0xff9381c8]
lappend results [mem_read 0xff9381cc]
lappend results [mem_read 0xff9381d0]
lappend results [mem_read 0xff9381d4]
lappend results [mem_read 0xff9381d8]
lappend results [mem_read 0xff9381dc]
lappend results [mem_read 0xff9381e0]
lappend results [mem_read 0xff9381e4]
lappend results [mem_read 0xff9381e8]
lappend results [mem_read 0xff9381ec]
lappend results [mem_read 0xff9381f0]
lappend results [mem_read 0xff9381f4]
lappend results [mem_read 0xff9381f8]
lappend results [mem_read 0xff9381fc]
lappend results [mem_read 0xff938200]
lappend results [mem_read 0xff938204]
lappend results [mem_read 0xff938208]
lappend results [mem_read 0xff93820c]
lappend results [mem_read 0xff938210]
lappend results [mem_read 0xff938214]
lappend results [mem_read 0xff938218]
lappend results [mem_read 0xff93821c]
lappend results [mem_read 0xff938220]
lappend results [mem_read 0xff938224]
lappend results [mem_read 0xff938228]
lappend results [mem_read 0xff93822c]
lappend results [mem_read 0xff938238]
lappend results [mem_read 0xff93823c]
lappend results [mem_read 0xff938240]
lappend results [mem_read 0xff938244]
lappend results [mem_read 0xff938248]
lappend results [mem_read 0xff93824c]
lappend results [mem_read 0xff938250]
lappend results [mem_read 0xff938254]
lappend results [mem_read 0xff938258]
lappend results [mem_read 0xff93825c]
lappend results [mem_read 0xff938260]
lappend results [mem_read 0xff938264]
lappend results [mem_read 0xff938268]
lappend results [mem_read 0xff93826c]
lappend results [mem_read 0xff938270]
lappend results [mem_read 0xff938274]
lappend results [mem_read 0xff938278]
lappend results [mem_read 0xff93827c]
lappend results [mem_read 0xff938280]
lappend results [mem_read 0xff938284]
