##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: APU_GIC_DIST_MAIN
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf9000000]
lappend results [mem_read 0xf9000004]
lappend results [mem_read 0xf9000008]
lappend results [mem_read 0xf9000040]
lappend results [mem_read 0xf9000048]
lappend results [mem_read 0xf9000050]
lappend results [mem_read 0xf9000058]
lappend results [mem_read 0xf9000080]
lappend results [mem_read 0xf9000084]
lappend results [mem_read 0xf9000088]
lappend results [mem_read 0xf900008c]
lappend results [mem_read 0xf9000090]
lappend results [mem_read 0xf9000094]
lappend results [mem_read 0xf9000100]
lappend results [mem_read 0xf9000104]
lappend results [mem_read 0xf9000108]
lappend results [mem_read 0xf900010c]
lappend results [mem_read 0xf9000110]
lappend results [mem_read 0xf9000114]
lappend results [mem_read 0xf9000180]
lappend results [mem_read 0xf9000184]
lappend results [mem_read 0xf9000188]
lappend results [mem_read 0xf900018c]
lappend results [mem_read 0xf9000190]
lappend results [mem_read 0xf9000194]
lappend results [mem_read 0xf9000200]
lappend results [mem_read 0xf9000204]
lappend results [mem_read 0xf9000208]
lappend results [mem_read 0xf900020c]
lappend results [mem_read 0xf9000210]
lappend results [mem_read 0xf9000214]
lappend results [mem_read 0xf9000280]
lappend results [mem_read 0xf9000284]
lappend results [mem_read 0xf9000288]
lappend results [mem_read 0xf900028c]
lappend results [mem_read 0xf9000290]
lappend results [mem_read 0xf9000294]
lappend results [mem_read 0xf9000300]
lappend results [mem_read 0xf9000304]
lappend results [mem_read 0xf9000308]
lappend results [mem_read 0xf900030c]
lappend results [mem_read 0xf9000310]
lappend results [mem_read 0xf9000314]
lappend results [mem_read 0xf9000380]
lappend results [mem_read 0xf9000384]
lappend results [mem_read 0xf9000388]
lappend results [mem_read 0xf900038c]
lappend results [mem_read 0xf9000390]
lappend results [mem_read 0xf9000394]
lappend results [mem_read 0xf9000400]
lappend results [mem_read 0xf9000404]
lappend results [mem_read 0xf9000408]
lappend results [mem_read 0xf900040c]
lappend results [mem_read 0xf9000410]
lappend results [mem_read 0xf9000414]
lappend results [mem_read 0xf9000418]
lappend results [mem_read 0xf900041c]
lappend results [mem_read 0xf9000420]
lappend results [mem_read 0xf9000424]
lappend results [mem_read 0xf9000428]
lappend results [mem_read 0xf900042c]
lappend results [mem_read 0xf9000430]
lappend results [mem_read 0xf9000434]
lappend results [mem_read 0xf9000438]
lappend results [mem_read 0xf900043c]
lappend results [mem_read 0xf9000440]
lappend results [mem_read 0xf9000444]
lappend results [mem_read 0xf9000448]
lappend results [mem_read 0xf900044c]
lappend results [mem_read 0xf9000450]
lappend results [mem_read 0xf9000454]
lappend results [mem_read 0xf9000458]
lappend results [mem_read 0xf900045c]
lappend results [mem_read 0xf9000460]
lappend results [mem_read 0xf9000464]
lappend results [mem_read 0xf9000468]
lappend results [mem_read 0xf900046c]
lappend results [mem_read 0xf9000470]
lappend results [mem_read 0xf9000474]
lappend results [mem_read 0xf9000478]
lappend results [mem_read 0xf900047c]
lappend results [mem_read 0xf9000480]
lappend results [mem_read 0xf9000484]
lappend results [mem_read 0xf9000488]
lappend results [mem_read 0xf900048c]
lappend results [mem_read 0xf9000490]
lappend results [mem_read 0xf9000494]
lappend results [mem_read 0xf9000498]
lappend results [mem_read 0xf900049c]
lappend results [mem_read 0xf90004a0]
lappend results [mem_read 0xf90004a4]
lappend results [mem_read 0xf90004a8]
lappend results [mem_read 0xf90004ac]
lappend results [mem_read 0xf90004b0]
lappend results [mem_read 0xf90004b4]
lappend results [mem_read 0xf90004b8]
lappend results [mem_read 0xf90004bc]
lappend results [mem_read 0xf9000800]
lappend results [mem_read 0xf9000804]
lappend results [mem_read 0xf9000808]
lappend results [mem_read 0xf900080c]
lappend results [mem_read 0xf9000810]
lappend results [mem_read 0xf9000814]
lappend results [mem_read 0xf9000818]
lappend results [mem_read 0xf900081c]
lappend results [mem_read 0xf9000820]
lappend results [mem_read 0xf9000824]
lappend results [mem_read 0xf9000828]
lappend results [mem_read 0xf900082c]
lappend results [mem_read 0xf9000830]
lappend results [mem_read 0xf9000834]
lappend results [mem_read 0xf9000838]
lappend results [mem_read 0xf900083c]
lappend results [mem_read 0xf9000840]
lappend results [mem_read 0xf9000844]
lappend results [mem_read 0xf9000848]
lappend results [mem_read 0xf900084c]
lappend results [mem_read 0xf9000850]
lappend results [mem_read 0xf9000854]
lappend results [mem_read 0xf9000858]
lappend results [mem_read 0xf900085c]
lappend results [mem_read 0xf9000860]
lappend results [mem_read 0xf9000864]
lappend results [mem_read 0xf9000868]
lappend results [mem_read 0xf900086c]
lappend results [mem_read 0xf9000870]
lappend results [mem_read 0xf9000874]
lappend results [mem_read 0xf9000878]
lappend results [mem_read 0xf900087c]
lappend results [mem_read 0xf9000880]
lappend results [mem_read 0xf9000884]
lappend results [mem_read 0xf9000888]
lappend results [mem_read 0xf900088c]
lappend results [mem_read 0xf9000890]
lappend results [mem_read 0xf9000894]
lappend results [mem_read 0xf9000898]
lappend results [mem_read 0xf900089c]
lappend results [mem_read 0xf90008a0]
lappend results [mem_read 0xf90008a4]
lappend results [mem_read 0xf90008a8]
lappend results [mem_read 0xf90008ac]
lappend results [mem_read 0xf90008b0]
lappend results [mem_read 0xf90008b4]
lappend results [mem_read 0xf90008b8]
lappend results [mem_read 0xf90008bc]
lappend results [mem_read 0xf9000c00]
lappend results [mem_read 0xf9000c04]
lappend results [mem_read 0xf9000c08]
lappend results [mem_read 0xf9000c0c]
lappend results [mem_read 0xf9000c10]
lappend results [mem_read 0xf9000c14]
lappend results [mem_read 0xf9000c18]
lappend results [mem_read 0xf9000c1c]
lappend results [mem_read 0xf9000c20]
lappend results [mem_read 0xf9000c24]
lappend results [mem_read 0xf9000c28]
lappend results [mem_read 0xf9000c2c]
lappend results [mem_read 0xf9000d00]
lappend results [mem_read 0xf9000d04]
lappend results [mem_read 0xf9000d08]
lappend results [mem_read 0xf9000d0c]
lappend results [mem_read 0xf9000d10]
lappend results [mem_read 0xf9000d14]
lappend results [mem_read 0xf9000e00]
lappend results [mem_read 0xf9000e04]
lappend results [mem_read 0xf9000e08]
lappend results [mem_read 0xf9000e0c]
lappend results [mem_read 0xf9000e10]
lappend results [mem_read 0xf9000e14]
lappend results [mem_read 0xf9000e18]
lappend results [mem_read 0xf9000e1c]
lappend results [mem_read 0xf9000e20]
lappend results [mem_read 0xf9000e24]
lappend results [mem_read 0xf9000e28]
lappend results [mem_read 0xf9000e2c]
lappend results [mem_read 0xf9000f00]
lappend results [mem_read 0xf9000f10]
lappend results [mem_read 0xf9000f14]
lappend results [mem_read 0xf9000f18]
lappend results [mem_read 0xf9000f1c]
lappend results [mem_read 0xf9000f20]
lappend results [mem_read 0xf9000f24]
lappend results [mem_read 0xf9000f28]
lappend results [mem_read 0xf9000f2c]
lappend results [mem_read 0xf9006100]
lappend results [mem_read 0xf9006104]
lappend results [mem_read 0xf9006108]
lappend results [mem_read 0xf900610c]
lappend results [mem_read 0xf9006110]
lappend results [mem_read 0xf9006114]
lappend results [mem_read 0xf9006118]
lappend results [mem_read 0xf900611c]
lappend results [mem_read 0xf9006120]
lappend results [mem_read 0xf9006124]
lappend results [mem_read 0xf9006128]
lappend results [mem_read 0xf900612c]
lappend results [mem_read 0xf9006130]
lappend results [mem_read 0xf9006134]
lappend results [mem_read 0xf9006138]
lappend results [mem_read 0xf900613c]
lappend results [mem_read 0xf9006140]
lappend results [mem_read 0xf9006144]
lappend results [mem_read 0xf9006148]
lappend results [mem_read 0xf900614c]
lappend results [mem_read 0xf9006150]
lappend results [mem_read 0xf9006154]
lappend results [mem_read 0xf9006158]
lappend results [mem_read 0xf900615c]
lappend results [mem_read 0xf9006160]
lappend results [mem_read 0xf9006164]
lappend results [mem_read 0xf9006168]
lappend results [mem_read 0xf900616c]
lappend results [mem_read 0xf9006170]
lappend results [mem_read 0xf9006174]
lappend results [mem_read 0xf9006178]
lappend results [mem_read 0xf900617c]
lappend results [mem_read 0xf9006180]
lappend results [mem_read 0xf9006184]
lappend results [mem_read 0xf9006188]
lappend results [mem_read 0xf900618c]
lappend results [mem_read 0xf9006190]
lappend results [mem_read 0xf9006194]
lappend results [mem_read 0xf9006198]
lappend results [mem_read 0xf900619c]
lappend results [mem_read 0xf90061a0]
lappend results [mem_read 0xf90061a4]
lappend results [mem_read 0xf90061a8]
lappend results [mem_read 0xf90061ac]
lappend results [mem_read 0xf90061b0]
lappend results [mem_read 0xf90061b4]
lappend results [mem_read 0xf90061b8]
lappend results [mem_read 0xf90061bc]
lappend results [mem_read 0xf90061c0]
lappend results [mem_read 0xf90061c4]
lappend results [mem_read 0xf90061c8]
lappend results [mem_read 0xf90061cc]
lappend results [mem_read 0xf90061d0]
lappend results [mem_read 0xf90061d4]
lappend results [mem_read 0xf90061d8]
lappend results [mem_read 0xf90061dc]
lappend results [mem_read 0xf90061e0]
lappend results [mem_read 0xf90061e4]
lappend results [mem_read 0xf90061e8]
lappend results [mem_read 0xf90061ec]
lappend results [mem_read 0xf90061f0]
lappend results [mem_read 0xf90061f4]
lappend results [mem_read 0xf90061f8]
lappend results [mem_read 0xf90061fc]
lappend results [mem_read 0xf9006200]
lappend results [mem_read 0xf9006204]
lappend results [mem_read 0xf9006208]
lappend results [mem_read 0xf900620c]
lappend results [mem_read 0xf9006210]
lappend results [mem_read 0xf9006214]
lappend results [mem_read 0xf9006218]
lappend results [mem_read 0xf900621c]
lappend results [mem_read 0xf9006220]
lappend results [mem_read 0xf9006224]
lappend results [mem_read 0xf9006228]
lappend results [mem_read 0xf900622c]
lappend results [mem_read 0xf9006230]
lappend results [mem_read 0xf9006234]
lappend results [mem_read 0xf9006238]
lappend results [mem_read 0xf900623c]
lappend results [mem_read 0xf9006240]
lappend results [mem_read 0xf9006244]
lappend results [mem_read 0xf9006248]
lappend results [mem_read 0xf900624c]
lappend results [mem_read 0xf9006250]
lappend results [mem_read 0xf9006254]
lappend results [mem_read 0xf9006258]
lappend results [mem_read 0xf900625c]
lappend results [mem_read 0xf9006260]
lappend results [mem_read 0xf9006264]
lappend results [mem_read 0xf9006268]
lappend results [mem_read 0xf900626c]
lappend results [mem_read 0xf9006270]
lappend results [mem_read 0xf9006274]
lappend results [mem_read 0xf9006278]
lappend results [mem_read 0xf900627c]
lappend results [mem_read 0xf9006280]
lappend results [mem_read 0xf9006284]
lappend results [mem_read 0xf9006288]
lappend results [mem_read 0xf900628c]
lappend results [mem_read 0xf9006290]
lappend results [mem_read 0xf9006294]
lappend results [mem_read 0xf9006298]
lappend results [mem_read 0xf900629c]
lappend results [mem_read 0xf90062a0]
lappend results [mem_read 0xf90062a4]
lappend results [mem_read 0xf90062a8]
lappend results [mem_read 0xf90062ac]
lappend results [mem_read 0xf90062b0]
lappend results [mem_read 0xf90062b4]
lappend results [mem_read 0xf90062b8]
lappend results [mem_read 0xf90062bc]
lappend results [mem_read 0xf90062c0]
lappend results [mem_read 0xf90062c4]
lappend results [mem_read 0xf90062c8]
lappend results [mem_read 0xf90062cc]
lappend results [mem_read 0xf90062d0]
lappend results [mem_read 0xf90062d4]
lappend results [mem_read 0xf90062d8]
lappend results [mem_read 0xf90062dc]
lappend results [mem_read 0xf90062e0]
lappend results [mem_read 0xf90062e4]
lappend results [mem_read 0xf90062e8]
lappend results [mem_read 0xf90062ec]
lappend results [mem_read 0xf90062f0]
lappend results [mem_read 0xf90062f4]
lappend results [mem_read 0xf90062f8]
lappend results [mem_read 0xf90062fc]
lappend results [mem_read 0xf9006300]
lappend results [mem_read 0xf9006304]
lappend results [mem_read 0xf9006308]
lappend results [mem_read 0xf900630c]
lappend results [mem_read 0xf9006310]
lappend results [mem_read 0xf9006314]
lappend results [mem_read 0xf9006318]
lappend results [mem_read 0xf900631c]
lappend results [mem_read 0xf9006320]
lappend results [mem_read 0xf9006324]
lappend results [mem_read 0xf9006328]
lappend results [mem_read 0xf900632c]
lappend results [mem_read 0xf9006330]
lappend results [mem_read 0xf9006334]
lappend results [mem_read 0xf9006338]
lappend results [mem_read 0xf900633c]
lappend results [mem_read 0xf9006340]
lappend results [mem_read 0xf9006344]
lappend results [mem_read 0xf9006348]
lappend results [mem_read 0xf900634c]
lappend results [mem_read 0xf9006350]
lappend results [mem_read 0xf9006354]
lappend results [mem_read 0xf9006358]
lappend results [mem_read 0xf900635c]
lappend results [mem_read 0xf9006360]
lappend results [mem_read 0xf9006364]
lappend results [mem_read 0xf9006368]
lappend results [mem_read 0xf900636c]
lappend results [mem_read 0xf9006370]
lappend results [mem_read 0xf9006374]
lappend results [mem_read 0xf9006378]
lappend results [mem_read 0xf900637c]
lappend results [mem_read 0xf9006380]
lappend results [mem_read 0xf9006384]
lappend results [mem_read 0xf9006388]
lappend results [mem_read 0xf900638c]
lappend results [mem_read 0xf9006390]
lappend results [mem_read 0xf9006394]
lappend results [mem_read 0xf9006398]
lappend results [mem_read 0xf900639c]
lappend results [mem_read 0xf90063a0]
lappend results [mem_read 0xf90063a4]
lappend results [mem_read 0xf90063a8]
lappend results [mem_read 0xf90063ac]
lappend results [mem_read 0xf90063b0]
lappend results [mem_read 0xf90063b4]
lappend results [mem_read 0xf90063b8]
lappend results [mem_read 0xf90063bc]
lappend results [mem_read 0xf90063c0]
lappend results [mem_read 0xf90063c4]
lappend results [mem_read 0xf90063c8]
lappend results [mem_read 0xf90063cc]
lappend results [mem_read 0xf90063d0]
lappend results [mem_read 0xf90063d4]
lappend results [mem_read 0xf90063d8]
lappend results [mem_read 0xf90063dc]
lappend results [mem_read 0xf90063e0]
lappend results [mem_read 0xf90063e4]
lappend results [mem_read 0xf90063e8]
lappend results [mem_read 0xf90063ec]
lappend results [mem_read 0xf90063f0]
lappend results [mem_read 0xf90063f4]
lappend results [mem_read 0xf90063f8]
lappend results [mem_read 0xf90063fc]
lappend results [mem_read 0xf9006400]
lappend results [mem_read 0xf9006404]
lappend results [mem_read 0xf9006408]
lappend results [mem_read 0xf900640c]
lappend results [mem_read 0xf9006410]
lappend results [mem_read 0xf9006414]
lappend results [mem_read 0xf9006418]
lappend results [mem_read 0xf900641c]
lappend results [mem_read 0xf9006420]
lappend results [mem_read 0xf9006424]
lappend results [mem_read 0xf9006428]
lappend results [mem_read 0xf900642c]
lappend results [mem_read 0xf9006430]
lappend results [mem_read 0xf9006434]
lappend results [mem_read 0xf9006438]
lappend results [mem_read 0xf900643c]
lappend results [mem_read 0xf9006440]
lappend results [mem_read 0xf9006444]
lappend results [mem_read 0xf9006448]
lappend results [mem_read 0xf900644c]
lappend results [mem_read 0xf9006450]
lappend results [mem_read 0xf9006454]
lappend results [mem_read 0xf9006458]
lappend results [mem_read 0xf900645c]
lappend results [mem_read 0xf9006460]
lappend results [mem_read 0xf9006464]
lappend results [mem_read 0xf9006468]
lappend results [mem_read 0xf900646c]
lappend results [mem_read 0xf9006470]
lappend results [mem_read 0xf9006474]
lappend results [mem_read 0xf9006478]
lappend results [mem_read 0xf900647c]
lappend results [mem_read 0xf9006480]
lappend results [mem_read 0xf9006484]
lappend results [mem_read 0xf9006488]
lappend results [mem_read 0xf900648c]
lappend results [mem_read 0xf9006490]
lappend results [mem_read 0xf9006494]
lappend results [mem_read 0xf9006498]
lappend results [mem_read 0xf900649c]
lappend results [mem_read 0xf90064a0]
lappend results [mem_read 0xf90064a4]
lappend results [mem_read 0xf90064a8]
lappend results [mem_read 0xf90064ac]
lappend results [mem_read 0xf90064b0]
lappend results [mem_read 0xf90064b4]
lappend results [mem_read 0xf90064b8]
lappend results [mem_read 0xf90064bc]
lappend results [mem_read 0xf90064c0]
lappend results [mem_read 0xf90064c4]
lappend results [mem_read 0xf90064c8]
lappend results [mem_read 0xf90064cc]
lappend results [mem_read 0xf90064d0]
lappend results [mem_read 0xf90064d4]
lappend results [mem_read 0xf90064d8]
lappend results [mem_read 0xf90064dc]
lappend results [mem_read 0xf90064e0]
lappend results [mem_read 0xf90064e4]
lappend results [mem_read 0xf90064e8]
lappend results [mem_read 0xf90064ec]
lappend results [mem_read 0xf90064f0]
lappend results [mem_read 0xf90064f4]
lappend results [mem_read 0xf90064f8]
lappend results [mem_read 0xf90064fc]
lappend results [mem_read 0xf9006500]
lappend results [mem_read 0xf9006504]
lappend results [mem_read 0xf9006508]
lappend results [mem_read 0xf900650c]
lappend results [mem_read 0xf9006510]
lappend results [mem_read 0xf9006514]
lappend results [mem_read 0xf9006518]
lappend results [mem_read 0xf900651c]
lappend results [mem_read 0xf9006520]
lappend results [mem_read 0xf9006524]
lappend results [mem_read 0xf9006528]
lappend results [mem_read 0xf900652c]
lappend results [mem_read 0xf9006530]
lappend results [mem_read 0xf9006534]
lappend results [mem_read 0xf9006538]
lappend results [mem_read 0xf900653c]
lappend results [mem_read 0xf9006540]
lappend results [mem_read 0xf9006544]
lappend results [mem_read 0xf9006548]
lappend results [mem_read 0xf900654c]
lappend results [mem_read 0xf9006550]
lappend results [mem_read 0xf9006554]
lappend results [mem_read 0xf9006558]
lappend results [mem_read 0xf900655c]
lappend results [mem_read 0xf9006560]
lappend results [mem_read 0xf9006564]
lappend results [mem_read 0xf9006568]
lappend results [mem_read 0xf900656c]
lappend results [mem_read 0xf9006570]
lappend results [mem_read 0xf9006574]
lappend results [mem_read 0xf9006578]
lappend results [mem_read 0xf900657c]
lappend results [mem_read 0xf9006580]
lappend results [mem_read 0xf9006584]
lappend results [mem_read 0xf9006588]
lappend results [mem_read 0xf900658c]
lappend results [mem_read 0xf9006590]
lappend results [mem_read 0xf9006594]
lappend results [mem_read 0xf9006598]
lappend results [mem_read 0xf900659c]
lappend results [mem_read 0xf90065a0]
lappend results [mem_read 0xf90065a4]
lappend results [mem_read 0xf90065a8]
lappend results [mem_read 0xf90065ac]
lappend results [mem_read 0xf90065b0]
lappend results [mem_read 0xf90065b4]
lappend results [mem_read 0xf90065b8]
lappend results [mem_read 0xf90065bc]
lappend results [mem_read 0xf90065c0]
lappend results [mem_read 0xf90065c4]
lappend results [mem_read 0xf90065c8]
lappend results [mem_read 0xf90065cc]
lappend results [mem_read 0xf90065d0]
lappend results [mem_read 0xf90065d4]
lappend results [mem_read 0xf90065d8]
lappend results [mem_read 0xf90065dc]
lappend results [mem_read 0xf90065e0]
lappend results [mem_read 0xf90065e4]
lappend results [mem_read 0xf90065e8]
lappend results [mem_read 0xf90065ec]
lappend results [mem_read 0xf90065f0]
lappend results [mem_read 0xf90065f4]
lappend results [mem_read 0xf90065f8]
lappend results [mem_read 0xf90065fc]
lappend results [mem_read 0xf900c000]
lappend results [mem_read 0xf900c004]
lappend results [mem_read 0xf900c084]
lappend results [mem_read 0xf900c088]
lappend results [mem_read 0xf900c08c]
lappend results [mem_read 0xf900c090]
lappend results [mem_read 0xf900c094]
lappend results [mem_read 0xf900ffd0]
lappend results [mem_read 0xf900ffd4]
lappend results [mem_read 0xf900ffd8]
lappend results [mem_read 0xf900ffdc]
lappend results [mem_read 0xf900ffe0]
lappend results [mem_read 0xf900ffe4]
lappend results [mem_read 0xf900ffe8]
lappend results [mem_read 0xf900ffec]
lappend results [mem_read 0xf900fff0]
lappend results [mem_read 0xf900fff4]
lappend results [mem_read 0xf900fff8]
lappend results [mem_read 0xf900fffc]
