define(['./_group'], function (_group) {
  // Indexes the object's values by a criterion, similar to `_.groupBy`, but for
  // when you know that your index values will be unique.
  var indexBy = _group(function (result, value, key) {
    result[key] = value;
  });

  return indexBy;
});