// Side effect imports
import "./prototype.js";
import { getSetGlobalLocale, defineLocale, updateLocale, getLocale, listLocales } from "./locales.js";
import { listMonths, listMonthsShort, listWeekdays, listWeekdaysShort, listWeekdaysMin } from "./lists.js";
export { getSetGlobalLocale, defineLocale, updateLocale, getLocale, listLocales, listMonths, listMonthsShort, listWeekdays, listWeekdaysShort, listWeekdaysMin };
import { deprecate } from "../utils/deprecate.js";
import { hooks } from "../utils/hooks.js";
hooks.lang = deprecate('moment.lang is deprecated. Use moment.locale instead.', getSetGlobalLocale);
hooks.langData = deprecate('moment.langData is deprecated. Use moment.localeData instead.', getLocale);
import "./en.js";