/*
* Copyright (c) 2021 Xilinx, Inc.
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
* associated documentation files (the "Software"), to deal in the Software without restriction, including 
* without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
* copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
* the following conditions: 
* 
* The above copyright notice and this permission notice shall be included in all copies or substantial 
* portions of the Software. 
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
* LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
* 
*
*
*/
export const api_url = MyAppGlobals.serverUrl;
export const socket_url = MyAppGlobals.socketUrl;
export let configObj = {};
export const notificationRef = document.querySelector('my-app').shadowRoot.querySelector('app-header-layout').querySelector("#toast");
export const sysmon_address = {
    "root": "0xF1270000",
    "lpd": "0xFFB80000",
    "fpd": "0xFD620000",
    "0": "0xF61A0000",
    "1": "0xF6310000",
    "2": "0xF6480000",
    "3": "0xF65F0000",
    "4": "0xF6630000",
    "5": "0xF6690000",
    "6": "0xF66E0000",
    "7": "0xF6770000",
    "8": "0xF67B0000",
    "9": "0xF6800000",
    "10": "0xF6850000",
    "11": "0xF6870000",
    "12": "0xF68D0000",
    "13": "0xF6930000",
    "14": "0xF6970000",
    "15": "0xF69D0000",
    "16": "0xF6A10000",
    "17": "0xF6A70000",
    "18": "0xF6AD0000",
    "19": "0xF6B30000",
    "20": "0xF6B80000",
    "21": "0xF6C10000",
    "22": "0xF6C50000",
    "23": "0xF6CA0000",
    "24": "0xF6D00000",
    "25": "0xF6D50000",
    "26": "0xF6DE0000",
    "27": "0xF6E20000",
    "28": "0xF6E70000",
    "29": "0xF6ED0000",
    "30": "0xF6F20000",
    "31": "0xF6FB0000",
    "32": "0xF6FF0000",
    "33": "0xF7040000",
    "34": "0xF7090000",
    "35": "0xF70C0000",
    "36": "0xF7130000",
    "37": "0xF71A0000",
    "38": "0xF71F0000",
}

export const systemdetails = {
    "RPU": [
        {
            "address": "0xff9a0004",
            "register": "RPU_GLBL_STATUS",
            "value": "--",
            "module_name": "RPU",
            "bitnames": "--"
        },
        {
            "address": "0xff9a0104",
            "register": "RPU_0_STATUS",
            "value": "--",
            "module_name": "RPU",
            "bitnames": "--"
        },
        {
            "address": "0xff9a0114",
            "register": "RPU_0_ISR",
            "value": "--",
            "module_name": "RPU",
            "bitnames": "--"
        },
        {
            "address": "0xff9a0204",
            "register": "RPU_1_STATUS",
            "value": "--",
            "module_name": "RPU",
            "bitnames": "--"
        },
        {
            "address": "0xff9a0214",
            "register": "RPU_1_ISR",
            "value": "--",
            "module_name": "RPU",
            "bitnames": "--"
        }
    ],
    "OCM": [
        {
            "address": "0xff960004",
            "register": "OCM_ISR",
            "value": "--",
            "module_name": "OCM",
            "bitnames": "--"
        },
        /*{
            "address": "0xff980004",
            "register": "ERR_STATUS1_LO",
            "value": "--",
            "module_name":"OCM_XMPU",
            "bitnames": "--"
        },
        {
            "address": "0xff980008",
            "register": "ERR_STATUS1_HI",
            "value": "--",
            "module_name":"OCM_XMPU",
            "bitnames": "--"
        },
        {
            "address": "0xff98000c",
            "register": "ERR_STATUS2",
            "value": "--",
            "module_name":"OCM_XMPU",
            "bitnames": "--"
        },
        {
            "address": "0xff980010",
            "register": "ISR",
            "value": "--",
            "module_name":"OCM_XMPU",
            "bitnames": "--"
        }*/
    ],
    "PSM": [
        /*{
            "address": "0xffc80030",
            "register": "IRQ_STATUS",
            "value": "--",
            "module_name":"MB_IOMODULE",
            "bitnames": "--"
        },*/
        {
            "address": "0xffc88004",
            "register": "ACPU0_PWR_STATUS",
            "value": "--",
            "module_name": "PSM_LOCAL_REG",
            "bitnames": "--"
        },
        {
            "address": "0xffc88014",
            "register": "ACPU1_PWR_STATUS",
            "value": "--",
            "module_name": "PSM_LOCAL_REG",
            "bitnames": "--"
        },
        {
            "address": "0xffc88084",
            "register": "RPU_PWR_STATUS",
            "value": "--",
            "module_name": "PSM_LOCAL_REG",
            "bitnames": "--"
        },
        {
            "address": "0xffc880bc",
            "register": "L2_PWR_STATUS",
            "value": "--",
            "module_name": "PSM_LOCAL_REG",
            "bitnames": "--"
        },
        {
            "address": "0xffc880cc",
            "register": "OCM_PWR_STATUS",
            "value": "--",
            "module_name": "PSM_LOCAL_REG",
            "bitnames": "--"
        },
        {
            "address": "0xffc880dc",
            "register": "TCM_PWR_STATUS",
            "value": "--",
            "module_name": "PSM_LOCAL_REG",
            "bitnames": "--"
        },
        {
            "address": "0xffc880e8",
            "register": "GEM_PWR_STATUS",
            "value": "--",
            "module_name": "PSM_LOCAL_REG",
            "bitnames": "--"
        },

        {
            "address": "0xffc88320",
            "register": "ADDR_ERROR_STATUS",
            "value": "--",
            "module_name": "PSM_LOCAL_REG",
            "bitnames": "--"
        },
        {
            "address": "0xffc88418",
            "register": "APU_WFI_STATUS",
            "value": "--",
            "module_name": "PSM_LOCAL_REG",
            "bitnames": "--"
        },
        {
            "address": "0xffc88510",
            "register": "MBISR_CNTRL",
            "value": "--",
            "module_name": "PSM_LOCAL_REG",
            "bitnames": "--"
        },
        {
            "address": "0xffc88514",
            "register": "MBISR_STATUS",
            "value": "--",
            "module_name": "PSM_LOCAL_REG",
            "bitnames": "--"
        },
        {
            "address": "0xffc90000",
            "register": "IR_STATUS",
            "value": "--",
            "module_name": "PSM_GLOBAL_REG",
            "bitnames": "--"
        },
        {
            "address": "0xffc90040",
            "register": "IR_STATUS_PERR",
            "value": "--",
            "module_name": "PSM_GLOBAL_REG",
            "bitnames": "--"
        },
        /*{
            "address": "0xffca0000",
            "register": "STATUS",
            "value": "--",
            "module_name":"MB_RAM_ECC_CTRL",
            "bitnames": "--"
        },
        {
            "address": "0xffcb0000",
            "register": "STATUS",
            "value": "--",
            "module_name":"MB_RAM_ECC_CTRL",
            "bitnames": "--"
        },
        {
            "address": "0xffce0000",
            "register": "DATA_STATUS",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xffce0008",
            "register": "STATUS1",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xffce000c",
            "register": "STATUS2",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xffce0010",
            "register": "STATUS3",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xffcf0008",
            "register": "MDM_UART_STATUS",
            "value": "--",
            "module_name":"MB_MDM",
            "bitnames": "--"
        },
        {
            "address": "0xffcf0010",
            "register": "MDM_DBG_CTRL_STATUS",
            "value": "--",
            "module_name":"MB_MDM",
            "bitnames": "--"
        }*/
    ],
    "ADMA": [
        {
            "address": "0xffa8011c",
            "register": "ZDMA_CH_STATUS",
            "value": "--",
            "module_name": "ADMA_CH0",
            "bitnames": "--"
        },
        {
            "address": "0xffa80100",
            "register": "ZDMA_CH_ISR",
            "value": "--",
            "module_name": "ADMA_CH0",
            "bitnames": "--"
        }
        /*,
        {
            "address": "0xffa9011c",
            "register": "ZDMA_CH_STATUS",
            "value": "--",
            "module_name":"ADMA_CH1",
            "bitnames": "--"
        },
        {
            "address": "0xffa90100",
            "register": "ZDMA_CH_ISR",
            "value": "--",
            "module_name":"ADMA_CH1",
            "bitnames": "--"
        },
        {
            "address": "0xffaa011c",
            "register": "ZDMA_CH_STATUS",
            "value": "--",
            "module_name":"ADMA_CH2",
            "bitnames": "--"
        },
        {
            "address": "0xffaa0100",
            "register": "ZDMA_CH_ISR",
            "value": "--",
            "module_name":"ADMA_CH2",
            "bitnames": "--"
        },
        {
            "address": "0xffab011c",
            "register": "ZDMA_CH_STATUS",
            "value": "--",
            "module_name":"ADMA_CH3",
            "bitnames": "--"
        },
        {
            "address": "0xffab0100",
            "register": "ZDMA_CH_ISR",
            "value": "--",
            "module_name":"ADMA_CH3",
            "bitnames": "--"
        },
        {
            "address": "0xffac011c",
            "register": "ZDMA_CH_STATUS",
            "value": "--",
            "module_name":"ADMA_CH4",
            "bitnames": "--"
        },
        {
            "address": "0xffac0100",
            "register": "ZDMA_CH_ISR",
            "value": "--",
            "module_name":"ADMA_CH4",
            "bitnames": "--"
        },
        {
            "address": "0xffad011c",
            "register": "ZDMA_CH_STATUS",
            "value": "--",
            "module_name":"ADMA_CH5",
            "bitnames": "--"
        },
        {
            "address": "0xffad0100",
            "register": "ZDMA_CH_ISR",
            "value": "--",
            "module_name":"ADMA_CH5",
            "bitnames": "--"
        },
        {
            "address": "0xffae011c",
            "register": "ZDMA_CH_STATUS",
            "value": "--",
            "module_name":"ADMA_CH6",
            "bitnames": "--"
        },
        {
            "address": "0xffae0100",
            "register": "ZDMA_CH_ISR",
            "value": "--",
            "module_name":"ADMA_CH6",
            "bitnames": "--"
        },
        {
            "address": "0xffaf011c",
            "register": "ZDMA_CH_STATUS",
            "value": "--",
            "module_name":"ADMA_CH7",
            "bitnames": "--"
        },
        {
            "address": "0xffaf0100",
            "register": "ZDMA_CH_ISR",
            "value": "--",
            "module_name":"ADMA_CH7",
            "bitnames": "--"
        }*/
    ],
    "APU": [
        {
            "address": "0xfd5c0010",
            "register": "ISR",
            "value": "--",
            "module_name": "APU_DUAL",
            "bitnames": "--"
        },
        {
            "address": "0xf0c20fb4",
            "register": "LOCKSTATUS",
            "value": "--",
            "module_name": "CX_FUNNEL_2P",
            "bitnames": "--"
        },
        {
            "address": "0xf0c20fb8",
            "register": "AUTHSTATUS",
            "value": "--",
            "module_name": "CX_FUNNEL_2P",
            "bitnames": "--"
        },
        {
            "address": "0xf0c30fb8",
            "register": "AUTHSTATUS",
            "value": "--",
            "module_name": "CX_ETF_4K",
            "bitnames": "--"
        },
        {
            "address": "0xf0c60fb8",
            "register": "AUTHSTATUS",
            "value": "--",
            "module_name": "CX_ELA_128",
            "bitnames": "--"
        },
        /*{
            "address": "0xf0ca0130",
            "register": "CTITRIGINSTATUS",
            "value": "--",
            "module_name":"CX_CTI",
            "bitnames": "--"
        },
        {
            "address": "0xf0ca0134",
            "register": "CTITRIGOUTSTATUS",
            "value": "--",
            "module_name":"CX_CTI",
            "bitnames": "--"
        },
        {
            "address": "0xf0ca0138",
            "register": "CTICHINSTATUS",
            "value": "--",
            "module_name":"CX_CTI",
            "bitnames": "--"
        },
        {
            "address": "0xf0ca013c",
            "register": "CTICHOUTSTATUS",
            "value": "--",
            "module_name":"CX_CTI",
            "bitnames": "--"
        },
        {
            "address": "0xf0ca0fb8",
            "register": "AUTHSTATUS",
            "value": "--",
            "module_name":"CX_CTI",
            "bitnames": "--"
        },*/
        {
            "address": "0xf900c000",
            "register": "GICD_ESTATUSR",
            "value": "--",
            "module_name": "APU_GIC_DIST_MAIN",
            "bitnames": "--"
        },
        {
            "address": "0xf900c084",
            "register": "GICD_SPISR0",
            "value": "--",
            "module_name": "APU_GIC_DIST_MAIN",
            "bitnames": "--"
        },
        {
            "address": "0xf900c088",
            "register": "GICD_SPISR1",
            "value": "--",
            "module_name": "APU_GIC_DIST_MAIN",
            "bitnames": "--"
        },
        {
            "address": "0xf900c08c",
            "register": "GICD_SPISR2",
            "value": "--",
            "module_name": "APU_GIC_DIST_MAIN",
            "bitnames": "--"
        },
        {
            "address": "0xf900c090",
            "register": "GICD_SPISR3",
            "value": "--",
            "module_name": "APU_GIC_DIST_MAIN",
            "bitnames": "--"
        },
        {
            "address": "0xf900c094",
            "register": "GICD_SPISR4",
            "value": "--",
            "module_name": "APU_GIC_DIST_MAIN",
            "bitnames": "--"
        },
        {
            "address": "0xf9050010",
            "register": "GICH_MISR",
            "value": "--",
            "module_name": "APU_GIC_A72_VIFCTL",
            "bitnames": "--"
        },
        {
            "address": "0xf9050020",
            "register": "GICH_EISR0",
            "value": "--",
            "module_name": "APU_GIC_A72_VIFCTL",
            "bitnames": "--"
        },
        {
            "address": "0xf906002c",
            "register": "GICV_STATUSR",
            "value": "--",
            "module_name": "APU_GIC_A72_VCPUIF",
            "bitnames": "--"
        },
        {
            "address": "0xf909c000",
            "register": "GICR_MISCSTATUSR",
            "value": "--",
            "module_name": "APU_GIC_REDIST_SGISPI",
            "bitnames": "--"
        },
        {
            "address": "0xf909c080",
            "register": "GICR_PPISR",
            "value": "--",
            "module_name": "APU_GIC_REDIST_SGISPI",
            "bitnames": "--"
        },
        /*{
            "address": "0xf90bc000",
            "register": "GICR_MISCSTATUSR",
            "value": "--",
            "module_name":"APU_GIC_REDIST_SGISPI",
            "bitnames": "--"
        },
        {
            "address": "0xf90bc080",
            "register": "GICR_PPISR",
            "value": "--",
            "module_name":"APU_GIC_REDIST_SGISPI",
            "bitnames": "--"
        },
        {
            "address": "0xf90dc000",
            "register": "GICR_MISCSTATUSR",
            "value": "--",
            "module_name":"APU_GIC_REDIST_SGISPI",
            "bitnames": "--"
        },
        {
            "address": "0xf90dc080",
            "register": "GICR_PPISR",
            "value": "--",
            "module_name":"APU_GIC_REDIST_SGISPI",
            "bitnames": "--"
        },
        {
            "address": "0xf90fc000",
            "register": "GICR_MISCSTATUSR",
            "value": "--",
            "module_name":"APU_GIC_REDIST_SGISPI",
            "bitnames": "--"
        },
        {
            "address": "0xf90fc080",
            "register": "GICR_PPISR",
            "value": "--",
            "module_name":"APU_GIC_REDIST_SGISPI",
            "bitnames": "--"
        }*/
    ],
    "GEM0": [
        {
            "address": "0xff0c0008",
            "register": "network_status",
            "value": "--",
            "module_name": "GEM",
            "bitnames": "--"
        },
        {
            "address": "0xff0c0014",
            "register": "transmit_status",
            "value": "--",
            "module_name": "GEM",
            "bitnames": "--"
        },
        {
            "address": "0xff0c0020",
            "register": "receive_status",
            "value": "--",
            "module_name": "GEM",
            "bitnames": "--"
        },
        {
            "address": "0xff0c0024",
            "register": "int_status",
            "value": "--",
            "module_name": "GEM",
            "bitnames": "--"
        },
        {
            "address": "0xff0c0400",
            "register": "int_q1_status",
            "value": "--",
            "module_name": "GEM",
            "bitnames": "--"
        }
    ],
    /*"GEM1": [
        {
            "address": "0xff0d0008",
            "register": "network_status",
            "value": "--",
            "module_name":"GEM",
            "bitnames": "--"
        },
        {
            "address": "0xff0d0014",
            "register": "transmit_status",
            "value": "--",
            "module_name":"GEM",
            "bitnames": "--"
        },
        {
            "address": "0xff0d0020",
            "register": "receive_status",
            "value": "--",
            "module_name":"GEM",
            "bitnames": "--"
        },
        {
            "address": "0xff0d0024",
            "register": "int_status",
            "value": "--",
            "module_name":"GEM",
            "bitnames": "--"
        },
        {
            "address": "0xff0d0400",
            "register": "int_q1_status",
            "value": "--",
            "module_name":"GEM",
            "bitnames": "--"
        }
    ],*/
    "SMMU": [
        {
            "address": "0xfd5f0010",
            "register": "ISR_0",
            "value": "--",
            "module_name": "SMMU_CSR",
            "bitnames": "--"
        },
        {
            "address": "0xfd800074",
            "register": "SMMU_STLBGSTATUS",
            "value": "--",
            "module_name": "SMMU500",
            "bitnames": "--"
        },
        {
            "address": "0xfd800474",
            "register": "SMMU_NSTLBGSTATUS",
            "value": "--",
            "module_name": "SMMU500",
            "bitnames": "--"
        },
        {
            "address": "0xfd802204",
            "register": "SMMU_TBU_PWR_STATUS",
            "value": "--",
            "module_name": "SMMU500",
            "bitnames": "--"
        },
        {
            "address": "0xfd803fb8",
            "register": "PMAUTHSTATUS",
            "value": "--",
            "module_name": "SMMU500",
            "bitnames": "--"
        }
    ],
    "Coherent": [
        {
            "address": "0xfd5e0010",
            "register": "ISR_0",
            "value": "--",
            "module_name": "CCI_REG",
            "bitnames": "--"
        },
        {
            "address": "0xfd00000c",
            "register": "status",
            "value": "--",
            "module_name": "CCI500",
            "bitnames": "--"
        }
    ],
    "WWDT0": [
        {
            "address": "0xfd4d2000",
            "register": "GWDT_Cntrl_Status_reg",
            "value": "--",
            "module_name": "WWDT",
            "bitnames": "--"
        },
        {
            "address": "0xfd4d0004",
            "register": "Enable_and_Status_reg",
            "value": "--",
            "module_name": "WWDT",
            "bitnames": "--"
        }
    ],
    /*"WWDT1": [
        {
            "address": "0xff120004",
            "register": "Enable_and_Status_reg",
            "value": "--",
            "module_name":"WWDT",
            "bitnames": "--"
        },
        {
            "address": "0xff122000",
            "register": "GWDT_Cntrl_Status_reg",
            "value": "--",
            "module_name":"WWDT",
            "bitnames": "--"
        }
    ],*/
    "I2C0": [
        {
            "address": "0xff020004",
            "register": "Status_reg0",
            "value": "--",
            "module_name": "PS_I2C",
            "bitnames": "--"
        },
        {
            "address": "0xff020010",
            "register": "Interrupt_status_reg0",
            "value": "--",
            "module_name": "PS_I2C",
            "bitnames": "--"
        }
    ],
    /*"I2C1": [
        {
            "address": "0xff030004",
            "register": "Status_reg0",
            "value": "--",
            "module_name":"PS_I2C",
            "bitnames": "--"
        },
        {
            "address": "0xff030010",
            "register": "Interrupt_status_reg0",
            "value": "--",
            "module_name":"PS_I2C",
            "bitnames": "--"
        }
    ],*/
    "CAN0": [
        {
            "address": "0xff060014",
            "register": "Error_Status_Register",
            "value": "--",
            "module_name": "CANFD",
            "bitnames": "--"
        },
        {
            "address": "0xff06001c",
            "register": "Interrupt_Status_Register",
            "value": "--",
            "module_name": "CANFD",
            "bitnames": "--"
        },
        {
            "address": "0xff060018",
            "register": "Status_Register",
            "value": "--",
            "module_name": "CANFD",
            "bitnames": "--"
        },
        {
            "address": "0xff0600a0",
            "register": "TX_Event_FIFO_Status_Register",
            "value": "--",
            "module_name": "CANFD",
            "bitnames": "--"
        },
        {
            "address": "0xff0600e8",
            "register": "RX_FIFO_Status_Register",
            "value": "--",
            "module_name": "CANFD",
            "bitnames": "--"
        }
    ],
    /*"CAN1": [
        {
            "address": "0xff070014",
            "register": "Error_Status_Register",
            "value": "--",
            "module_name":"CANFD",
            "bitnames": "--"
        },
        {
            "address": "0xff07001c",
            "register": "Interrupt_Status_Register",
            "value": "--",
            "module_name":"CANFD",
            "bitnames": "--"
        },
        {
            "address": "0xff070018",
            "register": "Status_Register",
            "value": "--",
            "module_name":"CANFD",
            "bitnames": "--"
        },
        {
            "address": "0xff0700a0",
            "register": "TX_Event_FIFO_Status_Register",
            "value": "--",
            "module_name":"CANFD",
            "bitnames": "--"
        },
        {
            "address": "0xff0700e8",
            "register": "RX_FIFO_Status_Register",
            "value": "--",
            "module_name":"CANFD",
            "bitnames": "--"
        }
    ],*/
    "USB": [
        {
            "address": "0xff9d0064",
            "register": "ir_status",
            "value": "--",
            "module_name": "USB2_REGS",
            "bitnames": "--"
        }
    ],
    "SPI0": [
        {
            "address": "0xff040004",
            "register": "Intr_status_reg0",
            "value": "--",
            "module_name": "SPI",
            "bitnames": "--"
        }
    ],
    /*"SPI1": [
        {
            "address": "0xff050004",
            "register": "Intr_status_reg0",
            "value": "--",
            "module_name":"SPI",
            "bitnames": "--"
        }
    ],*/
    "UART": [
        {
            "address": "0xff000004",
            "register": "UARTRSR_UARTECR",
            "value": "--",
            "module_name": "UART0",
            "bitnames": "--"
        },
        {
            "address": "0xff00003c",
            "register": "UARTRIS",
            "value": "--",
            "module_name": "UART0",
            "bitnames": "--"
        },
        {
            "address": "0xff000040",
            "register": "UARTMIS",
            "value": "--",
            "module_name": "UART0",
            "bitnames": "--"
        }
    ],
    "TRACE": [
        {
            "address": "0xf0100000",
            "register": "DATA_STATUS",
            "value": "--",
            "module_name": "MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xf0100008",
            "register": "STATUS1",
            "value": "--",
            "module_name": "MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xf010000c",
            "register": "STATUS2",
            "value": "--",
            "module_name": "MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xf0100010",
            "register": "STATUS3",
            "value": "--",
            "module_name": "MB_TMR_TRACE",
            "bitnames": "--"
        },
        /*{
            "address": "0xf0300000",
            "register": "DATA_STATUS",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xf0300008",
            "register": "STATUS1",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xf030000c",
            "register": "STATUS2",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xf0300010",
            "register": "STATUS3",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xffce0000",
            "register": "DATA_STATUS",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xffce0008",
            "register": "STATUS1",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xffce000c",
            "register": "STATUS2",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        },
        {
            "address": "0xffce0010",
            "register": "STATUS3",
            "value": "--",
            "module_name":"MB_TMR_TRACE",
            "bitnames": "--"
        }*/
    ],
    "TTC0": [
        {
            "address": "0xff0e0054",
            "register": "XTTCPS_ISR_OFFSET",
            "value": "--",
            "module_name": "TTC0",
            "bitnames": "--"
        },
        {
            "address": "0xff0e0058",
            "register": "Interrupt_Register_2",
            "value": "--",
            "module_name": "TTC0",
            "bitnames": "--"
        },
        {
            "address": "0xff0e005c",
            "register": "Interrupt_Register_3",
            "value": "--",
            "module_name": "TTC0",
            "bitnames": "--"
        },
        {
            "address": "0xff0e0060",
            "register": "XTTCPS_IER_OFFSET",
            "value": "--",
            "module_name": "TTC0",
            "bitnames": "--"
        },
        /*{
            "address": "0xff0E0064",
            "register": "Interrupt_Enable_2",
            "value": "--",
            "module_name":"TTC0",
            "bitnames": "--"
        },
        {
            "address": "0xff0E0068",
            "register": "Interrupt_Enable_3",
            "value": "--",
            "module_name":"TTC0",
            "bitnames": "--"
        }*/
    ],
    /*"TTC1":[
        {
            "address": "0xff0f0054",
            "register": "XTTCPS_ISR_OFFSET",
            "value": "--",
            "module_name":"TTC1",
            "bitnames": "--"
        },
        {
            "address": "0xff0f0058",
            "register": "Interrupt_Register_2",
            "value": "--",
            "module_name":"TTC1",
            "bitnames": "--"
        },
        {
            "address": "0xff0f005c",
            "register": "Interrupt_Register_3",
            "value": "--",
            "module_name":"TTC1",
            "bitnames": "--"
        },
        {
            "address": "0xff0f0060",
            "register": "XTTCPS_IER_OFFSET",
            "value": "--",
            "module_name":"TTC1",
            "bitnames": "--"
        },
        {
            "address": "0xff0f0064",
            "register": "Interrupt_Enable_2",
            "value": "--",
            "module_name":"TTC1",
            "bitnames": "--"
        },
        {
            "address": "0xff0f0068",
            "register": "Interrupt_Enable_3",
            "value": "--",
            "module_name":"TTC1",
            "bitnames": "--"
        }
    ]*/
}

export const CPMdetails = {
    "PLL": [
        {
            "address": "0xFCA00050",
            "register": "PLL_STATUS CPLL_LOCK",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00000001"
        },
        {
            "address": "0xFCA00050",
            "register": "PLL_STATUS CPLL_STABLE",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00000004"
        }
    ],
    "PCIE0": [
        {
            "address": "0xFCA50010",
            "register": "ISR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA50030",
            "register": "Core_clk frequency Information",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA50034",
            "register": "User_clk frequency Information",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA500EC",
            "register": "PL_LINK_CAP_MAX_LINK_WIDTH",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA500F0",
            "register": "PL_LINK_CAP_MAX_LINK_SPEED",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6010810",
            "register": "PCIe_0_NMU BSY",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6010030",
            "register": "PCIe_0_NMU ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF60705E0",
            "register": "PCIe_0_NMU ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6070614",
            "register": "PCIe_0_NSU1 STATUS",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6070648",
            "register": "PCIe_0_NSU2 STATUS",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF607067C",
            "register": "PCIe_0_NSU3 STATUS",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6060044",
            "register": "PCIe_0_NPS0 ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6030044",
            "register": "PCIe_0_NPS1 ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6032044",
            "register": "PCIe_0_NPS2 ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF60a0044",
            "register": "PCIe_0_NPS3 ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        }
    ],
    "PCIE1": [
        {
            "address": "0xFCA60010",
            "register": "ISR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA60030",
            "register": "Core_clk frequency Information",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA60034",
            "register": "User_clk frequency Information",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA600EC",
            "register": "PL_LINK_CAP_MAX_LINK_WIDTH",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA600F0",
            "register": "PL_LINK_CAP_MAX_LINK_SPEED",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6014810",
            "register": "PCIe_1_NMU BSY",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6014030",
            "register": "PCIe_1_NMU ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF60705E0",
            "register": "PCIe_1_NMU ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6070614",
            "register": "PCIe_1_NSU1 STATUS",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6070648",
            "register": "PCIe_1_NSU2 STATUS",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF607067C",
            "register": "PCIe_1_NSU3 STATUS",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6030044",
            "register": "PCIe_1_NPS0 ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6032044",
            "register": "PCIe_1_NPS1 ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF6062044",
            "register": "PCIe_1_NPS2 ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xF60a0044",
            "register": "PCIe_1_NPS3 ISR",
            "value": "--",
            "module_name": "NPI",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        }
    ],
    "PCIe_DMA": [
        {
            "address": "0xFCA70030",
            "register": "attr_dma_data_width",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA70E00",
            "register": "attr_design_use_mode",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA700B0",
            "register": "attr_dma_axi_slv_brdg_base_addr_l",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA700B4",
            "register": "attr_dma_axi_slv_brdg_base_addr_h",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        }
    ],
    "L2": [
        {
            "address": "0xFCD04108",
            "register": "agent_iccc0_ccc_event_counter_value",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCD04180",
            "register": "agent_iccc0_ccc_ecc_info",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCD041C0",
            "register": "agent_iccc0_ccc_shdw_chim_link_status",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCD041C8",
            "register": "agent_iccc0_ccc_shdw_chis_link_status",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCD06180",
            "register": "agent_iccc0_llc_event_counter_0",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCD06190",
            "register": "agent_iccc0_llc_event_counter_1",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        }
    ],
    "SLCR": [
        {
            "address": "0xFCA00004",
            "register": "IR_STATUS ADDR_DECODE_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00000001"
        },
        {
            "address": "0xFCA10020",
            "register": "CPM_VERSION",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00000100"
        },
        {
            "address": "0xFCA10300",
            "register": "PS_CORR_IR_STATUS CMN_ERRS",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00000100"
        },
        {
            "address": "0xFCA10300",
            "register": "PS_CORR_IR_STATUS CMN_ERRNS",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00000080"
        },
        {
            "address": "0xFCA10300",
            "register": "PS_CORR_IR_STATUS CMN_FAULTS",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00000400"
        },
        {
            "address": "0xFCA10300",
            "register": "PS_CORR_IR_STATUS CMN_FAULTNS",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00000200"
        },
        {
            "address": "0xFCA10300",
            "register": "PS_CORR_IR_STATUS L2_UNCORR_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00002000"
        },
        {
            "address": "0xFCA10300",
            "register": "PS_CORR_IR_STATUS L2_CORR_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00001000"
        },
        {
            "address": "0xFCA10300",
            "register": "PS_CORR_IR_STATUS ADDR_REMAP_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00010000"
        },
        {
            "address": "0xFCA10300",
            "register": "PS_CORR_IR_STATUS CPI1_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00400000"
        },
        {
            "address": "0xFCA10300",
            "register": "PS_CORR_IR_STATUS CPI0_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00200000"
        },
        {
            "address": "0xFCA10300",
            "register": "PS_CORR_IR_STATUS PL_IRQ1",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x01000000"
        },
        {
            "address": "0xFCA10300",
            "register": "PS_CORR_IR_STATUS PL_IRQ0",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x00800000"
        },
        {
            "address": "0xFCA10320",
            "register": "PS_UNCORR_IR_STATUS",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA10340",
            "register": "PS_MISC_IR_STATUS",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA10360",
            "register": "PL_CORR_IR_STATUS",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA10380",
            "register": "PL_UNCORR_IR_STATUS",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        },
        {
            "address": "0xFCA103A0",
            "register": "PL_MISC_IR_STATUS",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":false,
            "bitvalues":"0xFFFFFFFF"
        }
    ],
    "L2_CHI":[
        {
            "address": "0xFCA103BC",
            "register": "CPI0_TXSNP_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x0000001F"
        },
        {
            "address": "0xFCA103C0",
            "register": "CPI0_TXRSP_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x0000001F"
        },
        {
            "address": "0xFCA103C4",
            "register": "CPI0_TXDAT_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x000000FF"
        },
        {
            "address": "0xFCA103C8",
            "register": "CPI0_RXREQ_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x0000001F"
        },
        {
            "address": "0xFCA103CC",
            "register": "CPI0_RXRSP_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x0000001F"
        },
        {
            "address": "0xFCA103D0",
            "register": "CPI0_RXDAT_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x000000FF"
        },
        {
            "address": "0xFCA103D4",
            "register": "CPI1_TXSNP_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x0000001F"
        },
        {
            "address": "0xFCA103D8",
            "register": "CPI1_TXRSP_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x0000001F"
        },
        {
            "address": "0xFCA103DC",
            "register": "CPI1_TXDAT_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x000000FF"
        },
        {
            "address": "0xFCA103E0",
            "register": "CPI1_RXREQ_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x0000001F"
        },
        {
            "address": "0xFCA103E4",
            "register": "CPI1_RXRSP_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x0000001F"
        },
        {
            "address": "0xFCA103E8",
            "register": "CPI1_RXDAT_ERR",
            "value": "--",
            "module_name": "CPM",
            "bitnames": "--",
            "readspecificbits":true,
            "bitvalues":"0x000000FF"
        }
    ]
}
export const PMCdetails = {
    "RTC": [
        {
            "address": "0xF12A0020",
            "register": "RTC_INT_STATUS",
            "value": "--",
            "module_name": "RTC",
            "bitnames": "--"
        },
        {
            "address": "0xF12A0030",
            "register": "RTC_ADDR_ERROR",
            "value": "--",
            "module_name": "RTC",
            "bitnames": "--"
        }
    ],
    "BBRAM": [
        {
            "address": "0xF11F0000",
            "register": "BBRAM_STATUS",
            "value": "--",
            "module_name": "BBRAM",
            "bitnames": "--"
        },
        {
            "address": "0xF11F0038",
            "register": "SLV_ERR_ISR",
            "value": "--",
            "module_name": "BBRAM",
            "bitnames": "--"
        }
    ],
    "PMC-TAP": [
        {
            "address": "0xF11B0008",
            "register": "DAP_CFG",
            "value": "--",
            "module_name": "PMC-TAP",
            "bitnames": "--"
        },
        {
            "address": "0XF11B000C",
            "register": "DAP_SECURITY",
            "value": "--",
            "module_name": "PMC-TAP",
            "bitnames": "--"
        }
    ],
    "SD": [
        {
            "address": "0XF1040030",
            "register": "reg_normalintrsts",
            "value": "--",
            "module_name": "SD",
            "bitnames": "--"
        },
        {
            "address": "0XF1040032",
            "register": "reg_errorintrsts",
            "value": "--",
            "module_name": "SD",
            "bitnames": "--"
        },
        {
            "address": "0XF1040054",
            "register": "reg_admaerrsts",
            "value": "--",
            "module_name": "SD",
            "bitnames": "--"
        },
        {
            "address": "0XF104003C",
            "register": "reg_autocmderrsts",
            "value": "--",
            "module_name": "SD",
            "bitnames": "--"
        }
    ],
    "sysmon": [
        {
            "address": "0xF12805B4",
            "register": "sat0:CAL_STATUS",
            "value": "--",
            "module_name": "Sysmon",
            "bitnames": "--"
        },
        {
            "address": "0xF12805B8",
            "register": "sat0:CAL_STATUS_DEBUG",
            "value": "--",
            "module_name": "Sysmon",
            "bitnames": "--"
        },
        {
            "address": "0xF12905B4",
            "register": "sat1:CAL_STATUS",
            "value": "--",
            "module_name": "Sysmon",
            "bitnames": "--"
        },
        {
            "address": "0xF12905B8",
            "register": "sat1:CAL_STATUS_DEBUG",
            "value": "--",
            "module_name": "Sysmon",
            "bitnames": "--"
        }
    ],
    "AES": [
        {
            "address": "0xF11E0000",
            "register": "AES_STATUS",
            "value": "--",
            "module_name": "AES",
            "bitnames": "--"
        },
        {
            "address": "0xF11E0064",
            "register": "AES_KEY_ZEROED_STATUS",
            "value": "--",
            "module_name": "AES",
            "bitnames": "--"
        }
    ],
    "SHA3": [
        {
            "address": "0xF1210010",
            "register": "SHA3_SHA_DIGEST0",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF1210014",
            "register": "SHA3_SHA_DIGEST1",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF1210018",
            "register": "SHA3_SHA_DIGEST2",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF121001C",
            "register": "SHA3_SHA_DIGEST3",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF1210020",
            "register": "SHA3_SHA_DIGEST4",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF1210024",
            "register": "SHA3_SHA_DIGEST5",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF1210028",
            "register": "SHA3_SHA_DIGEST6",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF121002C",
            "register": "SHA3_SHA_DIGEST7",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF1210030",
            "register": "SHA3_SHA_DIGEST8",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF1210034",
            "register": "SHA3_SHA_DIGEST9",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF1210038",
            "register": "SHA3_SHA_DIGEST10",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF121003C",
            "register": "SHA3_SHA_DIGEST11",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        },
        {
            "address": "0xF1210008",
            "register": "SHA3_SHA_DONE",
            "value": "--",
            "module_name": "SHA3",
            "bitnames": "--"
        }
    ],
    "TRNG": [
        {
            "address": "0xF1230004",
            "register": "STATUS",
            "value": "--",
            "module_name": "TRNG",
            "bitnames": "--"
        },
        {
            "address": "0xF1230008",
            "register": "CTRL",
            "value": "--",
            "module_name": "TRNG",
            "bitnames": "--"
        }
    ],
    "ECDSA": [
        {
            "address": "0xF120000C",
            "register": "STATUS",
            "value": "--",
            "module_name": "ECDSA",
            "bitnames": "--"
        },
        {
            "address": "0xF1200048",
            "register": "ECDSA_RSA_ISR",
            "value": "--",
            "module_name": "ECDSA",
            "bitnames": "--"
        }
    ],
    "DMA0": [
        {
            "address": "0xF11C0000",
            "register": "PMCDMA_SRC_ADDR",
            "value": "--",
            "module_name": "DMA0",
            "bitnames": "--"
        },
        {
            "address": "0xF11C0004",
            "register": "PMCDMA_SRC_SIZE",
            "value": "--",
            "module_name": "DMA0",
            "bitnames": "--"
        },
        {
            "address": "0xF11C0008",
            "register": "PMCDMA_SRC_STS",
            "value": "--",
            "module_name": "DMA0",
            "bitnames": "--"
        },
        {
            "address": "0xF11C0014",
            "register": "PMCDMA_SRC_I_STS",
            "value": "--",
            "module_name": "DMA0",
            "bitnames": "--"
        },
        {
            "address": "0xF11C0800",
            "register": "PMCDMA_DST_ADDR",
            "value": "--",
            "module_name": "DMA0",
            "bitnames": "--"
        },
        {
            "address": "0xF11C0804",
            "register": "PMCDMA_DST_SIZE",
            "value": "--",
            "module_name": "DMA0",
            "bitnames": "--"
        },
        {
            "address": "0xF11C0808",
            "register": "PMCDMA_DST_STS",
            "value": "--",
            "module_name": "DMA0",
            "bitnames": "--"
        },
        {
            "address": "0xF11C0814",
            "register": "PMCDMA_DST_I_STS",
            "value": "--",
            "module_name": "DMA0",
            "bitnames": "--"
        }
    ],
    "DMA1": [
        {
            "address": "0xF11D0000",
            "register": "PMCDMA_SRC_ADDR",
            "value": "--",
            "module_name": "DMA1",
            "bitnames": "--"
        },
        {
            "address": "0xF11D0004",
            "register": "PMCDMA_SRC_SIZE",
            "value": "--",
            "module_name": "DMA1",
            "bitnames": "--"
        },
        {
            "address": "0xF11D0008",
            "register": "PMCDMA_SRC_STS",
            "value": "--",
            "module_name": "DMA1",
            "bitnames": "--"
        },
        {
            "address": "0xF11D0014",
            "register": "PMCDMA_SRC_I_STS",
            "value": "--",
            "module_name": "DMA1",
            "bitnames": "--"
        },
        {
            "address": "0xF11D0800",
            "register": "PMCDMA_DST_ADDR",
            "value": "--",
            "module_name": "DMA1",
            "bitnames": "--"
        },
        {
            "address": "0xF11D0804",
            "register": "PMCDMA_DST_SIZE",
            "value": "--",
            "module_name": "DMA1",
            "bitnames": "--"
        },
        {
            "address": "0xF11D0808",
            "register": "PMCDMA_DST_STS",
            "value": "--",
            "module_name": "DMA1",
            "bitnames": "--"
        },
        {
            "address": "0xF11D0814",
            "register": "PMCDMA_DST_I_STS",
            "value": "--",
            "module_name": "DMA1",
            "bitnames": "--"
        }
    ],
    "Efuse": [
        {
            "address": "0xF1240008",
            "register": "EFUSE_CTRL_STATUS",
            "value": "--",
            "module_name": "EFUSE",
            "bitnames": "--"
        },
        {
            "address": "0xF1240000",
            "register": "EFUSE_CTRL_WR_LOCK",
            "value": "--",
            "module_name": "EFUSE",
            "bitnames": "--"
        },
        {
            "address": "0xF1240004",
            "register": "EFUSE_CTRL_CFG",
            "value": "--",
            "module_name": "EFUSE",
            "bitnames": "--"
        },
        {
            "address": "0xF1240030",
            "register": "EFUSE_CTRL_EFUSE_ISR",
            "value": "--",
            "module_name": "EFUSE",
            "bitnames": "--"
        }
    ],
    "SBI": [
        {
            "address": "0xF122000C",
            "register": "SLAVE_BOOT_SBI_STATUS",
            "value": "--",
            "module_name": "SBI",
            "bitnames": "--"
        },
        {
            "address": "0xF1220300",
            "register": "SLAVE_BOOT_SBI_IRQ_STATUS",
            "value": "--",
            "module_name": "SBI",
            "bitnames": "--"
        }
    ],
    "SPI": [
        {
            "address": "0XF1011814",
            "register": "OSPIDMA_DST_I_STS",
            "value": "--",
            "module_name": "OSPI",
            "bitnames": "--"
        },
        {
            "address": "0XF1010040",
            "register": "irq_status_reg",
            "value": "--",
            "module_name": "OSPI",
            "bitnames": "--"
        },
        {
            "address": "0xF1030814",
            "register": "QSPI_QSPIDMA_DST_I_STS",
            "value": "--",
            "module_name": "QSPI",
            "bitnames": "--"
        },
        {
            "address": "0xF1030808",
            "register": "QSPI_QSPIDMA_DST_STS",
            "value": "--",
            "module_name": "QSPI",
            "bitnames": "--"
        }
    ],
    "USB2": [
        {
            "address": "0xFF9D0064",
            "register": "IR_status",
            "value": "--",
            "module_name": "USB2",
            "bitnames": "--"
        }
    ],
    "I2C": [
        {
            "address": "0XF1000010",
            "register": "XIICPS_ISR_OFFSET",
            "value": "--",
            "module_name": "I2C",
            "bitnames": "--"
        },
        {
            "address": "0XF1000004",
            "register": "XIICPS_SR_OFFSET",
            "value": "--",
            "module_name": "I2C",
            "bitnames": "--"
        }
    ],
    "PUF": [
        {
            "address": "0xF0050024",
            "register": "status",
            "value": "--",
            "module_name": "PUF",
            "bitnames": "--"
        },
        {
            "address": "0xF0050068",
            "register": "dbg2",
            "value": "--",
            "module_name": "PUF",
            "bitnames": "--"
        }
    ],
    "Analog": [
        {
            "address": "0xF1160004",
            "register": "glitch_det_status",
            "value": "--",
            "module_name": "ANALOG",
            "bitnames": "--"
        },
        {
            "address": "0xF1160040",
            "register": "PMC_ANLG_ISR",
            "value": "--",
            "module_name": "ANALOG",
            "bitnames": "--"
        }
    ]
}
export const NoCoffset = {
    "nmu_offset": "0x30",
    "nsu_offset": "0x44"
}
export const xsdbhelp = [
    {
        "category": "breakpoints",
        "command": "bpadd",
        "description": "Set a software or hardware breakpoint at address,function or set a read/write watchpoint,or set a cross-trigger breakpoint."
    },
    {
        "category": "breakpoints",
        "command": "bpdisable",
        "description": "Disable the Breakpoints/Watchpoints specified by <id-list>  or disable all the breakpoints when \"-all\" option is used."
    },
    {
        "category": "breakpoints",
        "command": "bpenable",
        "description": "Enable the Breakpoints/Watchpoints specified by <id-list> or enable all the breakpoints when \"-all\" option is used."
    },
    {
        "category": "breakpoints",
        "command": "bplist",
        "description": "List all the Beakpoints/Watchpoints along with brief status for each Breakpoint and the target on which it is set."
    },
    {
        "category": "breakpoints",
        "command": "bpremove",
        "description": "Remove the Breakpoints/Watchpoints specified by <id-list> or remove all the breakpoints when \"-all\" option is used."
    },
    {
        "category": "breakpoints",
        "command": "bpstatus",
        "description": "Print the status of a Breakpoint/Watchpoint specified by <id>.Status includes the target information for which the Breakpoint is active and also Breakpoint hitcount or error message."
    },
    {
        "category": "connections",
        "command": "connect",
        "description": "Allows users to connect to a server, list connections or switch between connections."
    },
    {
        "category": "connections",
        "command": "disconnect",
        "description": "Disconnect from active channel."
    },
    {
        "category": "connections",
        "command": "gdbremote connect",
        "description": "Connect to a GDB remote server, for example qemu. A special client named tcfgdbclient is used to connect to remote GDB server."
    },
    {
        "category": "connections",
        "command": "gdbremote disconnect",
        "description": "Disconnect from GDB remote server, for example qemu."
    },
    {
        "category": "connections",
        "command": "targets",
        "description": "List available targets."
    },
    {
        "category": "device",
        "command": "device program",
        "description": "Program PDI or BIT file into device device"
    },
    {
        "category": "device",
        "command": "device status",
        "description": "Return device JTAG Register status or list of available registers if no name is given"
    },
    {
        "category": "download",
        "command": "dow",
        "description": "Download ELF file <file> to active target."
    },
    {
        "category": "download",
        "command": "fpga",
        "description": "Configure FPGA with given bitstream."
    },
    {
        "category": "download",
        "command": "verify",
        "description": "Verify if the ELF file <file> is downloaded correctly to active target."
    },
    {
        "category": "jtag",
        "command": "jtag claim",
        "description": "Set claim mask for current JTAG device."
    },
    {
        "category": "jtag",
        "command": "jtag device_properties",
        "description": "Get JTAG device properties associated with <idcode>"
    },
    {
        "category": "jtag",
        "command": "jtag disclaim",
        "description": "Clear claim mask for current JTAG device."
    },
    {
        "category": "jtag",
        "command": "jtag frequency",
        "description": "Get JTAG clock frequency for current scan chain."
    },
    {
        "category": "jtag",
        "command": "jtag lock",
        "description": "Lock JTAG scan chain containing current JTAG target."
    },
    {
        "category": "jtag",
        "command": "jtag sequence",
        "description": "The jtag sequence command creates a new sequence object.After creation the sequence is empty."
    },
    {
        "category": "jtag",
        "command": "jtag servers",
        "description": "List, open, and close JTAG servers.JTAG servers are use to implement support for different types of JTAG cables.An open JTAG server will enumberate or connect to available JTAG ports."
    },
    {
        "category": "jtag",
        "command": "jtag skew",
        "description": "Get JTAG clock skew for current scan chain."
    },
    {
        "category": "jtag",
        "command": "jtag targets",
        "description": "List available JTAG targets."
    },
    {
        "category": "jtag",
        "command": "jtag unlock",
        "description": "Unlock JTAG scan chain containing current JTAG target."
    },
    {
        "category": "memory",
        "command": "init_ps",
        "description": "Initialize PS by running initalization sequence specified by init_data.The init_data contains mask_write,mask_poll and mask_delay commands in meta data format.mask_delay adds delay in milli seconds"
    },
    {
        "category": "memory",
        "command": "mask_poll",
        "description": "Read the address specified by addr and poll until the bit specified by mask is set to 1 or until timeout.If expected-value is specified,then compare the bit[s] aginst the expected value.A time delay specified by sleep is added between two successive poll cycles.Default sleep is set to 10 msec,and timeout is set to 100 iterations."
    },
    {
        "category": "memory",
        "command": "mask_write",
        "description": "Read the address specified by addr, clear the bits specified by mask,set the bits specified by data and write back the result to addr"
    },
    {
        "category": "memory",
        "command": "memmap",
        "description": " Add/remove a memory map entry for the active target."
    },
    {
        "category": "memory",
        "command": "mrd",
        "description": "Read <num> data values from the active target's memory address specified by <address>."
    },
    {
        "category": "memory",
        "command": "mwr",
        "description": "Write <num> data values from list of <values> to active target memory address specified by <address>.If <num> is not specified, all the <values> from the list are written sequentially from the address specifed by <address>.If <num> is greater than the size of the <values> list,the last word in the list is filled at the remaining address locations."
    },
    {
        "category": "memory",
        "command": "osa",
        "description": "Configure OS awareness for the symbol file <file-name> specified.If no symbol file is specifed and only one symbol file exists in target's memory map, then that symbol file is used.If no symbol file is specifed and multiple symbol files exist in target's memory map, then an error is thrown."
    },
    {
        "category": "miscellaneous",
        "command": "configparams",
        "description": "List name and description for available configuration parameters.Configuration parameters can be global or connection specific, therefore the list of available configuration parameters and their value may change depending on current connection."
    },
    {
        "category": "miscellaneous",
        "command": "loadhw",
        "description": "Load a Vivado HW design,and set the memory map for the current target.If the current target is a parent for a group of processors,memory map is set for all its child processors. If current target is a processor,memory map is set for all the child processors of it's parent.This command returns the HW design object."
    },
    {
        "category": "miscellaneous",
        "command": "mb_drrd",
        "description": "Read a MicroBlaze Debug Register available on MDM.cmd is 8-bit MDM command to access a Debug Register.bitlen is the register width.Returns hex register value."
    },
    {
        "category": "miscellaneous",
        "command": "mb_drwr",
        "description": "Write to MicroBlaze Debug Register available on MDM.cmd is 8-bit MDM command to access a Debug Register.data is the register value and bitlen is the register width."
    },
    {
        "category": "miscellaneous",
        "command": "mdm_drrd",
        "description": "Read a MDM Debug Register.cmd is 8-bit MDM command to access a Debug Register and bitlen is the register width.Returns hex register value."
    },
    {
        "category": "miscellaneous",
        "command": "mdm_drwr",
        "description": "Write to MDM Debug Register.cmd is 8-bit MDM command to access a Debug Register.data is the register value and bitlen is the register width."
    },
    {
        "category": "miscellaneous",
        "command": "unloadhw",
        "description": "Close the Vivado HW design which was opened during loadhw command,and clear the memory map for the current target.If the current target is a parent for a group of processors,memory map is cleared for all its child processors.If the current target is a processor,memory map is cleared for all the child processors of it's parent.This command does not clear memory map explicitly set by users."
    },
    {
        "category": "miscellaneous",
        "command": "version",
        "description": "Get SDK or TCF server version. When no option is specified,SDK build version is returned."
    },
    {
        "category": "miscellaneous",
        "command": "xsdbserver disconnect",
        "description": "Disconnect current XSDB server connection."
    },
    {
        "category": "miscellaneous",
        "command": "xsdbserver start",
        "description": "Start XSDB command server listener.XSDB command server allows external processes to connect to XSDB to evaluate commands.The XSDB server reads commands from the connected socket one line at the time.After evaluation,a line is sent back starting with 'okay' or 'error' followed by the result or error as a backslash quoted string."
    },
    {
        "category": "miscellaneous",
        "command": "xsdbserver stop",
        "description": "Stop XSDB command server listener and disconnect connected client if any."
    },
    {
        "category": "miscellaneous",
        "command": "xsdbserver version",
        "description": "Return XSDB command server protocol version."
    },
    {
        "category": "registers",
        "command": "rrd",
        "description": "Read registers or register definitions.For a processor core target,processor core register can be read.For a target representing a group of processor cores,system registers or IOU registers can be read."
    },
    {
        "category": "registers",
        "command": "rwr",
        "description": "Write the <value> to active target register specified by <reg> For a processor core target, processor core register can be written to.For a target representing a group of processor cores,system registers or IOU registers can be written."
    },
    {
        "category": "reset",
        "command": "rst",
        "description": "Reset the active target."
    },
    {
        "category": "running",
        "command": "backtrace",
        "description": "Return stack trace for current target.Target must be stopped.Use debug information for best result."
    },
    {
        "category": "running",
        "command": "con",
        "description": "Resume execution of active target."
    },
    {
        "category": "running",
        "command": "dis",
        "description": "Disassemble <num> instructions at address specified by <address>.The keyword 'pc' can be used to disassemble instructions at current PC.Default value for <num> is 1."
    },
    {
        "category": "running",
        "command": "locals",
        "description": "Get or set the value of a variable specified by <variable-name>.When variable name and value are not specified, values of all the local variables are returned.Elements of a complex data types like a structure can be accessed through '.' operator. For example, var1.int_type refers to int_type element in var1 struct.Array elements can be accessed through their indices.For example,array1[0] refers to the element at index 0 in array1."
    },
    {
        "category": "running",
        "command": "mbprofile",
        "description": "Configure and run the MB profiler, a non-intrusive profiler for profiling the application running on MB.The output file is generated in gmon.out format.The results can be viewed using gprof editor.In case of cycle count,an annotated disassembly file is also generated clearly marking time taken for execution of instructions."
    },
    {
        "category": "running",
        "command": "mbtrace",
        "description": "Configure and run MB program and event trace for tracing the application running on MB.The output is the disassembly of the executed program."
    },
    {
        "category": "running",
        "command": "nxt",
        "description": "Resume execution of the active target until control reaches instruction that belongs to a different line of source code, but runs any functions called at full speed.Error is returned if line number information not available.If <count> is greater than 1, repeat <count> times.Default value of count is 1."
    },
    {
        "category": "running",
        "command": "nxti",
        "description": "Step over a single machine instruction. If instruction is function call,execution continues until control returns from the function.If <count> is greater than 1, repeat <count> times.Default value of count is 1."
    },
    {
        "category": "running",
        "command": "print",
        "description": "Get or set the value of an expression specified by <expression>.The <expression> can include constants,local/global variables,CPU registers,or any operator,but pre-processor macros defined through #define are not supported.CPU registers can be specified in the format {$r1},where r1 is the register name.Elements of a complex data types like a structure can be accessed through '.' operator.For example, var1.int_type refers to int_type element in var1 struct.Array elements can be accessed through their indices.For example,array1[0] refers to the element at index 0 in array1."
    },
    {
        "category": "running",
        "command": "profile",
        "description": "Configure and run the GNU profiler.The profiling needs to enabled while building bsp and application to be profiled."
    },
    {
        "category": "running",
        "command": "state",
        "description": "Return the current execution state of target."
    },
    {
        "category": "running",
        "command": "stop",
        "description": "Suspend execution of active target."
    },
    {
        "category": "running",
        "command": "stp",
        "description": "Resume execution of the active target until control reaches instruction that belongs to different line of source code.If a function is called,stop at first line of the function code.Error is returned if line number information not available.If <count> is greater than 1,repeat <count> times.Default value of count is 1."
    },
    {
        "category": "running",
        "command": "stpi",
        "description": "Execute a single machine instruction. If instruction is function call,stop at first instruction of the function code,If <count> is greater than 1,repeat <count> times.Default value of count is 1."
    },
    {
        "category": "running",
        "command": "stpout",
        "description": "Resume execution of current target until control returns from current function.If <count> is greater than 1,repeat <count> times.Default value of count is 1."
    },
    {
        "category": "stream",
        "command": "jtagterminal",
        "description": "Start/Stop a Jtag based hyper-terminal to communicate with ARM DCC or MDM UART interface."
    },
    {
        "category": "stream",
        "command": "readjtaguart",
        "description": "Start/Stop reading from the ARM DCC or MDM Uart Tx interface.Jtag Uart output can be printed on stdout or redirected to a file."
    },
    {
        "category": "svf",
        "command": "svf con",
        "description": "Record resuming the execution of active target to SVF file."
    },
    {
        "category": "svf",
        "command": "svf config",
        "description": "Configure and generate SVF file"
    },
    {
        "category": "svf",
        "command": "svf delay",
        "description": "Record delay in tcks to SVF file."
    },
    {
        "category": "svf",
        "command": "svf dow",
        "description": "Record downloading of elf file <elf file> to the memory."
    },
    {
        "category": "svf",
        "command": "svf generate",
        "description": "Generate SVF file in the path specified in the config command."
    },
    {
        "category": "svf",
        "command": "svf mwr",
        "description": "Write <value> to the memory address specified by <address>."
    },
    {
        "category": "svf",
        "command": "svf stop",
        "description": "Record suspending execution of current target to SVF file."
    },
    {
        "category": "tfile",
        "command": "tfile close",
        "description": "Close specified file handle"
    },
    {
        "category": "tfile",
        "command": "tfile copy",
        "description": "Copy file <src> to <dest>"
    },
    {
        "category": "tfile",
        "command": "tfile fsetstat",
        "description": "Set file attributes for <handle>"
    },
    {
        "category": "tfile",
        "command": "tfile fstat",
        "description": "Get file attributes for <handle>"
    },
    {
        "category": "tfile",
        "command": "tfile ls",
        "description": "List directory content"
    },
    {
        "category": "tfile",
        "command": "tfile lstat",
        "description": "Get link file attributes for <path>"
    },
    {
        "category": "tfile",
        "command": "tfile mkdir",
        "description": "Make directory <path>"
    },
    {
        "category": "tfile",
        "command": "tfile open",
        "description": "Open specified file"
    },
    {
        "category": "tfile",
        "command": "tfile opendir",
        "description": "Open directory <path>"
    },
    {
        "category": "tfile",
        "command": "tfile read",
        "description": "Read from specified file handle"
    },
    {
        "category": "tfile",
        "command": "tfile readdir",
        "description": "Read directory"
    },
    {
        "category": "tfile",
        "command": "tfile readlink",
        "description": "Read link file"
    },
    {
        "category": "tfile",
        "command": "tfile realpath",
        "description": "Get real path of <path>"
    },
    {
        "category": "tfile",
        "command": "tfile remove",
        "description": "Remove <path>"
    },
    {
        "category": "tfile",
        "command": "tfile rename",
        "description": "Rename file or directory"
    },
    {
        "category": "tfile",
        "command": "tfile rmdir",
        "description": "Remove directory <path>"
    },
    {
        "category": "tfile",
        "command": "tfile roots",
        "description": "Get file system roots"
    },
    {
        "category": "tfile",
        "command": "tfile setstat",
        "description": "Set file attributes for <path>"
    },
    {
        "category": "tfile",
        "command": "tfile stat",
        "description": "Get file attributes for <path>"
    },
    {
        "category": "tfile",
        "command": "tfile symlink",
        "description": "Symlink file or directory"
    },
    {
        "category": "tfile",
        "command": "tfile user",
        "description": "Get user attributes"
    },
    {
        "category": "tfile",
        "command": "tfile write",
        "description": "Write to specified file handle"
    }
]