define(['./restArguments', './unzip'], function (restArguments, unzip) {
  // Zip together multiple lists into a single array -- elements that share
  // an index go together.
  var zip = restArguments(unzip);
  return zip;
});