define(['./restArguments', './difference'], function (restArguments, difference) {
  // Return a version of the array that does not contain the specified value(s).
  var without = restArguments(function (array, otherArrays) {
    return difference(array, otherArrays);
  });
  return without;
});