##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM5_DMA0_ATTR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfce10030]
lappend results [mem_read 0xfce10034]
lappend results [mem_read 0xfce10038]
lappend results [mem_read 0xfce1003c]
lappend results [mem_read 0xfce10040]
lappend results [mem_read 0xfce10044]
lappend results [mem_read 0xfce10048]
lappend results [mem_read 0xfce1004c]
lappend results [mem_read 0xfce10050]
lappend results [mem_read 0xfce10054]
lappend results [mem_read 0xfce10058]
lappend results [mem_read 0xfce1005c]
lappend results [mem_read 0xfce10060]
lappend results [mem_read 0xfce10064]
lappend results [mem_read 0xfce10068]
lappend results [mem_read 0xfce1006c]
lappend results [mem_read 0xfce10070]
lappend results [mem_read 0xfce10074]
lappend results [mem_read 0xfce10078]
lappend results [mem_read 0xfce1007c]
lappend results [mem_read 0xfce10080]
lappend results [mem_read 0xfce10084]
lappend results [mem_read 0xfce100c4]
lappend results [mem_read 0xfce100c8]
lappend results [mem_read 0xfce100cc]
lappend results [mem_read 0xfce100d0]
lappend results [mem_read 0xfce100d4]
lappend results [mem_read 0xfce100d8]
lappend results [mem_read 0xfce100dc]
lappend results [mem_read 0xfce100e0]
lappend results [mem_read 0xfce100e4]
lappend results [mem_read 0xfce100e8]
lappend results [mem_read 0xfce100ec]
lappend results [mem_read 0xfce100f0]
lappend results [mem_read 0xfce100f4]
lappend results [mem_read 0xfce100f8]
lappend results [mem_read 0xfce100fc]
lappend results [mem_read 0xfce10100]
lappend results [mem_read 0xfce10104]
lappend results [mem_read 0xfce10108]
lappend results [mem_read 0xfce1010c]
lappend results [mem_read 0xfce10110]
lappend results [mem_read 0xfce10114]
lappend results [mem_read 0xfce10118]
lappend results [mem_read 0xfce1011c]
lappend results [mem_read 0xfce10120]
lappend results [mem_read 0xfce10124]
lappend results [mem_read 0xfce10128]
lappend results [mem_read 0xfce1012c]
lappend results [mem_read 0xfce10130]
lappend results [mem_read 0xfce10134]
lappend results [mem_read 0xfce10138]
lappend results [mem_read 0xfce1013c]
lappend results [mem_read 0xfce10140]
lappend results [mem_read 0xfce10144]
lappend results [mem_read 0xfce10148]
lappend results [mem_read 0xfce1014c]
lappend results [mem_read 0xfce10150]
lappend results [mem_read 0xfce10154]
lappend results [mem_read 0xfce10158]
lappend results [mem_read 0xfce1015c]
lappend results [mem_read 0xfce10160]
lappend results [mem_read 0xfce10164]
lappend results [mem_read 0xfce1016c]
lappend results [mem_read 0xfce10170]
lappend results [mem_read 0xfce10174]
lappend results [mem_read 0xfce10178]
lappend results [mem_read 0xfce1017c]
lappend results [mem_read 0xfce10180]
lappend results [mem_read 0xfce10184]
lappend results [mem_read 0xfce10188]
lappend results [mem_read 0xfce1018c]
lappend results [mem_read 0xfce10190]
lappend results [mem_read 0xfce10194]
lappend results [mem_read 0xfce10198]
lappend results [mem_read 0xfce1019c]
lappend results [mem_read 0xfce101a0]
lappend results [mem_read 0xfce101a4]
lappend results [mem_read 0xfce101a8]
lappend results [mem_read 0xfce101ac]
lappend results [mem_read 0xfce101b0]
lappend results [mem_read 0xfce101b4]
lappend results [mem_read 0xfce101b8]
lappend results [mem_read 0xfce101bc]
lappend results [mem_read 0xfce101c0]
lappend results [mem_read 0xfce101c4]
lappend results [mem_read 0xfce101c8]
lappend results [mem_read 0xfce101cc]
lappend results [mem_read 0xfce101d0]
lappend results [mem_read 0xfce101d4]
lappend results [mem_read 0xfce101d8]
lappend results [mem_read 0xfce101dc]
lappend results [mem_read 0xfce101e0]
lappend results [mem_read 0xfce101e4]
lappend results [mem_read 0xfce101e8]
lappend results [mem_read 0xfce101ec]
lappend results [mem_read 0xfce101f0]
lappend results [mem_read 0xfce101f4]
lappend results [mem_read 0xfce101f8]
lappend results [mem_read 0xfce101fc]
lappend results [mem_read 0xfce10200]
lappend results [mem_read 0xfce10204]
lappend results [mem_read 0xfce10208]
lappend results [mem_read 0xfce1020c]
lappend results [mem_read 0xfce10210]
lappend results [mem_read 0xfce10214]
lappend results [mem_read 0xfce10218]
lappend results [mem_read 0xfce1021c]
lappend results [mem_read 0xfce10220]
lappend results [mem_read 0xfce10224]
lappend results [mem_read 0xfce10228]
lappend results [mem_read 0xfce1022c]
lappend results [mem_read 0xfce10230]
lappend results [mem_read 0xfce10234]
lappend results [mem_read 0xfce10238]
lappend results [mem_read 0xfce1023c]
lappend results [mem_read 0xfce10240]
lappend results [mem_read 0xfce10244]
lappend results [mem_read 0xfce10248]
lappend results [mem_read 0xfce1024c]
lappend results [mem_read 0xfce10250]
lappend results [mem_read 0xfce10254]
lappend results [mem_read 0xfce10258]
lappend results [mem_read 0xfce1025c]
lappend results [mem_read 0xfce10260]
lappend results [mem_read 0xfce10264]
lappend results [mem_read 0xfce10268]
lappend results [mem_read 0xfce1026c]
lappend results [mem_read 0xfce10270]
lappend results [mem_read 0xfce10274]
lappend results [mem_read 0xfce10278]
lappend results [mem_read 0xfce1027c]
lappend results [mem_read 0xfce10280]
lappend results [mem_read 0xfce10284]
lappend results [mem_read 0xfce10288]
lappend results [mem_read 0xfce1028c]
lappend results [mem_read 0xfce10290]
lappend results [mem_read 0xfce10294]
lappend results [mem_read 0xfce10298]
lappend results [mem_read 0xfce1029c]
lappend results [mem_read 0xfce102a0]
lappend results [mem_read 0xfce102a4]
lappend results [mem_read 0xfce102a8]
lappend results [mem_read 0xfce102ac]
lappend results [mem_read 0xfce102b0]
lappend results [mem_read 0xfce102b4]
lappend results [mem_read 0xfce102b8]
lappend results [mem_read 0xfce102bc]
lappend results [mem_read 0xfce102c0]
lappend results [mem_read 0xfce102c4]
lappend results [mem_read 0xfce102c8]
lappend results [mem_read 0xfce102cc]
lappend results [mem_read 0xfce102d0]
lappend results [mem_read 0xfce102d4]
lappend results [mem_read 0xfce102d8]
lappend results [mem_read 0xfce102dc]
lappend results [mem_read 0xfce102e0]
lappend results [mem_read 0xfce102e4]
lappend results [mem_read 0xfce102e8]
lappend results [mem_read 0xfce102ec]
lappend results [mem_read 0xfce102f0]
lappend results [mem_read 0xfce102f4]
lappend results [mem_read 0xfce102f8]
lappend results [mem_read 0xfce102fc]
lappend results [mem_read 0xfce10300]
lappend results [mem_read 0xfce10304]
lappend results [mem_read 0xfce10308]
lappend results [mem_read 0xfce1030c]
lappend results [mem_read 0xfce10310]
lappend results [mem_read 0xfce10314]
lappend results [mem_read 0xfce10318]
lappend results [mem_read 0xfce1031c]
lappend results [mem_read 0xfce10320]
lappend results [mem_read 0xfce10324]
lappend results [mem_read 0xfce10328]
lappend results [mem_read 0xfce1032c]
lappend results [mem_read 0xfce10330]
lappend results [mem_read 0xfce10334]
lappend results [mem_read 0xfce10338]
lappend results [mem_read 0xfce1033c]
lappend results [mem_read 0xfce10340]
lappend results [mem_read 0xfce10344]
lappend results [mem_read 0xfce10348]
lappend results [mem_read 0xfce1034c]
lappend results [mem_read 0xfce10350]
lappend results [mem_read 0xfce10354]
lappend results [mem_read 0xfce10358]
lappend results [mem_read 0xfce1035c]
lappend results [mem_read 0xfce10360]
lappend results [mem_read 0xfce10364]
lappend results [mem_read 0xfce10368]
lappend results [mem_read 0xfce1036c]
lappend results [mem_read 0xfce10370]
lappend results [mem_read 0xfce10374]
lappend results [mem_read 0xfce10378]
lappend results [mem_read 0xfce1037c]
lappend results [mem_read 0xfce10380]
lappend results [mem_read 0xfce10384]
lappend results [mem_read 0xfce10388]
lappend results [mem_read 0xfce1038c]
lappend results [mem_read 0xfce10390]
lappend results [mem_read 0xfce10394]
lappend results [mem_read 0xfce10398]
lappend results [mem_read 0xfce1039c]
lappend results [mem_read 0xfce103a0]
lappend results [mem_read 0xfce103a4]
lappend results [mem_read 0xfce103a8]
lappend results [mem_read 0xfce103ac]
lappend results [mem_read 0xfce103b0]
lappend results [mem_read 0xfce103b4]
lappend results [mem_read 0xfce103b8]
lappend results [mem_read 0xfce103bc]
lappend results [mem_read 0xfce103c0]
lappend results [mem_read 0xfce103c4]
lappend results [mem_read 0xfce103c8]
lappend results [mem_read 0xfce103cc]
lappend results [mem_read 0xfce103d0]
lappend results [mem_read 0xfce103d4]
lappend results [mem_read 0xfce103d8]
lappend results [mem_read 0xfce103dc]
lappend results [mem_read 0xfce103e0]
lappend results [mem_read 0xfce103e4]
lappend results [mem_read 0xfce103e8]
lappend results [mem_read 0xfce103ec]
lappend results [mem_read 0xfce103f0]
lappend results [mem_read 0xfce103f4]
lappend results [mem_read 0xfce103f8]
lappend results [mem_read 0xfce103fc]
lappend results [mem_read 0xfce10400]
lappend results [mem_read 0xfce10404]
lappend results [mem_read 0xfce10408]
lappend results [mem_read 0xfce1040c]
lappend results [mem_read 0xfce10410]
lappend results [mem_read 0xfce10414]
lappend results [mem_read 0xfce10418]
lappend results [mem_read 0xfce1041c]
lappend results [mem_read 0xfce10420]
lappend results [mem_read 0xfce10424]
lappend results [mem_read 0xfce10428]
lappend results [mem_read 0xfce1042c]
lappend results [mem_read 0xfce10430]
lappend results [mem_read 0xfce10434]
lappend results [mem_read 0xfce10438]
lappend results [mem_read 0xfce1043c]
lappend results [mem_read 0xfce10440]
lappend results [mem_read 0xfce10444]
lappend results [mem_read 0xfce10448]
lappend results [mem_read 0xfce1044c]
lappend results [mem_read 0xfce10450]
lappend results [mem_read 0xfce10454]
lappend results [mem_read 0xfce10458]
lappend results [mem_read 0xfce1045c]
lappend results [mem_read 0xfce10460]
lappend results [mem_read 0xfce10464]
lappend results [mem_read 0xfce10468]
lappend results [mem_read 0xfce1046c]
lappend results [mem_read 0xfce10470]
lappend results [mem_read 0xfce10474]
lappend results [mem_read 0xfce10478]
lappend results [mem_read 0xfce1047c]
lappend results [mem_read 0xfce10480]
lappend results [mem_read 0xfce10484]
lappend results [mem_read 0xfce10488]
lappend results [mem_read 0xfce1048c]
lappend results [mem_read 0xfce10490]
lappend results [mem_read 0xfce10494]
lappend results [mem_read 0xfce10498]
lappend results [mem_read 0xfce1049c]
lappend results [mem_read 0xfce104a0]
lappend results [mem_read 0xfce104a4]
lappend results [mem_read 0xfce104a8]
lappend results [mem_read 0xfce104ac]
lappend results [mem_read 0xfce104b0]
lappend results [mem_read 0xfce104b4]
lappend results [mem_read 0xfce104b8]
lappend results [mem_read 0xfce104bc]
lappend results [mem_read 0xfce104c0]
lappend results [mem_read 0xfce104c4]
lappend results [mem_read 0xfce104c8]
lappend results [mem_read 0xfce104cc]
lappend results [mem_read 0xfce104d0]
lappend results [mem_read 0xfce104d4]
lappend results [mem_read 0xfce104d8]
lappend results [mem_read 0xfce104dc]
lappend results [mem_read 0xfce104e0]
lappend results [mem_read 0xfce104e4]
lappend results [mem_read 0xfce104e8]
lappend results [mem_read 0xfce104ec]
lappend results [mem_read 0xfce104f0]
lappend results [mem_read 0xfce104f4]
lappend results [mem_read 0xfce104f8]
lappend results [mem_read 0xfce104fc]
lappend results [mem_read 0xfce10500]
lappend results [mem_read 0xfce10504]
lappend results [mem_read 0xfce10508]
lappend results [mem_read 0xfce1050c]
lappend results [mem_read 0xfce10510]
lappend results [mem_read 0xfce10514]
lappend results [mem_read 0xfce10518]
lappend results [mem_read 0xfce1051c]
lappend results [mem_read 0xfce10520]
lappend results [mem_read 0xfce10524]
lappend results [mem_read 0xfce10528]
lappend results [mem_read 0xfce1052c]
lappend results [mem_read 0xfce10530]
lappend results [mem_read 0xfce10534]
lappend results [mem_read 0xfce10538]
lappend results [mem_read 0xfce1053c]
lappend results [mem_read 0xfce10540]
lappend results [mem_read 0xfce10544]
lappend results [mem_read 0xfce10548]
lappend results [mem_read 0xfce1054c]
lappend results [mem_read 0xfce10550]
lappend results [mem_read 0xfce10554]
lappend results [mem_read 0xfce10558]
lappend results [mem_read 0xfce1055c]
lappend results [mem_read 0xfce10560]
lappend results [mem_read 0xfce10564]
lappend results [mem_read 0xfce10568]
lappend results [mem_read 0xfce1056c]
lappend results [mem_read 0xfce10570]
lappend results [mem_read 0xfce10574]
lappend results [mem_read 0xfce10578]
lappend results [mem_read 0xfce1057c]
lappend results [mem_read 0xfce10580]
lappend results [mem_read 0xfce10584]
lappend results [mem_read 0xfce10588]
lappend results [mem_read 0xfce1058c]
lappend results [mem_read 0xfce10590]
lappend results [mem_read 0xfce10594]
lappend results [mem_read 0xfce10598]
lappend results [mem_read 0xfce1059c]
lappend results [mem_read 0xfce105a0]
lappend results [mem_read 0xfce105a4]
lappend results [mem_read 0xfce105a8]
lappend results [mem_read 0xfce105ac]
lappend results [mem_read 0xfce105b0]
lappend results [mem_read 0xfce105b4]
lappend results [mem_read 0xfce105b8]
lappend results [mem_read 0xfce105bc]
lappend results [mem_read 0xfce105c0]
lappend results [mem_read 0xfce105c4]
lappend results [mem_read 0xfce105c8]
lappend results [mem_read 0xfce105cc]
lappend results [mem_read 0xfce105d0]
lappend results [mem_read 0xfce105d4]
lappend results [mem_read 0xfce105d8]
lappend results [mem_read 0xfce105dc]
lappend results [mem_read 0xfce105e0]
lappend results [mem_read 0xfce105e4]
lappend results [mem_read 0xfce105e8]
lappend results [mem_read 0xfce105ec]
lappend results [mem_read 0xfce105f0]
lappend results [mem_read 0xfce105f4]
lappend results [mem_read 0xfce105f8]
lappend results [mem_read 0xfce105fc]
lappend results [mem_read 0xfce10600]
lappend results [mem_read 0xfce10604]
lappend results [mem_read 0xfce10608]
lappend results [mem_read 0xfce1060c]
lappend results [mem_read 0xfce10610]
lappend results [mem_read 0xfce10614]
lappend results [mem_read 0xfce10618]
lappend results [mem_read 0xfce1061c]
lappend results [mem_read 0xfce10620]
lappend results [mem_read 0xfce10624]
lappend results [mem_read 0xfce10628]
lappend results [mem_read 0xfce1062c]
lappend results [mem_read 0xfce10630]
lappend results [mem_read 0xfce10634]
lappend results [mem_read 0xfce10638]
lappend results [mem_read 0xfce1063c]
lappend results [mem_read 0xfce10640]
lappend results [mem_read 0xfce10644]
lappend results [mem_read 0xfce10648]
lappend results [mem_read 0xfce1064c]
lappend results [mem_read 0xfce10650]
lappend results [mem_read 0xfce10654]
lappend results [mem_read 0xfce10658]
lappend results [mem_read 0xfce1065c]
lappend results [mem_read 0xfce10660]
lappend results [mem_read 0xfce10664]
lappend results [mem_read 0xfce10668]
lappend results [mem_read 0xfce1066c]
lappend results [mem_read 0xfce10670]
lappend results [mem_read 0xfce10674]
lappend results [mem_read 0xfce10678]
lappend results [mem_read 0xfce1067c]
lappend results [mem_read 0xfce10680]
lappend results [mem_read 0xfce10684]
lappend results [mem_read 0xfce10688]
lappend results [mem_read 0xfce1068c]
lappend results [mem_read 0xfce10690]
lappend results [mem_read 0xfce10694]
lappend results [mem_read 0xfce10698]
lappend results [mem_read 0xfce1069c]
lappend results [mem_read 0xfce106a0]
lappend results [mem_read 0xfce106a4]
lappend results [mem_read 0xfce106a8]
lappend results [mem_read 0xfce106ac]
lappend results [mem_read 0xfce106b0]
lappend results [mem_read 0xfce106b4]
lappend results [mem_read 0xfce106b8]
lappend results [mem_read 0xfce106bc]
lappend results [mem_read 0xfce106c0]
lappend results [mem_read 0xfce106c4]
lappend results [mem_read 0xfce106c8]
lappend results [mem_read 0xfce106cc]
lappend results [mem_read 0xfce106d0]
lappend results [mem_read 0xfce106d4]
lappend results [mem_read 0xfce106d8]
lappend results [mem_read 0xfce106dc]
lappend results [mem_read 0xfce106e0]
lappend results [mem_read 0xfce106e4]
lappend results [mem_read 0xfce106e8]
lappend results [mem_read 0xfce106ec]
lappend results [mem_read 0xfce106f0]
lappend results [mem_read 0xfce106f4]
lappend results [mem_read 0xfce106f8]
lappend results [mem_read 0xfce106fc]
lappend results [mem_read 0xfce10700]
lappend results [mem_read 0xfce10704]
lappend results [mem_read 0xfce10708]
lappend results [mem_read 0xfce1070c]
lappend results [mem_read 0xfce10710]
lappend results [mem_read 0xfce10714]
lappend results [mem_read 0xfce10718]
lappend results [mem_read 0xfce1071c]
lappend results [mem_read 0xfce10720]
lappend results [mem_read 0xfce10724]
lappend results [mem_read 0xfce10728]
lappend results [mem_read 0xfce1072c]
lappend results [mem_read 0xfce10730]
lappend results [mem_read 0xfce10734]
lappend results [mem_read 0xfce10738]
lappend results [mem_read 0xfce1073c]
lappend results [mem_read 0xfce10740]
lappend results [mem_read 0xfce10744]
lappend results [mem_read 0xfce10748]
lappend results [mem_read 0xfce1074c]
lappend results [mem_read 0xfce10750]
lappend results [mem_read 0xfce10754]
lappend results [mem_read 0xfce10758]
lappend results [mem_read 0xfce1075c]
lappend results [mem_read 0xfce10760]
lappend results [mem_read 0xfce10764]
lappend results [mem_read 0xfce10768]
lappend results [mem_read 0xfce1076c]
lappend results [mem_read 0xfce10770]
lappend results [mem_read 0xfce10774]
lappend results [mem_read 0xfce10778]
lappend results [mem_read 0xfce1077c]
