/*
* Copyright (c) 2021 Xilinx, Inc.
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
* associated documentation files (the "Software"), to deal in the Software without restriction, including 
* without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
* copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
* the following conditions: 
* 
* The above copyright notice and this permission notice shall be included in all copies or substantial 
* portions of the Software. 
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
* LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
* 
*
*
*/
import {html, PolymerElement} from '@polymer/polymer/polymer-element.js';
import '../../../shared-styles.js';
import { configObj } from '../../../shared/constants.js';

class ClockAITree extends PolymerElement {
  static get template() {
    return html`
    <style include="shared-styles">
      .card {
        margin: 15px 0 0 0;
        padding: 0px 15px 15px 15px;
      }
    </style>
    <div class="card">
      <custom-tab key="me" lists={{lists}}></custom-tab>
    </div>
    `;
  }

  static get properties() {
    return {
      lists: {
        type: Array,
        value: [],
      }
    };
  }

  connectedCallback() {
    super.connectedCallback();
    const keys = configObj['meclockdata']['metreekeys'];
    this.lists = _.map(keys, (key) => {
        return {
          key: "clockai_tree",
          permission: true,
          displayname: key
        }
    });
    import('../../../shared/custom_tab.js');
  }

  ready() {
    super.ready();
  }
}

window.customElements.define('clockaiengine-tree', ClockAITree);