##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: FPD_CCI_CORE
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfd000000]
lappend results [mem_read 0xfd000008]
lappend results [mem_read 0xfd00000c]
lappend results [mem_read 0xfd000010]
lappend results [mem_read 0xfd000014]
lappend results [mem_read 0xfd000100]
lappend results [mem_read 0xfd001000]
lappend results [mem_read 0xfd001004]
lappend results [mem_read 0xfd001100]
lappend results [mem_read 0xfd001104]
lappend results [mem_read 0xfd001110]
lappend results [mem_read 0xfd002000]
lappend results [mem_read 0xfd002004]
lappend results [mem_read 0xfd002100]
lappend results [mem_read 0xfd002104]
lappend results [mem_read 0xfd002110]
lappend results [mem_read 0xfd003000]
lappend results [mem_read 0xfd003004]
lappend results [mem_read 0xfd003100]
lappend results [mem_read 0xfd003104]
lappend results [mem_read 0xfd003110]
lappend results [mem_read 0xfd004000]
lappend results [mem_read 0xfd004004]
lappend results [mem_read 0xfd004100]
lappend results [mem_read 0xfd004104]
lappend results [mem_read 0xfd004110]
lappend results [mem_read 0xfd005000]
lappend results [mem_read 0xfd005004]
lappend results [mem_read 0xfd005100]
lappend results [mem_read 0xfd005104]
lappend results [mem_read 0xfd005110]
lappend results [mem_read 0xfd006000]
lappend results [mem_read 0xfd006004]
lappend results [mem_read 0xfd006100]
lappend results [mem_read 0xfd006104]
lappend results [mem_read 0xfd006110]
lappend results [mem_read 0xfd010000]
lappend results [mem_read 0xfd010004]
lappend results [mem_read 0xfd010008]
lappend results [mem_read 0xfd01000c]
lappend results [mem_read 0xfd020000]
lappend results [mem_read 0xfd020004]
lappend results [mem_read 0xfd020008]
lappend results [mem_read 0xfd02000c]
lappend results [mem_read 0xfd030000]
lappend results [mem_read 0xfd030004]
lappend results [mem_read 0xfd030008]
lappend results [mem_read 0xfd03000c]
lappend results [mem_read 0xfd040000]
lappend results [mem_read 0xfd040004]
lappend results [mem_read 0xfd040008]
lappend results [mem_read 0xfd04000c]
lappend results [mem_read 0xfd050000]
lappend results [mem_read 0xfd050004]
lappend results [mem_read 0xfd050008]
lappend results [mem_read 0xfd05000c]
lappend results [mem_read 0xfd060000]
lappend results [mem_read 0xfd060004]
lappend results [mem_read 0xfd060008]
lappend results [mem_read 0xfd06000c]
lappend results [mem_read 0xfd070000]
lappend results [mem_read 0xfd070004]
lappend results [mem_read 0xfd070008]
lappend results [mem_read 0xfd07000c]
lappend results [mem_read 0xfd080000]
lappend results [mem_read 0xfd080004]
lappend results [mem_read 0xfd080008]
lappend results [mem_read 0xfd08000c]
