var _createAssigner = require('./_createAssigner.js');

var keys = require('./keys.js'); // Assigns a given object with all the own properties in the passed-in
// object(s).
// (https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object/assign)


var extendOwn = _createAssigner(keys);

module.exports = extendOwn;