define(['./underscore'], function (underscore) {
  // Helper function to continue chaining intermediate results.
  function chainResult(instance, obj) {
    return instance._chain ? underscore(obj).chain() : obj;
  }

  return chainResult;
});