##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CANFD1
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff070000]
lappend results [mem_read 0xff070004]
lappend results [mem_read 0xff070008]
lappend results [mem_read 0xff07000c]
lappend results [mem_read 0xff070010]
lappend results [mem_read 0xff070014]
lappend results [mem_read 0xff070018]
lappend results [mem_read 0xff07001c]
lappend results [mem_read 0xff070020]
lappend results [mem_read 0xff070024]
lappend results [mem_read 0xff070028]
lappend results [mem_read 0xff070088]
lappend results [mem_read 0xff07008c]
lappend results [mem_read 0xff070090]
lappend results [mem_read 0xff070094]
lappend results [mem_read 0xff070098]
lappend results [mem_read 0xff07009c]
lappend results [mem_read 0xff0700a0]
lappend results [mem_read 0xff0700a4]
lappend results [mem_read 0xff0700e0]
lappend results [mem_read 0xff0700e8]
lappend results [mem_read 0xff0700ec]
lappend results [mem_read 0xff070100]
lappend results [mem_read 0xff070104]
lappend results [mem_read 0xff070108]
lappend results [mem_read 0xff07010c]
lappend results [mem_read 0xff070110]
lappend results [mem_read 0xff070114]
lappend results [mem_read 0xff070118]
lappend results [mem_read 0xff07011c]
lappend results [mem_read 0xff070120]
lappend results [mem_read 0xff070124]
lappend results [mem_read 0xff070128]
lappend results [mem_read 0xff07012c]
lappend results [mem_read 0xff070130]
lappend results [mem_read 0xff070134]
lappend results [mem_read 0xff070138]
lappend results [mem_read 0xff07013c]
lappend results [mem_read 0xff070140]
lappend results [mem_read 0xff070144]
lappend results [mem_read 0xff070a00]
lappend results [mem_read 0xff070a04]
lappend results [mem_read 0xff072000]
lappend results [mem_read 0xff072004]
lappend results [mem_read 0xff072100]
lappend results [mem_read 0xff072104]
lappend results [mem_read 0xff072108]
lappend results [mem_read 0xff07210c]
lappend results [mem_read 0xff072110]
lappend results [mem_read 0xff072114]
lappend results [mem_read 0xff072118]
lappend results [mem_read 0xff07211c]
lappend results [mem_read 0xff072120]
lappend results [mem_read 0xff072124]
lappend results [mem_read 0xff072128]
lappend results [mem_read 0xff07212c]
lappend results [mem_read 0xff072130]
lappend results [mem_read 0xff072134]
lappend results [mem_read 0xff072138]
lappend results [mem_read 0xff07213c]
lappend results [mem_read 0xff072140]
lappend results [mem_read 0xff072144]
lappend results [mem_read 0xff074100]
lappend results [mem_read 0xff074104]
lappend results [mem_read 0xff074108]
lappend results [mem_read 0xff07410c]
lappend results [mem_read 0xff074110]
lappend results [mem_read 0xff074114]
lappend results [mem_read 0xff074118]
lappend results [mem_read 0xff07411c]
lappend results [mem_read 0xff074120]
lappend results [mem_read 0xff074124]
lappend results [mem_read 0xff074128]
lappend results [mem_read 0xff07412c]
lappend results [mem_read 0xff074130]
lappend results [mem_read 0xff074134]
lappend results [mem_read 0xff074138]
lappend results [mem_read 0xff07413c]
lappend results [mem_read 0xff074140]
lappend results [mem_read 0xff074144]
