##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: LPD_XPPU
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff990000]
lappend results [mem_read 0xff990004]
lappend results [mem_read 0xff990008]
lappend results [mem_read 0xff99000c]
lappend results [mem_read 0xff990010]
lappend results [mem_read 0xff990014]
lappend results [mem_read 0xff990018]
lappend results [mem_read 0xff99001c]
lappend results [mem_read 0xff990020]
lappend results [mem_read 0xff99003c]
lappend results [mem_read 0xff990044]
lappend results [mem_read 0xff990048]
lappend results [mem_read 0xff99004c]
lappend results [mem_read 0xff990054]
lappend results [mem_read 0xff990058]
lappend results [mem_read 0xff99005c]
lappend results [mem_read 0xff990100]
lappend results [mem_read 0xff990104]
lappend results [mem_read 0xff990108]
lappend results [mem_read 0xff99010c]
lappend results [mem_read 0xff990110]
lappend results [mem_read 0xff990114]
lappend results [mem_read 0xff990118]
lappend results [mem_read 0xff99011c]
lappend results [mem_read 0xff990120]
lappend results [mem_read 0xff990124]
lappend results [mem_read 0xff990128]
lappend results [mem_read 0xff99012c]
lappend results [mem_read 0xff990130]
lappend results [mem_read 0xff990134]
lappend results [mem_read 0xff990138]
lappend results [mem_read 0xff99013c]
lappend results [mem_read 0xff990140]
lappend results [mem_read 0xff990144]
lappend results [mem_read 0xff990148]
lappend results [mem_read 0xff99014c]
lappend results [mem_read 0xff990150]
lappend results [mem_read 0xff990154]
lappend results [mem_read 0xff9900fc]
lappend results [mem_read 0xff991000]
lappend results [mem_read 0xff991004]
lappend results [mem_read 0xff991008]
lappend results [mem_read 0xff99100c]
lappend results [mem_read 0xff991010]
lappend results [mem_read 0xff991014]
lappend results [mem_read 0xff991018]
lappend results [mem_read 0xff99101c]
lappend results [mem_read 0xff991020]
lappend results [mem_read 0xff991024]
lappend results [mem_read 0xff991028]
lappend results [mem_read 0xff99102c]
lappend results [mem_read 0xff991030]
lappend results [mem_read 0xff991034]
lappend results [mem_read 0xff991038]
lappend results [mem_read 0xff99103c]
lappend results [mem_read 0xff991040]
lappend results [mem_read 0xff991044]
lappend results [mem_read 0xff991048]
lappend results [mem_read 0xff99104c]
lappend results [mem_read 0xff991050]
lappend results [mem_read 0xff991054]
lappend results [mem_read 0xff991058]
lappend results [mem_read 0xff99105c]
lappend results [mem_read 0xff991060]
lappend results [mem_read 0xff991064]
lappend results [mem_read 0xff991068]
lappend results [mem_read 0xff99106c]
lappend results [mem_read 0xff991070]
lappend results [mem_read 0xff991074]
lappend results [mem_read 0xff991078]
lappend results [mem_read 0xff99107c]
lappend results [mem_read 0xff991080]
lappend results [mem_read 0xff991084]
lappend results [mem_read 0xff991088]
lappend results [mem_read 0xff99108c]
lappend results [mem_read 0xff991090]
lappend results [mem_read 0xff991094]
lappend results [mem_read 0xff991098]
lappend results [mem_read 0xff99109c]
lappend results [mem_read 0xff9910a0]
lappend results [mem_read 0xff9910a4]
lappend results [mem_read 0xff9910a8]
lappend results [mem_read 0xff9910ac]
lappend results [mem_read 0xff9910b0]
lappend results [mem_read 0xff9910b4]
lappend results [mem_read 0xff9910b8]
lappend results [mem_read 0xff9910bc]
lappend results [mem_read 0xff9910c0]
lappend results [mem_read 0xff9910c4]
lappend results [mem_read 0xff9910c8]
lappend results [mem_read 0xff9910cc]
lappend results [mem_read 0xff9910d0]
lappend results [mem_read 0xff9910d4]
lappend results [mem_read 0xff9910d8]
lappend results [mem_read 0xff9910dc]
lappend results [mem_read 0xff9910e0]
lappend results [mem_read 0xff9910e4]
lappend results [mem_read 0xff9910e8]
lappend results [mem_read 0xff9910ec]
lappend results [mem_read 0xff9910f0]
lappend results [mem_read 0xff9910f4]
lappend results [mem_read 0xff9910f8]
lappend results [mem_read 0xff9910fc]
lappend results [mem_read 0xff991100]
lappend results [mem_read 0xff991104]
lappend results [mem_read 0xff991108]
lappend results [mem_read 0xff99110c]
lappend results [mem_read 0xff991110]
lappend results [mem_read 0xff991114]
lappend results [mem_read 0xff991118]
lappend results [mem_read 0xff99111c]
lappend results [mem_read 0xff991120]
lappend results [mem_read 0xff991124]
lappend results [mem_read 0xff991128]
lappend results [mem_read 0xff99112c]
lappend results [mem_read 0xff991130]
lappend results [mem_read 0xff991134]
lappend results [mem_read 0xff991138]
lappend results [mem_read 0xff99113c]
lappend results [mem_read 0xff991140]
lappend results [mem_read 0xff991144]
lappend results [mem_read 0xff991148]
lappend results [mem_read 0xff99114c]
lappend results [mem_read 0xff991150]
lappend results [mem_read 0xff991154]
lappend results [mem_read 0xff991158]
lappend results [mem_read 0xff99115c]
lappend results [mem_read 0xff991160]
lappend results [mem_read 0xff991164]
lappend results [mem_read 0xff991168]
lappend results [mem_read 0xff99116c]
lappend results [mem_read 0xff991170]
lappend results [mem_read 0xff991174]
lappend results [mem_read 0xff991178]
lappend results [mem_read 0xff99117c]
lappend results [mem_read 0xff991180]
lappend results [mem_read 0xff991184]
lappend results [mem_read 0xff991188]
lappend results [mem_read 0xff99118c]
lappend results [mem_read 0xff991190]
lappend results [mem_read 0xff991194]
lappend results [mem_read 0xff991198]
lappend results [mem_read 0xff99119c]
lappend results [mem_read 0xff9911a0]
lappend results [mem_read 0xff9911a4]
lappend results [mem_read 0xff9911a8]
lappend results [mem_read 0xff9911ac]
lappend results [mem_read 0xff9911b0]
lappend results [mem_read 0xff9911b4]
lappend results [mem_read 0xff9911b8]
lappend results [mem_read 0xff9911bc]
lappend results [mem_read 0xff9911c0]
lappend results [mem_read 0xff9911c4]
lappend results [mem_read 0xff9911c8]
lappend results [mem_read 0xff9911cc]
lappend results [mem_read 0xff9911d0]
lappend results [mem_read 0xff9911d4]
lappend results [mem_read 0xff9911d8]
lappend results [mem_read 0xff9911dc]
lappend results [mem_read 0xff9911e0]
lappend results [mem_read 0xff9911e4]
lappend results [mem_read 0xff9911e8]
lappend results [mem_read 0xff9911ec]
lappend results [mem_read 0xff9911f0]
lappend results [mem_read 0xff9911f4]
lappend results [mem_read 0xff9911f8]
lappend results [mem_read 0xff9911fc]
lappend results [mem_read 0xff991200]
lappend results [mem_read 0xff991204]
lappend results [mem_read 0xff991208]
lappend results [mem_read 0xff99120c]
lappend results [mem_read 0xff991210]
lappend results [mem_read 0xff991214]
lappend results [mem_read 0xff991218]
lappend results [mem_read 0xff99121c]
lappend results [mem_read 0xff991220]
lappend results [mem_read 0xff991224]
lappend results [mem_read 0xff991228]
lappend results [mem_read 0xff99122c]
lappend results [mem_read 0xff991230]
lappend results [mem_read 0xff991234]
lappend results [mem_read 0xff991238]
lappend results [mem_read 0xff99123c]
lappend results [mem_read 0xff991240]
lappend results [mem_read 0xff991244]
lappend results [mem_read 0xff991248]
lappend results [mem_read 0xff99124c]
lappend results [mem_read 0xff991250]
lappend results [mem_read 0xff991254]
lappend results [mem_read 0xff991258]
lappend results [mem_read 0xff99125c]
lappend results [mem_read 0xff991260]
lappend results [mem_read 0xff991264]
lappend results [mem_read 0xff991268]
lappend results [mem_read 0xff99126c]
lappend results [mem_read 0xff991270]
lappend results [mem_read 0xff991274]
lappend results [mem_read 0xff991278]
lappend results [mem_read 0xff99127c]
lappend results [mem_read 0xff991280]
lappend results [mem_read 0xff991284]
lappend results [mem_read 0xff991288]
lappend results [mem_read 0xff99128c]
lappend results [mem_read 0xff991290]
lappend results [mem_read 0xff991294]
lappend results [mem_read 0xff991298]
lappend results [mem_read 0xff99129c]
lappend results [mem_read 0xff9912a0]
lappend results [mem_read 0xff9912a4]
lappend results [mem_read 0xff9912a8]
lappend results [mem_read 0xff9912ac]
lappend results [mem_read 0xff9912b0]
lappend results [mem_read 0xff9912b4]
lappend results [mem_read 0xff9912b8]
lappend results [mem_read 0xff9912bc]
lappend results [mem_read 0xff9912c0]
lappend results [mem_read 0xff9912c4]
lappend results [mem_read 0xff9912c8]
lappend results [mem_read 0xff9912cc]
lappend results [mem_read 0xff9912d0]
lappend results [mem_read 0xff9912d4]
lappend results [mem_read 0xff9912d8]
lappend results [mem_read 0xff9912dc]
lappend results [mem_read 0xff9912e0]
lappend results [mem_read 0xff9912e4]
lappend results [mem_read 0xff9912e8]
lappend results [mem_read 0xff9912ec]
lappend results [mem_read 0xff9912f0]
lappend results [mem_read 0xff9912f4]
lappend results [mem_read 0xff9912f8]
lappend results [mem_read 0xff9912fc]
lappend results [mem_read 0xff991300]
lappend results [mem_read 0xff991304]
lappend results [mem_read 0xff991308]
lappend results [mem_read 0xff99130c]
lappend results [mem_read 0xff991310]
lappend results [mem_read 0xff991314]
lappend results [mem_read 0xff991318]
lappend results [mem_read 0xff99131c]
lappend results [mem_read 0xff991320]
lappend results [mem_read 0xff991324]
lappend results [mem_read 0xff991328]
lappend results [mem_read 0xff99132c]
lappend results [mem_read 0xff991330]
lappend results [mem_read 0xff991334]
lappend results [mem_read 0xff991338]
lappend results [mem_read 0xff99133c]
lappend results [mem_read 0xff991340]
lappend results [mem_read 0xff991344]
lappend results [mem_read 0xff991348]
lappend results [mem_read 0xff99134c]
lappend results [mem_read 0xff991350]
lappend results [mem_read 0xff991354]
lappend results [mem_read 0xff991358]
lappend results [mem_read 0xff99135c]
lappend results [mem_read 0xff991360]
lappend results [mem_read 0xff991364]
lappend results [mem_read 0xff991368]
lappend results [mem_read 0xff99136c]
lappend results [mem_read 0xff991370]
lappend results [mem_read 0xff991374]
lappend results [mem_read 0xff991378]
lappend results [mem_read 0xff99137c]
lappend results [mem_read 0xff991380]
lappend results [mem_read 0xff991384]
lappend results [mem_read 0xff991388]
lappend results [mem_read 0xff99138c]
lappend results [mem_read 0xff991390]
lappend results [mem_read 0xff991394]
lappend results [mem_read 0xff991398]
lappend results [mem_read 0xff99139c]
lappend results [mem_read 0xff9913a0]
lappend results [mem_read 0xff9913a4]
lappend results [mem_read 0xff9913a8]
lappend results [mem_read 0xff9913ac]
lappend results [mem_read 0xff9913b0]
lappend results [mem_read 0xff9913b4]
lappend results [mem_read 0xff9913b8]
lappend results [mem_read 0xff9913bc]
lappend results [mem_read 0xff9913c0]
lappend results [mem_read 0xff9913c4]
lappend results [mem_read 0xff9913c8]
lappend results [mem_read 0xff9913cc]
lappend results [mem_read 0xff9913d0]
lappend results [mem_read 0xff9913d4]
lappend results [mem_read 0xff9913d8]
lappend results [mem_read 0xff9913dc]
lappend results [mem_read 0xff9913e0]
lappend results [mem_read 0xff9913e4]
lappend results [mem_read 0xff9913e8]
lappend results [mem_read 0xff9913ec]
lappend results [mem_read 0xff9913f0]
lappend results [mem_read 0xff9913f4]
lappend results [mem_read 0xff9913f8]
lappend results [mem_read 0xff9913fc]
lappend results [mem_read 0xff991600]
lappend results [mem_read 0xff991604]
lappend results [mem_read 0xff991608]
lappend results [mem_read 0xff99160c]
lappend results [mem_read 0xff991610]
lappend results [mem_read 0xff991614]
lappend results [mem_read 0xff991618]
lappend results [mem_read 0xff99161c]
lappend results [mem_read 0xff991620]
lappend results [mem_read 0xff991624]
lappend results [mem_read 0xff991628]
lappend results [mem_read 0xff99162c]
lappend results [mem_read 0xff991630]
lappend results [mem_read 0xff991634]
lappend results [mem_read 0xff991638]
lappend results [mem_read 0xff99163c]
lappend results [mem_read 0xff991640]
