##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_CPM_ELA2A
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0f40000]
lappend results [mem_read 0xf0f40004]
lappend results [mem_read 0xf0f40008]
lappend results [mem_read 0xf0f40010]
lappend results [mem_read 0xf0f40020]
lappend results [mem_read 0xf0f40024]
lappend results [mem_read 0xf0f40028]
lappend results [mem_read 0xf0f4002c]
lappend results [mem_read 0xf0f40040]
lappend results [mem_read 0xf0f40044]
lappend results [mem_read 0xf0f40048]
lappend results [mem_read 0xf0f4004c]
lappend results [mem_read 0xf0f40100]
lappend results [mem_read 0xf0f40104]
lappend results [mem_read 0xf0f40108]
lappend results [mem_read 0xf0f4010c]
lappend results [mem_read 0xf0f40110]
lappend results [mem_read 0xf0f40114]
lappend results [mem_read 0xf0f40120]
lappend results [mem_read 0xf0f40130]
lappend results [mem_read 0xf0f40134]
lappend results [mem_read 0xf0f40140]
lappend results [mem_read 0xf0f40144]
lappend results [mem_read 0xf0f40148]
lappend results [mem_read 0xf0f4014c]
lappend results [mem_read 0xf0f40180]
lappend results [mem_read 0xf0f40184]
lappend results [mem_read 0xf0f40188]
lappend results [mem_read 0xf0f4018c]
lappend results [mem_read 0xf0f40200]
lappend results [mem_read 0xf0f40204]
lappend results [mem_read 0xf0f40208]
lappend results [mem_read 0xf0f4020c]
lappend results [mem_read 0xf0f40210]
lappend results [mem_read 0xf0f40214]
lappend results [mem_read 0xf0f40220]
lappend results [mem_read 0xf0f40230]
lappend results [mem_read 0xf0f40234]
lappend results [mem_read 0xf0f40240]
lappend results [mem_read 0xf0f40244]
lappend results [mem_read 0xf0f40248]
lappend results [mem_read 0xf0f4024c]
lappend results [mem_read 0xf0f40280]
lappend results [mem_read 0xf0f40284]
lappend results [mem_read 0xf0f40288]
lappend results [mem_read 0xf0f4028c]
lappend results [mem_read 0xf0f40300]
lappend results [mem_read 0xf0f40304]
lappend results [mem_read 0xf0f40308]
lappend results [mem_read 0xf0f4030c]
lappend results [mem_read 0xf0f40310]
lappend results [mem_read 0xf0f40314]
lappend results [mem_read 0xf0f40320]
lappend results [mem_read 0xf0f40330]
lappend results [mem_read 0xf0f40334]
lappend results [mem_read 0xf0f40340]
lappend results [mem_read 0xf0f40344]
lappend results [mem_read 0xf0f40348]
lappend results [mem_read 0xf0f4034c]
lappend results [mem_read 0xf0f40380]
lappend results [mem_read 0xf0f40384]
lappend results [mem_read 0xf0f40388]
lappend results [mem_read 0xf0f4038c]
lappend results [mem_read 0xf0f40400]
lappend results [mem_read 0xf0f40404]
lappend results [mem_read 0xf0f40408]
lappend results [mem_read 0xf0f4040c]
lappend results [mem_read 0xf0f40410]
lappend results [mem_read 0xf0f40414]
lappend results [mem_read 0xf0f40420]
lappend results [mem_read 0xf0f40430]
lappend results [mem_read 0xf0f40434]
lappend results [mem_read 0xf0f40440]
lappend results [mem_read 0xf0f40444]
lappend results [mem_read 0xf0f40448]
lappend results [mem_read 0xf0f4044c]
lappend results [mem_read 0xf0f40480]
lappend results [mem_read 0xf0f40484]
lappend results [mem_read 0xf0f40488]
lappend results [mem_read 0xf0f4048c]
lappend results [mem_read 0xf0f40500]
lappend results [mem_read 0xf0f40504]
lappend results [mem_read 0xf0f40508]
lappend results [mem_read 0xf0f4050c]
lappend results [mem_read 0xf0f40510]
lappend results [mem_read 0xf0f40514]
lappend results [mem_read 0xf0f40520]
lappend results [mem_read 0xf0f40530]
lappend results [mem_read 0xf0f40534]
lappend results [mem_read 0xf0f40540]
lappend results [mem_read 0xf0f40544]
lappend results [mem_read 0xf0f40548]
lappend results [mem_read 0xf0f4054c]
lappend results [mem_read 0xf0f40580]
lappend results [mem_read 0xf0f40584]
lappend results [mem_read 0xf0f40588]
lappend results [mem_read 0xf0f4058c]
lappend results [mem_read 0xf0f40ee8]
lappend results [mem_read 0xf0f40ef8]
lappend results [mem_read 0xf0f40f00]
lappend results [mem_read 0xf0f40fb0]
lappend results [mem_read 0xf0f40fb4]
lappend results [mem_read 0xf0f40fb8]
lappend results [mem_read 0xf0f40fbc]
lappend results [mem_read 0xf0f40fc0]
lappend results [mem_read 0xf0f40fc4]
lappend results [mem_read 0xf0f40fc8]
lappend results [mem_read 0xf0f40fcc]
