##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: PMC_GLOBAL
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf1110000]
lappend results [mem_read 0xf1110004]
lappend results [mem_read 0xf1110008]
lappend results [mem_read 0xf1110010]
lappend results [mem_read 0xf1110014]
lappend results [mem_read 0xf1110018]
lappend results [mem_read 0xf111001c]
lappend results [mem_read 0xf1110030]
lappend results [mem_read 0xf1110034]
lappend results [mem_read 0xf1110038]
lappend results [mem_read 0xf111003c]
lappend results [mem_read 0xf1110040]
lappend results [mem_read 0xf1110050]
lappend results [mem_read 0xf1110054]
lappend results [mem_read 0xf1110058]
lappend results [mem_read 0xf111005c]
lappend results [mem_read 0xf1110060]
lappend results [mem_read 0xf1110064]
lappend results [mem_read 0xf1110100]
lappend results [mem_read 0xf111010c]
lappend results [mem_read 0xf1110110]
lappend results [mem_read 0xf1110114]
lappend results [mem_read 0xf1110118]
lappend results [mem_read 0xf111011c]
lappend results [mem_read 0xf1110120]
lappend results [mem_read 0xf1110210]
lappend results [mem_read 0xf1110214]
lappend results [mem_read 0xf1110218]
lappend results [mem_read 0xf111021c]
lappend results [mem_read 0xf1110220]
lappend results [mem_read 0xf1110310]
lappend results [mem_read 0xf1110314]
lappend results [mem_read 0xf1110318]
lappend results [mem_read 0xf111031c]
lappend results [mem_read 0xf1110320]
lappend results [mem_read 0xf1110324]
lappend results [mem_read 0xf1110328]
lappend results [mem_read 0xf1110410]
lappend results [mem_read 0xf1110414]
lappend results [mem_read 0xf1110418]
lappend results [mem_read 0xf111041c]
lappend results [mem_read 0xf1110420]
lappend results [mem_read 0xf1110430]
lappend results [mem_read 0xf1110434]
lappend results [mem_read 0xf1110438]
lappend results [mem_read 0xf111043c]
lappend results [mem_read 0xf1110440]
lappend results [mem_read 0xf1110444]
lappend results [mem_read 0xf1110500]
lappend results [mem_read 0xf1110518]
lappend results [mem_read 0xf1110610]
lappend results [mem_read 0xf1110614]
lappend results [mem_read 0xf1110618]
lappend results [mem_read 0xf111061c]
lappend results [mem_read 0xf1110620]
lappend results [mem_read 0xf1110624]
lappend results [mem_read 0xf1110634]
lappend results [mem_read 0xf1110800]
lappend results [mem_read 0xf1110880]
lappend results [mem_read 0xf1110884]
lappend results [mem_read 0xf1110900]
lappend results [mem_read 0xf1110910]
lappend results [mem_read 0xf1110930]
lappend results [mem_read 0xf1110934]
lappend results [mem_read 0xf1110938]
lappend results [mem_read 0xf111093c]
lappend results [mem_read 0xf1111018]
lappend results [mem_read 0xf111101c]
lappend results [mem_read 0xf1111020]
lappend results [mem_read 0xf1111040]
lappend results [mem_read 0xf1111044]
lappend results [mem_read 0xf1111048]
lappend results [mem_read 0xf111104c]
lappend results [mem_read 0xf1111050]
lappend results [mem_read 0xf1111054]
lappend results [mem_read 0xf1111058]
lappend results [mem_read 0xf111105c]
lappend results [mem_read 0xf1111100]
lappend results [mem_read 0xf1111200]
lappend results [mem_read 0xf1111204]
lappend results [mem_read 0xf1120000]
lappend results [mem_read 0xf1120004]
lappend results [mem_read 0xf1120100]
lappend results [mem_read 0xf1120200]
lappend results [mem_read 0xf1130000]
lappend results [mem_read 0xf1130004]
lappend results [mem_read 0xf1130010]
lappend results [mem_read 0xf1130014]
lappend results [mem_read 0xf1130020]
lappend results [mem_read 0xf1130024]
lappend results [mem_read 0xf1130028]
lappend results [mem_read 0xf1130030]
lappend results [mem_read 0xf1130034]
lappend results [mem_read 0xf1130038]
lappend results [mem_read 0xf1130040]
lappend results [mem_read 0xf1130044]
lappend results [mem_read 0xf1130048]
lappend results [mem_read 0xf1130050]
lappend results [mem_read 0xf1130054]
lappend results [mem_read 0xf1130058]
lappend results [mem_read 0xf1130060]
lappend results [mem_read 0xf1130064]
lappend results [mem_read 0xf1130068]
lappend results [mem_read 0xf1130070]
lappend results [mem_read 0xf1130074]
lappend results [mem_read 0xf1130078]
lappend results [mem_read 0xf1130080]
lappend results [mem_read 0xf1130084]
lappend results [mem_read 0xf1130088]
lappend results [mem_read 0xf1130090]
lappend results [mem_read 0xf1130094]
lappend results [mem_read 0xf1130098]
lappend results [mem_read 0xf1130100]
lappend results [mem_read 0xf1130200]
lappend results [mem_read 0xf1140000]
lappend results [mem_read 0xf1140004]
lappend results [mem_read 0xf1140008]
lappend results [mem_read 0xf114000c]
lappend results [mem_read 0xf1140014]
lappend results [mem_read 0xf1140018]
lappend results [mem_read 0xf114001c]
lappend results [mem_read 0xf1140020]
lappend results [mem_read 0xf1140028]
lappend results [mem_read 0xf114002c]
lappend results [mem_read 0xf1140030]
lappend results [mem_read 0xf1140034]
lappend results [mem_read 0xf114003c]
lappend results [mem_read 0xf1140040]
lappend results [mem_read 0xf1140044]
lappend results [mem_read 0xf1140048]
lappend results [mem_read 0xf1140050]
lappend results [mem_read 0xf1140054]
lappend results [mem_read 0xf1140058]
lappend results [mem_read 0xf114005c]
lappend results [mem_read 0xf11400a0]
lappend results [mem_read 0xf11400a4]
lappend results [mem_read 0xf11400a8]
lappend results [mem_read 0xf11400ac]
lappend results [mem_read 0xf1150000]
lappend results [mem_read 0xf1150004]
lappend results [mem_read 0xf1150008]
lappend results [mem_read 0xf115000c]
lappend results [mem_read 0xf1150010]
lappend results [mem_read 0xf1150018]
lappend results [mem_read 0xf1150020]
lappend results [mem_read 0xf1150024]
lappend results [mem_read 0xf1150028]
lappend results [mem_read 0xf115002c]
lappend results [mem_read 0xf1150030]
lappend results [mem_read 0xf1150034]
lappend results [mem_read 0xf1150038]
lappend results [mem_read 0xf115003c]
lappend results [mem_read 0xf1150040]
lappend results [mem_read 0xf1150044]
lappend results [mem_read 0xf1150048]
lappend results [mem_read 0xf115004c]
