/*
* Copyright (c) 2021 Xilinx, Inc.
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
* associated documentation files (the "Software"), to deal in the Software without restriction, including 
* without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
* copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
* the following conditions: 
* 
* The above copyright notice and this permission notice shall be included in all copies or substantial 
* portions of the Software. 
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
* LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
* 
*
*
*/
import {html, PolymerElement} from '@polymer/polymer/polymer-element.js';
import {api_url} from './../../shared/constants.js';
import './../../shared/module-table.js';
class psmoduleTable extends PolymerElement {
  static get template() {
    return html`
    <div id="psmoduleWidgetlevel">
    <module-table id="psModule" url={{url}} data-urltcl$={{urlTCL}} key="ps"></module-table>
    </div>
    <div id="psregisterWidgetlevel">
    </div>
    `;
  }
  static get properties() {
    return {
      url:{
        type: String,
        value: `${api_url}hardware/am012`
      },
      urlTCL:{
        type: String,
        value: `${api_url}generatetclfile`
      }
    };
  }
  ready(){
    super.ready();
    document.querySelector("#pageloader").style.display = "none";
  }
}

window.customElements.define('ps-module', psmoduleTable);