/**
@license
Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
'use strict';

/*
 * Polyfills loaded: HTML Imports, Custom Elements, Shady DOM/Shady CSS, platform polyfills, template
 * Used in: IE 11
 */

import './webcomponents-pf_js-index.js';
import './webcomponents-pf_dom-index.js';
import '../unresolved.js';
import '../flag-parser.js';
import '../../node_modules/@webcomponents/template/template.js';
import '../../node_modules/@webcomponents/shadydom/src/shadydom.js';
import '../../node_modules/@webcomponents/custom-elements/src/custom-elements.js';
import '../../node_modules/@webcomponents/shadycss/entrypoints/scoping-shim.js';
import '../../node_modules/@webcomponents/url/url.js';
