##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: XRAM_XMPU0
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff930000]
lappend results [mem_read 0xff930004]
lappend results [mem_read 0xff930008]
lappend results [mem_read 0xff93000c]
lappend results [mem_read 0xff930010]
lappend results [mem_read 0xff930014]
lappend results [mem_read 0xff930018]
lappend results [mem_read 0xff93001c]
lappend results [mem_read 0xff930020]
lappend results [mem_read 0xff930100]
lappend results [mem_read 0xff930104]
lappend results [mem_read 0xff930108]
lappend results [mem_read 0xff93010c]
lappend results [mem_read 0xff930110]
lappend results [mem_read 0xff930114]
lappend results [mem_read 0xff930118]
lappend results [mem_read 0xff93011c]
lappend results [mem_read 0xff930120]
lappend results [mem_read 0xff930124]
lappend results [mem_read 0xff930128]
lappend results [mem_read 0xff93012c]
lappend results [mem_read 0xff930130]
lappend results [mem_read 0xff930134]
lappend results [mem_read 0xff930138]
lappend results [mem_read 0xff93013c]
lappend results [mem_read 0xff930140]
lappend results [mem_read 0xff930144]
lappend results [mem_read 0xff930148]
lappend results [mem_read 0xff93014c]
lappend results [mem_read 0xff930150]
lappend results [mem_read 0xff930154]
lappend results [mem_read 0xff930158]
lappend results [mem_read 0xff93015c]
lappend results [mem_read 0xff930160]
lappend results [mem_read 0xff930164]
lappend results [mem_read 0xff930168]
lappend results [mem_read 0xff93016c]
lappend results [mem_read 0xff930170]
lappend results [mem_read 0xff930174]
lappend results [mem_read 0xff930178]
lappend results [mem_read 0xff93017c]
lappend results [mem_read 0xff930180]
lappend results [mem_read 0xff930184]
lappend results [mem_read 0xff930188]
lappend results [mem_read 0xff93018c]
lappend results [mem_read 0xff930190]
lappend results [mem_read 0xff930194]
lappend results [mem_read 0xff930198]
lappend results [mem_read 0xff93019c]
lappend results [mem_read 0xff9301a0]
lappend results [mem_read 0xff9301a4]
lappend results [mem_read 0xff9301a8]
lappend results [mem_read 0xff9301ac]
lappend results [mem_read 0xff9301b0]
lappend results [mem_read 0xff9301b4]
lappend results [mem_read 0xff9301b8]
lappend results [mem_read 0xff9301bc]
lappend results [mem_read 0xff9301c0]
lappend results [mem_read 0xff9301c4]
lappend results [mem_read 0xff9301c8]
lappend results [mem_read 0xff9301cc]
lappend results [mem_read 0xff9301d0]
lappend results [mem_read 0xff9301d4]
lappend results [mem_read 0xff9301d8]
lappend results [mem_read 0xff9301dc]
lappend results [mem_read 0xff9301e0]
lappend results [mem_read 0xff9301e4]
lappend results [mem_read 0xff9301e8]
lappend results [mem_read 0xff9301ec]
lappend results [mem_read 0xff9301f0]
lappend results [mem_read 0xff9301f4]
lappend results [mem_read 0xff9301f8]
lappend results [mem_read 0xff9301fc]
lappend results [mem_read 0xff930200]
lappend results [mem_read 0xff930204]
lappend results [mem_read 0xff930208]
lappend results [mem_read 0xff93020c]
lappend results [mem_read 0xff930210]
lappend results [mem_read 0xff930214]
lappend results [mem_read 0xff930218]
lappend results [mem_read 0xff93021c]
lappend results [mem_read 0xff930220]
lappend results [mem_read 0xff930224]
lappend results [mem_read 0xff930228]
lappend results [mem_read 0xff93022c]
lappend results [mem_read 0xff930238]
lappend results [mem_read 0xff93023c]
lappend results [mem_read 0xff930240]
lappend results [mem_read 0xff930244]
lappend results [mem_read 0xff930248]
lappend results [mem_read 0xff93024c]
lappend results [mem_read 0xff930250]
lappend results [mem_read 0xff930254]
lappend results [mem_read 0xff930258]
lappend results [mem_read 0xff93025c]
lappend results [mem_read 0xff930260]
lappend results [mem_read 0xff930264]
lappend results [mem_read 0xff930268]
lappend results [mem_read 0xff93026c]
lappend results [mem_read 0xff930270]
lappend results [mem_read 0xff930274]
lappend results [mem_read 0xff930278]
lappend results [mem_read 0xff93027c]
lappend results [mem_read 0xff930280]
lappend results [mem_read 0xff930284]
