##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM4_L2_CSR
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfcd04020]
lappend results [mem_read 0xfcd04040]
lappend results [mem_read 0xfcd04140]
lappend results [mem_read 0xfcd04148]
lappend results [mem_read 0xfcd04150]
lappend results [mem_read 0xfcd04158]
lappend results [mem_read 0xfcd04160]
lappend results [mem_read 0xfcd04168]
lappend results [mem_read 0xfcd04170]
lappend results [mem_read 0xfcd04178]
lappend results [mem_read 0xfcd04080]
lappend results [mem_read 0xfcd04028]
lappend results [mem_read 0xfcd04180]
lappend results [mem_read 0xfcd04100]
lappend results [mem_read 0xfcd04108]
lappend results [mem_read 0xfcd04030]
lappend results [mem_read 0xfcd04038]
lappend results [mem_read 0xfcd04088]
lappend results [mem_read 0xfcd04090]
lappend results [mem_read 0xfcd04098]
lappend results [mem_read 0xfcd040a0]
lappend results [mem_read 0xfcd040a8]
lappend results [mem_read 0xfcd040b0]
lappend results [mem_read 0xfcd040b8]
lappend results [mem_read 0xfcd040c0]
lappend results [mem_read 0xfcd040c8]
lappend results [mem_read 0xfcd04198]
lappend results [mem_read 0xfcd041a0]
lappend results [mem_read 0xfcd04190]
lappend results [mem_read 0xfcd04048]
lappend results [mem_read 0xfcd04050]
lappend results [mem_read 0xfcd041c0]
lappend results [mem_read 0xfcd041c8]
lappend results [mem_read 0xfcd041b8]
lappend results [mem_read 0xfcd041b0]
lappend results [mem_read 0xfcd041a8]
lappend results [mem_read 0xfcd041d0]
lappend results [mem_read 0xfcd04078]
lappend results [mem_read 0xfcd04000]
lappend results [mem_read 0xfcd04008]
lappend results [mem_read 0xfcd04010]
lappend results [mem_read 0xfcd04018]
lappend results [mem_read 0xfcd06050]
lappend results [mem_read 0xfcd06058]
lappend results [mem_read 0xfcd06048]
lappend results [mem_read 0xfcd06000]
lappend results [mem_read 0xfcd06008]
lappend results [mem_read 0xfcd06010]
lappend results [mem_read 0xfcd06018]
lappend results [mem_read 0xfcd06020]
lappend results [mem_read 0xfcd06028]
lappend results [mem_read 0xfcd06030]
lappend results [mem_read 0xfcd06038]
lappend results [mem_read 0xfcd060c8]
lappend results [mem_read 0xfcd06120]
lappend results [mem_read 0xfcd06118]
lappend results [mem_read 0xfcd06100]
lappend results [mem_read 0xfcd06110]
lappend results [mem_read 0xfcd06108]
lappend results [mem_read 0xfcd06180]
lappend results [mem_read 0xfcd06190]
lappend results [mem_read 0xfcd06188]
lappend results [mem_read 0xfcd06198]
lappend results [mem_read 0xfcd06070]
lappend results [mem_read 0xfcd06040]
lappend results [mem_read 0xfcd06140]
lappend results [mem_read 0xfcd06148]
lappend results [mem_read 0xfcd06150]
lappend results [mem_read 0xfcd06158]
lappend results [mem_read 0xfcd06160]
lappend results [mem_read 0xfcd06168]
lappend results [mem_read 0xfcd061c8]
lappend results [mem_read 0xfcd061d0]
lappend results [mem_read 0xfcd061c0]
lappend results [mem_read 0xfcd061e0]
lappend results [mem_read 0xfcd060e0]
lappend results [mem_read 0xfcd061d8]
lappend results [mem_read 0xfcd06078]
lappend results [mem_read 0xfcd060c0]
lappend results [mem_read 0xfcd060d0]
lappend results [mem_read 0xfcd060d8]
