##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: OSPI
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf1010000]
lappend results [mem_read 0xf1010004]
lappend results [mem_read 0xf1010008]
lappend results [mem_read 0xf101000c]
lappend results [mem_read 0xf1010010]
lappend results [mem_read 0xf1010014]
lappend results [mem_read 0xf1010018]
lappend results [mem_read 0xf101001c]
lappend results [mem_read 0xf1010020]
lappend results [mem_read 0xf1010024]
lappend results [mem_read 0xf1010028]
lappend results [mem_read 0xf101002c]
lappend results [mem_read 0xf1010038]
lappend results [mem_read 0xf101003c]
lappend results [mem_read 0xf1010040]
lappend results [mem_read 0xf1010044]
lappend results [mem_read 0xf1010048]
lappend results [mem_read 0xf1010050]
lappend results [mem_read 0xf1010054]
lappend results [mem_read 0xf1010058]
lappend results [mem_read 0xf1010060]
lappend results [mem_read 0xf1010064]
lappend results [mem_read 0xf1010068]
lappend results [mem_read 0xf101006c]
lappend results [mem_read 0xf1010070]
lappend results [mem_read 0xf1010074]
lappend results [mem_read 0xf1010078]
lappend results [mem_read 0xf101007c]
lappend results [mem_read 0xf1010080]
lappend results [mem_read 0xf101008c]
lappend results [mem_read 0xf1010090]
lappend results [mem_read 0xf1010094]
lappend results [mem_read 0xf10100a0]
lappend results [mem_read 0xf10100a4]
lappend results [mem_read 0xf10100a8]
lappend results [mem_read 0xf10100ac]
lappend results [mem_read 0xf10100b0]
lappend results [mem_read 0xf10100b4]
lappend results [mem_read 0xf10100b8]
lappend results [mem_read 0xf10100bc]
lappend results [mem_read 0xf10100c0]
lappend results [mem_read 0xf10100e0]
lappend results [mem_read 0xf10100e4]
lappend results [mem_read 0xf10100fc]
lappend results [mem_read 0xf1011000]
lappend results [mem_read 0xf1011008]
lappend results [mem_read 0xf101100c]
lappend results [mem_read 0xf1011014]
lappend results [mem_read 0xf1011018]
lappend results [mem_read 0xf101101c]
lappend results [mem_read 0xf1011020]
lappend results [mem_read 0xf1011024]
lappend results [mem_read 0xf1011800]
lappend results [mem_read 0xf1011804]
lappend results [mem_read 0xf1011808]
lappend results [mem_read 0xf101180c]
lappend results [mem_read 0xf1011814]
lappend results [mem_read 0xf1011818]
lappend results [mem_read 0xf101181c]
lappend results [mem_read 0xf1011820]
lappend results [mem_read 0xf1011824]
lappend results [mem_read 0xf1011828]
lappend results [mem_read 0xf1011ff8]
