##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: PMC_XMPU
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf12f0000]
lappend results [mem_read 0xf12f0004]
lappend results [mem_read 0xf12f0008]
lappend results [mem_read 0xf12f000c]
lappend results [mem_read 0xf12f0010]
lappend results [mem_read 0xf12f0014]
lappend results [mem_read 0xf12f0018]
lappend results [mem_read 0xf12f001c]
lappend results [mem_read 0xf12f0020]
lappend results [mem_read 0xf12f0100]
lappend results [mem_read 0xf12f0104]
lappend results [mem_read 0xf12f0108]
lappend results [mem_read 0xf12f010c]
lappend results [mem_read 0xf12f0110]
lappend results [mem_read 0xf12f0114]
lappend results [mem_read 0xf12f0118]
lappend results [mem_read 0xf12f011c]
lappend results [mem_read 0xf12f0120]
lappend results [mem_read 0xf12f0124]
lappend results [mem_read 0xf12f0128]
lappend results [mem_read 0xf12f012c]
lappend results [mem_read 0xf12f0130]
lappend results [mem_read 0xf12f0134]
lappend results [mem_read 0xf12f0138]
lappend results [mem_read 0xf12f013c]
lappend results [mem_read 0xf12f0140]
lappend results [mem_read 0xf12f0144]
lappend results [mem_read 0xf12f0148]
lappend results [mem_read 0xf12f014c]
lappend results [mem_read 0xf12f0150]
lappend results [mem_read 0xf12f0154]
lappend results [mem_read 0xf12f0158]
lappend results [mem_read 0xf12f015c]
lappend results [mem_read 0xf12f0160]
lappend results [mem_read 0xf12f0164]
lappend results [mem_read 0xf12f0168]
lappend results [mem_read 0xf12f016c]
lappend results [mem_read 0xf12f0170]
lappend results [mem_read 0xf12f0174]
lappend results [mem_read 0xf12f0178]
lappend results [mem_read 0xf12f017c]
lappend results [mem_read 0xf12f0180]
lappend results [mem_read 0xf12f0184]
lappend results [mem_read 0xf12f0188]
lappend results [mem_read 0xf12f018c]
lappend results [mem_read 0xf12f0190]
lappend results [mem_read 0xf12f0194]
lappend results [mem_read 0xf12f0198]
lappend results [mem_read 0xf12f019c]
lappend results [mem_read 0xf12f01a0]
lappend results [mem_read 0xf12f01a4]
lappend results [mem_read 0xf12f01a8]
lappend results [mem_read 0xf12f01ac]
lappend results [mem_read 0xf12f01b0]
lappend results [mem_read 0xf12f01b4]
lappend results [mem_read 0xf12f01b8]
lappend results [mem_read 0xf12f01bc]
lappend results [mem_read 0xf12f01c0]
lappend results [mem_read 0xf12f01c4]
lappend results [mem_read 0xf12f01c8]
lappend results [mem_read 0xf12f01cc]
lappend results [mem_read 0xf12f01d0]
lappend results [mem_read 0xf12f01d4]
lappend results [mem_read 0xf12f01d8]
lappend results [mem_read 0xf12f01dc]
lappend results [mem_read 0xf12f01e0]
lappend results [mem_read 0xf12f01e4]
lappend results [mem_read 0xf12f01e8]
lappend results [mem_read 0xf12f01ec]
lappend results [mem_read 0xf12f01f0]
lappend results [mem_read 0xf12f01f4]
lappend results [mem_read 0xf12f01f8]
lappend results [mem_read 0xf12f01fc]
lappend results [mem_read 0xf12f0200]
lappend results [mem_read 0xf12f0204]
lappend results [mem_read 0xf12f0208]
lappend results [mem_read 0xf12f020c]
lappend results [mem_read 0xf12f0210]
lappend results [mem_read 0xf12f0214]
lappend results [mem_read 0xf12f0218]
lappend results [mem_read 0xf12f021c]
lappend results [mem_read 0xf12f0220]
lappend results [mem_read 0xf12f0224]
lappend results [mem_read 0xf12f0228]
lappend results [mem_read 0xf12f022c]
lappend results [mem_read 0xf12f0238]
lappend results [mem_read 0xf12f023c]
lappend results [mem_read 0xf12f0240]
lappend results [mem_read 0xf12f0244]
lappend results [mem_read 0xf12f0248]
lappend results [mem_read 0xf12f024c]
lappend results [mem_read 0xf12f0250]
lappend results [mem_read 0xf12f0254]
lappend results [mem_read 0xf12f0258]
lappend results [mem_read 0xf12f025c]
lappend results [mem_read 0xf12f0260]
lappend results [mem_read 0xf12f0264]
lappend results [mem_read 0xf12f0268]
lappend results [mem_read 0xf12f026c]
lappend results [mem_read 0xf12f0270]
lappend results [mem_read 0xf12f0274]
lappend results [mem_read 0xf12f0278]
lappend results [mem_read 0xf12f027c]
lappend results [mem_read 0xf12f0280]
lappend results [mem_read 0xf12f0284]
