##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
Module_Name	Name	Address	 Access_Type	Reset_Value	Description
CPM4_CRX	RST_DBG	0XFCA00300	rw	 0X00000001	Reset for SOC Debug Logic
CPM4_CRX	RST_PCIE_CONFIG	0XFCA00304	rw	 0X00000001	Reset for PCIe configuration Registers (PCIE_ATTRIB*)
CPM4_CRX	RST_PCIE_CORE0	0XFCA00308	rw	 0X00000001	Reset for PCIe core0
CPM4_CRX	RST_PCIE_CORE1	0XFCA0030C	rw	 0X00000001	Reset for PCIe core1
CPM4_CRX	RST_CMN	0XFCA00314	rw	 0X00000001	Reset for CMN block
CPM4_CRX	RST_L2_0	0XFCA00318	rw	 0X00000001	Reset for L2 block(includes CHI RegSlice and interrupt synchronization)
CPM4_CRX	RST_L2_1	0XFCA0031C	rw	 0X00000001	Reset for L2 block(includes CHI RegSlice and interrupt synchronization)
CPM4_CRX	RST_ADDR_REMAP	0XFCA00320	rw	 0X00000001	Reset for Address Remap block
CPM4_CRX	RST_CPI0	0XFCA00324	rw	 0X00000001	Reset for CPI0
CPM4_CRX	RST_CPI1	0XFCA00328	rw	 0X00000001	Reset for CPI1