var underscore = require('./underscore.js'); // Start chaining a wrapped Underscore object.


function chain(obj) {
  var instance = underscore(obj);
  instance._chain = true;
  return instance;
}

module.exports = chain;