define(['./_tagTester', './_setup'], function (_tagTester, _setup) {
  var isFunction = _tagTester('Function'); // Optimize `isFunction` if appropriate. Work around some `typeof` bugs in old
  // v8, IE 11 (#1621), Safari 8 (#1929), and PhantomJS (#2236).


  var nodelist = _setup.root.document && _setup.root.document.childNodes;

  if (typeof /./ != 'function' && typeof Int8Array != 'object' && typeof nodelist != 'function') {
    isFunction = function (obj) {
      return typeof obj == 'function' || false;
    };
  }

  var isFunction$1 = isFunction;
  return isFunction$1;
});