##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: PSM_INT_GPV
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xffc9f080]
lappend results [mem_read 0xffc9f084]
lappend results [mem_read 0xffc9f088]
lappend results [mem_read 0xffc9f08c]
lappend results [mem_read 0xffc9f090]
lappend results [mem_read 0xffc9f094]
lappend results [mem_read 0xffc9f098]
lappend results [mem_read 0xffc9f09c]
lappend results [mem_read 0xffc9f0a0]
lappend results [mem_read 0xffc9f0a4]
lappend results [mem_read 0xffc9f0a8]
lappend results [mem_read 0xffc9f0ac]
lappend results [mem_read 0xffc9f0b0]
lappend results [mem_read 0xffc9f0b4]
lappend results [mem_read 0xffc9f0b8]
lappend results [mem_read 0xffc9f0bc]
lappend results [mem_read 0xffc9f0c0]
lappend results [mem_read 0xffc9f0c4]
lappend results [mem_read 0xffc9f0c8]
lappend results [mem_read 0xffc9f0cc]
lappend results [mem_read 0xffc9f0d0]
lappend results [mem_read 0xffc9f0d4]
lappend results [mem_read 0xffc9f0d8]
lappend results [mem_read 0xffc9f0dc]
lappend results [mem_read 0xffc9f0e0]
lappend results [mem_read 0xffc9f0e4]
lappend results [mem_read 0xffc9f0e8]
lappend results [mem_read 0xffc9f0ec]
lappend results [mem_read 0xffc9f0f0]
lappend results [mem_read 0xffc9f0f4]
lappend results [mem_read 0xffc9f0f8]
lappend results [mem_read 0xffc9f0fc]
lappend results [mem_read 0xffc9f100]
lappend results [mem_read 0xffc9f104]
lappend results [mem_read 0xffc9f108]
lappend results [mem_read 0xffc9f10c]
lappend results [mem_read 0xffc9f110]
lappend results [mem_read 0xffc9f114]
lappend results [mem_read 0xffc9f118]
lappend results [mem_read 0xffc9f11c]
lappend results [mem_read 0xffc9f120]
lappend results [mem_read 0xffc9f124]
lappend results [mem_read 0xffc9f128]
lappend results [mem_read 0xffc9f12c]
lappend results [mem_read 0xffc9f130]
lappend results [mem_read 0xffc9f134]
lappend results [mem_read 0xffc9f138]
lappend results [mem_read 0xffc9f13c]
lappend results [mem_read 0xffc9f140]
lappend results [mem_read 0xffc9f144]
lappend results [mem_read 0xffc9f148]
lappend results [mem_read 0xffc9f14c]
lappend results [mem_read 0xffc9f150]
lappend results [mem_read 0xffc9f154]
lappend results [mem_read 0xffc9f158]
lappend results [mem_read 0xffc9f15c]
lappend results [mem_read 0xffc9f160]
lappend results [mem_read 0xffc9f164]
lappend results [mem_read 0xffc9f168]
lappend results [mem_read 0xffc9f16c]
lappend results [mem_read 0xffc9f170]
lappend results [mem_read 0xffc9f174]
lappend results [mem_read 0xffc9f178]
lappend results [mem_read 0xffc9f17c]
lappend results [mem_read 0xffc9f180]
lappend results [mem_read 0xffc9f184]
lappend results [mem_read 0xffc9f188]
lappend results [mem_read 0xffc9f18c]
lappend results [mem_read 0xffc9f190]
lappend results [mem_read 0xffc9f194]
lappend results [mem_read 0xffc9f198]
lappend results [mem_read 0xffc9f19c]
lappend results [mem_read 0xffc9f1a0]
lappend results [mem_read 0xffc9f1a4]
lappend results [mem_read 0xffc9f1a8]
lappend results [mem_read 0xffc9f1ac]
lappend results [mem_read 0xffc9f1b0]
lappend results [mem_read 0xffc9f1b4]
lappend results [mem_read 0xffc9f1b8]
lappend results [mem_read 0xffc9f1bc]
lappend results [mem_read 0xffc9f1c0]
lappend results [mem_read 0xffc9f1c4]
lappend results [mem_read 0xffc9f1c8]
lappend results [mem_read 0xffc9f1cc]
lappend results [mem_read 0xffc9f1d0]
lappend results [mem_read 0xffc9f1d4]
lappend results [mem_read 0xffc9f1d8]
lappend results [mem_read 0xffc9f1dc]
lappend results [mem_read 0xffc9f1e0]
lappend results [mem_read 0xffc9f1e4]
lappend results [mem_read 0xffc9f1e8]
lappend results [mem_read 0xffc9f1ec]
lappend results [mem_read 0xffc9f1f0]
lappend results [mem_read 0xffc9f1f4]
lappend results [mem_read 0xffc9f1f8]
lappend results [mem_read 0xffc9f1fc]
lappend results [mem_read 0xffc9f200]
lappend results [mem_read 0xffc9f204]
lappend results [mem_read 0xffc9f208]
lappend results [mem_read 0xffc9f20c]
lappend results [mem_read 0xffc9f210]
lappend results [mem_read 0xffc9f214]
lappend results [mem_read 0xffc9f218]
lappend results [mem_read 0xffc9f21c]
lappend results [mem_read 0xffc9f220]
lappend results [mem_read 0xffc9f224]
lappend results [mem_read 0xffc9f228]
lappend results [mem_read 0xffc9f22c]
lappend results [mem_read 0xffc9f230]
lappend results [mem_read 0xffc9f234]
lappend results [mem_read 0xffc9f238]
lappend results [mem_read 0xffc9f23c]
lappend results [mem_read 0xffc9f240]
lappend results [mem_read 0xffc9f244]
lappend results [mem_read 0xffc9f248]
lappend results [mem_read 0xffc9f24c]
lappend results [mem_read 0xffc9f250]
lappend results [mem_read 0xffc9f254]
lappend results [mem_read 0xffc9f258]
lappend results [mem_read 0xffc9f25c]
lappend results [mem_read 0xffc9f260]
lappend results [mem_read 0xffc9f264]
lappend results [mem_read 0xffc9f268]
lappend results [mem_read 0xffc9f26c]
lappend results [mem_read 0xffc9f270]
lappend results [mem_read 0xffc9f274]
lappend results [mem_read 0xffc9f278]
lappend results [mem_read 0xffc9f27c]
lappend results [mem_read 0xffc9f280]
lappend results [mem_read 0xffc9f284]
lappend results [mem_read 0xffc9f288]
lappend results [mem_read 0xffc9f28c]
lappend results [mem_read 0xffc9f290]
lappend results [mem_read 0xffc9f294]
lappend results [mem_read 0xffc9f298]
lappend results [mem_read 0xffc9f29c]
lappend results [mem_read 0xffc9f2a0]
lappend results [mem_read 0xffc9f2a4]
lappend results [mem_read 0xffc9f2a8]
lappend results [mem_read 0xffc9f2ac]
lappend results [mem_read 0xffc9f2b0]
lappend results [mem_read 0xffc9f2b4]
lappend results [mem_read 0xffc9f2b8]
lappend results [mem_read 0xffc9f2bc]
lappend results [mem_read 0xffc9f2c0]
lappend results [mem_read 0xffc9f2c4]
lappend results [mem_read 0xffc9f2c8]
lappend results [mem_read 0xffc9f2cc]
lappend results [mem_read 0xffc9f2d0]
lappend results [mem_read 0xffc9f2d4]
lappend results [mem_read 0xffc9f2d8]
lappend results [mem_read 0xffc9f2dc]
lappend results [mem_read 0xffc9f2e0]
lappend results [mem_read 0xffc9f2e4]
lappend results [mem_read 0xffc9f2e8]
lappend results [mem_read 0xffc9f2ec]
lappend results [mem_read 0xffc9f2f0]
lappend results [mem_read 0xffc9f2f4]
lappend results [mem_read 0xffc9f2f8]
lappend results [mem_read 0xffc9f2fc]
