##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: CPM5_ADDRREMAP
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xfcdb0000]
lappend results [mem_read 0xfcdb0004]
lappend results [mem_read 0xfcdb0008]
lappend results [mem_read 0xfcdb000c]
lappend results [mem_read 0xfcdb0024]
lappend results [mem_read 0xfcdb0028]
lappend results [mem_read 0xfcdb002c]
lappend results [mem_read 0xfcdb0030]
lappend results [mem_read 0xfcdb0034]
lappend results [mem_read 0xfcdb0038]
lappend results [mem_read 0xfcdb003c]
lappend results [mem_read 0xfcdb0040]
lappend results [mem_read 0xfcdb0044]
lappend results [mem_read 0xfcdb0048]
lappend results [mem_read 0xfcdb004c]
lappend results [mem_read 0xfcdb0050]
lappend results [mem_read 0xfcdb0054]
lappend results [mem_read 0xfcdb0058]
lappend results [mem_read 0xfcdb005c]
lappend results [mem_read 0xfcdb0060]
lappend results [mem_read 0xfcdb0064]
lappend results [mem_read 0xfcdb0068]
lappend results [mem_read 0xfcdb006c]
lappend results [mem_read 0xfcdb0070]
lappend results [mem_read 0xfcdb0074]
lappend results [mem_read 0xfcdb0078]
lappend results [mem_read 0xfcdb007c]
lappend results [mem_read 0xfcdb0080]
lappend results [mem_read 0xfcdb0084]
lappend results [mem_read 0xfcdb0088]
lappend results [mem_read 0xfcdb008c]
lappend results [mem_read 0xfcdb0090]
lappend results [mem_read 0xfcdb0094]
lappend results [mem_read 0xfcdb0098]
lappend results [mem_read 0xfcdb009c]
lappend results [mem_read 0xfcdb00a0]
lappend results [mem_read 0xfcdb00a4]
lappend results [mem_read 0xfcdb00a8]
lappend results [mem_read 0xfcdb00ac]
lappend results [mem_read 0xfcdb00b0]
lappend results [mem_read 0xfcdb00b4]
lappend results [mem_read 0xfcdb00b8]
lappend results [mem_read 0xfcdb00bc]
lappend results [mem_read 0xfcdb00c0]
lappend results [mem_read 0xfcdb00c4]
lappend results [mem_read 0xfcdb00c8]
lappend results [mem_read 0xfcdb00cc]
lappend results [mem_read 0xfcdb00d0]
lappend results [mem_read 0xfcdb00d4]
lappend results [mem_read 0xfcdb00d8]
lappend results [mem_read 0xfcdb00dc]
lappend results [mem_read 0xfcdb00e0]
lappend results [mem_read 0xfcdb00e4]
lappend results [mem_read 0xfcdb00e8]
lappend results [mem_read 0xfcdb00ec]
lappend results [mem_read 0xfcdb00f0]
lappend results [mem_read 0xfcdb00f4]
lappend results [mem_read 0xfcdb00f8]
lappend results [mem_read 0xfcdb00fc]
lappend results [mem_read 0xfcdb0100]
lappend results [mem_read 0xfcdb0104]
lappend results [mem_read 0xfcdb0108]
lappend results [mem_read 0xfcdb010c]
lappend results [mem_read 0xfcdb0110]
lappend results [mem_read 0xfcdb0114]
lappend results [mem_read 0xfcdb0118]
lappend results [mem_read 0xfcdb011c]
lappend results [mem_read 0xfcdb0120]
lappend results [mem_read 0xfcdb0124]
lappend results [mem_read 0xfcdb0128]
lappend results [mem_read 0xfcdb012c]
lappend results [mem_read 0xfcdb0130]
lappend results [mem_read 0xfcdb0134]
lappend results [mem_read 0xfcdb0138]
lappend results [mem_read 0xfcdb013c]
lappend results [mem_read 0xfcdb0140]
lappend results [mem_read 0xfcdb0144]
lappend results [mem_read 0xfcdb0148]
lappend results [mem_read 0xfcdb014c]
lappend results [mem_read 0xfcdb0150]
lappend results [mem_read 0xfcdb0154]
lappend results [mem_read 0xfcdb0158]
lappend results [mem_read 0xfcdb015c]
lappend results [mem_read 0xfcdb0160]
lappend results [mem_read 0xfcdb0164]
lappend results [mem_read 0xfcdb0168]
lappend results [mem_read 0xfcdb016c]
lappend results [mem_read 0xfcdb0170]
lappend results [mem_read 0xfcdb0174]
lappend results [mem_read 0xfcdb0178]
lappend results [mem_read 0xfcdb017c]
lappend results [mem_read 0xfcdb0180]
lappend results [mem_read 0xfcdb0184]
lappend results [mem_read 0xfcdb0188]
lappend results [mem_read 0xfcdb018c]
lappend results [mem_read 0xfcdb0190]
lappend results [mem_read 0xfcdb0194]
lappend results [mem_read 0xfcdb0198]
lappend results [mem_read 0xfcdb019c]
lappend results [mem_read 0xfcdb01a0]
lappend results [mem_read 0xfcdb01a4]
lappend results [mem_read 0xfcdb0200]
lappend results [mem_read 0xfcdb0204]
lappend results [mem_read 0xfcdb0208]
lappend results [mem_read 0xfcdb020c]
lappend results [mem_read 0xfcdb0210]
lappend results [mem_read 0xfcdb0214]
lappend results [mem_read 0xfcdb0218]
lappend results [mem_read 0xfcdb021c]
lappend results [mem_read 0xfcdb0220]
lappend results [mem_read 0xfcdb0224]
