import './mixins/field-button.js';
import './mixins/menu-overlay.js';
import './mixins/overlay.js';
import './mixins/required-field.js';
import './badge.js';
import './color.js';
import './font-icons.js';
import './icons.js';
import './sizing.js';
import './spacing.js';
import './style.js';
import './typography.js';
/**
@license
Copyright (c) 2019 Vaadin Ltd.
This program is available under Apache License Version 2.0, available at https://vaadin.com/license/
*/

/*
  FIXME(polymer-modulizer): the above comments were extracted
  from HTML and may be out of place here. Review them and
  then delete this comment!
*/

;