##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: OCM_XMPU
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xff980000]
lappend results [mem_read 0xff980004]
lappend results [mem_read 0xff980008]
lappend results [mem_read 0xff98000c]
lappend results [mem_read 0xff980010]
lappend results [mem_read 0xff980014]
lappend results [mem_read 0xff980018]
lappend results [mem_read 0xff98001c]
lappend results [mem_read 0xff980020]
lappend results [mem_read 0xff980100]
lappend results [mem_read 0xff980104]
lappend results [mem_read 0xff980108]
lappend results [mem_read 0xff98010c]
lappend results [mem_read 0xff980110]
lappend results [mem_read 0xff980114]
lappend results [mem_read 0xff980118]
lappend results [mem_read 0xff98011c]
lappend results [mem_read 0xff980120]
lappend results [mem_read 0xff980124]
lappend results [mem_read 0xff980128]
lappend results [mem_read 0xff98012c]
lappend results [mem_read 0xff980130]
lappend results [mem_read 0xff980134]
lappend results [mem_read 0xff980138]
lappend results [mem_read 0xff98013c]
lappend results [mem_read 0xff980140]
lappend results [mem_read 0xff980144]
lappend results [mem_read 0xff980148]
lappend results [mem_read 0xff98014c]
lappend results [mem_read 0xff980150]
lappend results [mem_read 0xff980154]
lappend results [mem_read 0xff980158]
lappend results [mem_read 0xff98015c]
lappend results [mem_read 0xff980160]
lappend results [mem_read 0xff980164]
lappend results [mem_read 0xff980168]
lappend results [mem_read 0xff98016c]
lappend results [mem_read 0xff980170]
lappend results [mem_read 0xff980174]
lappend results [mem_read 0xff980178]
lappend results [mem_read 0xff98017c]
lappend results [mem_read 0xff980180]
lappend results [mem_read 0xff980184]
lappend results [mem_read 0xff980188]
lappend results [mem_read 0xff98018c]
lappend results [mem_read 0xff980190]
lappend results [mem_read 0xff980194]
lappend results [mem_read 0xff980198]
lappend results [mem_read 0xff98019c]
lappend results [mem_read 0xff9801a0]
lappend results [mem_read 0xff9801a4]
lappend results [mem_read 0xff9801a8]
lappend results [mem_read 0xff9801ac]
lappend results [mem_read 0xff9801b0]
lappend results [mem_read 0xff9801b4]
lappend results [mem_read 0xff9801b8]
lappend results [mem_read 0xff9801bc]
lappend results [mem_read 0xff9801c0]
lappend results [mem_read 0xff9801c4]
lappend results [mem_read 0xff9801c8]
lappend results [mem_read 0xff9801cc]
lappend results [mem_read 0xff9801d0]
lappend results [mem_read 0xff9801d4]
lappend results [mem_read 0xff9801d8]
lappend results [mem_read 0xff9801dc]
lappend results [mem_read 0xff9801e0]
lappend results [mem_read 0xff9801e4]
lappend results [mem_read 0xff9801e8]
lappend results [mem_read 0xff9801ec]
lappend results [mem_read 0xff9801f0]
lappend results [mem_read 0xff9801f4]
lappend results [mem_read 0xff9801f8]
lappend results [mem_read 0xff9801fc]
lappend results [mem_read 0xff980200]
lappend results [mem_read 0xff980204]
lappend results [mem_read 0xff980208]
lappend results [mem_read 0xff98020c]
lappend results [mem_read 0xff980210]
lappend results [mem_read 0xff980214]
lappend results [mem_read 0xff980218]
lappend results [mem_read 0xff98021c]
lappend results [mem_read 0xff980220]
lappend results [mem_read 0xff980224]
lappend results [mem_read 0xff980228]
lappend results [mem_read 0xff98022c]
lappend results [mem_read 0xff980238]
lappend results [mem_read 0xff98023c]
lappend results [mem_read 0xff980240]
lappend results [mem_read 0xff980244]
lappend results [mem_read 0xff980248]
lappend results [mem_read 0xff98024c]
lappend results [mem_read 0xff980250]
lappend results [mem_read 0xff980254]
lappend results [mem_read 0xff980258]
lappend results [mem_read 0xff98025c]
lappend results [mem_read 0xff980260]
lappend results [mem_read 0xff980264]
lappend results [mem_read 0xff980268]
lappend results [mem_read 0xff98026c]
lappend results [mem_read 0xff980270]
lappend results [mem_read 0xff980274]
lappend results [mem_read 0xff980278]
lappend results [mem_read 0xff98027c]
lappend results [mem_read 0xff980280]
lappend results [mem_read 0xff980284]
