define(['./_createAssigner', './allKeys'], function (_createAssigner, allKeys) {
  // Extend a given object with all the properties in passed-in object(s).
  var extend = _createAssigner(allKeys);

  return extend;
});