define(['./findLastIndex', './_createIndexFinder'], function (findLastIndex, _createIndexFinder) {
  // Return the position of the last occurrence of an item in an array,
  // or -1 if the item is not included in the array.
  var lastIndexOf = _createIndexFinder(-1, findLastIndex);

  return lastIndexOf;
});