##
# Copyright (c) 2021 Xilinx, Inc.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
# associated documentation files (the "Software"), to deal in the Software without restriction, including 
# without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to 
# the following conditions: 
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial 
# portions of the Software. 
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
# LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# 
#
##
# Instance: DBG_RPU1_ETM
set results {}
proc mem_read {add} {
    if {[catch {mrd $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
proc mem_read16 {add} {
    if {[catch {mrd -size h $add} err]} {
        return "$add: $err"
    } else {
        return $err
    }
}
lappend results [mem_read 0xf0a70000]
lappend results [mem_read 0xf0a70004]
lappend results [mem_read 0xf0a70008]
lappend results [mem_read 0xf0a70010]
lappend results [mem_read 0xf0a70014]
lappend results [mem_read 0xf0a70018]
lappend results [mem_read 0xf0a7001c]
lappend results [mem_read 0xf0a70020]
lappend results [mem_read 0xf0a70024]
lappend results [mem_read 0xf0a7002c]
lappend results [mem_read 0xf0a70030]
lappend results [mem_read 0xf0a70034]
lappend results [mem_read 0xf0a7003c]
lappend results [mem_read 0xf0a70040]
lappend results [mem_read 0xf0a70044]
lappend results [mem_read 0xf0a70048]
lappend results [mem_read 0xf0a7004c]
lappend results [mem_read 0xf0a70050]
lappend results [mem_read 0xf0a70054]
lappend results [mem_read 0xf0a70058]
lappend results [mem_read 0xf0a7005c]
lappend results [mem_read 0xf0a70080]
lappend results [mem_read 0xf0a70084]
lappend results [mem_read 0xf0a70088]
lappend results [mem_read 0xf0a7008c]
lappend results [mem_read 0xf0a70090]
lappend results [mem_read 0xf0a70094]
lappend results [mem_read 0xf0a70098]
lappend results [mem_read 0xf0a7009c]
lappend results [mem_read 0xf0a700c0]
lappend results [mem_read 0xf0a700c8]
lappend results [mem_read 0xf0a70100]
lappend results [mem_read 0xf0a70108]
lappend results [mem_read 0xf0a70140]
lappend results [mem_read 0xf0a70144]
lappend results [mem_read 0xf0a70150]
lappend results [mem_read 0xf0a70154]
lappend results [mem_read 0xf0a70160]
lappend results [mem_read 0xf0a70164]
lappend results [mem_read 0xf0a70170]
lappend results [mem_read 0xf0a70174]
lappend results [mem_read 0xf0a70180]
lappend results [mem_read 0xf0a70184]
lappend results [mem_read 0xf0a70188]
lappend results [mem_read 0xf0a7018c]
lappend results [mem_read 0xf0a70190]
lappend results [mem_read 0xf0a70194]
lappend results [mem_read 0xf0a7019c]
lappend results [mem_read 0xf0a701a0]
lappend results [mem_read 0xf0a701a4]
lappend results [mem_read 0xf0a701b0]
lappend results [mem_read 0xf0a701bc]
lappend results [mem_read 0xf0a701e0]
lappend results [mem_read 0xf0a701e4]
lappend results [mem_read 0xf0a701e8]
lappend results [mem_read 0xf0a701ec]
lappend results [mem_read 0xf0a70200]
lappend results [mem_read 0xf0a70314]
lappend results [mem_read 0xf0a70ed8]
lappend results [mem_read 0xf0a70edc]
lappend results [mem_read 0xf0a70ee0]
lappend results [mem_read 0xf0a70ee4]
lappend results [mem_read 0xf0a70ee8]
lappend results [mem_read 0xf0a70eec]
lappend results [mem_read 0xf0a70ef0]
lappend results [mem_read 0xf0a70ef4]
lappend results [mem_read 0xf0a70ef8]
lappend results [mem_read 0xf0a70f00]
lappend results [mem_read 0xf0a70fa0]
lappend results [mem_read 0xf0a70fa4]
lappend results [mem_read 0xf0a70fb0]
lappend results [mem_read 0xf0a70fb4]
lappend results [mem_read 0xf0a70fb8]
lappend results [mem_read 0xf0a70fc8]
lappend results [mem_read 0xf0a70fcc]
